@@ -32,15 +32,12 @@ static const KCmdLineOptions options[]=
 	KCmdLineLastOption
 };
 
-int main( int argc, char **argv )
+extern "C" int kdemain( int argc, char **argv )
 {
     KCmdLineArgs::init( argc, argv, newExampleAboutData() );
     KCmdLineArgs::addCmdLineOptions( options );
     KoApplication app;
 
-    app.dcopClient()->attach();
-    app.dcopClient()->registerAs( "example" );
-
     if (!app.start()) // parses command line args, create initial docs and shells
 	return 1;
     return app.exec();
