@@ -1,4 +1,3 @@
-// -*- Mode: c++-mode; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (c) 2003 Rob Buis <buis@kde.org>
 
@@ -22,7 +21,6 @@
 
 #include <math.h>
 
-#include <qregexp.h>
 #include <qdatetime.h>
 #include <qfileinfo.h>
 #include <qdir.h>
@@ -33,6 +31,7 @@
 #include <koUnit.h>
 #include <koDocumentInfo.h>
 #include <koDocument.h>
+#include <ooutils.h>
 
 #include <kgenericfactory.h>
 #include <koFilterChain.h>
@@ -47,7 +46,7 @@
 #include <core/vgroup.h>
 
 typedef KGenericFactory<OoDrawImport, KoFilter> OoDrawImportFactory;
-K_EXPORT_COMPONENT_FACTORY( liboodrawimport, OoDrawImportFactory( "oodrawimport" ) )
+K_EXPORT_COMPONENT_FACTORY( liboodrawimport, OoDrawImportFactory( "kofficefilters" ) )
 
 
 OoDrawImport::OoDrawImport( KoFilter *, const char *, const QStringList & )
@@ -61,24 +60,35 @@ OoDrawImport::~OoDrawImport()
 {
 }
 
-KoFilter::ConversionStatus
-OoDrawImport::convert( QCString const & from, QCString const & to )
+KoFilter::ConversionStatus OoDrawImport::convert( QCString const & from, QCString const & to )
 {
-	kdDebug() << "Entering Oodraw Import filter: " << from << " - " << to << endl;
+    kdDebug() << "Entering Oodraw Import filter: " << from << " - " << to << endl;
 
-	if( from != "application/vnd.sun.xml.draw" || to != "application/x-karbon" )
-	{
-		kdWarning() << "Invalid mimetypes " << from << " " << to << endl;
-		return KoFilter::NotImplemented;
-	}
+    if( from != "application/vnd.sun.xml.draw" || to != "application/x-karbon" )
+    {
+        kdWarning() << "Invalid mimetypes " << from << " " << to << endl;
+        return KoFilter::NotImplemented;
+    }
 
-	KoFilter::ConversionStatus preStatus = openFile();
+    m_zip = new KZip(  m_chain->inputFile() );
 
-	if( preStatus != KoFilter::OK )
-		return preStatus;
+    if ( !m_zip->open( IO_ReadOnly ) )
+    {
+        kdError(30518) << "Couldn't open the requested file "<< m_chain->inputFile() << endl;
+        delete m_zip;
+        return KoFilter::FileNotFound;
+    }
 
+    KoFilter::ConversionStatus preStatus = openFile();
+
+    if( preStatus != KoFilter::OK )
+    {
+        m_zip->close();
+        delete m_zip;
+        return preStatus;
+    }
 /*QDomDocument docinfo;
-createDocumentInfo( docinfo );
+  createDocumentInfo( docinfo );
 
 // store document info
 KoStoreDevice* out = m_chain->storageFile( "documentinfo.xml", KoStore::Write );
@@ -89,91 +99,70 @@ QCString info = docinfo.toCString();
 // WARNING: we cannot use KoStore::write(const QByteArray&) because it gives an extra NULL character at the end.
 out->writeBlock( info , info.length() );
 }*/
+    QDomDocument docinfo;
+    createDocumentInfo( docinfo );
+    // store document info
+    KoStoreDevice* out = m_chain->storageFile( "documentinfo.xml", KoStore::Write );
+    if( out )
+    {
+        QCString info = docinfo.toCString();
+        //kdDebug(30518) << " info :" << info << endl;
+        // WARNING: we cannot use KoStore::write(const QByteArray&) because it gives an extra NULL character at the end.
+        out->writeBlock( info , info.length() );
+    }
 
-	convert();
-	QDomDocument outdoc = m_document.saveXML();
+    convert();
+    QDomDocument outdoc = m_document.saveXML();
 
-	// store document content
-	KoStoreDevice *out = m_chain->storageFile( "maindoc.xml", KoStore::Write );
-	if( out )
-	{
-		QCString content = outdoc.toCString();
-		kdDebug() << " content :" << content << endl;
-		out->writeBlock( content , content.length() );
-	}
+    // store document content
+    out = m_chain->storageFile( "maindoc.xml", KoStore::Write );
+    if( out )
+    {
+        QCString content = outdoc.toCString();
+        kdDebug() << " content :" << content << endl;
+        out->writeBlock( content , content.length() );
+    }
+    m_zip->close();
+    delete m_zip;
 
-	kdDebug() << "######################## OoDrawImport::convert done ####################" << endl;
-	return KoFilter::OK;
+    kdDebug() << "######################## OoDrawImport::convert done ####################" << endl;
+
+    return KoFilter::OK;
 }
 
+// Very related to OoWriterImport::createDocumentInfo
+void OoDrawImport::createDocumentInfo( QDomDocument &docinfo )
+{
+    docinfo = KoDocument::createDomDocument( "document-info" /*DTD name*/, "document-info" /*tag name*/, "1.1" );
+
+    OoUtils::createDocumentInfo(m_meta, docinfo);
+    //kdDebug(30518) << " meta-info :" << m_meta.toCString() << endl;
+}
+
+
 // Very related to OoWriterImport::openFile()
-KoFilter::ConversionStatus
-OoDrawImport::openFile()
+KoFilter::ConversionStatus OoDrawImport::openFile()
 {
-	KoStore *store = KoStore::createStore( m_chain->inputFile(), KoStore::Read);
+    KoFilter::ConversionStatus status = loadAndParse( "content.xml", m_content );
+    if ( status != KoFilter::OK )
+    {
+        kdError(30518) << "Content.xml could not be parsed correctly! Aborting!" << endl;
+        return status;
+    }
 
-	if( !store )
-	{
-		kdWarning() << "Couldn't open the requested file." << endl;
-		return KoFilter::FileNotFound;
-	}
+    // We do not stop if the following calls fail.
+    QDomDocument styles;
+    loadAndParse( "styles.xml", styles );
+    loadAndParse( "meta.xml", m_meta );
+    loadAndParse( "settings.xml", m_settings );
 
-	if( !store->open( "content.xml" ) )
-	{
-		kdWarning() << "This file doesn't seem to be a valid OoDraw file" << endl;
-		delete store;
-		return KoFilter::WrongFormat;
-	}
+    emit sigProgress( 10 );
+    createStyleMap( styles );
 
-	QDomDocument styles;
-
-	m_content.setContent( store->device() );
-	store->close();
-
-	//kdDebug() << "m_content.toCString() :" << m_content.toCString() << endl;
-	kdDebug() << "File containing content loaded " << endl;
-
-	if( store->open( "styles.xml" ) )
-	{
-		styles.setContent( store->device() );
-		store->close();
-
-		//kdDebug() << "styles.toCString() :" << styles.toCString() << endl;
-		kdDebug() << "File containing styles loaded" << endl;
-	}
-	else
-		kdWarning() << "Style definitions do not exist!" << endl;
-
-	if( store->open( "meta.xml" ) )
-	{
-		m_meta.setContent( store->device() );
-		store->close();
-
-		kdDebug() << "File containing meta definitions loaded" << endl;
-	}
-	else
-		kdWarning() << "Meta definitions do not exist!" << endl;
-
-	if( store->open( "settings.xml" ) )
-	{
-		m_settings.setContent( store->device() );
-		store->close();
-
-		kdDebug() << "File containing settings loaded" << endl;
-	}
-	else
-		kdWarning() << "Settings do not exist!" << endl;
-
-	delete store;
-
-	emit sigProgress( 10 );
-	createStyleMap( styles );
-
-	return KoFilter::OK;
+    return KoFilter::OK;
 }
 
-void
-OoDrawImport::convert()
+void OoDrawImport::convert()
 {
 	m_document.saveAsPath( false );
 
@@ -226,6 +215,12 @@ OoDrawImport::convert()
     }
 }
 
+
+KoFilter::ConversionStatus OoDrawImport::loadAndParse(const QString& filename, QDomDocument& doc)
+{
+     return OoUtils::loadAndParse( filename, doc, m_zip);
+}
+
 void
 OoDrawImport::parseGroup( VGroup *parent, const QDomElement& parentobject )
 {
@@ -373,7 +368,7 @@ OoDrawImport::appendPen( VObject &obj )
 			QValueList<float> dashes;
 			stroke.setType( VStroke::solid );
 			QString style = m_styleStack.attribute( "draw:stroke-dash" );
-			if( style == "Ultrafine Dashed" || 
+			if( style == "Ultrafine Dashed" ||
 				style == "Fine Dashed (var)" || style == "Dashed (var)" )
 				stroke.dashPattern().setArray( dashes << 2 << 2 );
 			else if( style == "Fine Dashed" )
@@ -656,7 +651,7 @@ OoDrawImport::parseViewBox( const QDomElement& object )
 	{
 		// allow for viewbox def with ',' or whitespace
 		QString viewbox( object.attribute( "svg:viewBox" ) );
-		QStringList points = QStringList::split( ' ', viewbox.replace( QRegExp(","), " ").simplifyWhiteSpace() );
+		QStringList points = QStringList::split( ' ', viewbox.replace( ',', ' ').simplifyWhiteSpace() );
 
 		rect.setX( points[0].toFloat() );
 		rect.setY( points[1].toFloat() );
