@@ -35,11 +35,10 @@
 #include <core/vimage.h>
 #include <qcolor.h>
 #include <qfile.h>
-#include <qregexp.h>
 #include <kfilterdev.h>
 
 typedef KGenericFactory<SvgImport, KoFilter> SvgImportFactory;
-K_EXPORT_COMPONENT_FACTORY( libkarbonsvgimport, SvgImportFactory( "karbonsvgimport" ) )
+K_EXPORT_COMPONENT_FACTORY( libkarbonsvgimport, SvgImportFactory( "kofficefilters" ) )
 
 SvgImport::SvgImport(KoFilter *, const char *, const QStringList&) :
     KoFilter(),
@@ -95,7 +94,7 @@ KoFilter::ConversionStatus SvgImport::convert(const QCString& from, const QCStri
 	if ( ! parsed )
 	{
 	        kdError(30514) << "Error while parsing file: "
-		        << "at line " << line << " column: " << col 
+		        << "at line " << line << " column: " << col
 		        << " message: " << errormessage << endl;
 		// ### TODO: feedback to the user
 	        return KoFilter::ParsingError;
@@ -133,7 +132,7 @@ SvgImport::convert()
 	{
 		// allow for viewbox def with ',' or whitespace
 		QString viewbox( docElem.attribute( "viewBox" ) );
-		QStringList points = QStringList::split( ' ', viewbox.replace( QRegExp(","), " ").simplifyWhiteSpace() );
+		QStringList points = QStringList::split( ' ', viewbox.replace( ',', ' ').simplifyWhiteSpace() );
 
 		gc->matrix.scale( width / points[2].toFloat() , height / points[3].toFloat() );
 		m_outerRect.setWidth( m_outerRect.width() * ( points[2].toFloat() / width ) );
@@ -171,14 +170,77 @@ SvgImport::fromPercentage( const QString &s )
 		return s.toDouble();
 }
 
+// parses the number into parameter number
+const char *
+getNumber( const char *ptr, double &number )
+{
+	int integer, exponent;
+	double decimal, frac;
+	int sign, expsign;
+
+	exponent = 0;
+	integer = 0;
+	frac = 1.0;
+	decimal = 0;
+	sign = 1;
+	expsign = 1;
+
+	// read the sign
+	if(*ptr == '+')
+		ptr++;
+	else if(*ptr == '-')
+	{
+		ptr++;
+		sign = -1;
+	}
+
+	// read the integer part
+	while(*ptr != '\0' && *ptr >= '0' && *ptr <= '9')
+		integer = (integer * 10) + *(ptr++) - '0';
+	if(*ptr == '.') // read the decimals
+	{
+		ptr++;
+		while(*ptr != '\0' && *ptr >= '0' && *ptr <= '9')
+			decimal += (*(ptr++) - '0') * (frac *= 0.1);
+	}
+
+	if(*ptr == 'e' || *ptr == 'E') // read the exponent part
+	{
+		ptr++;
+
+		// read the sign of the exponent
+		if(*ptr == '+')
+			ptr++;
+		else if(*ptr == '-')
+		{
+			ptr++;
+			expsign = -1;
+		}
+
+		exponent = 0;
+		while(*ptr != '\0' && *ptr >= '0' && *ptr <= '9')
+		{
+			exponent *= 10;
+			exponent += *ptr - '0';
+			ptr++;
+		}
+	}
+	number = integer + decimal;
+	number *= sign * pow( (double)10, double( expsign * exponent ) );
+
+	return ptr;
+}
+
+
 double
 SvgImport::parseUnit( const QString &unit, bool horiz, bool vert, KoRect bbox )
 {
 	// TODO : percentage?
-	bool ok = false;
-	double value = unit.toDouble( &ok );
+	double value = 0;
+	const char *start = unit.latin1();
+	const char *end = getNumber( start, value );
 
-	if( !ok )
+	if( uint( end - start ) < unit.length() )
 	{
 		if( unit.right( 2 ) == "pt" )
 			value = ( value / 72.0 ) * DPI;
@@ -502,7 +564,7 @@ SvgImport::parsePA( VObject *obj, SvgGraphicsContext *gc, const QString &command
 	else if( command == "font-family" )
 	{
 		QString family = params;
-		family.replace( QRegExp( "'" ) , QChar( ' ' ) );
+		family.replace( '\'' , ' ' );
 		gc->font.setFamily( family );
 	}
 	else if( command == "font-size" )
@@ -675,19 +737,22 @@ SvgImport::parseGroup( VGroup *grp, const QDomElement &e )
 			bool bFirst = true;
 
 			QString points = b.attribute( "points" ).simplifyWhiteSpace();
-			points.replace( QRegExp( "," ), " " );
-			points.replace( QRegExp( "\r" ), "" );
-		    points.replace( QRegExp( "\n" ), "" );
+			points.replace( ',', ' ' );
+			points.remove( '\r' );
+			points.remove( '\n' );
 			QStringList pointList = QStringList::split( ' ', points );
-			for( QStringList::Iterator it = pointList.begin(); it != pointList.end(); it++ )
+			for( QStringList::Iterator it = pointList.begin(); it != pointList.end(); )
 			{
+				KoPoint point;
+				point.setX( (*(it++)).toDouble() );
+				point.setY( (*(it++)).toDouble() );
 				if( bFirst )
 				{
-					path->moveTo( KoPoint( (*(it++)).toDouble(), (*it).toDouble() ) );
+					path->moveTo( point );
 					bFirst = false;
 				}
 				else
-					path->lineTo( KoPoint( (*(it++)).toDouble(), (*it).toDouble() ) );
+					path->lineTo( point );
 			}
 			if( b.tagName() == "polygon" ) path->close();
 			obj = path;
