@@ -44,8 +44,7 @@ PNGExportDia::PNGExportDia( const QDomDocument &dom, const QString &outFile, QWi
       _fileOut( outFile )
 {
     kapp->restoreOverrideCursor();
-
-    KFormula::DocumentWrapper* wrapper = new KFormula::DocumentWrapper( kapp->config(), 0 );
+    wrapper = new KFormula::DocumentWrapper( kapp->config(), 0 );
     KFormula::Document* doc = new KFormula::Document;
     wrapper->document( doc );
     formula = doc->createFormula();
@@ -70,7 +69,6 @@ PNGExportDia::PNGExportDia( const QDomDocument &dom, const QString &outFile, QWi
 
 PNGExportDia::~PNGExportDia()
 {
-    delete formula;
     delete wrapper;
 }
 
@@ -175,7 +173,6 @@ void PNGExportDia::proportionalClicked()
 
 void PNGExportDia::setupGUI()
 {
-    resize( size() );
     QWidget *page = new QWidget( this );
     setMainWidget(page);
 
