@@ -21,6 +21,7 @@
 
 #include <qdom.h>
 #include <qfile.h>
+#include <qdatetime.h>
 
 #include <kdebug.h>
 #include <kgenericfactory.h>
@@ -29,24 +30,38 @@
 #include <koUnit.h>
 
 typedef KGenericFactory<OoImpressExport, KoFilter> OoImpressExportFactory;
-K_EXPORT_COMPONENT_FACTORY( libooimpressexport, OoImpressExportFactory( "ooimpressexport" ) )
+K_EXPORT_COMPONENT_FACTORY( libooimpressexport, OoImpressExportFactory( "kofficefilters" ) )
 
 
 OoImpressExport::OoImpressExport( KoFilter *, const char *, const QStringList & )
     : KoFilter()
     , m_currentPage( 0 )
+    , m_objectIndex( 0 )
     , m_pageHeight( 0 )
+    , m_activePage( 0 )
+    , m_gridX( -1.0 )
+    , m_gridY( -1.0 )
+    , m_snapToGrid( false )
+    , m_pictureIndex( 0 )
+    , m_storeinp( 0L )
+    , m_storeout( 0L )
 {
 }
 
+OoImpressExport::~OoImpressExport()
+{
+    delete m_storeout;
+    delete m_storeinp;
+}
+
 KoFilter::ConversionStatus OoImpressExport::convert( const QCString & from,
                                                      const QCString & to )
 {
-    kdDebug() << "Entering Ooimpress Export filter: " << from << " - " << to << endl;
+    kdDebug(30518) << "Entering Ooimpress Export filter: " << from << " - " << to << endl;
 
     if ( ( to != "application/vnd.sun.xml.impress") || (from != "application/x-kpresenter" ) )
     {
-        kdWarning() << "Invalid mimetypes " << to << " " << from << endl;
+        kdWarning(30518) << "Invalid mimetypes " << to << " " << from << endl;
         return KoFilter::NotImplemented;
     }
 
@@ -64,25 +79,24 @@ KoFilter::ConversionStatus OoImpressExport::convert( const QCString & from,
     createDocumentMeta( meta );
 
     // store document meta
-    KoStore * store = KoStore::createStore( m_chain->outputFile(), KoStore::Write, "", KoStore::Zip );
+    m_storeout = KoStore::createStore( m_chain->outputFile(), KoStore::Write, "", KoStore::Zip );
 
-    if ( !store )
+    if ( !m_storeout )
     {
-        kdWarning() << "Couldn't open the requested file." << endl;
+        kdWarning(30518) << "Couldn't open the requested file." << endl;
         return KoFilter::FileNotFound;
     }
 
-    if ( !store->open( "meta.xml" ) )
+    if ( !m_storeout->open( "meta.xml" ) )
     {
-        kdWarning() << "Couldn't open the file 'meta.xml'." << endl;
-        delete store;
+        kdWarning(30518) << "Couldn't open the file 'meta.xml'." << endl;
         return KoFilter::CreationError;
     }
 
     QCString metaString = meta.toCString();
-    //kdDebug() << "meta :" << metaString << endl;
-    store->write( metaString , metaString.length() );
-    store->close();
+    //kdDebug(30518) << "meta :" << metaString << endl;
+    m_storeout->write( metaString , metaString.length() );
+    m_storeout->close();
 
     QDomDocument content( impl.createDocumentType( "office:document-content",
                                                    "-//OpenOffice.org//DTD OfficeDocument 1.0//EN",
@@ -94,17 +108,35 @@ KoFilter::ConversionStatus OoImpressExport::convert( const QCString & from,
     m_styleFactory.addAutomaticStyles( content, m_styles );
 
     // store document content
-    if ( !store->open( "content.xml" ) )
+    if ( !m_storeout->open( "content.xml" ) )
     {
-        kdWarning() << "Couldn't open the file 'content.xml'." << endl;
-        delete store;
+        kdWarning(30518) << "Couldn't open the file 'content.xml'." << endl;
         return KoFilter::CreationError;
     }
 
     QCString contentString = content.toCString();
-    //kdDebug() << "content :" << contentString << endl;
-    store->write( contentString , contentString.length() );
-    store->close();
+    //kdDebug(30518) << "content :" << contentString << endl;
+    m_storeout->write( contentString , contentString.length() );
+    m_storeout->close();
+
+    QDomDocument settings( impl.createDocumentType( "office:document-content",
+                                                   "-//OpenOffice.org//DTD OfficeDocument 1.0//EN",
+                                                   "office.dtd" ) );
+
+    createDocumentSettings( settings );
+
+    // store document content
+    if ( !m_storeout->open( "settings.xml" ) )
+    {
+        kdWarning(30518) << "Couldn't open the file 'settings.xml'." << endl;
+        return KoFilter::CreationError;
+    }
+
+    QCString settingsString = settings.toCString();
+    //kdDebug(30518) << "content :" << settingsString << endl;
+    m_storeout->write( settingsString , settingsString.length() );
+    m_storeout->close();
+
 
     QDomDocument styles( impl.createDocumentType( "office:document-styles",
                                                   "-//OpenOffice.org//DTD OfficeDocument 1.0//EN",
@@ -113,17 +145,16 @@ KoFilter::ConversionStatus OoImpressExport::convert( const QCString & from,
     createDocumentStyles( styles );
 
     // store document styles
-    if ( !store->open( "styles.xml" ) )
+    if ( !m_storeout->open( "styles.xml" ) )
     {
-        kdWarning() << "Couldn't open the file 'styles.xml'." << endl;
-        delete store;
+        kdWarning(30518) << "Couldn't open the file 'styles.xml'." << endl;
         return KoFilter::CreationError;
     }
 
     QCString stylesString = styles.toCString();
-    //kdDebug() << "styles :" << stylesString << endl;
-    store->write( stylesString , stylesString.length() );
-    store->close();
+    //kdDebug(30518) << "styles :" << stylesString << endl;
+    m_storeout->write( stylesString , stylesString.length() );
+    m_storeout->close();
 
     QDomDocument manifest( impl.createDocumentType( "manifest:manifest",
                                                     "-//OpenOffice.org//DTD Manifest 1.0//EN",
@@ -132,53 +163,47 @@ KoFilter::ConversionStatus OoImpressExport::convert( const QCString & from,
     createDocumentManifest( manifest );
 
     // store document manifest
-    store->enterDirectory( "META-INF" );
-    if ( !store->open( "manifest.xml" ) )
+    m_storeout->enterDirectory( "META-INF" );
+    if ( !m_storeout->open( "manifest.xml" ) )
     {
-        kdWarning() << "Couldn't open the file 'META-INF/manifest.xml'." << endl;
-        delete store;
+        kdWarning(30518) << "Couldn't open the file 'META-INF/manifest.xml'." << endl;
         return KoFilter::CreationError;
     }
 
     QCString manifestString = manifest.toCString();
-    //kdDebug() << "manifest :" << manifestString << endl;
-    store->write( manifestString , manifestString.length() );
-    store->close();
-
-    delete store;
+    //kdDebug(30518) << "manifest :" << manifestString << endl;
+    m_storeout->write( manifestString , manifestString.length() );
+    m_storeout->close();
 
     return KoFilter::OK;
 }
 
 KoFilter::ConversionStatus OoImpressExport::openFile()
 {
-    KoStore * store = KoStore::createStore( m_chain->inputFile(), KoStore::Read );
+    m_storeinp = KoStore::createStore( m_chain->inputFile(), KoStore::Read );
 
-    if ( !store )
+    if ( !m_storeinp )
     {
-        kdWarning() << "Couldn't open the requested file." << endl;
+        kdWarning(30518) << "Couldn't open the requested file." << endl;
         return KoFilter::FileNotFound;
     }
 
-    if ( !store->open( "maindoc.xml" ) )
+    if ( !m_storeinp->open( "maindoc.xml" ) )
     {
-        kdWarning() << "This file doesn't seem to be a valid KPresenter file" << endl;
-        delete store;
+        kdWarning(30518) << "This file doesn't seem to be a valid KPresenter file" << endl;
         return KoFilter::WrongFormat;
     }
 
-    m_maindoc.setContent( store->device() );
-    store->close();
+    m_maindoc.setContent( m_storeinp->device() );
+    m_storeinp->close();
 
-    if ( store->open( "documentinfo.xml" ) )
+    if ( m_storeinp->open( "documentinfo.xml" ) )
     {
-        m_documentinfo.setContent( store->device() );
-        store->close();
+        m_documentinfo.setContent( m_storeinp->device() );
+        m_storeinp->close();
     }
     else
-        kdWarning() << "Documentinfo do not exist!" << endl;
-
-    delete store;
+        kdWarning(30518) << "Documentinfo do not exist!" << endl;
 
     emit sigProgress( 10 );
 
@@ -217,25 +242,39 @@ void OoImpressExport::createDocumentMeta( QDomDocument & docmeta )
             creator.appendChild( docmeta.createTextNode( fullName.text() ) );
             meta.appendChild( creator );
         }
-
-        n = i.namedItem( "about" ).namedItem( "title" );
-        if ( !n.isNull() )
-        {
-            QDomElement title = n.toElement();
-            QDomElement user = docmeta.createElement( "meta:user-defined" );
-            user.setAttribute( "meta:name", "Info 1" );
-            user.appendChild( docmeta.createTextNode( title.text() ) );
-            meta.appendChild( user );
-        }
-
         n = i.namedItem( "about" ).namedItem( "abstract" );
         if ( !n.isNull() )
         {
-            QDomElement user = docmeta.createElement( "meta:user-defined" );
-            user.setAttribute( "meta:name", "Info 2" );
+            QDomElement user = docmeta.createElement( "dc:description" );
             user.appendChild( n.firstChild() );
             meta.appendChild( user );
         }
+        n = i.namedItem( "about" ).namedItem( "keyword" );
+        if ( !n.isNull() )
+        {
+            QDomElement text = n.toElement();
+            QDomElement key = docmeta.createElement( "meta:keywords" );
+            QDomElement keyword = docmeta.createElement( "meta:keyword" );
+            key.appendChild( keyword );
+            keyword.appendChild(  docmeta.createTextNode( text.text() ) );
+            meta.appendChild( key );
+        }
+        n = i.namedItem( "about" ).namedItem( "subject" );
+        if ( !n.isNull() )
+        {
+            QDomElement text = n.toElement();
+            QDomElement subjet = docmeta.createElement( "dc:subject" );
+            subjet.appendChild(  docmeta.createTextNode( text.text() ) );
+            meta.appendChild( subjet );
+        }
+        n = i.namedItem( "about" ).namedItem( "title" );
+        if ( !n.isNull() )
+        {
+            QDomElement text = n.toElement();
+            QDomElement title = docmeta.createElement( "dc:title" );
+            title.appendChild(  docmeta.createTextNode( text.text() ) );
+            meta.appendChild( title );
+        }
     }
 
 //     QDomElement statistic = docmeta.createElement( "meta:document-statistic" );
@@ -283,6 +322,78 @@ void OoImpressExport::createDocumentStyles( QDomDocument & docstyles )
     docstyles.appendChild( content );
 }
 
+void OoImpressExport::createDocumentSettings( QDomDocument & docsetting )
+{
+    docsetting.appendChild( docsetting.createProcessingInstruction( "xml","version=\"1.0\" encoding=\"UTF-8\"" ) );
+
+    QDomElement setting = docsetting.createElement( "office:document-settings" );
+    setting.setAttribute( "xmlns:office", "http://openoffice.org/2000/office");
+    setting.setAttribute( "xmlns:config", "http://openoffice.org/2001/config" );
+    setting.setAttribute( "office:class", "presentation" );
+    setting.setAttribute( "office:version", "1.0" );
+
+    QDomElement begin = docsetting.createElement( "office:settings" );
+
+    QDomElement configItem = docsetting.createElement("config:config-item-set" );
+    configItem.setAttribute( "config:name", "view-settings" );
+
+    QDomElement mapIndexed = docsetting.createElement( "config:config-item-map-indexed" );
+    mapIndexed.setAttribute("config:name", "Views" );
+    configItem.appendChild( mapIndexed );
+
+    //<config:config-item-map-indexed config:name="Views">
+
+    QDomElement mapItem = docsetting.createElement("config:config-item-map-entry" );
+
+    QDomElement attribute =  docsetting.createElement("config:config-item" );
+    attribute.setAttribute( "config:name", "SnapLinesDrawing" );
+    attribute.setAttribute( "config:type", "string" );
+    attribute.appendChild( docsetting.createTextNode( m_helpLine ) );
+    mapItem.appendChild( attribute );
+    //<config:config-item config:name="SnapLinesDrawing" config:type="string">H5983V700V10777H4518V27601P50000,9000P8021,2890</config:config-item>
+
+    attribute =  docsetting.createElement("config:config-item" );
+    attribute.setAttribute( "config:name", "IsSnapToGrid" );
+    attribute.setAttribute( "config:type", "boolean" );
+    attribute.appendChild( docsetting.createTextNode( m_snapToGrid ? "true" : "false" ) );
+    mapItem.appendChild( attribute );
+
+    if (  m_gridX >=0 )
+    {
+        attribute =  docsetting.createElement("config:config-item" );
+        attribute.setAttribute( "config:name", "GridFineWidth" );
+        attribute.setAttribute( "config:type", "int" );
+        attribute.appendChild( docsetting.createTextNode( QString::number( ( int ) ( KoUnit::toMM( ( m_gridX )  )*100 ) ) ) );
+        mapItem.appendChild( attribute );
+    }
+
+    if ( m_gridY >=0 )
+    {
+        attribute =  docsetting.createElement("config:config-item" );
+        attribute.setAttribute( "config:name", "GridFineHeight" );
+        attribute.setAttribute( "config:type", "int" );
+        attribute.appendChild( docsetting.createTextNode( QString::number( ( int ) ( KoUnit::toMM( ( m_gridY )  )*100 ) ) ) );
+        mapItem.appendChild( attribute );
+    }
+
+    attribute =  docsetting.createElement("config:config-item" );
+    attribute.setAttribute( "config:name", "SelectedPage" );
+    attribute.setAttribute( "config:type", "short" );
+    attribute.appendChild( docsetting.createTextNode( QString::number( m_activePage ) ) );
+    mapItem.appendChild( attribute );
+
+
+    mapIndexed.appendChild( mapItem );
+
+    begin.appendChild( configItem );
+
+    setting.appendChild( begin );
+
+
+    docsetting.appendChild( setting );
+
+}
+
 void OoImpressExport::createDocumentContent( QDomDocument & doccontent )
 {
     doccontent.appendChild( doccontent.createProcessingInstruction( "xml","version=\"1.0\" encoding=\"UTF-8\"" ) );
@@ -302,6 +413,7 @@ void OoImpressExport::createDocumentContent( QDomDocument & doccontent )
     content.setAttribute( "xmlns:math", "http://www.w3.org/1998/Math/MathML" );
     content.setAttribute( "xmlns:form", "http://openoffice.org/2000/form" );
     content.setAttribute( "xmlns:script", "http://openoffice.org/2000/script" );
+    content.setAttribute( "xmlns:presentation", "http://openoffice.org/2000/presentation" );
     content.setAttribute( "office:class", "presentation" );
     content.setAttribute( "office:version", "1.0" );
 
@@ -330,10 +442,14 @@ void OoImpressExport::createDocumentManifest( QDomDocument & docmanifest )
     entry.setAttribute( "manifest:full-path", "/" );
     manifest.appendChild( entry );
 
-    entry = docmanifest.createElement( "manifest:file-entry" );
-    entry.setAttribute( "manifest:media-type", "" );
-    entry.setAttribute( "manifest:full-path", "Pictures/" );
-    manifest.appendChild( entry );
+    QMap<QString, QString>::Iterator it;
+    for ( it = m_pictureLst.begin(); it != m_pictureLst.end(); ++it )
+    {
+        entry = docmanifest.createElement( "manifest:file-entry" );
+        entry.setAttribute( "manifest:media-type", it.data() );
+        entry.setAttribute( "manifest:full-path", it.key() );
+        manifest.appendChild( entry );
+    }
 
     entry = docmanifest.createElement( "manifest:file-entry" );
     entry.setAttribute( "manifest:media-type", "text/xml" );
@@ -350,9 +466,106 @@ void OoImpressExport::createDocumentManifest( QDomDocument & docmanifest )
     entry.setAttribute( "manifest:full-path", "meta.xml" );
     manifest.appendChild( entry );
 
+    entry = docmanifest.createElement( "manifest:file-entry" );
+    entry.setAttribute( "manifest:media-type", "text/xml" );
+    entry.setAttribute( "manifest:full-path", "settings.xml" );
+    manifest.appendChild( entry );
+
     docmanifest.appendChild( manifest );
 }
 
+QString OoImpressExport::pictureKey( QDomElement &elem )
+{
+    // Default date/time is the *nix epoch: 1970-01-01 00:00:00,000
+    int year=1970, month=1, day=1;
+    int hour=0, minute=0, second=0, msec=0; // We must initialize to zero, as not all compilers are C99-compliant
+    if ( elem.tagName() ==  "KEY" )
+    {
+        if( elem.hasAttribute( "year" ) )
+            year=elem.attribute( "year" ).toInt();
+        if( elem.hasAttribute( "month" ) )
+            month=elem.attribute( "month" ).toInt();
+        if( elem.hasAttribute( "day" ) )
+            day=elem.attribute( "day" ).toInt();
+        if( elem.hasAttribute( "hour" ) )
+            hour=elem.attribute( "hour" ).toInt();
+        if( elem.hasAttribute( "minute" ) )
+            minute=elem.attribute( "minute" ).toInt();
+        if( elem.hasAttribute( "second" ) )
+            second=elem.attribute( "second" ).toInt();
+        if( elem.hasAttribute( "msec" ) )
+            msec=elem.attribute( "msec" ).toInt();
+    }
+    QDateTime key;
+    key.setDate( QDate( year, month, day ) );
+    key.setTime( QTime( hour, minute, second, msec ) );
+    return key.toString();
+}
+
+void OoImpressExport::createPictureList( QDomNode &pictures )
+{
+    pictures = pictures.firstChild();
+    for( ; !pictures.isNull(); pictures = pictures.nextSibling() )
+    {
+        if ( pictures.isElement() )
+        {
+            QDomElement element = pictures.toElement();
+            if ( element.tagName() ==  "KEY" )
+            {
+                //kdDebug(30518)<<"element.attribute( name ) :"<<element.attribute( "name" )<<endl;
+                m_kpresenterPictureLst.insert( pictureKey( element ), element.attribute( "name" ) );
+            }
+            else
+                kdDebug(30518)<<" Tag not recognize :"<<element.tagName()<<endl;
+        }
+    }
+}
+
+void OoImpressExport::createAttribute( QDomNode &attributeValue )
+{
+    QDomElement elem = attributeValue.toElement();
+    if(elem.hasAttribute("activePage"))
+        m_activePage=elem.attribute("activePage").toInt();
+    if(elem.hasAttribute("gridx"))
+        m_gridX = elem.attribute("gridx").toDouble();
+    if(elem.hasAttribute("gridy"))
+        m_gridY = elem.attribute("gridy").toDouble();
+    if(elem.hasAttribute("snaptogrid"))
+        m_snapToGrid = (bool)elem.attribute("snaptogrid").toInt();
+}
+
+void OoImpressExport::createHelpLine( QDomNode &helpline )
+{
+    helpline = helpline.firstChild();
+    QDomElement helplines;
+    for( ; !helpline.isNull(); helpline = helpline.nextSibling() )
+    {
+        if ( helpline.isElement() )
+        {
+            helplines = helpline.toElement();
+            if ( helplines.tagName()=="Vertical" )
+            {
+                int tmpX = ( int ) ( KoUnit::toMM( helplines.attribute("value").toDouble() )*100 );
+                m_helpLine+="V"+QString::number( tmpX );
+            }
+            else if ( helplines.tagName()=="Horizontal" )
+            {
+                int tmpY = ( int ) ( KoUnit::toMM( helplines.attribute("value").toDouble() )*100 );
+                m_helpLine+="H"+QString::number( tmpY );
+            }
+            else if ( helplines.tagName()=="HelpPoint" )
+            {
+                QString str( "P%1,%2" );
+                int tmpX = ( int ) ( KoUnit::toMM( helplines.attribute("posX").toDouble()  )*100 );
+                int tmpY = ( int ) ( KoUnit::toMM( helplines.attribute("posY").toDouble() )*100 );
+                m_helpLine+=str.arg( QString::number( tmpX ) ).arg( QString::number( tmpY ) );
+            }
+        }
+    }
+    //kdDebug(30518)<<"m_helpLine :"<<m_helpLine<<endl;
+}
+
+
 void OoImpressExport::exportBody( QDomDocument & doccontent, QDomElement & body )
 {
     QDomNode doc = m_maindoc.namedItem( "DOC" );
@@ -365,8 +578,21 @@ void OoImpressExport::exportBody( QDomDocument & doccontent, QDomElement & body
     QDomNode objects = doc.namedItem( "OBJECTS" );
     QDomNode pictures = doc.namedItem( "PICTURES" );
     QDomNode sounds = doc.namedItem( "SOUNDS" );
+    QDomNode helpline = doc.namedItem( "HELPLINES" );
+    QDomNode attributeValue = doc.namedItem( "ATTRIBUTES" );
+    QDomNode infiniLoop = doc.namedItem( "INFINITLOOP" );
+    QDomNode manualSwitch = doc.namedItem( "MANUALSWITCH" );
+    QDomNode customSlideShow = doc.namedItem( "CUSTOMSLIDESHOWCONFIG" );
+    QDomNode customSlideShowDefault = doc.namedItem( "DEFAULTCUSTOMSLIDESHOWNAME" );
+
     QDomNode bgpage = background.firstChild();
 
+    createPictureList( pictures );
+
+    createHelpLine( helpline );
+
+    createAttribute( attributeValue );
+
     // store the paper settings
     QDomElement p = paper.toElement();
     m_masterPageStyle = m_styleFactory.createPageMasterStyle( p );
@@ -375,8 +601,9 @@ void OoImpressExport::exportBody( QDomDocument & doccontent, QDomElement & body
     m_currentPage = 1;
 
     // parse all pages
-    for ( QDomNode title = titles.firstChild(); !title.isNull();
-          title = title.nextSibling() )
+    QDomNode note = notes.firstChild();
+    for ( QDomNode title = titles.firstChild(); !title.isNull() && !note.isNull();
+          title = title.nextSibling(), note = note.nextSibling() )
     {
         // create the page style and ignore the fact that there may
         // be less backgrounds than pages
@@ -391,63 +618,164 @@ void OoImpressExport::exportBody( QDomDocument & doccontent, QDomElement & body
         drawPage.setAttribute( "draw:id", m_currentPage );
         drawPage.setAttribute( "draw:master-page-name", m_masterPageStyle );
 
-        // I am not sure if objects are always stored sorted so I parse all
-        // of them to find the ones belonging to a certain page.
-        for ( QDomNode object = objects.firstChild(); !object.isNull();
-              object = object.nextSibling() )
-        {
-            QDomElement o = object.toElement();
-
-            QDomElement orig = o.namedItem( "ORIG" ).toElement();
-            float y = orig.attribute( "y" ).toFloat();
-
-            if ( y < m_pageHeight * ( m_currentPage - 1 ) ||
-                 y >= m_pageHeight * m_currentPage )
-                continue; // object not on current page
-
-            switch( o.attribute( "type" ).toInt() )
-            {
-            case 0: // image
-                break;
-            case 1: // line
-                appendLine( doccontent, o, drawPage );
-                break;
-            case 2: // rectangle
-                appendRectangle( doccontent, o, drawPage );
-                break;
-            case 3: // circle, ellipse
-                appendEllipse( doccontent, o, drawPage );
-                break;
-            case 4: // textbox
-                appendTextbox( doccontent, o, drawPage );
-                break;
-            case 8: // pie, chord, arc
-                appendEllipse( doccontent, o, drawPage, true );
-                break;
-            case 12: // polyline
-                appendPolyline( doccontent, o, drawPage );
-                break;
-            case 13: //OT_QUADRICBEZIERCURVE = 13
-            case 14: //OT_CUBICBEZIERCURVE = 14
-                //todo
-                // "draw:path"
-                break;
-            case 15: // polygon
-            case 16: // close polygone
-                appendPolyline( doccontent, o, drawPage, true /*polygon*/ );
-                break;
-            }
-        }
+        appendObjects( doccontent, objects, drawPage );
 
+        QDomElement noteElement = note.toElement();
+        appendNote( doccontent, noteElement, drawPage );
         body.appendChild( drawPage );
         m_currentPage++;
     }
+    int infiniLoopValue = -1;
+    int manualSwitchValue = -1;
+    if ( !infiniLoop.isNull() && infiniLoop.toElement().hasAttribute( "value" ))
+    {
+        bool ok;
+        int val = infiniLoop.toElement().attribute( "value" ).toInt( &ok );
+        if ( ok )
+            infiniLoopValue = val;
+    }
+    if ( !manualSwitch.isNull() && manualSwitch.toElement().hasAttribute( "value" ))
+    {
+        bool ok;
+        int val = manualSwitch.toElement().attribute( "value" ).toInt( &ok );
+        if ( ok )
+            manualSwitchValue = val;
+    }
+    if ( infiniLoopValue != -1 || manualSwitchValue != -1 || !customSlideShowDefault.isNull())
+    {
+        QDomElement settings = doccontent.createElement( "presentation:settings" );
+        if ( infiniLoopValue !=-1 )
+            settings.setAttribute( "presentation:force-manual", ( manualSwitchValue==1 ) ? "true" : "false" );
+        if ( manualSwitchValue != -1 )
+            settings.setAttribute( "presentation:endless", ( infiniLoopValue==1 ) ? "true": "false" );
+        if ( !customSlideShowDefault.isNull() )
+            settings.setAttribute( "presentation:show", customSlideShowDefault.toElement().attribute( "name" ) );
+
+        if ( !customSlideShow.isNull() )
+        {
+            for ( QDomNode customPage = customSlideShow.firstChild(); !customPage.isNull();
+                  customPage = customPage.nextSibling() )
+            {
+                QDomElement show = customPage.toElement();
+                if ( !show.isNull() && show.tagName()=="CUSTOMSLIDESHOW" )
+                {
+                    QDomElement showElement = doccontent.createElement( "presentation:show" );
+                    showElement.setAttribute( "presentation:name",show.attribute( "name" ) );
+                    showElement.setAttribute( "presentation:pages",show.attribute( "pages" ) );
+                    settings.appendChild( showElement );
+                }
+            }
+        }
+        body.appendChild( settings );
+    }
+}
+
+
+void OoImpressExport::appendObjects(QDomDocument & doccontent, QDomNode &objects, QDomElement &drawPage)
+{
+    // I am not sure if objects are always stored sorted so I parse all
+    // of them to find the ones belonging to a certain page.
+    for ( QDomNode object = objects.firstChild(); !object.isNull();
+          object = object.nextSibling() )
+    {
+        QDomElement o = object.toElement();
+
+        QDomElement orig = o.namedItem( "ORIG" ).toElement();
+        float y = orig.attribute( "y" ).toFloat();
+
+        if ( y < m_pageHeight * ( m_currentPage - 1 ) ||
+             y >= m_pageHeight * m_currentPage )
+            continue; // object not on current page
+
+        switch( o.attribute( "type" ).toInt() )
+        {
+        case 0: // image
+            appendPicture( doccontent, o, drawPage );
+            break;
+        case 1: // line
+            appendLine( doccontent, o, drawPage );
+            break;
+        case 2: // rectangle
+            appendRectangle( doccontent, o, drawPage );
+            break;
+        case 3: // circle, ellipse
+            appendEllipse( doccontent, o, drawPage );
+            break;
+        case 4: // textbox
+            appendTextbox( doccontent, o, drawPage );
+            break;
+        case 5:
+            kdDebug(30518)<<" autoform not implemented\n";
+            break;
+        case 6:
+            kdDebug(30518)<<" clipart not implemented\n";
+            break;
+        case 8: // pie, chord, arc
+            appendEllipse( doccontent, o, drawPage, true );
+            break;
+        case 9: //part
+            kdDebug(30518)<<" part object not implemented \n";
+            break;
+        case 10:
+            appendGroupObject( doccontent, o, drawPage );
+            break;
+        case 11:
+            kdDebug(30518)<<" free hand not implemented\n";
+            break;
+        case 12: // polyline
+            appendPolyline( doccontent, o, drawPage );
+            break;
+        case 13: //OT_QUADRICBEZIERCURVE = 13
+        case 14: //OT_CUBICBEZIERCURVE = 14
+            //todo
+            // "draw:path"
+            break;
+        case 15: // polygon
+        case 16: // close polygone
+            appendPolyline( doccontent, o, drawPage, true /*polygon*/ );
+            break;
+        }
+        ++m_objectIndex;
+    }
+
+}
+
+void OoImpressExport::appendGroupObject( QDomDocument & doc, QDomElement & source, QDomElement & target )
+{
+    QDomElement groupElement = doc.createElement( "draw:g" );
+    QDomNode objects = source.namedItem( "OBJECTS" );
+    appendObjects( doc, objects, groupElement);
+    target.appendChild( groupElement );
+}
+
+void OoImpressExport::appendNote( QDomDocument & doc, QDomElement & source, QDomElement & target )
+{
+    QString noteText = source.attribute("note");
+    //kdDebug(30518)<<"noteText :"<<noteText<<endl;
+    if ( noteText.isEmpty() )
+        return;
+    QDomElement noteElement = doc.createElement( "presentation:notes" );
+    QDomElement noteTextBox = doc.createElement( "draw:text-box" );
+
+    //TODO : add draw:text-box size :
+    //<draw:text-box draw:style-name="gr2" draw:text-style-name="P2" draw:layer="layout" svg:width="13.336cm" svg:height="56.288cm" svg:x="-0.54cm" svg:y="-14.846cm">
+
+    QStringList text = QStringList::split( "\n", noteText );
+    for ( QStringList::Iterator it = text.begin(); it != text.end(); ++it ) {
+        QDomElement tmp = doc.createElement( "text:p" );
+        tmp.appendChild( doc.createTextNode( *it ) );
+        noteTextBox.appendChild( tmp );
+    }
+    noteElement.appendChild( noteTextBox );
+    target.appendChild( noteElement );
 }
 
 void OoImpressExport::appendTextbox( QDomDocument & doc, QDomElement & source, QDomElement & target )
 {
     QDomElement textbox = doc.createElement( "draw:text-box" );
 
+    QDomNode textobject = source.namedItem( "TEXTOBJ" );
+
     // create the graphic style
     QString gs = m_styleFactory.createGraphicStyle( source );
     textbox.setAttribute( "draw:style-name", gs );
@@ -456,7 +784,6 @@ void OoImpressExport::appendTextbox( QDomDocument & doc, QDomElement & source, Q
     set2DGeometry( source, textbox );
 
     // parse every paragraph
-    QDomNode textobject = source.namedItem( "TEXTOBJ" );
     for ( QDomNode paragraph = textobject.firstChild(); !paragraph.isNull();
           paragraph = paragraph.nextSibling() )
     {
@@ -540,6 +867,58 @@ void OoImpressExport::appendText( QDomDocument & doc, QDomElement & source, QDom
     target.appendChild( textspan );
 }
 
+void OoImpressExport::appendPicture( QDomDocument & doc, QDomElement & source, QDomElement & target )
+{
+    QDomElement image = doc.createElement( "draw:image" );
+
+    // create the graphic style
+    QString gs = m_styleFactory.createGraphicStyle( source );
+    image.setAttribute( "draw:style-name", gs );
+    QDomElement key = source.namedItem( "KEY" ).toElement();
+
+    QString pictureName = QString( "Picture/Picture%1" ).arg( m_pictureIndex );
+
+    image.setAttribute( "xlink:type", "simple" );
+    image.setAttribute( "xlink:show", "embed" );
+    image.setAttribute( "xlink:actuate", "onLoad");
+
+    if ( !key.isNull() )
+    {
+        QString str = pictureKey( key );
+        QString returnstr = m_kpresenterPictureLst[str];
+        const int pos=returnstr.findRev('.');
+        if (pos!=-1)
+        {
+            const QString extension( returnstr.mid(pos+1) );
+            pictureName +="."+extension;
+        }
+
+        if ( m_storeinp->open( returnstr ) )
+        {
+            if ( m_storeout->open( pictureName ) )
+            {
+                QByteArray data(8*1024);
+                uint total = 0;
+                for ( int block = 0; ( block = m_storeinp->read(data.data(), data.size()) ) > 0;
+                      total += block )
+                    m_storeout->write(data.data(), data.size());
+                m_storeout->close();
+                m_storeinp->close();
+            }
+        }
+    }
+    image.setAttribute( "xlink:href", "#" + pictureName );
+
+// set the geometry
+    set2DGeometry( source, image );
+    target.appendChild( image );
+
+    m_pictureLst.insert( pictureName , "image/png" );
+
+    ++m_pictureIndex;
+}
+
+
 void OoImpressExport::appendLine( QDomDocument & doc, QDomElement & source, QDomElement & target )
 {
     QDomElement line = doc.createElement( "draw:line" );
@@ -609,6 +988,15 @@ void OoImpressExport::set2DGeometry( QDomElement & source, QDomElement & target,
     float y = orig.attribute( "y" ).toFloat();
     y -= m_pageHeight * ( m_currentPage - 1 );
 
+    QDomElement angle = source.namedItem( "ANGLE").toElement();
+    if ( !angle.isNull() )
+    {
+        QString returnAngle = rotateValue( angle.attribute( "value" ).toDouble() );
+        if ( !returnAngle.isEmpty() )
+            target.setAttribute("draw:transform",returnAngle );
+    }
+
+    target.setAttribute( "draw:id",  QString::number( m_objectIndex ) );
     target.setAttribute( "svg:x", StyleFactory::toCM( orig.attribute( "x" ) ) );
     target.setAttribute( "svg:y", QString( "%1cm" ).arg( KoUnit::toCM( y ) ) );
     target.setAttribute( "svg:width", StyleFactory::toCM( size.attribute( "width" ) ) );
@@ -634,7 +1022,7 @@ void OoImpressExport::set2DGeometry( QDomElement & source, QDomElement & target,
                 target.setAttribute( "draw:kind", "cut");
                 break;
             default:
-                kdDebug()<<" type unknown : "<<typePie<<endl;
+                kdDebug(30518)<<" type unknown : "<<typePie<<endl;
                 break;
             }
         }
@@ -673,7 +1061,6 @@ void OoImpressExport::set2DGeometry( QDomElement & source, QDomElement & target,
         QDomElement point = source.namedItem( "POINTS" ).toElement();
         if ( !point.isNull() ) {
             QDomElement elemPoint = point.firstChild().toElement();
-            unsigned int index = 0;
             QString listOfPoint;
             int maxX=0;
             int maxY=0;
@@ -700,25 +1087,59 @@ void OoImpressExport::set2DGeometry( QDomElement & source, QDomElement & target,
     }
 }
 
+QString OoImpressExport::rotateValue( double val )
+{
+    QString str;
+    if ( val!=0.0 )
+    {
+        double value = -1 * ( ( double )val* M_PI )/180.0;
+        str=QString( "rotate (%1)" ).arg( value );
+    }
+    return str;
+}
+
+
 void OoImpressExport::setLineGeometry( QDomElement & source, QDomElement & target )
 {
     QDomElement orig = source.namedItem( "ORIG" ).toElement();
     QDomElement size = source.namedItem( "SIZE" ).toElement();
     QDomElement linetype = source.namedItem( "LINETYPE" ).toElement();
     QDomElement name = source.namedItem( "OBJECTNAME").toElement();
-
+    QDomElement angle = source.namedItem( "ANGLE").toElement();
+    if ( !angle.isNull() )
+    {
+        QString returnAngle = rotateValue( angle.attribute( "value" ).toDouble() );
+        if ( !returnAngle.isEmpty() )
+            target.setAttribute("draw:transform",returnAngle );
+    }
     float x1 = orig.attribute( "x" ).toFloat();
     float y1 = orig.attribute( "y" ).toFloat();
     float x2 = size.attribute( "width" ).toFloat();
     float y2 = size.attribute( "height" ).toFloat();
-    float type = linetype.attribute( "value" ).toInt();
+    int type = 0;
+    if ( !linetype.isNull() )
+        type = linetype.attribute( "value" ).toInt();
     y1 -= m_pageHeight * ( m_currentPage - 1 );
     x2 += x1;
     y2 += y1;
 
-    target.setAttribute( "svg:x1", StyleFactory::toCM( orig.attribute( "x" ) ) );
-    target.setAttribute( "svg:x2", QString( "%1cm" ).arg( KoUnit::toCM( x2 ) ) );
-    if ( type == 3 ) // from left bottom to right top
+    target.setAttribute( "draw:id",  QString::number( m_objectIndex ) );
+    QString xpos1 = StyleFactory::toCM( orig.attribute( "x" ) );
+    QString xpos2 = QString( "%1cm" ).arg( KoUnit::toCM( x2 ) );
+
+    if ( type == 0 )
+    {
+        target.setAttribute( "svg:y1", QString( "%1cm" ).arg( KoUnit::toCM( y2/2.0 ) ) );
+        target.setAttribute( "svg:y2", QString( "%1cm" ).arg( KoUnit::toCM( y2/2.0 ) ) );
+    }
+    else if ( type == 1 )
+    {
+        target.setAttribute( "svg:y1", QString( "%1cm" ).arg( KoUnit::toCM( y1 ) ) );
+        target.setAttribute( "svg:y2", QString( "%1cm" ).arg( KoUnit::toCM( y2 ) ) );
+        xpos1 = QString( "%1cm" ).arg( KoUnit::toCM( x1/2.0 ) );
+        xpos2 = xpos1;
+    }
+    else if ( type == 3 ) // from left bottom to right top
     {
         target.setAttribute( "svg:y1", QString( "%1cm" ).arg( KoUnit::toCM( y2 ) ) );
         target.setAttribute( "svg:y2", QString( "%1cm" ).arg( KoUnit::toCM( y1 ) ) );
@@ -728,6 +1149,8 @@ void OoImpressExport::setLineGeometry( QDomElement & source, QDomElement & targe
         target.setAttribute( "svg:y1", QString( "%1cm" ).arg( KoUnit::toCM( y1 ) ) );
         target.setAttribute( "svg:y2", QString( "%1cm" ).arg( KoUnit::toCM( y2 ) ) );
     }
+    target.setAttribute( "svg:x1", xpos1 );
+    target.setAttribute( "svg:x2", xpos2 );
 
     QString nameStr = name.attribute("objectName");
     if( !nameStr.isEmpty() )
