@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2000 David Faure <faure@kde.org>
+   Copyright (C) 2004 Nicolas GOUTTE <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,11 +21,13 @@
 #include <csvexport.h>
 
 #include <qfile.h>
+#include <qtextcodec.h>
 
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <kgenericfactory.h>
 #include <koFilterChain.h>
+#include <koFilterManager.h>
 
 #include <kspread_map.h>
 #include <kspread_sheet.h>
@@ -34,9 +37,9 @@
 #include <csvexportdialog.h>
 
 typedef KGenericFactory<CSVExport, KoFilter> CSVExportFactory;
-K_EXPORT_COMPONENT_FACTORY( libcsvexport, CSVExportFactory( "csvfilter" ) )
+K_EXPORT_COMPONENT_FACTORY( libcsvexport, CSVExportFactory( "kofficefilters" ) )
 
-class Cell 
+class Cell
 {
  public:
   int row, col;
@@ -53,13 +56,13 @@ class Cell
 };
 
 
-CSVExport::CSVExport( KoFilter *, const char *, const QStringList & ) 
-  : KoFilter() 
+CSVExport::CSVExport( KoFilter *, const char *, const QStringList & )
+  : KoFilter(), m_eol("\n")
 {
 }
 
 
-void CSVExport::exportCell( KSpreadSheet const * const sheet, int col, int row, QString & separators, 
+void CSVExport::exportCell( KSpreadSheet const * const sheet, int col, int row, QString & separators,
                             QString & line, QChar const & csvDelimiter, QChar const & textQuote )
 {
   KSpreadCell const * const cell = sheet->cellAt( col, row );
@@ -67,6 +70,13 @@ void CSVExport::exportCell( KSpreadSheet const * const sheet, int col, int row,
   QString text;
   if ( !cell->isDefault() && !cell->isEmpty() )
   {
+    if ( cell->isFormula() )
+        text = cell->strOutText();
+    else if ( !cell->link().isEmpty() )
+        text = cell->text(); // untested
+    else
+        text = cell->strOutText();
+#if 0
     switch( cell->content() )
     {
      case KSpreadCell::Text:
@@ -78,11 +88,12 @@ void CSVExport::exportCell( KSpreadSheet const * const sheet, int col, int row,
       break;
      case KSpreadCell::Formula:
       //      cell->setCalcDirtyFlag();
-      //      cell->calc(); 
+      //      cell->calc();
       //      text = cell->value().asString();
       text = cell->strOutText();
       break;
     }
+#endif
   }
   if ( !text.isEmpty() )
   {
@@ -127,33 +138,69 @@ KoFilter::ConversionStatus CSVExport::convert( const QCString & from, const QCSt
     return KoFilter::NotImplemented;
   }
 
-  CSVExportDialog expDialog( 0 );
-  expDialog.fillTable( ksdoc->map() );
+  CSVExportDialog *expDialog = 0;
+  if (!m_chain->manager()->getBatchMode())
+  {
+    expDialog= new CSVExportDialog( 0 );
 
-  if ( !expDialog.exec() )
-    return KoFilter::UserCancelled;
+    if (!expDialog)
+    {
+      kdError(30501) << "Dialog has not been created! Aborting!" << endl;
+      return KoFilter::StupidError;
+    }
+    expDialog->fillSheet( ksdoc->map() );
 
+    if ( !expDialog->exec() )
+    {
+      delete expDialog;
+      return KoFilter::UserCancelled;
+    }
+  }
+
+  QTextCodec* codec = 0;
   QChar csvDelimiter;
+  if (expDialog)
+  {
+	codec = expDialog->getCodec();
+	if ( !codec )
+	{
+	  delete expDialog;
+	  return KoFilter::StupidError;
+	}
+	csvDelimiter = expDialog->getDelimiter();
+  }
+  else
+  {
+    codec = QTextCodec::codecForName("UTF-8");
+    csvDelimiter = ',';
+  }
 
-  csvDelimiter = expDialog.getDelimiter();
 
-  // Now get hold of the table to export
-  // (Hey, this could be part of the dialog too, choosing which table to export....
+  // Now get hold of the sheet to export
+  // (Hey, this could be part of the dialog too, choosing which sheet to export....
   //  It's great to have parametrable filters... IIRC even MSOffice doesn't have that)
-  // Ok, for now we'll use the first table - my document has only one table anyway ;-)))
+  // Ok, for now we'll use the first sheet - my document has only one sheet anyway ;-)))
 
   bool first = true;
   QString str;
-  QChar textQuote = expDialog.getTextQuote();
+  QChar textQuote;
+  if (expDialog)
+    textQuote = expDialog->getTextQuote();
+  else
+    textQuote = '"';
 
-  if ( expDialog.exportSelectionOnly() )
+  if ( expDialog && expDialog->exportSelectionOnly() )
   {
+    kdDebug(30501) << "Export as selection mode" << endl;
     KSpreadView const * const view = static_cast<KSpreadView*>(ksdoc->views().getFirst());
 
     if ( !view ) // no view if embedded document
+    {
+      delete expDialog;
       return KoFilter::StupidError;
+    }
 
-    KSpreadSheet const * const sheet = view->activeTable();
+    KSpreadSheet const * const sheet = view->activeSheet();
 
     QRect selection = view->selection();
     int right       = selection.right();
@@ -176,37 +223,43 @@ KoFilter::ConversionStatus CSVExport::convert( const QCString & from, const QCSt
         str += line;
         emptyLines = QString::null;
       }
-      // Append a CR, but in a temp string -> if no other real line,
+      // Append an end of line, but in a temp string -> if no other real line,
       // then those will be dropped
-      emptyLines += "\n";
+      emptyLines += m_eol;
     }
   }
   else
   {
-    QPtrListIterator<KSpreadSheet> it( ksdoc->map()->tableList() );
+    kdDebug(30501) << "Export as full mode" << endl;
+    QPtrListIterator<KSpreadSheet> it( ksdoc->map()->sheetList() );
     for( ; it.current(); ++it )
     {
       KSpreadSheet const * const sheet = it.current();
 
-      if ( !expDialog.exportTable( sheet->tableName() ) )
+      if (expDialog && !expDialog->exportSheet( sheet->sheetName() ) )
       {
         continue;
       }
 
-      if ( !first || expDialog.printAlwaysTableDelimiter() )
+      if ( !first || ( expDialog && expDialog->printAlwaysSheetDelimiter() ) )
       {
         if ( !first)
-          str += "\n";
+          str += m_eol;
 
-        QString name( expDialog.getTableDelimiter() );
-        QString tname( i18n("<TABLENAME>") );
+	QString name;
+	if (expDialog)
+	  name = expDialog->getSheetDelimiter();
+	else
+	  name = "********<SHEETNAME>********";
+        const QString tname( i18n("<SHEETNAME>") );
         int pos = name.find( tname );
         if ( pos != -1 )
         {
-          name.replace( pos, tname.length(), sheet->tableName() );
+          name.replace( pos, tname.length(), sheet->sheetName() );
         }
         str += name;
-        str += "\n\n";
+        str += m_eol;
+        str += m_eol;
       }
 
       first = false;
@@ -215,6 +268,7 @@ KoFilter::ConversionStatus CSVExport::convert( const QCString & from, const QCSt
       // or, cleaner and already sorted, we use KSpreadSheet's API (slower probably, though)
       int iMaxColumn = sheet->maxColumn();
       int iMaxRow    = sheet->maxRow();
+      kdDebug(30501) << "Max row x column: " << iMaxRow << " x " << iMaxColumn << endl;
 
       // this is just a bad approximation which fails for documents with less than 50 rows, but
       // we don't need any progress stuff there anyway :) (Werner)
@@ -231,7 +285,7 @@ KoFilter::ConversionStatus CSVExport::convert( const QCString & from, const QCSt
           emit sigProgress(value);
           i = 0;
         }
-          
+
         QString separators;
         QString line;
         for ( int currentcolumn = 1 ; currentcolumn <= iMaxColumn ; currentcolumn++ )
@@ -244,28 +298,31 @@ KoFilter::ConversionStatus CSVExport::convert( const QCString & from, const QCSt
           str += line;
           emptyLines = QString::null;
         }
-        // Append a CR, but in a temp string -> if no other real line,
+        // Append an end of line, but in a temp string -> if no other real line,
         // then those will be dropped
-        emptyLines += "\n";
+        emptyLines += m_eol;
       }
     }
   }
-  str += "\n"; // Last CR
+  str += m_eol; // Last end of line
   emit sigProgress(100);
 
-  // Ok, now write to export file
-  QCString cstr(str.local8Bit()); // I assume people will prefer local8Bit over utf8... Another param ?
-
   QFile out(m_chain->outputFile());
-  if ( !out.open( IO_WriteOnly ) ) 
+  if ( !out.open( IO_WriteOnly ) )
   {
     kdError(30501) << "Unable to open output file!" << endl;
     out.close();
+    delete expDialog;
     return KoFilter::StupidError;
   }
-  out.writeBlock(cstr.data(), cstr.length());
+
+  QTextStream outStream( &out );
+  outStream.setCodec( codec );
+
+  outStream << str;
 
   out.close();
+  delete expDialog;
   return KoFilter::OK;
 }
 
