@@ -1,6 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 2000 David Faure <faure@kde.org>
    Copyright (C) 2000 Norbert Andres <nandres@web.de>
+   Copyright (C) 2005 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -33,6 +34,8 @@
 #include <kmessagebox.h>
 #include <kmdcodec.h>
 #include <kgenericfactory.h>
+#include <klocale.h>
+
 #include <koDocumentInfo.h>
 #include <koFilterChain.h>
 #include <koGlobal.h>
@@ -60,7 +63,7 @@ public:
 protected:
     virtual void setupTranslations( void )
     {
-        KGlobal::locale()->insertCatalogue( "kspreadopencalcfilter" );
+        KGlobal::locale()->insertCatalogue( "kofficefilters" );
     }
 };
 
@@ -112,7 +115,7 @@ KoFilter::ConversionStatus OpenCalcExport::convert( const QCString & from,
     return KoFilter::NotImplemented;
   }
 
-  KSpreadDoc const * const ksdoc = static_cast<const KSpreadDoc *>(document);
+  const KSpreadDoc * ksdoc = static_cast<const KSpreadDoc *>(document);
 
   if ( ksdoc->mimeType() != "application/x-kspread" )
   {
@@ -121,7 +124,6 @@ KoFilter::ConversionStatus OpenCalcExport::convert( const QCString & from,
   }
 
   m_locale = static_cast<KSpreadDoc*>(document)->locale();
-
   if ( !writeFile( ksdoc ) )
     return KoFilter::CreationError;
 
@@ -130,7 +132,7 @@ KoFilter::ConversionStatus OpenCalcExport::convert( const QCString & from,
   return KoFilter::OK;
 }
 
-bool OpenCalcExport::writeFile( KSpreadDoc const * const ksdoc )
+bool OpenCalcExport::writeFile( const KSpreadDoc * ksdoc )
 {
   KoStore * store = KoStore::createStore( m_chain->outputFile(), KoStore::Write, "", KoStore::Zip );
 
@@ -170,7 +172,7 @@ bool OpenCalcExport::writeFile( KSpreadDoc const * const ksdoc )
   return true;
 }
 
-bool OpenCalcExport::exportDocInfo( KoStore * store, KSpreadDoc const * const ksdoc )
+bool OpenCalcExport::exportDocInfo( KoStore * store, const KSpreadDoc* ksdoc )
 {
   if ( !store->open( "meta.xml" ) )
     return false;
@@ -205,14 +207,22 @@ bool OpenCalcExport::exportDocInfo( KoStore * store, KSpreadDoc const * const ks
   data.appendChild( meta.createTextNode( authorPage->fullName() ) );
   officeMeta.appendChild( data );
 
-  data = meta.createElement( "meta:user-defined" );
-  data.setAttribute( "meta:name", "Info 1" );
+  data = meta.createElement( "dc:description" );
+  data.appendChild( meta.createTextNode( aboutPage->abstract() ) );
+  officeMeta.appendChild( data );
+
+  data = meta.createElement( "meta:keywords" );
+  QDomElement dataItem = meta.createElement( "meta:keyword" );
+  dataItem.appendChild( meta.createTextNode( aboutPage->keywords() ) );
+  data.appendChild( dataItem );
+  officeMeta.appendChild( data );
+
+  data = meta.createElement( "dc:title" );
   data.appendChild( meta.createTextNode( aboutPage->title() ) );
   officeMeta.appendChild( data );
 
-  data = meta.createElement( "meta:user-defined" );
-  data.setAttribute( "meta:name", "Info 2" );
-  data.appendChild( meta.createTextNode( aboutPage->abstract() ) );
+  data = meta.createElement( "dc:subject" );
+  data.appendChild( meta.createTextNode( aboutPage->subject() ) );
   officeMeta.appendChild( data );
 
   const QDateTime dt ( QDateTime::currentDateTime() );
@@ -251,56 +261,9 @@ bool OpenCalcExport::exportDocInfo( KoStore * store, KSpreadDoc const * const ks
   return true;
 }
 
-bool OpenCalcExport::exportContent( KoStore * store, KSpreadDoc const * const ksdoc )
-{
-  if ( !store->open( "content.xml" ) )
-    return false;
-
-  createDefaultStyles();
-
-  QDomDocument doc;
-  doc.appendChild( doc.createProcessingInstruction( "xml","version=\"1.0\" encoding=\"UTF-8\"" ) );
-
-  QDomElement content = doc.createElement( "office:document-content" );
-  content.setAttribute( "xmlns:office", "http://openoffice.org/2000/office");
-  content.setAttribute( "xmlns:style", "http://openoffice.org/2000/style" );
-  content.setAttribute( "xmlns:text", "http://openoffice.org/2000/text" );
-  content.setAttribute( "xmlns:table", "http://openoffice.org/2000/table" );
-  content.setAttribute( "xmlns:draw", "http://openoffice.org/2000/drawing" );
-  content.setAttribute( "xmlns:fo", "http://www.w3.org/1999/XSL/Format" );
-  content.setAttribute( "xmlns:xlink", "http://www.w3.org/1999/xlink" );
-  content.setAttribute( "xmlns:number", "http://openoffice.org/2000/datastyle" );
-  content.setAttribute( "xmlns:svg", "http://www.w3.org/2000/svg" );
-  content.setAttribute( "xmlns:chart", "http://openoffice.org/2000/chart" );
-  content.setAttribute( "xmlns:dr3d", "http://openoffice.org/2000/dr3d" );
-  content.setAttribute( "xmlns:math", "http://www.w3.org/1998/Math/MathML" );
-  content.setAttribute( "xmlns:form", "http://openoffice.org/2000/form" );
-  content.setAttribute( "xmlns:script", "http://openoffice.org/2000/script" );
-  content.setAttribute( "office:class", "spreadsheet" );
-  content.setAttribute( "office:version", "1.0" );
-
-  QDomElement data = doc.createElement( "office:script" );
-  content.appendChild( data );
-
-  if ( !exportBody( doc, content, ksdoc ) )
-    return false;
-
-  doc.appendChild( content );
-
-  QCString f( doc.toCString() );
-  kdDebug(30518) << "Content: " << (char const * ) f << endl;
-
-  store->write( f, f.length() );
-
-  if ( !store->close() )
-    return false;
-
-  return true;
-}
-
 bool OpenCalcExport::exportSettings( KoStore * store, const KSpreadDoc * ksdoc )
 {
-    if ( !store->open( "settings.xml" ) )
+  if ( !store->open( "settings.xml" ) )
     return false;
 
   QDomDocument doc;
@@ -332,7 +295,7 @@ bool OpenCalcExport::exportSettings( KoStore * store, const KSpreadDoc * ksdoc )
   if ( view ) // no view if embedded document
   {
       KSpreadCanvas * canvas = view->canvasWidget();
-      activeTable = canvas->activeTable()->tableName();
+      activeTable = canvas->activeSheet()->sheetName();
       // save current sheet selection before to save marker, otherwise current pos is not saved
       view->saveCurrentSheetSelection();
   }
@@ -342,7 +305,7 @@ bool OpenCalcExport::exportSettings( KoStore * store, const KSpreadDoc * ksdoc )
   QDomElement configmaped = doc.createElement( "config:config-item-map-named" );
   configmaped.setAttribute( "config:name","Tables" );
 
-  QPtrListIterator<KSpreadSheet> it( ksdoc->map()->tableList() );
+  QPtrListIterator<KSpreadSheet> it( ksdoc->map()->sheetList() );
   for( ; it.current(); ++it )
   {
       QPoint marker;
@@ -390,6 +353,52 @@ bool OpenCalcExport::exportSettings( KoStore * store, const KSpreadDoc * ksdoc )
   return true;
 }
 
+bool OpenCalcExport::exportContent( KoStore * store, const KSpreadDoc * ksdoc )
+{
+  if ( !store->open( "content.xml" ) )
+    return false;
+
+  createDefaultStyles();
+
+  QDomDocument doc;
+  doc.appendChild( doc.createProcessingInstruction( "xml","version=\"1.0\" encoding=\"UTF-8\"" ) );
+
+  QDomElement content = doc.createElement( "office:document-content" );
+  content.setAttribute( "xmlns:office", "http://openoffice.org/2000/office");
+  content.setAttribute( "xmlns:style", "http://openoffice.org/2000/style" );
+  content.setAttribute( "xmlns:text", "http://openoffice.org/2000/text" );
+  content.setAttribute( "xmlns:table", "http://openoffice.org/2000/table" );
+  content.setAttribute( "xmlns:draw", "http://openoffice.org/2000/drawing" );
+  content.setAttribute( "xmlns:fo", "http://www.w3.org/1999/XSL/Format" );
+  content.setAttribute( "xmlns:xlink", "http://www.w3.org/1999/xlink" );
+  content.setAttribute( "xmlns:number", "http://openoffice.org/2000/datastyle" );
+  content.setAttribute( "xmlns:svg", "http://www.w3.org/2000/svg" );
+  content.setAttribute( "xmlns:chart", "http://openoffice.org/2000/chart" );
+  content.setAttribute( "xmlns:dr3d", "http://openoffice.org/2000/dr3d" );
+  content.setAttribute( "xmlns:math", "http://www.w3.org/1998/Math/MathML" );
+  content.setAttribute( "xmlns:form", "http://openoffice.org/2000/form" );
+  content.setAttribute( "xmlns:script", "http://openoffice.org/2000/script" );
+  content.setAttribute( "office:class", "spreadsheet" );
+  content.setAttribute( "office:version", "1.0" );
+
+  QDomElement data = doc.createElement( "office:script" );
+  content.appendChild( data );
+
+  if ( !exportBody( doc, content, ksdoc ) )
+    return false;
+
+  doc.appendChild( content );
+
+  QCString f( doc.toCString() );
+  kdDebug(30518) << "Content: " << (char const * ) f << endl;
+
+  store->write( f, f.length() );
+
+  if ( !store->close() )
+    return false;
+
+  return true;
+}
 
  // e.g.: Sheet4.A1:Sheet4.E28
 QString convertRangeToRef( const QString & tableName, const QRect & _area )
@@ -397,6 +406,7 @@ QString convertRangeToRef( const QString & tableName, const QRect & _area )
     return tableName + "." + KSpreadCell::name( _area.left(), _area.top() ) + ":" + tableName + "."+ KSpreadCell::name( _area.right(), _area.bottom() );
 }
 
+
 QString convertRefToBase( QString const & table, QRect const & rect )
 {
   QPoint bottomRight( rect.bottomRight() );
@@ -404,7 +414,7 @@ QString convertRefToBase( QString const & table, QRect const & rect )
   QString s( "$" );
   s += table;
   s += ".$";
-  s += util_encodeColumnLabelText( bottomRight.x() );
+  s += /*util_encodeColumnLabelText*/KSpreadCell::columnName( bottomRight.x() );
   s += '$';
   s += QString::number( bottomRight.y() );
 
@@ -422,11 +432,11 @@ QString convertRefToRange( QString const & table, QRect const & rect )
   QString s( "$" );
   s += table;
   s += ".$";
-  s += util_encodeColumnLabelText( topLeft.x() );
+  s += /*util_encodeColumnLabelText*/KSpreadCell::columnName( topLeft.x() );
   s += '$';
   s += QString::number( topLeft.y() );
   s += ":.$";
-  s += util_encodeColumnLabelText( bottomRight.x() );
+  s += /*util_encodeColumnLabelText*/KSpreadCell::columnName( bottomRight.x() );
   s += '$';
   s += QString::number( bottomRight.y() );
 
@@ -446,8 +456,8 @@ void exportNamedExpr( QDomDocument & doc, QDomElement & parent,
     Reference ref = *it;
 
     namedRange.setAttribute( "table:name", ref.ref_name );
-    namedRange.setAttribute( "table:base-cell-address", convertRefToBase( ref.table_name, ref.rect ) );
-    namedRange.setAttribute( "table:cell-range-address", convertRefToRange( ref.table_name, ref.rect ) );
+    namedRange.setAttribute( "table:base-cell-address", convertRefToBase( ref.sheet_name, ref.rect ) );
+    namedRange.setAttribute( "table:cell-range-address", convertRefToRange( ref.sheet_name, ref.rect ) );
 
     parent.appendChild( namedRange );
 
@@ -455,7 +465,7 @@ void exportNamedExpr( QDomDocument & doc, QDomElement & parent,
   }
 }
 
-bool OpenCalcExport::exportBody( QDomDocument & doc, QDomElement & content, KSpreadDoc const * const ksdoc )
+bool OpenCalcExport::exportBody( QDomDocument & doc, QDomElement & content, const KSpreadDoc * ksdoc )
 {
   QDomElement fontDecls  = doc.createElement( "office:font-decls" );
   QDomElement autoStyles = doc.createElement( "office:automatic-styles" );
@@ -474,7 +484,9 @@ bool OpenCalcExport::exportBody( QDomDocument & doc, QDomElement & content, KSpr
     }
   }
 
-  QPtrListIterator<KSpreadSheet> it( ksdoc->map()->tableList() );
+
+
+  QPtrListIterator<KSpreadSheet> it( ksdoc->map()->sheetList() );
 
   for( it.toFirst(); it.current(); ++it )
   {
@@ -516,7 +528,7 @@ bool OpenCalcExport::exportBody( QDomDocument & doc, QDomElement & content, KSpr
     if ( _printRange != ( QRect( QPoint( 1, 1 ), QPoint( KS_colMax, KS_rowMax ) ) ) )
     {
         QString range= convertRangeToRef( name, _printRange );
-        //kdDebug()<<" range : "<<range<<endl;
+        //kdDebug(30518)<<" range : "<<range<<endl;
         tabElem.setAttribute( "table:print-ranges", range );
     }
 
@@ -553,14 +565,14 @@ bool OpenCalcExport::exportBody( QDomDocument & doc, QDomElement & content, KSpr
 }
 
 void OpenCalcExport::exportSheet( QDomDocument & doc, QDomElement & tabElem,
-                                  KSpreadSheet const * const sheet, int maxCols, int maxRows )
+                                  const KSpreadSheet * sheet, int maxCols, int maxRows )
 {
   kdDebug(30518) << "exportSheet: " << sheet->tableName() << endl;
   int i = 1;
 
   while ( i <= maxCols )
   {
-    ColumnFormat const * const column = sheet->columnFormat( i );
+    const ColumnFormat * column = sheet->columnFormat( i );
     ColumnStyle cs;
     cs.breakB = Style::automatic;
     cs.size   = column->mmWidth() / 10;
@@ -570,7 +582,7 @@ void OpenCalcExport::exportSheet( QDomDocument & doc, QDomElement & tabElem,
     int repeated = 1;
     while ( j <= maxCols )
     {
-      ColumnFormat const * const c = sheet->columnFormat( j );
+      const ColumnFormat *c = sheet->columnFormat( j );
       ColumnStyle cs1;
       cs1.breakB = Style::automatic;
       cs1.size   = c->mmWidth() / 10;
@@ -584,7 +596,7 @@ void OpenCalcExport::exportSheet( QDomDocument & doc, QDomElement & tabElem,
 
     QDomElement colElem = doc.createElement( "table:table-column" );
     colElem.setAttribute( "table:style-name", m_styles.columnStyle( cs ) );
-    colElem.setAttribute( "table:default-cell-style-name", "Default" );
+    colElem.setAttribute( "table:default-cell-style-name", "Default" );//todo fixme create style from cell
     if ( hide )
       colElem.setAttribute( "table:visibility", "collapse" );
 
@@ -597,7 +609,7 @@ void OpenCalcExport::exportSheet( QDomDocument & doc, QDomElement & tabElem,
 
   for ( i = 1; i <= maxRows; ++i )
   {
-    RowFormat const * const row = sheet->rowFormat( i );
+    const RowFormat * row = sheet->rowFormat( i );
     RowStyle rs;
     rs.breakB = Style::automatic;
     rs.size   = row->mmHeight() / 10;
@@ -614,14 +626,14 @@ void OpenCalcExport::exportSheet( QDomDocument & doc, QDomElement & tabElem,
 }
 
 void OpenCalcExport::exportCells( QDomDocument & doc, QDomElement & rowElem,
-                                  KSpreadSheet const * const sheet, int row, int maxCols )
+                                  const KSpreadSheet *sheet, int row, int maxCols )
 {
   int i = 1;
   while ( i <= maxCols )
   {
     int  repeated = 1;
     bool hasComment = false;
-    KSpreadCell const * const cell = sheet->cellAt( i, row );
+    const KSpreadCell* cell = sheet->cellAt( i, row );
     QDomElement cellElem;
 
     if ( !cell->isObscuringForced() )
@@ -651,7 +663,7 @@ void OpenCalcExport::exportCells( QDomDocument & doc, QDomElement & rowElem,
       int j = i + 1;
       while ( j <= maxCols )
       {
-        KSpreadCell const * const cell1 = sheet->cellAt( j, row );
+        const KSpreadCell *cell1 = sheet->cellAt( j, row );
 
         CellStyle c1;
         CellStyle::loadData( c1, cell1 ); // TODO: number style
@@ -676,9 +688,9 @@ void OpenCalcExport::exportCells( QDomDocument & doc, QDomElement & rowElem,
     else if ( value.isNumber() )
     {
       kdDebug(30518) << "Type: Number" << endl;
-      KSpreadFormat::FormatType type = cell->getFormatType( i, row );
+      FormatType type = cell->getFormatType( i, row );
 
-      if ( type == KSpreadFormat::Percentage )
+      if ( type == Percentage_format )
         cellElem.setAttribute( "table:value-type", "percentage" );
       else
         cellElem.setAttribute( "table:value-type", "float" );
@@ -697,6 +709,30 @@ void OpenCalcExport::exportCells( QDomDocument & doc, QDomElement & rowElem,
       QString formula( convertFormula( cell->text() ) );
       cellElem.setAttribute( "table:formula", formula );
     }
+    else if ( !cell->link().isEmpty() )
+    {
+      QDomElement link = doc.createElement( "text:p" );
+      QDomElement linkref = doc.createElement( "text:a" );
+
+      QString tmp = cell->link();
+       if ( localReferenceAnchor( tmp ) )
+           linkref.setAttribute( "xlink:href", ( "#"+tmp ) );
+       else
+           linkref.setAttribute( "xlink:href", tmp  );
+
+       linkref.appendChild( doc.createTextNode( cell->text() ) );
+
+       link.appendChild( linkref );
+       cellElem.appendChild( link );
+    }
+    else if ( !cell->isEmpty() )
+    {
+      QDomElement textElem = doc.createElement( "text:p" );
+      textElem.appendChild( doc.createTextNode( cell->strOutText() ) );
+
+      cellElem.appendChild( textElem );
+      kdDebug(30518) << "Cell StrOut: " << cell->strOutText() << endl;
+    }
 
     if ( cell->isForceExtraCells() )
     {
@@ -721,22 +757,13 @@ void OpenCalcExport::exportCells( QDomDocument & doc, QDomElement & rowElem,
       cellElem.appendChild( annotation );
     }
 
-    if ( !cell->isEmpty() )
-    {
-      QDomElement textElem = doc.createElement( "text:p" );
-      textElem.appendChild( doc.createTextNode( cell->strOutText() ) );
-
-      cellElem.appendChild( textElem );
-      kdDebug(30518) << "Cell StrOut: " << cell->strOutText() << endl;
-    }
-
     rowElem.appendChild( cellElem );
 
     i += repeated;
   }
 }
 
-void OpenCalcExport::maxRowCols( KSpreadSheet const * const sheet,
+void OpenCalcExport::maxRowCols( const KSpreadSheet *sheet,
                                  int & maxCols, int & maxRows )
 {
   KSpreadCell const * cell = sheet->firstCell();
@@ -773,7 +800,7 @@ void OpenCalcExport::maxRowCols( KSpreadSheet const * const sheet,
 
 }
 
-bool OpenCalcExport::exportStyles( KoStore * store, KSpreadDoc const * const ksdoc )
+bool OpenCalcExport::exportStyles( KoStore * store, const KSpreadDoc *ksdoc )
 {
   if ( !store->open( "styles.xml" ) )
     return false;
@@ -846,7 +873,7 @@ void OpenCalcExport::exportDefaultCellStyle( QDomDocument & doc, QDomElement & o
   KSpreadDoc * ksdoc    = static_cast<KSpreadDoc *>(document);
 
   KSpreadFormat * format = new KSpreadFormat( 0, ksdoc->styleManager()->defaultStyle() );
-  KLocale const * const locale = ksdoc->locale();
+  const KLocale *locale = ksdoc->locale();
   QString language;
   QString country;
   QString charSet;
@@ -881,10 +908,10 @@ void OpenCalcExport::createDefaultStyles()
 }
 
 void OpenCalcExport::exportPageAutoStyles( QDomDocument & doc, QDomElement & autoStyles,
-                                           KSpreadDoc const * const ksdoc )
+                                           const KSpreadDoc *ksdoc )
 {
-  QPtrListIterator<KSpreadSheet> it( ksdoc->map()->tableList() );
-  KSpreadSheet const * const sheet = it.toFirst();
+  QPtrListIterator<KSpreadSheet> it( ksdoc->map()->sheetList() );
+  const KSpreadSheet * sheet = it.toFirst();
 
   float width  = 20.999;
   float height = 29.699;
@@ -935,14 +962,14 @@ void OpenCalcExport::exportPageAutoStyles( QDomDocument & doc, QDomElement & aut
 }
 
 void OpenCalcExport::exportMasterStyles( QDomDocument & doc, QDomElement & masterStyles,
-                                         KSpreadDoc const * const ksdoc )
+                                         const KSpreadDoc * ksdoc )
 {
   QDomElement masterPage = doc.createElement( "style:master-page" );
   masterPage.setAttribute( "style:name", "Default" );
   masterPage.setAttribute( "style:page-master-name", "pm1" );
 
-  QPtrListIterator<KSpreadSheet> it( ksdoc->map()->tableList() );
-  KSpreadSheet const * const sheet = it.toFirst();
+  QPtrListIterator<KSpreadSheet> it( ksdoc->map()->sheetList() );
+  const KSpreadSheet * sheet = it.toFirst();
 
   QString headerLeft;
   QString headerCenter;
@@ -1047,7 +1074,7 @@ void OpenCalcExport::addText( QString const & text, QDomDocument & doc,
 }
 
 void OpenCalcExport::convertPart( QString const & part, QDomDocument & doc,
-                                  QDomElement & parent, KSpreadDoc const * const ksdoc )
+                                  QDomElement & parent, const KSpreadDoc * ksdoc )
 {
   QString text;
   QString var;
@@ -1205,7 +1232,7 @@ QString OpenCalcExport::convertFormula( QString const & formula ) const
         decimalSymbol = decimal.at( 0 );
     }
   }
-  
+
   QString s;
   QRegExp exp("(\\$?)([a-zA-Z]+)(\\$?)([0-9]+)");
   int n = exp.search( formula, 0 );
