@@ -26,6 +26,8 @@
 #include <koFilter.h>
 #include <qptrlist.h>
 
+class KLocale;
+
 class KoStore;
 class KSpreadDoc;
 class KSpreadSheet;
@@ -48,30 +50,30 @@ class OpenCalcExport : public KoFilter
   enum files { metaXML = 0x01, contentXML = 0x02, stylesXML = 0x04, settingsXML = 0x08 };
   OpenCalcStyles m_styles;
 
-  bool writeFile( KSpreadDoc const * const ksdoc );
+  bool writeFile( const KSpreadDoc * ksdoc );
 
-  bool exportDocInfo( KoStore * store, KSpreadDoc const * const ksdoc );
-  bool exportStyles ( KoStore * store, KSpreadDoc const * const ksdoc );
-  bool exportContent( KoStore * store, KSpreadDoc const * const ksdoc );
+  bool exportDocInfo( KoStore * store, const KSpreadDoc * ksdoc );
+  bool exportStyles ( KoStore * store, const KSpreadDoc * ksdoc );
+  bool exportContent( KoStore * store, const KSpreadDoc * ksdoc );
     bool exportSettings( KoStore * store, const KSpreadDoc * ksdoc );
 
-  bool exportBody( QDomDocument & doc, QDomElement & content, KSpreadDoc const * const ksdoc );
+  bool exportBody( QDomDocument & doc, QDomElement & content, const KSpreadDoc * ksdoc );
   void exportSheet( QDomDocument & doc, QDomElement & tabElem,
-                    KSpreadSheet const * const sheet, int maxCols, int maxRows );
+                    const KSpreadSheet * sheet, int maxCols, int maxRows );
   void exportCells( QDomDocument & doc, QDomElement & rowElem,
-                    KSpreadSheet const * const sheet, int row, int maxCols );
+                    const KSpreadSheet * sheet, int row, int maxCols );
   void exportDefaultCellStyle( QDomDocument & doc, QDomElement & officeStyles );
   void exportPageAutoStyles( QDomDocument & doc, QDomElement & autoStyles,
-                             KSpreadDoc const * const ksdoc );
+                             const KSpreadDoc * ksdoc );
   void exportMasterStyles( QDomDocument & doc, QDomElement & masterStyles,
-                           KSpreadDoc const * const ksdoc );
+                           const KSpreadDoc *ksdoc );
 
   bool writeMetaFile( KoStore * store, uint filesWritten );
 
-  void maxRowCols( KSpreadSheet const * const sheet,
+  void maxRowCols( const KSpreadSheet * sheet,
                    int & maxCols, int & maxRows );
   void convertPart( QString const & part, QDomDocument & doc,
-                    QDomElement & parent, KSpreadDoc const * const ksdoc );
+                    QDomElement & parent, const KSpreadDoc * ksdoc );
   void addText( QString const & text, QDomDocument & doc,
                 QDomElement & parent );
 
