@@ -1,7 +1,7 @@
-// $Header: /home/kde/koffice/filters/kword/abiword/abiwordexport.cc,v 1.80.2.1 2002/09/02 08:32:59 mlaurent Exp $
+//
 
 /* This file is part of the KDE project
-   Copyright (C) 2001, 2002 Nicolas GOUTTE <nicog@snafu.de>
+   Copyright (C) 2001, 2002, 2003, 2004 Nicolas GOUTTE <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -33,11 +33,7 @@
 */
 
 #include <qmap.h>
-#include <qregexp.h>
 #include <qiodevice.h>
-#include <qbuffer.h>
-#include <qimage.h>
-#include <qpicture.h>
 #include <qtextstream.h>
 #include <qdom.h>
 
@@ -47,7 +43,7 @@
 #include <kgenericfactory.h>
 #include <kimageio.h>
 
-#include <koGlobal.h>
+#include <koPageLayout.h>
 #include <koFilterChain.h>
 #include <koPictureKey.h>
 
@@ -59,8 +55,19 @@
 #include <abiwordexport.h>
 #include <abiwordexport.moc>
 
-typedef KGenericFactory<ABIWORDExport, KoFilter> ABIWORDExportFactory;
-K_EXPORT_COMPONENT_FACTORY( libabiwordexport, ABIWORDExportFactory( "kwordabiwordexport" ) );
+class ABIWORDExportFactory : KGenericFactory<ABIWORDExport, KoFilter>
+{
+public:
+    ABIWORDExportFactory(void) : KGenericFactory<ABIWORDExport, KoFilter> ("kwordabiwordexport")
+    {}
+protected:
+    virtual void setupTranslations( void )
+    {
+        KGlobal::locale()->insertCatalogue( "kofficefilters" );
+    }
+};
+
+K_EXPORT_COMPONENT_FACTORY( libabiwordexport, ABIWORDExportFactory() )
 
 class StyleMap : public QMap<QString,LayoutData>
 {
@@ -73,7 +80,7 @@ class AbiWordWorker : public KWEFBaseWorker
 {
 public:
     AbiWordWorker(void);
-    virtual ~AbiWordWorker(void) { delete m_streamOut;}
+    virtual ~AbiWordWorker(void) { delete m_streamOut; delete m_ioDevice; }
 public:
     virtual bool doOpenFile(const QString& filenameOut, const QString& to);
     virtual bool doCloseFile(void); // Close file in normal conditions
@@ -94,6 +101,7 @@ public:
     virtual bool doOpenSpellCheckIgnoreList (void); // AbiWord's <ignorewords>
     virtual bool doCloseSpellCheckIgnoreList (void); // AbiWord's </ignorewords>
     virtual bool doFullSpellCheckIgnoreWord (const QString& ignoreword); // AbiWord's <iw>
+    virtual bool doFullDocumentInfo(const KWEFDocumentInfo& docInfo); // AbiWord's <metadata>
 private:
     void processParagraphData (const QString& paraText,
         const TextFormatting& formatLayout,
@@ -112,14 +120,11 @@ private:
     QString layoutToCss(const LayoutData& layoutOrigin,
         const LayoutData& layout, const bool force) const;
     QString escapeAbiWordText(const QString& strText) const;
-    bool makeImage(const FrameAnchor& anchor, const bool isImage);
-    bool convertUnknownImage(const QString& name, QByteArray& image);
+    bool makeTable(const FrameAnchor& anchor);
+    bool makePicture(const FrameAnchor& anchor);
     void writeAbiProps(const TextFormatting& formatLayout, const TextFormatting& format);
-    void writeImageData(const QString& koStoreName, const QString& keyName);
-    void writeClipartData(const QString& koStoreName, const QString& keyName);
-    void writeSvgData(const QString& koStoreName, const QString& keyName);
     void writePictureData(const QString& koStoreName, const QString& keyName);
-
+    QString transformToTextDate(const QDateTime& dt);
 private:
     QIODevice* m_ioDevice;
     QTextStream* m_streamOut;
@@ -128,6 +133,7 @@ private:
     StyleMap m_styleMap;
     double m_paperBorderTop,m_paperBorderLeft,m_paperBorderBottom,m_paperBorderRight;
     bool m_inIgnoreWords; // true if <ignorewords> has been written
+    KWEFDocumentInfo m_docInfo; // document information
 };
 
 AbiWordWorker::AbiWordWorker(void) : m_ioDevice(NULL), m_streamOut(NULL),
@@ -167,10 +173,6 @@ bool AbiWordWorker::doOpenFile(const QString& filenameOut, const QString& )
         ||(strExt==".bzabw")||(strExt==".BZABW")) //in case of .bzabw (extension used prioritary with AbiWord)
     {
         // Compressed with bzip2
-
-        // It seems that bzip2-compressed AbiWord files were planned
-        //   but AbiWord CVS 2001-12-15 does not have import and export filters for them anymore.
-        //   We leave this code but leave the .desktop file without bzip2 files
         strMimeType="application/x-bzip2";
     }
     else
@@ -196,12 +198,6 @@ bool AbiWordWorker::doOpenFile(const QString& filenameOut, const QString& )
     }
 
     m_streamOut=new QTextStream(m_ioDevice);
-    if (!m_ioDevice)
-    {
-        kdError(30506) << "Could not create output stream! Aborting!" << endl;
-        m_ioDevice->close();
-        return false;
-    }
 
     // We only export in UTF-8 (are there AbiWord ports that cannot read UTF-8? Be careful SVG uses UTF-8 too!)
     m_streamOut->setEncoding( QTextStream::UnicodeUTF8 );
@@ -210,6 +206,8 @@ bool AbiWordWorker::doOpenFile(const QString& filenameOut, const QString& )
 
 bool AbiWordWorker::doCloseFile(void)
 {
+    delete m_streamOut;
+    m_streamOut=NULL;
     if (m_ioDevice)
         m_ioDevice->close();
     return (m_ioDevice);
@@ -217,6 +215,7 @@ bool AbiWordWorker::doCloseFile(void)
 
 bool AbiWordWorker::doOpenDocument(void)
 {
+    kdDebug(30506)<< "AbiWordWorker::doOpenDocument" << endl;
     // Make the file header
 
     // First the XML header in UTF-8 version
@@ -234,77 +233,28 @@ bool AbiWordWorker::doOpenDocument(void)
     // As we do not use xmlns:awml, do we need to define it?
     // *m_streamOut << " xmlns:awml=\"http://www.abisource.com/awml.dtd\"";
     *m_streamOut << " xmlns:xlink=\"http://www.w3.org/1999/xlink\"";
-    // AbiWord CVS 2002-02-22 defines other namesapces, which we are not using.
-    *m_streamOut << " version=\"\" fileformat=\"1.0\" styles=\"unlocked\">\n";
+    // AbiWord CVS 2002-02-22 defines other namespaces, which we are not using.
+    // AbiWord CVS 2002-12-23 has no fileformat attribute anymore
+    // ### TODO: add document language and document direction of writing.
+    *m_streamOut << " xml:space=\"preserve\" version=\"1.1.2\" template=\"false\" styles=\"unlocked\">\n";
     // Second magic: "<!-- This file is an AbiWord document."
     // TODO/FIXME: write as much spaces as AbiWord does for the following line.
     *m_streamOut << "<!-- This file is an AbiWord document. -->\n";
     // We have chosen NOT to have the full comment header that AbiWord files normally have.
+    // ### TODO: perhaps we should add the comment: do not edit the file
     *m_streamOut << "\n";
 
-    // Put the rest of the information in the way AbiWord puts its debug info!
-
-    // Say who we are (with the CVS revision number) in case we have a bug in our filter output!
-    *m_streamOut << "<!-- KWord_Export_Filter_Version =";
-
-    QString strVersion("$Revision: 1.80.2.1 $");
-    // Remove the dollar signs
-    //  (We don't want that the version number changes if the AbiWord file is itself put in a CVS storage.)
-    *m_streamOut << strVersion.mid(10).replace(QRegExp("\\$"),""); // Note: double escape character (one for C++, one for QRegExp!)
-
-    *m_streamOut << " -->\n\n";
 
     return true;
 }
 
-bool AbiWordWorker::convertUnknownImage(const QString& strName, QByteArray& image)
+void AbiWordWorker::writePictureData(const QString& koStoreName, const QString& keyName)
 {
-    QIODevice* io=getSubFileDevice(strName);
-    if (!io)
-    {
-        // NO message error, as there must be already one
-        return false;
-    }
-
-    kdDebug(30506) << "Image " << strName << " has size: " << io->size() << endl;
-
-    QImageIO imageIO(io,NULL);
-
-    if (!imageIO.read())
-    {
-        kdWarning(30506) << "Could not read image: " << strName << " (AbiWordWorker::convertUnknownImage)" << endl;
-        return false;
-    }
-
-    kdDebug(30506) << "Image: " << strName << " (AbiWordWorker::convertUnknownImage)" << endl;
-
-    QBuffer buffer(image); // A QBuffer is a QIODevice
-    if (!buffer.open(IO_WriteOnly))
-    {
-        kdWarning(30506) << "Could not open buffer! (AbiWordWorker::convertUnknownImage)" << endl;
-        return false;
-    }
-
-    imageIO.setIODevice(&buffer);
-    imageIO.setFormat("PNG");
-
-    if (!imageIO.write())
-    {
-        kdWarning(30506) << "Could not write converted image! (AbiWordWorker::convertUnknownImage)" << endl;
-        return false;
-    }
-    buffer.close();
-
-    return true;
-}
-
-void AbiWordWorker::writeImageData(const QString& koStoreName, const QString& keyName)
-{
-    kdDebug(30506) << "Picture is Image " << endl;
+    kdDebug(30506) << "AbiWordWorker::writeImageData" << endl;
 
     QByteArray image;
 
-    QString strExtension(koStoreName);
+    QString strExtension(koStoreName.lower());
     const int result=koStoreName.findRev(".");
     if (result>=0)
     {
@@ -313,26 +263,22 @@ void AbiWordWorker::writeImageData(const QString& koStoreName, const QString& ke
 
     bool isImageLoaded=false;
 
-    QString strMime;
-
     if (strExtension=="png")
     {
-        strMime="image/png";
-        isImageLoaded=loadKoStoreFile(koStoreName,image);
+        isImageLoaded=loadSubFile(koStoreName,image);
     }
     else
     {
-        // All other image types must be converted to PNG
-        //   (yes, even JPEG!)
-        strMime="image/png";
-        isImageLoaded=convertUnknownImage(koStoreName,image);
+        // All other picture types must be converted to PNG
+        //   (yes, even JPEG, SVG or WMF!)
+        isImageLoaded=loadAndConvertToImage(koStoreName,strExtension,"PNG",image);
     }
 
     if (isImageLoaded)
     {
         *m_streamOut << "<d name=\"" << keyName << "\""
             << " base64=\"yes\""
-            << " mime=\"" << strMime << "\">\n";
+            << " mime=\"image/png\">\n";
 
         QCString base64=KCodecs::base64Encode(image,true);
 
@@ -342,116 +288,10 @@ void AbiWordWorker::writeImageData(const QString& koStoreName, const QString& ke
     }
     else
     {
-        kdWarning(30506) << "Unable to load image: " << koStoreName << endl;
+        kdWarning(30506) << "Unable to load picture: " << koStoreName << endl;
     }
 }
 
-void AbiWordWorker::writeClipartData(const QString& koStoreName, const QString& keyName)
-{
-    // We must always convert the image to SVG
-    QString strMime="image/svg-xml"; // Yes, it is -xml not +xml
-
-    kdDebug(30506) << "Picture is QPicture " << koStoreName << endl;
-
-    QPicture picture;
-
-    QIODevice* io=getSubFileDevice(koStoreName);
-    if (!io)
-    {
-        // NO message error, as there must be already one
-        return;
-    }
-
-    if (picture.load(io,NULL))
-    {
-        *m_streamOut << "<d name=\"" << keyName << "\""
-            << " base64=\"no\""
-            << " mime=\"" << strMime << "\">\n"
-            << "<![CDATA["; // Open CDATA section
-        // Do not add a new line after <![CDATA[ (No white space before a XML declaration)
-        // TODO/FIXME. aarrgghh, we cannot have a XML declaration at all!
-
-        // Save picture as SVG
-
-        // Not sure what is better: call the QIODevice directly or through QTextStream::device()?
-        // QPicture::save saves in UTF-8, so we have no problem!
-        // TODO/FIXME. aarrgghh, we cannot have a XML declaration at all!
-        if (!picture.save(m_streamOut->device(),"svg"))
-        {
-            kdWarning(30506) << "Could not save clipart: "  << koStoreName << endl;
-        }
-
-        *m_streamOut << "]]>\n" // Close CDATA section
-            << "</d>\n";
-    }
-    else
-    {
-        kdWarning(30506) << "Unable to load clipart: " << koStoreName << endl;
-    }
-}
-
-void AbiWordWorker::writeSvgData(const QString& koStoreName, const QString& keyName)
-{
-    QByteArray svg;
-    QString strMime="image/svg-xml"; // Yes, it is -xml not +xml
-
-    kdDebug(30506) << "Picture is SVG" << endl;
-
-    if (!loadKoStoreFile(koStoreName,svg))
-    {
-        // NO message error, as there must be already one
-        return;
-    }
-
-    QDomDocument svgDoc;
-    if (!svgDoc.setContent(svg))
-    {
-        kdWarning(30506) << "Parsing of SVG failed..." << endl;
-        return; // TODO: full error line/column/message
-    }
-
-    *m_streamOut << "<d name=\"" << keyName << "\""
-        << " base64=\"no\""
-        << " mime=\"" << strMime << "\">\n"
-        << "<![CDATA["; // Open CDATA section
-
-    // Do not add a new line after <![CDATA[ (No white space before a XML declaration)
-    // TODO/FIXME. aarrgghh, we cannot have a XML declaration at all!
-    *m_streamOut << svgDoc;
-
-    *m_streamOut << "]]>\n" // Close CDATA section
-        << "</d>\n";
-}
-
-void AbiWordWorker::writePictureData(const QString& koStoreName, const QString& keyName)
-{
-    kdDebug(30506) << "Picture " << koStoreName << endl;
-    QString strExtension(koStoreName);
-    const int result=koStoreName.findRev(".");
-    if (result>=0)
-    {
-        strExtension=koStoreName.mid(result+1).lower();
-    }
-
-    if (strExtension=="wmf")
-    {
-        kdDebug(30506) << "Type " << strExtension << " not supported!" << endl;
-    }
-    else if (strExtension=="svg")
-    {
-        writeSvgData(koStoreName,keyName);
-    }
-    else if (strExtension=="qpic")
-    {
-        writeClipartData(koStoreName,keyName);
-    }
-    else
-    {
-        writeImageData(koStoreName,keyName);
-    }
-}
-
-
 bool AbiWordWorker::doCloseDocument(void)
 {
     // Before writing the <data> element,
@@ -467,8 +307,7 @@ bool AbiWordWorker::doCloseDocument(void)
         for (it=m_mapPictureData.begin(); it!=m_mapPictureData.end(); it++)
         {
             // Warning: do not mix up KWord's key and the iterator's key!
-            writeImageData(it.key(),it.data().filename());
-            writeClipartData(it.key(),it.data().filename());
+            writePictureData(it.key(),it.data().filename());
         }
 
         *m_streamOut << "</data>\n";
@@ -527,7 +366,7 @@ QString AbiWordWorker::textFormatToAbiProps(const TextFormatting& formatOrigin,
         && (force || (formatOrigin.fontName!=formatData.fontName)))
     {
         strElement+="font-family: ";
-        strElement+=fontName; // TODO: add alternative font names
+        strElement+= escapeAbiWordText(fontName); // TODO: add alternative font names
         strElement+="; ";
     }
 
@@ -644,16 +483,53 @@ QString AbiWordWorker::textFormatToAbiProps(const TextFormatting& formatOrigin,
     return strElement;
 }
 
-bool AbiWordWorker::makeImage(const FrameAnchor& anchor, const bool isImage)
+bool AbiWordWorker::makeTable(const FrameAnchor& anchor)
+{
+#if 0
+    *m_streamOut << "</p>\n"; // Close previous paragraph ### TODO: do it correctly like for HTML
+    *m_streamOut << "<table>\n";
+#endif
+
+    QValueList<TableCell>::ConstIterator itCell;
+    for (itCell=anchor.table.cellList.begin();
+        itCell!=anchor.table.cellList.end(); itCell++)
+    {
+#if 0
+        // ### TODO: rowspan, colspan
+
+        // AbiWord seems to work by attaching to the cell borders
+        *m_streamOut << "<cell props=\"";
+        *m_streamOut << "left-attach:" << (*itCell).col << "; ";
+        *m_streamOut << "right-attach:" << (*itCell).col + 1 << "; ";
+        *m_streamOut << "top-attach:" << (*itCell).row << "; ";
+        *m_streamOut << "bot-attach:" << (*itCell).row + 1;
+        *m_streamOut << "\">\n";
+#endif
+        if (!doFullAllParagraphs(*(*itCell).paraList))
+        {
+            return false;
+        }
+#if 0
+        *m_streamOut << "</cell>\n";
+#endif
+    }
+#if 0
+    *m_streamOut << "</table>\n";
+    *m_streamOut << "<p>\n"; // Re-open the "previous" paragraph ### TODO: do it correctly like for HTML
+#endif
+    return true;
+}
+
+bool AbiWordWorker::makePicture(const FrameAnchor& anchor)
 {
     kdDebug(30506) << "New image/clipart: " << anchor.picture.koStoreName
-        << " , " << anchor.picture.key.toString() << " (is image:" << isImage << ")" <<endl;
+        << " , " << anchor.picture.key.toString() << endl;
 
-    const double height=anchor.bottom - anchor.top;
-    const double width =anchor.right  - anchor.left;
+    const double height=anchor.frame.bottom - anchor.frame.top;
+    const double width =anchor.frame.right  - anchor.frame.left;
 
     // TODO: we are only using the filename, not the rest of the key
-    // TODO:  (bad if they are two images of the same name, but of different key)
+    // TODO:  (bad if there are two images of the same name, but of a different key)
     *m_streamOut << "<image dataid=\"" << anchor.picture.key.filename() << "\"";
     *m_streamOut << " props= \"height:" << height << "pt;width:" << width << "pt\"";
     *m_streamOut << "/>"; // NO end of line!
@@ -763,6 +639,31 @@ void AbiWordWorker::processVariable ( const QString&,
             << escapeAbiWordText(formatData.variable.getLinkName())
             << "</c></a>";
     }
+#if 0
+                else if (11==(*paraFormatDataIt).variable.m_type)
+                {
+                    // Footnote
+                    QString value = (*paraFormatDataIt).variable.getFootnoteValue();
+                    bool automatic = (*paraFormatDataIt).variable.getFootnoteAuto();
+                    QValueList<ParaData> *paraList = (*paraFormatDataIt).variable.getFootnotePara();
+                    if( paraList )
+                    {
+                        QString fstr;
+                        QValueList<ParaData>::ConstIterator it;
+                        for (it=paraList->begin();it!=paraList->end();it++)
+                            fstr += ProcessParagraphData( (*it).text, (*it).layout,(*it).formattingList);
+                        str += "{\\super ";
+                        str += automatic ? "\\chftn " : value;
+                        str += "{\\footnote ";
+                        str += "{\\super ";
+                        str += automatic ? "\\chftn " : value;
+                        str += fstr;
+                        str += " }";
+                        str += " }";
+                        str += " }";
+                    }
+                }
+#endif
     else
     {
         // Generic variable
@@ -775,14 +676,14 @@ void AbiWordWorker::processAnchor ( const QString&,
     const FormatData& formatData)
 {
     // We have an image or a table
-    // However, AbiWord does not support tables
-    if (2==formatData.frameAnchor.type)
-    {   // <IMAGE>
-        makeImage(formatData.frameAnchor,true);
+    if ( (2==formatData.frameAnchor.type) // <IMAGE> or <PICTURE>
+        || (5==formatData.frameAnchor.type) ) // <CLIPART>
+    {
+        makePicture(formatData.frameAnchor);
     }
-    else if (5==formatData.frameAnchor.type)
-    {   // <CLIPART>
-        makeImage(formatData.frameAnchor,false);
+    else if (6==formatData.frameAnchor.type)
+    {
+        makeTable(formatData.frameAnchor);
     }
     else
     {
@@ -905,43 +806,79 @@ QString AbiWordWorker::layoutToCss(const LayoutData& layoutOrigin,
     {
         props += "text-indent: ";
         props += QString::number(layout.indentFirst);
-        props += "; ";
+        props += "pt; ";
     }
 
     if ((layout.marginBottom>=0.0)
-        && (force || (layoutOrigin.indentRight!=layout.indentRight)))
+        && ( force || ( layoutOrigin.marginBottom != layout.marginBottom ) ) )
     {
        props += QString("margin-bottom:%1pt; ").arg(layout.marginBottom);
     }
 
     if ((layout.marginTop>=0.0)
-        && (force || (layoutOrigin.indentRight!=layout.indentRight)))
+        && ( force || ( layoutOrigin.marginTop != layout.marginTop ) ) )
     {
        props += QString("margin-top:%1pt; ").arg(layout.marginTop);
     }
 
-    if (!force
-        && (layoutOrigin.lineSpacingType==layoutOrigin.lineSpacingType)
-        && (layoutOrigin.lineSpacing==layoutOrigin.lineSpacing))
+    if (force
+        || ( layoutOrigin.lineSpacingType != layout.lineSpacingType )
+        || ( layoutOrigin.lineSpacing != layout.lineSpacing ) )
     {
-        // Do nothing!
-    }
-    else if (!layout.lineSpacingType)
-    {
-        // We have a custom line spacing (in points)
-        props += QString("line-height:%1pt; ").arg(layout.lineSpacing);
-    }
-    else if ( 15==layout.lineSpacingType  )
-    {
-        props += "line-height:1.5; "; // One-and-half
-    }
-    else if ( 20==layout.lineSpacingType  )
-    {
-        props += "line-height:2.0; "; // Two
-    }
-    else if ( layout.lineSpacingType!=10  )
-    {
-        kdWarning(30506) << "Curious lineSpacingType: " << layout.lineSpacingType << " (Ignoring!)" << endl;
+        switch ( layout.lineSpacingType )
+        {
+        case LayoutData::LS_CUSTOM:
+            {
+                // We have a custom line spacing (in points). However AbiWord cannot do it, so transform in "at-least"
+                props += "line-height=:";
+                props += QString::number( layout.lineSpacing ); // ### TODO: rounding?
+                props += "pt+; ";
+                break;
+            }
+        case LayoutData::LS_SINGLE:
+            {
+                props += "line-height:1.0; "; // One
+                break;
+            }
+        case LayoutData::LS_ONEANDHALF:
+            {
+                props += "line-height:1.5; "; // One-and-half
+                break;
+            }
+        case LayoutData::LS_DOUBLE:
+            {
+                props += "line-height:2.0; "; // Two
+                break;
+            }
+        case LayoutData::LS_MULTIPLE:
+            {
+                props += "line-height:";
+                props += QString::number( layout.lineSpacing ); // ### TODO: rounding?
+                props += "; ";
+                break;
+            }
+        case LayoutData::LS_FIXED:
+            {
+                // We have a fixed line height (in points)
+                props += "line-height:";
+                props += QString::number( layout.lineSpacing ); // ### TODO: rounding?
+                props += "pt; ";
+                break;
+            }
+        case LayoutData::LS_ATLEAST:
+            {
+                // We have an "at-least" line height (in points)
+                props += "line-height=:";
+                props += QString::number( layout.lineSpacing ); // ### TODO: rounding?
+                props += "pt+; "; // The + makes the difference
+                break;
+            }
+        default:
+            {
+                kdWarning(30506) << "Unsupported lineSpacingType: " << layout.lineSpacingType << " (Ignoring!)" << endl;
+                break;
+            }
+        }
     }
 
     // Add all AbiWord properties collected in the <FORMAT> element
@@ -1174,6 +1111,116 @@ bool AbiWordWorker::doFullSpellCheckIgnoreWord (const QString& ignoreword)
     return true;
 }
 
+// Similar to QDateTime::toString, but guaranteed *not* to be translated
+QString AbiWordWorker::transformToTextDate(const QDateTime& dt)
+{
+    if (dt.isValid())
+    {
+        QString result;
+
+        const QDate date(dt.date());
+
+        const char* dayName[7] = { "Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun" };
+        const int dow = date.dayOfWeek() - 1;
+        if ((dow<0) || (dow>6))
+            result += "Mon"; // Unknown day, rename it Monday.
+        else
+            result += dayName[dow];
+        result += ' ';
+
+        const char* monthName[12] = { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
+        const int month = date.month() - 1;
+        if ((month<0) || (month>11))
+            result += "Jan"; // Unknown month, rename it January
+        else
+            result += monthName[month];
+        result += ' ';
+
+        QString temp;
+
+        temp = "00";
+        temp += QString::number(date.day(), 10);
+        result += temp.right(2);
+        result += ' ';
+
+        const QTime time(dt.time());
+
+        temp = "00";
+        temp += QString::number(time.hour(), 10);
+        result += temp.right(2);
+        result += ':';
+
+        temp = "00";
+        temp += QString::number(time.minute(), 10);
+        result += temp.right(2);
+        result += ':';
+
+        temp = "00";
+        temp += QString::number(time.second(), 10);
+        result += temp.right(2);
+        result += ' ';
+
+        temp = "0000";
+        temp += QString::number(date.year(), 10);
+        result += temp.right(4);
+
+        return result;
+    }
+    else
+    {
+        // Invalid, so give back 1970-01-01
+        return "Thu Jan 01 00:00:00 1970";
+    }
+}
+
+bool AbiWordWorker::doFullDocumentInfo(const KWEFDocumentInfo& docInfo)
+{
+    m_docInfo=docInfo;
+
+    *m_streamOut << "<metadata>\n";
+
+    // First all Dublin Core data
+    *m_streamOut << "<m key=\"dc.format\">application/x-abiword</m>\n";
+    if (!m_docInfo.title.isEmpty())
+    {
+        *m_streamOut << "<m key=\"dc.title\">" << escapeAbiWordText(m_docInfo.title) << "</m>\n";
+    }
+    if (!m_docInfo.abstract.isEmpty())
+    {
+        *m_streamOut << "<m key=\"dc.description\">" << escapeAbiWordText(m_docInfo.abstract) << "</m>\n";
+    }
+
+    if ( !m_docInfo.keywords.isEmpty() )
+    {
+        *m_streamOut << "<m key=\"abiword.keywords\">" << escapeAbiWordText(m_docInfo.keywords) << "</m>\n";
+    }
+    if ( !m_docInfo.subject.isEmpty() )
+    {
+        *m_streamOut << "<m key=\"dc.subject\">" << escapeAbiWordText(m_docInfo.subject) << "</m>\n";
+    }
+
+    // Say who we are (with the CVS revision number) in case we have a bug in our filter output!
+    *m_streamOut << "<m key=\"abiword.generator\">KWord Export Filter";
+
+    QString strVersion("$Revision: 388669 $");
+    // Remove the dollar signs
+    //  (We don't want that the version number changes if the AbiWord file is itself put in a CVS storage.)
+    *m_streamOut << strVersion.mid(10).remove('$');
+
+    *m_streamOut << "</m>\n";
+
+    QDateTime now (QDateTime::currentDateTime(Qt::UTC)); // current time in UTC
+    *m_streamOut << "<m key=\"abiword.date_last_changed\">"
+         << escapeAbiWordText(transformToTextDate(now))
+         << "</m>\n";
+
+    *m_streamOut << "</metadata>\n";
+
+    return true;
+}
+
+
+// ==========================================================================================
 
 ABIWORDExport::ABIWORDExport(KoFilter */*parent*/, const char */*name*/, const QStringList &) :
                      KoFilter() {
