@@ -1,8 +1,8 @@
-// $Header: /home/kde/koffice/filters/kword/ascii/ExportDialog.h,v 1.4 2002/12/31 12:30:29 goutte Exp $
+// 
 
 /*
    This file is part of the KDE project
-   Copyright (C) 2001 Nicolas GOUTTE <goutte@kde.org>
+   Copyright (C) 2001, 2004 Nicolas GOUTTE <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -40,8 +40,6 @@ public:
     QTextCodec* getCodec(void) const;
 private:
     ExportDialogUI* m_dialog;
-private slots:
-    void comboBoxEncodingActivated(int);
 };
 
 #endif /* EXPORT_DIALOG_H */
