@@ -1,10 +1,10 @@
-// $Header: /home/kde/koffice/filters/kword/ascii/asciiexport.cc,v 1.42 2003/12/12 22:18:39 goutte Exp $
+// 
 
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
    Copyright (c) 2000 ID-PRO Deutschland GmbH. All rights reserved.
                       Contact: Wolf-Michael Bolle <Bolle@ID-PRO.de>
-   Copyright (C) 2001, 2002 Nicolas GOUTTE <goutte@kde.org>
+   Copyright (C) 2001, 2002, 2004 Nicolas GOUTTE <goutte@kde.org>
    Copyright (C) 2003 Clarence Dang <dang@kde.org>
 
    This library is free software; you can redistribute it and/or
@@ -37,6 +37,7 @@
 #include <kgenericfactory.h>
 
 #include <koFilterChain.h>
+#include <koFilterManager.h>
 #include <koStore.h>
 
 #include <KWEFStructures.h>
@@ -57,7 +58,7 @@ public:
 protected:
     virtual void setupTranslations(void)
     {
-        KGlobal::locale()->insertCatalogue("kwordasciifilter");
+        KGlobal::locale()->insertCatalogue("kofficefilters");
     }
 };
 
@@ -134,7 +135,7 @@ bool ASCIIWorker::doOpenFile(const QString& filenameOut, const QString& /*to*/)
     }
 
     m_streamOut = new QTextStream(m_ioDevice);
-    if (!m_ioDevice)
+    if (!m_streamOut)
     {
         kdError(30502) << "Could not create output stream! Aborting!" << endl;
         m_ioDevice->close();
@@ -442,21 +443,22 @@ KoFilter::ConversionStatus ASCIIExport::convert(const QCString& from, const QCSt
     {
         return KoFilter::NotImplemented;
     }
-
-    AsciiExportDialog* dialog = new AsciiExportDialog();
-
-    if (!dialog)
+    AsciiExportDialog* dialog = 0;
+    if (!m_chain->manager()->getBatchMode())
     {
-        kdError(30502) << "Dialog has not been created! Aborting!" << endl;
-        return KoFilter::StupidError;
+      dialog = new AsciiExportDialog();
+      if (!dialog)
+      {
+	kdError(30502) << "Dialog has not been created! Aborting!" << endl;
+	return KoFilter::StupidError;
+      }
+      
+      if (!dialog->exec())
+      {
+	kdError(30502) << "Dialog was aborted! Aborting filter!" << endl;
+	return KoFilter::UserCancelled;
+      }
     }
-
-    if (!dialog->exec())
-    {
-        kdError(30502) << "Dialog was aborted! Aborting filter!" << endl;
-        return KoFilter::UserCancelled;
-    }
-
     ASCIIWorker* worker = new ASCIIWorker();
 
     if (!worker)
@@ -465,9 +467,24 @@ KoFilter::ConversionStatus ASCIIExport::convert(const QCString& from, const QCSt
         delete dialog;
         return KoFilter::StupidError;
     }
+    QTextCodec* codec;
+    if (dialog)
+    	codec = dialog->getCodec();
+    else
+        codec = QTextCodec::codecForName("UTF-8");
+    
+    if ( !codec )
+    {
+        kdError(30502) << "No codec!" << endl;
+        delete dialog;
+        return KoFilter::StupidError;
+    }
 
-    worker->setCodec(dialog->getCodec());
-    worker->setEndOfLine(dialog->getEndOfLine());
+    worker->setCodec( codec );
+    if (dialog)
+    	worker->setEndOfLine(dialog->getEndOfLine());
+    else
+        worker->setEndOfLine("\n");
 
     delete dialog;
 
