@@ -1,9 +1,9 @@
-// $Id: asciiimport.cc,v 1.39 2003/08/16 12:22:48 mueller Exp $
+//
 
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
    Copyright (C) 2000 Michael Johnson <mikej@xnet.com>
-   Copyright (C) 2001, 2002 Nicolas GOUTTE <goutte@kde.org>
+   Copyright (C) 2001, 2002, 2004 Nicolas GOUTTE <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,7 +29,7 @@
 
 #include <qobject.h>
 #include <qstring.h>
-#include <qregexp.h>
+// #include <qregexp.h> // Currently not needed (due to disabled code)
 #include <qtextcodec.h>
 #include <qfile.h>
 #include <qtextstream.h>
@@ -41,8 +41,10 @@
 #include <kgenericfactory.h>
 
 #include <koGlobal.h>
+#include <koPageLayout.h>
 #include <koStore.h>
 #include <koFilterChain.h>
+#include <koFilterManager.h>
 
 #include <asciiimport.h>
 #include <asciiimport.moc>
@@ -56,7 +58,7 @@ public:
 protected:
     virtual void setupTranslations( void )
     {
-        KGlobal::locale()->insertCatalogue( "kwordasciifilter" );
+        KGlobal::locale()->insertCatalogue( "kofficefilters" );
     }
 };
 
@@ -182,15 +184,15 @@ void ASCIIImport::prepareDocument(QDomDocument& mainDocument, QDomElement& mainF
     elementFormat.appendChild(element);
 
     element=mainDocument.createElement("COLOR");
-    element.setAttribute("red",  0);
-    element.setAttribute("green",0);
-    element.setAttribute("blue", 0);
+    element.setAttribute("red",  -1);
+    element.setAttribute("green",1);
+    element.setAttribute("blue", -1);
     elementFormat.appendChild(element);
 
     element=mainDocument.createElement("TEXTBACKGROUNDCOLOR");
-    element.setAttribute("red",  255);
-    element.setAttribute("green",255);
-    element.setAttribute("blue", 255);
+    element.setAttribute("red",  -1);
+    element.setAttribute("green",-1);
+    element.setAttribute("blue", -1);
     elementFormat.appendChild(element);
 
 }
@@ -200,18 +202,35 @@ KoFilter::ConversionStatus ASCIIImport::convert( const QCString& from, const QCS
     if (to!="application/x-kword" || from!="text/plain")
         return KoFilter::NotImplemented;
 
-    AsciiImportDialog* dialog = new AsciiImportDialog();
-    if (!dialog->exec())
+    AsciiImportDialog* dialog = 0;
+    if (!m_chain->manager()->getBatchMode())
     {
-        kdDebug(30502) << "Dialog was aborted! Aborting filter!" << endl; // this isn't an error!
-        return KoFilter::UserCancelled;
+    	dialog = new AsciiImportDialog();
+	if (!dialog)
+	{
+	  kdError(30502) << "Dialog has not been created! Aborting!" << endl;
+	  return KoFilter::StupidError;
+	}
+	if (!dialog->exec())
+	{
+	  kdDebug(30502) << "Dialog was aborted! Aborting filter!" << endl; // this isn't an error!
+	  return KoFilter::UserCancelled;
+	}
     }
 
-    QTextCodec* codec=dialog->getCodec();
-    int paragraphStrategy=dialog->getParagraphStrategy();
-
-    delete dialog;
-
+    QTextCodec* codec;
+    int paragraphStrategy;
+    if (dialog)
+    {
+      	codec = dialog->getCodec();
+	paragraphStrategy=dialog->getParagraphStrategy();
+	delete dialog;
+    }
+    else
+    {
+      codec = QTextCodec::codecForName("UTF-8");
+      paragraphStrategy=0;
+    }
 
     QFile in(m_chain->inputFile());
     if(!in.open(IO_ReadOnly)) {
@@ -638,7 +657,7 @@ bool ASCIIImport::Table( QString *Line, int *linecount, int no_lines,
              {
              // save and remove tabs at beginning of the line
              text = *Line;  // copy
-             Line->replace(QRegExp("^[\\ \t]*"), "");
+             Line->remove(QRegExp("^[\\ \t]*"));
              }
 
          // find column positions and record text fields
@@ -855,13 +874,13 @@ int ASCIIImport::MultSpaces(const QString& text, const int index) const
                      {
                      type = "6";
                      // delete * at beginning of line
-                     text.replace( QRegExp("^[ \t]*\\* "), "");
+                     text.remove( QRegExp("^[ \t]*\\* ") );
                      }
                   else if( listtype[begin] == dash) // write out a dash list
                      {
                      type = "7";
                      // delete - at beginning of line
-                     text.replace( QRegExp("^[ \t]*\\- "), "");
+                     text.remove( QRegExp("^[ \t]*\\- ") );
                      }
                   else if( listtype[begin] == none) // write out a paragraph
                      type = "";
