@@ -88,7 +88,6 @@ QString HtmlCssWorker::escapeCssIdentifier(const QString& strText) const
     return strReturn;
 }
 
-
 QString HtmlCssWorker::textFormatToCss(const TextFormatting& formatOrigin,
     const TextFormatting& formatData, const bool force) const
 {
@@ -108,9 +107,9 @@ QString HtmlCssWorker::textFormatToCss(const TextFormatting& formatOrigin,
             strElement+=escapeHtmlText(fontName);
         else
         {   // If the font name contains a space, it should be quoted.
-            strElement+='"';
+            strElement+='\'';
             strElement+=escapeHtmlText(fontName);
-            strElement+='"';
+            strElement+='\'';
         }
         // ### TODO: add alternative font names
         strElement+="; ";
@@ -370,7 +369,7 @@ QString HtmlCssWorker::layoutToCss(const LayoutData& layoutOrigin,
         {
         case LayoutData::LS_CUSTOM:
             { 
-                // ### TODO: CSS 2 does not known neither "at-least" nor KWord's "custom"
+                // ### TODO: CSS 2 does not known "at-least".
 #if 0
                 // We have a custom line spacing (in points)
                 const QString height ( QString::number(layout.lineSpacing) ); // ### TODO: rounding?
@@ -433,8 +432,8 @@ QString HtmlCssWorker::layoutToCss(const LayoutData& layoutOrigin,
 
     // TODO: Konqueror/KHTML does not support "text-shadow"
     if (!force
-        && (layoutOrigin.shadowDirection==layoutOrigin.shadowDirection)
-        && (layoutOrigin.shadowDistance==layoutOrigin.shadowDistance))
+        && ( layoutOrigin.shadowDirection == layout.shadowDirection )
+        && ( layoutOrigin.shadowDistance == layout.shadowDistance ) )
     {
         // Do nothing!
     }
@@ -668,7 +667,7 @@ bool HtmlCssWorker::doOpenStyles(void)
     }
 
     // Say who we are (with the CVS revision number)
-    const QString strVersion("$Revision: 1.15.2.6 $");
+    const QString strVersion("$Revision: 396514 $");
     // Eliminate the dollar signs
     //  (We don't want that the version number changes if the HTML file is itself put in a CVS storage.)
     *m_streamOut << "/* KWORD_CSS_EXPORT ="
