@@ -1,8 +1,8 @@
-// $Header: /home/kde/koffice/filters/kword/html/export/ExportFilter.cc,v 1.40.2.1 2004/01/01 12:47:11 goutte Exp $
+//
 
 /*
    This file is part of the KDE project
-   Copyright (C) 2001, 2002 Nicolas GOUTTE <goutte@kde.org>
+   Copyright (C) 2001, 2002, 2004 Nicolas GOUTTE <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -56,14 +56,18 @@ bool HtmlWorker::makeTable(const FrameAnchor& anchor)
     for (itCell=anchor.table.cellList.begin();
         itCell!=anchor.table.cellList.end(); itCell++)
     {
-        // TODO: rowspan, colspan
         if (rowCurrent!=(*itCell).row)
         {
             rowCurrent=(*itCell).row;
             *m_streamOut << "</tr>\n<tr>\n";
         }
 
-        *m_streamOut << "<td>\n";
+        *m_streamOut << "<td";
+        if ( (*itCell).m_rows > 1 )
+            *m_streamOut << " rowspan=\"" << (*itCell).m_rows << "\"";
+        if ( (*itCell).m_cols > 1 )
+            *m_streamOut << " colspan=\"" << (*itCell).m_cols << "\"";
+        *m_streamOut << ">\n";
 
         if (!doFullAllParagraphs(*(*itCell).paraList))
         {
@@ -121,7 +125,7 @@ QString HtmlWorker::getAdditionalFileName(const QString& additionalName)
 
 bool HtmlWorker::makeImage(const FrameAnchor& anchor)
 {
-    QString strImageName(getAdditionalFileName(anchor.picture.koStoreName));
+    const QString strImageName(getAdditionalFileName(anchor.picture.koStoreName));
 
     QString strImagePath(m_strFileDir);
     strImagePath+='/';
@@ -133,90 +137,106 @@ bool HtmlWorker::makeImage(const FrameAnchor& anchor)
 
     if (loadSubFile(anchor.picture.koStoreName,image))
     {
-        QFile file(strImagePath);
+        bool writePicture = false;
 
-        if ( !file.open (IO_WriteOnly) )
+        const double height = anchor.frame.bottom - anchor.frame.top;
+        const double width  = anchor.frame.right  - anchor.frame.left;
+
+        const int pos = anchor.picture.koStoreName.findRev( '.' );
+        QString extension;
+        if ( pos > -1 )
+            extension = anchor.picture.koStoreName.mid( pos+1 ).lower();
+
+        if ( extension == "png" || extension == "jpeg" || extension == "jpg" || extension == "gif"
+            || extension == "bmp" ) // A few file types known by all HTML user agents
         {
-            kdError(30503) << "Unable to open image output file!" << endl;
-            return false;
+            *m_streamOut << "<img "; // This is an empty element!
+            *m_streamOut << "src=\"" << escapeHtmlText(strImageName) << "\" ";
+            *m_streamOut << "alt=\"" << escapeHtmlText(anchor.picture.key.filename()) << "\"";
+            *m_streamOut << (isXML()?"/>":">");
+            writePicture = true;
+        }
+        else if ( extension == "svg" )
+        {
+            // Save picture as SVG
+            *m_streamOut << "<object data=\"" << escapeHtmlText(strImageName) << "\"";
+            *m_streamOut << " type=\"image/svg+xml\"";
+            *m_streamOut << " height=\"" << height << "\" width=\"" << width << "\">\n";
+            *m_streamOut << "</object>"; // <object> is *not* an empty element in HTML!
+            writePicture = true;
+        }
+        else if ( extension == "qpic" )
+        {
+
+            QPicture picture;
+
+            QIODevice* io=getSubFileDevice(anchor.picture.koStoreName);
+            if (!io)
+            {
+                // NO message error, as there must be already one
+                return false;
+            }
+
+            // TODO: if we have alreasy SVG, do *not* go through QPicture!
+            if (picture.load(io))
+            {
+
+                // Save picture as SVG
+                *m_streamOut << "<object data=\"" << escapeHtmlText(strImageName) << "\"";
+                *m_streamOut << " type=\"image/svg+xml\"";
+                *m_streamOut << " height=\"" << height << "\" width=\"" << width << "\">\n";
+                *m_streamOut << "</object>"; // <object> is *not* an empty element in HTML!
+                // TODO: other props for image
+
+                kdDebug(30506) << "Trying to save clipart to " << strImageName << endl;
+                if (!picture.save(strImagePath,"svg"))
+                {
+                    kdError(30506) << "Could not save clipart: "  << anchor.picture.koStoreName
+                        << " to " << strImageName << endl;
+                    return false;
+                }
+
+            }
+        }
+        else
+        {
+            // ### TODO: avoid loading the picture 2 times
+            image.resize( 0 );
+            if ( ! loadAndConvertToImage( anchor.picture.koStoreName, extension, "PNG", image ) )
+            {
+                kdWarning(30503) << "Could not convert picture to PNG!" << endl;
+                return false;
+            }
+            *m_streamOut << "<img "; // This is an empty element!
+            *m_streamOut << "src=\"" << escapeHtmlText(strImageName) << "\" ";
+            *m_streamOut << "alt=\"" << escapeHtmlText(anchor.picture.key.filename()) << "\"";
+            *m_streamOut << (isXML()?"/>":">");
+            writePicture = true;
         }
 
-        file.writeBlock(image);
-        file.close();
+        // Do we still need to write the original picture?
+        if ( writePicture )
+        {
+            QFile file(strImagePath);
 
-        *m_streamOut << "<img "; // This is an empty element!
-        *m_streamOut << "src=\"" << escapeHtmlText(strImageName) << "\" ";
-        *m_streamOut << "alt=\"" << escapeHtmlText(anchor.picture.key.filename()) << "\"";
-        *m_streamOut << (isXML()?"/>":">") << "\n";
-        kdDebug(30503) << "Image written" << endl;
+            if ( !file.open (IO_WriteOnly) )
+            {
+                kdError(30503) << "Unable to open image output file!" << endl;
+                return false;
+            }
+
+            file.writeBlock(image);
+            file.close();
+        }
     }
     else
     {
-        kdWarning(30503) << "Unable to load image " << anchor.picture.koStoreName << endl;
+        kdWarning(30503) << "Unable to load picture " << anchor.picture.koStoreName << endl;
     }
 
     return true;
 }
 
-bool HtmlWorker::makeClipart(const FrameAnchor& anchor)
-{
-    kdDebug(30506) << "New clipart: " << anchor.picture.koStoreName
-        << " , " << anchor.picture.key.toString() <<endl;
-
-    QString strAdditionalName(anchor.picture.koStoreName);
-    if (!strAdditionalName.endsWith(".svg"))
-    {
-        // TODO: remove the extension of the KoStore name (could it make duplicated files?)
-        strAdditionalName+=".svg";
-    }
-
-    QString strImageName(getAdditionalFileName(strAdditionalName));
-
-    QString strImagePath(m_strFileDir);
-    strImagePath+='/';
-    strImagePath+=strImageName;
-
-    const double height = anchor.frame.bottom - anchor.frame.top;
-    const double width  = anchor.frame.right  - anchor.frame.left;
-
-    QPicture picture;
-
-    QIODevice* io=getSubFileDevice(anchor.picture.koStoreName);
-    if (!io)
-    {
-        // NO message error, as there must be already one
-        return false;
-    }
-
-    // TODO: if we have alreasy SVG, do *not* go through QPicture!
-    if (picture.load(io))
-    {
-
-        // Save picture as SVG
-        *m_streamOut << "<object data=\"" << escapeHtmlText(strImageName) << "\"";
-        *m_streamOut << " type=\"image/svg+xml\"";
-        *m_streamOut << " height=\"" << height << "\" width=\"" << width << "\">\n";
-        *m_streamOut << "</object>\n"; // <object> is *not* an empty element in HTML!
-        // TODO: other props for image
-
-        kdDebug(30506) << "Trying to save clipart to " << strImageName << endl;
-        if (!picture.save(strImagePath,"svg"))
-        {
-            kdError(30506) << "Could not save clipart: "  << anchor.picture.koStoreName
-                << " to " << strImageName << endl;
-            return false;
-        }
-
-    }
-    else
-    {
-        kdWarning(30506) << "Unable to load clipart: " << anchor.picture.koStoreName << endl;
-        return false;
-    }
-    return true;
-}
-
-
 void HtmlWorker::formatTextParagraph(const QString& strText,
  const FormatData& formatOrigin, const FormatData& format)
 {
@@ -316,33 +336,37 @@ void HtmlWorker::ProcessParagraphData (const QString& strTag, const QString &par
             {
                 // We have an image, a clipart or a table
 
-                // But first, we must sure that the paragraph is not opened.
-                if (!paragraphNotOpened)
-                {
-                    // The paragraph was opened, so close it.
-                    closeParagraph(strTag,layout);
-                }
-
                 if (6==(*paraFormatDataIt).frameAnchor.type)
                 {
+                    // We have a table
+                    // But first, we must sure that the paragraph is not opened.
+                    if (!paragraphNotOpened)
+                    {
+                        // The paragraph was opened, so close it.
+                        closeParagraph(strTag,layout);
+                    }
                     makeTable((*paraFormatDataIt).frameAnchor);
+                    // The paragraph will need to be opened again
+                    paragraphNotOpened=true;
+
                 }
-                else if (2==(*paraFormatDataIt).frameAnchor.type)
+
+                else if ( ( 2 == (*paraFormatDataIt).frameAnchor.type )
+                    || ( 5 == (*paraFormatDataIt).frameAnchor.type ) )
                 {
+                    // <img> and <object> need to be in a paragraph
+                    if (paragraphNotOpened)
+                    {
+                        openParagraph( strTag, layout,partialText.ref(0). direction() );
+                        paragraphNotOpened=false;
+                    }
                     makeImage((*paraFormatDataIt).frameAnchor);
                 }
-                else if (5==(*paraFormatDataIt).frameAnchor.type)
-                {
-                    makeClipart((*paraFormatDataIt).frameAnchor);
-                }
                 else
                 {
                     kdWarning(30503) << "Unknown anchor type: "
                         << (*paraFormatDataIt).frameAnchor.type << endl;
                 }
-
-                // The paragraph will need to be opened again
-                paragraphNotOpened=true;
             }
         }
         if (!paragraphNotOpened)
@@ -562,11 +586,11 @@ bool HtmlWorker::doOpenHead(void)
     *m_streamOut << (isXML()?" /":"") << ">\n" ;
 
     // Say who we are (with the CVS revision number) in case we have a bug in our filter output!
-    QString strVersion("$Revision: 1.40.2.1 $");
+    QString strVersion("$Revision: 396742 $");
     // Eliminate the dollar signs
     //  (We don't want that the version number changes if the HTML file is itself put in a CVS storage.)
     *m_streamOut << "<meta name=\"Generator\" content=\"KWord HTML Export Filter Version"
-              << strVersion.mid(10).replace('$',"")
+              << strVersion.mid( 10 ).remove( '$' )
               << "\""<< (isXML()?" /":"") // X(HT)ML closes empty elements, HTML not!
               << ">\n";
 
@@ -578,6 +602,11 @@ bool HtmlWorker::doOpenHead(void)
     }
     *m_streamOut << "<title>"<< escapeHtmlText(m_strTitle) <<"</title>\n";  // <TITLE> is mandatory!
 
+    if( !customCSSURL().isEmpty() )
+    {
+      *m_streamOut << "<link ref=\"stylesheet\" type=\"text/css\" href=\"" << customCSSURL() << "\" title=\"Style\" >\n" << endl;
+    }
+
     //TODO: transform documentinfo.xml into many <META> elements (at least the author!)
 
     return true;
