@@ -44,11 +44,10 @@ void qt_leave_modal( QWidget *widget );
 
 
 bool KHTMLReader::filter(KURL url) {
-	kdDebug() << "KHTMLReader::filter" << endl;
+	kdDebug(30503) << "KHTMLReader::filter" << endl;
 	QObject::connect(_html,SIGNAL(completed()),this,SLOT(completed()));
 
 	_state.clear();
-	_html->begin();
 	_list_depth=0;
 
 	_html->view()->resize(600,530);
@@ -57,7 +56,7 @@ bool KHTMLReader::filter(KURL url) {
 	_html->setPluginsEnabled(false);
 	_html->setJavaEnabled(false);
 	if (_html->openURL(url) == false) {
-		qWarning("openURL returned false");
+		kdWarning(30503) << "openURL returned false" << endl;
 		return false;
 	}
 
@@ -130,14 +129,14 @@ void KHTMLReader::startNewLayout(bool startNewFormat, QDomElement layout) {
 
 
 void KHTMLReader::completed() {
-	kdDebug() << "KHTMLReader::completed" << endl;
+	kdDebug(30503) << "KHTMLReader::completed" << endl;
         qApp->exit_loop();
 	DOM::Document doc=_html->document(); // FIXME parse <HEAD> too
 	DOM::NodeList list=doc.getElementsByTagName("body");
 	DOM::Node docbody=list.item(0);
 
 	if (docbody.isNull()) {
-		qWarning("no <BODY>, giving up");
+		kdWarning(30503) << "no <BODY>, giving up" << endl;
 		_it_worked=false;
 		return;
 	}
@@ -150,7 +149,7 @@ void KHTMLReader::completed() {
 	if (!dochead.isNull())
 		parse_head(dochead);
 	else
-		qWarning("WARNING: no html <HEAD> section");
+		kdWarning(30503) << "WARNING: no html <HEAD> section" << endl;
 
 	_writer->cleanUpParagraph(state()->paragraph);
         _it_worked=_writer->writeDoc();
@@ -274,13 +273,13 @@ void KHTMLReader::parseStyle(DOM::Element e) {
 	_writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
 
      // debugging code.
-     qWarning("e.style()");
+     kdDebug(30503) << "e.style()" << endl;
      for (unsigned int i=0;i<s1.length();i++) {
-        qWarning(QString("%1: %2").arg(s1.item(i).string()).arg(s1.getPropertyValue(s1.item(i)).string()));
+        kdDebug(30503) << QString("%1: %2").arg(s1.item(i).string()).arg(s1.getPropertyValue(s1.item(i)).string()) << endl;
      }
-     qWarning("override style");
+     kdDebug(30503) << "override style" << endl;
      for (unsigned int i=0;i<s2.length();i++) {
-        qWarning(QString("%1: %2").arg(s2.item(i).string()).arg(s2.getPropertyValue(s2.item(i)).string()));
+        kdDebug(30503) << QString("%1: %2").arg(s2.item(i).string()).arg(s2.getPropertyValue(s2.item(i)).string()) << endl;
      }
 #endif
 }
@@ -312,7 +311,7 @@ void KHTMLReader::startNewParagraph(bool startnewformat, bool startnewlayout) {
 	  we do this by incrementing the 'environment depth' and changing the numbering type to 'no numbering'
 	 **/
 	QString ct=_writer->getLayoutAttribute(state()->paragraph,"COUNTER","type");
-	if ((ct != QString::null) && (ct != "0")) {
+	if ((!ct.isNull()) && (ct != "0")) {
 		_writer->layoutAttribute(state()->paragraph,"COUNTER","type","0");
 		_writer->layoutAttribute(state()->paragraph,"COUNTER","numberingtype","0");
 		_writer->layoutAttribute(state()->paragraph,"COUNTER","righttext","");
@@ -336,7 +335,7 @@ KHTMLReader::~KHTMLReader(){
 
 bool KHTMLReader::parse_CommonAttributes(DOM::Element e) {
         QString s=e.getAttribute("align").string();
-        if (s != "") {
+        if (!s.isEmpty()) {
               _writer->formatAttribute(state()->paragraph,"FLOW","align",s);
         }
         return true;
@@ -425,7 +424,7 @@ bool KHTMLReader::parse_table(DOM::Element e) {
  	int has_borders=false;
 	QColor bgcolor=parsecolor("#FFFFFF");
  	DOM::Element table_body=e.firstChild();
- 	if (table_body.getAttribute("bgcolor").string() != "")
+ 	if (!table_body.getAttribute("bgcolor").string().isEmpty())
  	       bgcolor=parsecolor(table_body.getAttribute("bgcolor").string());
  	if ((e.getAttribute("border").string().toInt() > 0))
  		has_borders=true;
@@ -436,14 +435,14 @@ bool KHTMLReader::parse_table(DOM::Element e) {
  	if (rows.tagName().string().lower() == "tr") {
 
  	    QColor obgcolor=bgcolor;
- 	    if (rows.getAttribute("bgcolor").string() != "")
+ 	    if (!rows.getAttribute("bgcolor").string().isEmpty())
  	       	bgcolor=parsecolor(rows.getAttribute("bgcolor").string());
 
  		ncol=0;
  		for (DOM::Element cols=rows.firstChild();!cols.isNull();cols=cols.nextSibling()) {
  		        if (cols.tagName().string().lower() == "td") {
  		             QColor bbgcolor=bgcolor;
-		 	    if (cols.getAttribute("bgcolor").string() != "")
+		 	    if (!cols.getAttribute("bgcolor").string().isEmpty())
  	       			bgcolor=parsecolor(cols.getAttribute("bgcolor").string());
 
 			    	pushNewState();
@@ -508,7 +507,7 @@ bool KHTMLReader::parse_font(DOM::Element e) {
 	// fixme don't hardcode 12 font size ...
 	QString face=e.getAttribute("face").string();
         QColor color=parsecolor("#000000");
-        if (e.getAttribute("color").string() != "")
+        if (!e.getAttribute("color").string().isEmpty())
         	color=parsecolor(e.getAttribute("color").string());
         QString size=e.getAttribute("size").string();
         int isize=-1;
