@@ -22,7 +22,7 @@
 #include <stdlib.h>		/* for atoi function    */
 #include <kdebug.h>		/* for kdDebug() stream */
 #include "para.h"
-#include "texte.h"		/* father class.        */
+#include "textFrame.h"		/* father class.        */
 #include "format.h"		/* children classes.    */
 //#include "picturezone.h"
 #include "fileheader.h"
@@ -38,15 +38,16 @@ int Para::_tabulation = 0;
 /*******************************************/
 /* Constructor                             */
 /*******************************************/
-Para::Para(Texte* texte)
+Para::Para(TextFrame* textFrame)
 {
-	_element    = texte;
+	_element    = textFrame;
 	_lines      = 0;
 	_name       = 0;
 	_info       = EP_NONE;	/* the parag is not a footnote */
 	//_hardbrk   = EP_FLOW;	/* and it's not a new page */
 	_currentPos = 0;		/* At the beginning of the paragraph */
 	_tabulation = 0;
+	_text = "";
 }
 
 /*******************************************/
@@ -54,7 +55,7 @@ Para::Para(Texte* texte)
 /*******************************************/
 Para::~Para()
 {
-	kdDebug() << "Destruction of a parag." << endl;
+	kdDebug(30522) << "Destruction of a parag." << endl;
 	if(_lines != 0)
 		delete _lines;
 }
@@ -95,7 +96,7 @@ int Para::getNbCharPara() const
 
 	if(_lines != 0)
 	{
-		kdDebug() << "  NB ZONE : " << _lines->count() << endl;
+		kdDebug(30522) << "  NB ZONE : " << _lines->count() << endl;
 
 		for(zone = _lines->first(); zone != 0; zone = _lines->next())
 		{
@@ -114,6 +115,8 @@ int Para::getNbCharPara() const
 					break;
 				case EF_ANCHOR:
 					break;
+				case EF_ERROR:
+					break;
 			}
 		}
 	}
@@ -127,17 +130,15 @@ void Para::analyse(const QDomNode balise)
 {
 	/* MARKUP TYPE :  PARAGRAPH */
 
-	/* Analyse of the parameters */
-	kdDebug() << "ANALYSE A PARAGRAPH" << endl;
+	kdDebug(30522) << "**** PARAGRAPH ****" << endl;
 
 	/* Analyse of the children markups */
 	for(int index = 0; index < getNbChild(balise); index++)
 	{
 		if(getChildName(balise, index).compare("TEXT")== 0)
 		{
-			_texte =  getChild(getChild(balise, index), 0).nodeValue();
-			kdDebug() << "TEXT : " << _texte << endl;
-
+			_text =  getData(balise, index);
+			kdDebug(30522) << "TEXT : " << _text << endl;
 		}
 		else if(getChildName(balise, index).compare("NAME")== 0)
 		{
@@ -153,19 +154,18 @@ void Para::analyse(const QDomNode balise)
 		}*/
 		else if(getChildName(balise, index).compare("FORMATS")== 0)
 		{
-			// Garder pour la nouvelle dtd
 			// IMPORTANT ==> police + style
-			kdDebug() << "FORMATS" << endl;
+			kdDebug(30522) << "FORMATS" << endl;
 			analyseFormats(getChild(balise, index));
 
 		}
 		else if(getChildName(balise, index).compare("LAYOUT")== 0)
 		{
-			kdDebug() << "LAYOUT" << endl;
+			kdDebug(30522) << "LAYOUT" << endl;
 			analyseLayoutPara(getChild(balise, index));
 		}
 	}
-	kdDebug() << "END OF PARAGRAPH" << endl;
+	kdDebug(30522) << " **** END PARAGRAPH ****" << endl;
 }
 
 /*******************************************/
@@ -226,11 +226,11 @@ void Para::analyseLayoutPara(const QDomNode balise)
 		{
 			//analyseFormat(balise);
 			/* No more format : verify if all the text zone has been formated */
-			if(_currentPos != _texte.length())
+			if(_currentPos != _text.length())
 			{
-				zone = new TextZone(_texte, this);
+				zone = new TextZone(_text, this);
 				((TextZone*) zone)->setPos(_currentPos);
-				((TextZone*) zone)->setLength(_currentPos - _texte.length());
+				((TextZone*) zone)->setLength(_currentPos - _text.length());
 				((TextZone*) zone)->analyse();
 				if(_lines == 0)
 					_lines = new QPtrList<Format>;
@@ -241,7 +241,7 @@ void Para::analyseLayoutPara(const QDomNode balise)
 			}
 		}
 		/*else
-			kdDebug() << " FORMAT FIELD UNKNOWN" << endl;*/
+			kdDebug(30522) << " FORMAT FIELD UNKNOWN" << endl;*/
 	}
 }
 
@@ -258,11 +258,11 @@ void Para::analyseFormats(const QDomNode balise)
 	{
 		if(getChildName(balise, index).compare("FORMAT")== 0)
 		{
-			kdDebug() << "A FORMAT !!!" << endl;
+			kdDebug(30522) << "A FORMAT !!!" << endl;
 			analyseFormat(getChild(balise, index));
 		}
 		else
-			kdDebug() << " FORMAT UNUSEFULL HERE" << endl;
+			kdDebug(30522) << " FORMAT UNUSEFULL HERE" << endl;
 	}
 }
 
@@ -278,14 +278,14 @@ void Para::analyseFormat(const QDomNode balise)
 	Format *zone      = 0;
 	Format *zoneFirst = 0;
 
-	kdDebug() << "ANALYSE FORMAT BODY" << endl;
+	kdDebug(30522) << "ANALYSE FORMAT BODY" << endl;
 	switch(getTypeFormat(balise))
 	{
-		case EF_ERROR: kdDebug() << "Id format error" << endl;
+		case EF_ERROR: kdDebug(30522) << "Id format error" << endl;
 			break;
 		case EF_TEXTZONE: /* It's a text line (1) */
-				zone = new TextZone(_texte, this);
-				if(_currentPos != _texte.length())
+				zone = new TextZone(_text, this);
+				if(_currentPos != _text.length())
 				{
 					zone->analyse(balise);
 					if(zone->getPos() != _currentPos)
@@ -293,7 +293,7 @@ void Para::analyseFormat(const QDomNode balise)
 						if(_lines == 0)
 							_lines = new QPtrList<Format>;
 							/* Create first a default format */
-						zoneFirst = new TextZone(_texte, this);
+						zoneFirst = new TextZone(_text, this);
 						zoneFirst->setPos(_currentPos);
 						zoneFirst->setLength(zone->getPos() - _currentPos);
 						((TextZone*) zoneFirst)->analyse();
@@ -321,7 +321,7 @@ void Para::analyseFormat(const QDomNode balise)
 				zone->analyse(balise);
 			break;
 		default: /* Unknown */
-				kdDebug() << "Format not yet supported" << endl;
+				kdDebug(30522) << "Format not yet supported" << endl;
 	}
 
 	if(zone->getPos() != _currentPos)
@@ -329,11 +329,11 @@ void Para::analyseFormat(const QDomNode balise)
 		if(_lines == 0)
 			_lines = new QPtrList<Format>;
 			/* Create first a default format */
-		zoneFirst = new TextZone(_texte, this);
+		zoneFirst = new TextZone(_text, this);
 		zoneFirst->setPos(_currentPos);
 		zoneFirst->setLength(zone->getPos() - _currentPos);
 		((TextZone*) zoneFirst)->analyse();
-		kdDebug() << "pos courante : " << _currentPos << endl;
+		kdDebug(30522) << "pos courante : " << _currentPos << endl;
 		/* Add the text without format */
 		_lines->append(zoneFirst);
 		_currentPos = _currentPos + zoneFirst->getLength();
@@ -359,7 +359,7 @@ void Para::analyseFormat(const QDomNode balise)
 void Para::generate(QTextStream &out)
 {
 
-	kdDebug() << "  GENERATION PARA" << endl;
+	kdDebug(30522) << "  GENERATION PARA" << endl;
 
 	if(getInfo() != EP_FOOTNOTE && getFrameType() != SS_HEADERS &&
 	   getFrameType() != SS_FOOTERS)
@@ -373,10 +373,13 @@ void Para::generate(QTextStream &out)
 		generateDebut(out);
 	}
 
-	if(_lines != 0)
+	/* If text is a \n, then it's a break line. */
+	if(_text == "\n")
+		out << "\\\\" << endl;
+	else if(_lines != 0)
 	{
 		Format* zone = 0;
-		kdDebug() << "  NB ZONE : " << _lines->count() << endl;
+		kdDebug(30522) << "  NB ZONE : " << _lines->count() << endl;
 
 		for(zone = _lines->first(); zone != 0; zone = _lines->next())
 		{
@@ -395,7 +398,7 @@ void Para::generate(QTextStream &out)
 		if(isHardBreakAfter())
 			out << "\\newpage" << endl;
 	}
-	kdDebug() << "PARA GENERATED" << endl;
+	kdDebug(30522) << "PARA GENERATED" << endl;
 }
 
 /*******************************************/
@@ -416,10 +419,10 @@ void Para::generateDebut(QTextStream &out)
 		 * It can be 20 char. / 5 cm  = 4 char / cm so */
 		/* nbLines = nb_char_para / (4 * cell size) + 1 */
 		//sizeCell = (_element->getRight() - _element->getLeft()) / 27;
-		//kdDebug() << "SIZE OF CELL : " << sizeCell << endl;
+		//kdDebug(30522) << "SIZE OF CELL : " << sizeCell << endl;
 		// TODO : arrondir au superieur avec tgmath.h ??
 		//_nbLines = ((_element->getBottom() - _element->getTop()) / 27) + 1;
-		//kdDebug() << "NB OF LINES : " << _nbLines << endl;
+		//kdDebug(30522) << "NB OF LINES : " << _nbLines << endl;
 		/* 2 at least, 1 for the line, 1 for the space line */
 		/*if(_nbLines < 2)
 			_nbLines = 2;
@@ -430,22 +433,22 @@ void Para::generateDebut(QTextStream &out)
 	{
 		/* switch the type, the depth do */
 		generateTitle(out);
-		indent();
+		Config::instance()->indent();
 	}
 	else if(isEnum())
 	{
-		writeIndent(out);
+		Config::instance()->writeIndent(out);
 		out << "\\item ";
 	}
 	else
-		writeIndent(out);
+		Config::instance()->writeIndent(out);
 }
 
 void Para::generateBeginEnv(QTextStream &out)
 {
-	kdDebug() << "Begin new Env : " << getEnv() << endl;
+	kdDebug(30522) << "Begin new Env : " << getEnv() << endl;
 
-	writeIndent(out);
+	Config::instance()->writeIndent(out);
 
 	switch(getEnv())
 	{
@@ -457,9 +460,11 @@ void Para::generateBeginEnv(QTextStream &out)
 			break;
 		case ENV_JUSTIFY: out << endl;
 			break;
+		case ENV_NONE:
+			break;
 	}
 	
-	indent();
+	Config::instance()->indent();
 }
 
 /*******************************************/
@@ -472,7 +477,7 @@ void Para::openList(QTextStream &out)
 {
 	EType *type_temp = 0;
 
-	writeIndent(out);
+	Config::instance()->writeIndent(out);
 
 	switch(getCounterType())
 	{
@@ -512,11 +517,11 @@ void Para::openList(QTextStream &out)
 			out << "\\begin{itemize}[SPECIAL]" << endl;
 	}
 
-	indent();
+	Config::instance()->indent();
 
 	/* Keep the list type */
 	type_temp = new EType(getCounterType());
-	kdDebug() << " type list to open : " << *type_temp << endl;
+	kdDebug(30522) << " type list to open : " << *type_temp << endl;
 	_historicList.push(type_temp);
 }
 
@@ -539,32 +544,34 @@ void Para::generateFin(QTextStream &out)
 /*******************************************/
 void Para::generateEndEnv(QTextStream &out)
 {
-	kdDebug() << "end of an environment : " << getEnv() << endl;
+	kdDebug(30522) << "end of an environment : " << getEnv() << endl;
 	
-	desindent();
+	Config::instance()->desindent();
 	
 	switch(getEnv())
 	{
 		case ENV_LEFT:
 				out << endl;
-				writeIndent(out);
+				Config::instance()->writeIndent(out);
 				out << "\\end{flushleft}";
 			break;
 		case ENV_RIGHT:
 				out << endl;
-				writeIndent(out);
+				Config::instance()->writeIndent(out);
 				out << "\\end{flushright}";
 			break;
 		case ENV_CENTER:
 				out << endl;
-				writeIndent(out);
+				Config::instance()->writeIndent(out);
 				out << "\\end{center}";
 			break;
 		case ENV_JUSTIFY:
 			break;
+		case ENV_NONE:
+			break;
 	}
 
-	desindent();
+	Config::instance()->desindent();
 }
 
 /*******************************************/
@@ -583,7 +590,7 @@ void Para::closeList(QTextStream &out, Para* next)
 		/* We must close all the lists since
 		 * after this paragraph it's a normal paragraph.
 		 */
-		kdDebug() << "lists to close" << endl;
+		kdDebug(30522) << "lists to close" << endl;
 		while(!_historicList.isEmpty())
 		{
 			EType *type_temp = 0;
@@ -604,13 +611,13 @@ void Para::closeList(QTextStream &out, Para* next)
 void Para::closeList(EType type, QTextStream &out)
 {
 	//out << endl;
-	kdDebug() << " type list to close : " << type << endl;
+	kdDebug(30522) << " type list to close : " << type << endl;
 
 	/* Because of a new markup, we need a new line. */
 	out << endl;
 
-	desindent();
-	writeIndent(out);
+	Config::instance()->desindent();
+	Config::instance()->writeIndent(out);
 	
 	/* but the next parag is not a same list */
 	switch(type)
@@ -637,11 +644,11 @@ void Para::closeList(EType type, QTextStream &out)
 				out << "no suported" << endl;
 	}
 
-	writeIndent(out);
+	Config::instance()->writeIndent(out);
 
 	/* Pop the list which has been closed */
 	_historicList.remove();
-	kdDebug() << "removed" << endl;
+	kdDebug(30522) << "removed" << endl;
 }
 
 /*******************************************/
