@@ -50,19 +50,20 @@
 #include <qdatetime.h>
 
 #include <koPictureKey.h>
-
-// FormatData is a container for data retrieved from the FORMAT tag
-// and its subtags to be used in the PARAGRAPH tag.
-
+#include <koffice_export.h>
+/**
+ * TextFormatting is a container for data retrieved from the \<FORMAT\> tag
+ * and its subtags to be used in the \<PARAGRAPH\> tag.
+ */
 class TextFormatting
 {
     public:
         TextFormatting(): italic (false), underline (false), underlineWord(false),
-            strikeout (false),
+            strikeout (false), strikeoutWord( false ),
             weight (50), fontSize (0), verticalAlignment (0), missing (true) {}
 
         TextFormatting(const bool newMissing) : italic (false),
-            underline (false), underlineWord(false), strikeout (false),
+            underline (false), underlineWord(false), strikeout (false), strikeoutWord( false ),
             weight (50), fontSize (0), verticalAlignment (0),
             missing (newMissing) {}
 
@@ -76,7 +77,7 @@ class TextFormatting
                          QColor  bg,
                          int     v) :
             fontName (f), italic (i), underline (u), underlineWord(false),
-            strikeout(s),
+            strikeout(s), strikeoutWord( false ),
             weight (w), fontSize (sz), fgColor (fg),
             bgColor (bg), verticalAlignment (v), missing (false) {}
 
@@ -84,19 +85,17 @@ class TextFormatting
 
         bool    italic;
 
-        // As doubled underlined was introduced late in KWord, we must use a compatibe way
-        // First with "underline", we check if an underline is wanted or not.
-        // Then with "underValue", we check the type of the underline (simple, double...)
-        bool    underline;       // underline? (If true, we do not know if simple or double or what else)
+        bool    underline;       ///< Any underline? (If true, we do not know if simple or double or what else)
 
-        QString    underlineValue; // "value" of the underline: single, double, bold-single...
-        QString    underlineStyle; // underline style: solid, dash, dot dash, ....
-        bool       underlineWord;  // true if word-by-word (i.e spaces aren't underlined)
-        QColor     underlineColor; // color of the line
+        QString    underlineValue; ///< "value" of the underline: single, double, bold-single...
+        QString    underlineStyle; ///< underline style: solid, dash, dot dash, ....
+        bool       underlineWord;  ///< true if word-by-word (i.e spaces are not underlined)
+        QColor     underlineColor; ///< color of the line
 
-        bool    strikeout;             // true if strikeout
-        QString strikeoutType;         // single, bold, double
-        QString strikeoutLineStyle;    // solid, dash, dot, ....
+        bool    strikeout;             ///< true if strikeout
+        QString strikeoutType;         ///< type of strikeout: single, bold, double
+        QString strikeoutLineStyle;    ///< type of the strikeout line: solid, dash, dot, ....
+	bool 	strikeoutWord;	///< \todo: not finished ###
 
         int     weight;
         int     fontSize;
@@ -105,8 +104,13 @@ class TextFormatting
         int     verticalAlignment;
 
         QString fontAttribute;
+        /**
+         * Language code
+         * @note the test language "xx" in converted to "en_US"
+         */
+        QString language;
 
-        bool    missing;   // true if the FormatData does not correspond to a real <FORMAT> element
+        bool    missing;   ///< true if this TextFormatting object does not correspond to a real \<FORMAT\> element
 };
 
 
@@ -115,12 +119,12 @@ class Picture
     public:
         Picture () {}
 
-        KoPictureKey key;      // Picture key: where the picture came from
-        QString koStoreName;   // Picture store name: filename within kwd archive
+        KoPictureKey key;      ///< Picture key: where the picture came from
+        QString koStoreName;   ///< Picture store name: filename within KWord archive
 };
 
 /**
- * For FRAME Tag.
+ * For \<FRAME\> Tag.
  * Look at kword.dtd for a complete description
  * of individuals class members
  */
@@ -157,20 +161,21 @@ public:
 
 class ParaData;
 
-class TableCell
+class KOFFICEFILTER_EXPORT TableCell
 {
    public:
-      TableCell (): col( 0 ), row( 0 ), paraList( 0 ) {}
+      TableCell (): col( 0 ), row( 0 ), m_cols( 0 ), m_rows( 0 ), paraList( 0 ) {}
 
-      TableCell ( int                   c,
-                  int                   r,
-                  QValueList<ParaData> *p,
-                  FrameData &frameData  ) : col (c), row (r), paraList (p), frame (frameData) {}
+      /// \since 1.4 (changes of parameters)
+      TableCell ( int c, int r, int _cols, int _rows, QValueList<ParaData> *p, FrameData &frameData  )
+         : col (c), row (r), m_cols( _cols ), m_rows( _rows ), paraList (p), frame (frameData) {}
 
       ~TableCell ();
 
       int                   col;
       int                   row;
+      int m_cols; ///< \since 1.4
+      int m_rows; ///< \since 1.4
       QValueList<ParaData> *paraList;
       FrameData   frame;
 };
@@ -181,17 +186,15 @@ class Table
    public:
       Table () : cols (0) {}
 
-      void addCell ( int                   c,
-                     int                   r,
-                     QValueList<ParaData> &p,
-                     FrameData &frameData  );
+      /// \since 1.4 (change of parameters)
+      void addCell ( int c, int r, int _cols, int _rows, QValueList<ParaData> &p, FrameData &frameData );
 
       int                   cols;
       QValueList<TableCell> cellList;
 };
 
 
-//This is basically FRAMESET tag
+/// This is basically \<FRAMESET\> tag
 class FrameAnchor
 {
    public:
@@ -200,7 +203,7 @@ class FrameAnchor
 
       FrameAnchor ( const KoPictureKey& n  ) : key (n), type (-1) {}
 
-      KoPictureKey key; // KoPictureKey
+      KoPictureKey key; ///< Picture key
       int     type;
       FrameData   frame;
 
@@ -208,7 +211,10 @@ class FrameAnchor
       Table   table;
 };
 
-class VariableData
+/**
+ * Data of variables
+ */
+class KOFFICEFILTER_EXPORT VariableData
 {
 public:
     VariableData (): m_type(-1), footnotePara(0) {}
@@ -219,29 +225,42 @@ public:
       footnotePara(other.footnotePara) {}
 public:
     /**
-     * Set parameters of a <LINK> element
+     * Set parameters of a LINK element
      */
     void setLink(const QString& linkName, const QString& hrefName);
-    QString getLinkName(void) const; // Name of link (attribute "linkName" of <LINK>)
-    QString getHrefName(void) const; // Reference of link (attribute "hrefName" of <LINK>)
+    QString getLinkName(void) const; ///< Name of link (attribute "linkName" of \<LINK\>)
+    QString getHrefName(void) const; ///< Reference of link (attribute "hrefName" of \<LINK\>)
     /**
-     * Set parameters of a <PGNUM> element
+     * Set parameters of a PGNUM element
      */
     void setPgNum(const QString& subtype, const QString& value);
     bool isPageNumber(void) const;
     bool isPageCount(void) const;
-    /*
-     * Set parameters of a <FIELD> element
+    /**
+     * Set parameters of a FIELD element
      */
     void setField(const QString& subtype, const QString& value);
     QString getFieldName(void) const;
     QString getFieldValue(void) const;
-    /*
-     * Set parameters of a <FOOTNOTE> element
+    /**
+     * Set parameters of a \<FOOTNOTE\> element
+     * @since 1.4 (change of parameters)
+     */
+    void setFootnote( const QString& notetype, const QString& automatic, const QString& value, QValueList<ParaData>* para );
+    /**
+     * Is the footnote an automatic one?
+     * @return true for an automatical foornote, false for a manual footnote
      */
-    void setFootnote(bool automatic, const QString& value, QValueList<ParaData>* para);
     bool getFootnoteAuto(void) const;
+    /// Get the value (counter) of the footnote
     QString getFootnoteValue(void) const;
+    /**
+     * Get type of footnote
+     * @return true for footnote, false for endnote
+     * @since 1.4
+     */
+    bool getFootnoteType( void ) const;
+    /// Paragrapgh of the footnote
     QValueList<ParaData>* getFootnotePara(void) const;
 
     /**
@@ -284,7 +303,7 @@ public:
           text(other.text), frameAnchor(other.frameAnchor), variable(other.variable) {}
 public:
     int id;
-    int pos;    // Start of text to which this format applies
+    int pos;    ///< Start position of text to which this format applies
     int len;
 
     TextFormatting  text;
@@ -301,7 +320,7 @@ public:
 };
 
 
-// Counter structure, for LayoutData
+/// Counter structure, for LayoutData
 class CounterData
 {
 public:
@@ -311,9 +330,9 @@ public:
 
     enum Numbering
     {
-        NUM_LIST    = 0,   // Numbered as a list item
-        NUM_CHAPTER = 1,   // Numbered as a heading
-        NUM_NONE    = 2    // No counter
+        NUM_LIST    = 0,   ///< Numbered as a list item
+        NUM_CHAPTER = 1,   ///< Numbered as a heading
+        NUM_NONE    = 2    ///< No counter
     };
 
     enum Style
@@ -343,11 +362,11 @@ public:
     QString customFont;
     //QString custom;
 
-    QString text;   // text at the time of saving (no formatting info though)
+    QString text;   ///< text at the time of saving (no formatting info though)
 };
 
 
-// Border
+/// Border
 class BorderData
 {
 public:
@@ -359,9 +378,9 @@ public:
 };
 
 /**
-  * Tabulator (see also <TABULATOR> element in KWord's DTD)
+  * Tabulator (see also \<TABULATOR\> element in KWord's DTD)
   */
-class TabulatorData
+class KOFFICEFILTER_EXPORT TabulatorData
 {
 public:
 
@@ -395,7 +414,7 @@ public:
     virtual ~TabulatorList(void) {}
 };
 
-// Paragraph layout
+/// Paragraph layout
 class LayoutData
 {
 public:
@@ -411,30 +430,30 @@ public:
 
     QString     styleName;
     QString     styleFollowing;
-    QString     alignment;      // left, right, center, justify
+    QString     alignment;      ///< left, right, center, justify
     CounterData counter;
     FormatData  formatData;
-    double      indentFirst;    // indentation correction of first line (can be negative!)
-    double      indentLeft;     // left indentation (a negative value means invalid)
-    double      indentRight;    // right indentation (a negative value means invalid)
-    double      marginTop;      // space before the paragraph  (a negative value means invalid)
-    double      marginBottom;   // space after the paragraph (a negative value means invalid)
+    double      indentFirst;    ///< indentation correction of first line (can be negative!)
+    double      indentLeft;     ///< left indentation (a negative value means invalid)
+    double      indentRight;    ///< right indentation (a negative value means invalid)
+    double      marginTop;      ///< space before the paragraph  (a negative value means invalid)
+    double      marginBottom;   ///< space after the paragraph (a negative value means invalid)
 
-    int         lineSpacingType;// 0=custom, 10=one line, 15=one and half lines, 20= 2 lines
-    double      lineSpacing;    // Space between lines in pt, if lineSpacingType==0
+    int         lineSpacingType;///< 0=custom, 10=one line, 15=one and half lines, 20= 2 lines \todo: document the other values
+    double      lineSpacing;    ///< Space between lines in pt, if lineSpacingType==0
 
     bool        pageBreakBefore;
     bool        pageBreakAfter;
     bool        keepLinesTogether;
 
-    double      shadowDistance; // distance of <SHADOW>
-    int         shadowDirection;// direction of <SHADOW>
-    QColor      shadowColor;    // red, green, blue of <SHADOW>
+    double      shadowDistance; ///< distance of \<SHADOW\>
+    int         shadowDirection;///< direction of \<SHADOW\>
+    QColor      shadowColor;    ///< red, green, blue of \<SHADOW\>
     BorderData  leftBorder;
     BorderData  rightBorder;
     BorderData  topBorder;
     BorderData  bottomBorder;
-    TabulatorList tabulatorList; // List of tabulators
+    TabulatorList tabulatorList; ///< List of tabulators
 };
 
 
@@ -462,14 +481,14 @@ struct HeaderFooterData
 typedef HeaderFooterData HeaderData;
 typedef HeaderFooterData FooterData;
 
-// data for FRAMESET which holds footnotes
+/// data for \<FRAMESET\> which holds footnotes
 struct FootnoteData
 {
     QString frameName;
     QValueList<ParaData> para;
 };
 
-// see <VARIABLESETTINGS> in the KWord DTD
+/// see \<VARIABLESETTINGS\> in the KWord DTD
 class VariableSettingsData
 {
 public:
@@ -499,6 +518,8 @@ public:
     // <ABOUT>
     QString title;
     QString abstract;
+    QString keywords;
+    QString subject;
     // <AUTHOR>
     QString fullName;
     QString jobTitle;
@@ -511,6 +532,27 @@ public:
     QString city;
     QString street;
     QString initial;
+    QString position;
+    QString telephonework;
+};
+
+/// \since 1.4
+class Bookmark
+{
+public:
+    Bookmark();
+    /// Bookmark name
+    QString m_name;
+    /// Name of the frameset where the bookmark is
+    QString m_frameset;
+    /// Number of the paragrapgh where the booksmark starts
+    int m_startparag;
+    /// Number of the paragrapgh where the booksmark starts
+    int m_endparag;
+    /// Position where the bookmark starts in the paragraph
+    int m_cursorIndexStart;
+    /// Position where the bookmark ends in the paragraph
+    int m_cursorIndexEnd;
 };
 
 // Helper functions
