@@ -53,7 +53,7 @@ public:
 protected:
 	virtual void setupTranslations (void)
 	{
-		KGlobal::locale()->insertCatalogue ("kwordmswritefilter");
+		KGlobal::locale()->insertCatalogue ("kofficefilters");
 	}
 };
 
@@ -1346,7 +1346,7 @@ MSWriteImport::~MSWriteImport ()
 
 KoFilter::ConversionStatus MSWriteImport::convert (const QCString &from, const QCString &to)
 {
-	kdDebug (30509) << "MSWriteImport $Date: 2003/08/31 10:59:34 $ using LibMSWrite "
+	kdDebug (30509) << "MSWriteImport $Date: 2004-02-14 17:58:46 +0100 (Sat, 14 Feb 2004) $ using LibMSWrite "
 			  				<< MSWrite::Version << endl;
 
 	if (to != "application/x-kword" || from != "application/x-mswrite")
