@@ -40,7 +40,7 @@
 #include "palmdocexport.h"
 
 typedef KGenericFactory<PalmDocExport, KoFilter> PalmDocExportFactory;
-K_EXPORT_COMPONENT_FACTORY( libpalmdocexport, PalmDocExportFactory( "palmdocexport" ) )
+K_EXPORT_COMPONENT_FACTORY( libpalmdocexport, PalmDocExportFactory( "kofficefilters" ) )
 
 class PalmDocWorker : public KWEFBaseWorker
 {
@@ -103,7 +103,7 @@ bool PalmDocWorker::doFullDocumentInfo( const KWEFDocumentInfo& docInfo )
 bool PalmDocWorker::doFullParagraph(const QString& paraText, 
   const LayoutData& layout, const ValueListFormatData& paraFormatDataList)
 {
-  kdDebug() << "Entering ::doFullParagraph" << endl;
+  kdDebug(30525) << "Entering ::doFullParagraph" << endl;
   text.append( paraText );
   text.append( "\n\n" );
 
