@@ -49,11 +49,11 @@ public:
 protected:
     virtual void setupTranslations( void )
     {
-        KGlobal::locale()->insertCatalogue( "olefilterswinword97filter" );
+        KGlobal::locale()->insertCatalogue( "kofficefilters" );
     }
 };
 
-K_EXPORT_COMPONENT_FACTORY( libolefilter, OLEFilterFactory() );
+K_EXPORT_COMPONENT_FACTORY( libolefilter, OLEFilterFactory() )
 
 OLEFilter::OLEFilter(KoFilter *, const char *, const QStringList&) :
                      KoEmbeddingFilter(), numPic( 0 ),
@@ -190,7 +190,7 @@ void OLEFilter::slotSaveDocumentInformation(
     author->setTitle(title);
     author->setCompany(company);
     author->setEmail(email);
-    author->setTelephone(telephone);
+    author->setTelephoneHome(telephone);
     author->setFax(fax);
     author->setCountry(postalCode);
     author->setPostalCode(country);
