@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2002, The Karbon Developers
+   Copyright (C) 2002, 2003 The Karbon Developers
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,10 +22,12 @@
 
 #include "vcommand.h"
 
-
 class VSelection;
 
-
+/**
+ * Command that changes the z-order of the selection within a layer
+ * to front, back, one step up, or one step down.
+ */
 class VZOrderCmd : public VCommand
 {
 public:
@@ -38,14 +40,16 @@ public:
 	};
 
 	VZOrderCmd( VDocument* doc, VOrder );
+	VZOrderCmd( VDocument* doc, VObject *obj, VOrder );
 	virtual ~VZOrderCmd();
 
 	virtual void execute();
 	virtual void unexecute();
+	virtual bool isExecuted() { return true; }
 
-private:
-	VSelection* m_selection;
-	VOrder m_state;
+protected:
+	VSelection *m_selection;
+	VOrder		m_state;
 };
 
 #endif
