@@ -24,6 +24,9 @@
 
 #include <koPoint.h>
 #include <koRect.h>
+#include <koStore.h>
+#include <koxmlwriter.h>
+#include <koxmlns.h>
 
 #include "vcomposite.h"
 #include "vcomposite_iface.h"
@@ -224,6 +227,12 @@ VPath::close()
 	m_paths.append( path );
 }
 
+bool
+VPath::isClosed() const
+{
+	return m_paths.getLast()->isEmpty() || m_paths.getLast()->isClosed();
+}
+
 void
 VPath::combine( const VPath& composite )
 {
@@ -348,6 +357,45 @@ VPath::save( QDomElement& element ) const
 	}
 }
 
+void
+VPath::saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles ) const
+{
+	if( state() != deleted )
+	{
+		docWriter->startElement( "draw:path" );
+
+		QString d;
+		saveSvgPath( d );
+		docWriter->addAttribute( "svg:d", d );
+
+		// save fill rule if necessary:
+		if( !( m_fillRule == evenOdd ) )
+			docWriter->addAttribute( "svg:fill-rule", "winding" );
+		VObject::saveOasis( store, docWriter, mainStyles );
+
+		docWriter->endElement();
+	}
+}
+
+bool
+VPath::loadOasis( const QDomElement &element, KoOasisContext &context )
+{
+	setState( normal );
+
+	QString data = element.attributeNS( KoXmlNS::svg, "d", QString::null );
+	if( data.length() > 0 )
+	{
+		loadSvgPath( data );
+	}
+
+	m_fillRule = element.attributeNS( KoXmlNS::svg, "fill-rule", QString::null ) == "winding" ? winding : evenOdd;
+
+	QString trafo = element.attributeNS( KoXmlNS::draw, "transform", QString::null );
+	if( !trafo.isEmpty() )
+		transform( trafo );
+
+	return VObject::loadOasis( element, context );
+}
 
 void
 VPath::load( const QDomElement& element )
@@ -510,18 +558,19 @@ VPath::parseTransform( const QString &transform )
 	return result;
 }
 
-void
-VPath::writeTransform( QDomElement &me ) const
+QString
+VPath::buildSvgTransform() const
 {
+	QString transform;
 	if( !m_matrix.isIdentity() )
 	{
-		QString transform = QString("matrix(%1, %2, %3, %4, %5, %6)").arg( m_matrix.m11() )
-																	.arg( m_matrix.m12() )
-																	.arg( m_matrix.m21() )
-																	.arg( m_matrix.m22() )
-																	.arg( m_matrix.dx() )
-																	.arg( m_matrix.dy() );
-		me.setAttribute( "transform", transform );
+		transform = QString(  "matrix(%1, %2, %3, %4, %5, %6)" ).arg( m_matrix.m11() )
+																.arg( m_matrix.m12() )
+																.arg( m_matrix.m21() )
+																.arg( m_matrix.m22() )
+																.arg( m_matrix.dx() )
+																.arg( m_matrix.dy() );
 	}
+	return transform;
 }
 
