@@ -23,6 +23,11 @@
 
 #include <qdom.h>
 
+#include <koStore.h>
+#include <koxmlwriter.h>
+#include <kooasiscontext.h>
+#include <koStyleStack.h>
+
 #include "vcomposite.h"
 #include "shapes/vellipse.h"
 #include "shapes/vrectangle.h"
@@ -168,6 +173,68 @@ VGroup::save( QDomElement& element ) const
 	}
 }
 
+void
+VGroup::saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles ) const
+{
+	docWriter->startElement( "draw:g" );
+
+	// save objects:
+	VObjectListIterator itr = m_objects;
+
+	for ( ; itr.current(); ++itr )
+		itr.current()->saveOasis( store, docWriter, mainStyles );
+
+	docWriter->endElement();
+}
+
+bool
+VGroup::loadOasis( const QDomElement &element, KoOasisContext &context )
+{
+	m_objects.setAutoDelete( true );
+	m_objects.clear();
+	m_objects.setAutoDelete( false );
+
+	QDomNodeList list = element.childNodes();
+	for( uint i = 0; i < list.count(); ++i )
+	{
+		if( list.item( i ).isElement() )
+		{
+			QDomElement e = list.item( i ).toElement();
+
+			context.styleStack().save();
+
+			if( e.tagName() == "draw:path" )
+			{
+				VPath* composite = new VPath( this );
+				composite->loadOasis( e, context );
+				append( composite );
+			}
+			else if( e.tagName() == "draw:ellipse" )
+			{
+				VEllipse* ellipse = new VEllipse( this );
+				ellipse->loadOasis( e, context );
+				append( ellipse );
+			}
+			else if( e.tagName() == "draw:rect" )
+			{
+				VRectangle* rectangle = new VRectangle( this );
+				rectangle->loadOasis( e, context );
+				append( rectangle );
+			}
+			else if( e.tagName() == "draw:g" )
+			{
+				VGroup* group = new VGroup( this );
+				group->loadOasis( e, context );
+				append( group );
+			}
+
+			context.styleStack().restore();
+		}
+	}
+
+	return true;
+}
+
 void
 VGroup::load( const QDomElement& element )
 {
