@@ -147,6 +147,16 @@ VLayer::save( QDomElement& element ) const
 	VObject::save( me );
 }
 
+void
+VLayer::saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles ) const
+{
+	// save objects:
+	VObjectListIterator itr = m_objects;
+
+	for ( ; itr.current(); ++itr )
+		itr.current()->saveOasis( store, docWriter, mainStyles );
+}
+
 void
 VLayer::load( const QDomElement& element )
 {
