@@ -20,6 +20,11 @@
 
 #include <qdom.h>
 
+#include <koGenStyles.h>
+#include <koStyleStack.h>
+#include <koUnit.h>
+#include <koxmlns.h>
+
 #include "vobject.h"
 #include "vstroke.h"
 #include <kdebug.h>
@@ -99,6 +104,63 @@ VStroke::save( QDomElement& element ) const
 	m_dashPattern.save( me );
 }
 
+void
+VStroke::saveOasis( KoGenStyle &style ) const
+{
+	if( m_type == solid )
+	{
+		style.addProperty( "draw:stroke", "solid" );
+		style.addProperty( "svg:stroke-color", QColor( m_color ).name() );
+		style.addPropertyPt( "svg:stroke-width", m_lineWidth );
+		if( m_color.opacity() < 1 )
+			style.addProperty( "svg:stroke-opacity", QString( "%1%" ).arg( m_color.opacity() * 100. ) );
+	}
+	else if( m_type == none )
+		style.addProperty( "draw:stroke", "none" );
+	/*else if( m_type == grad )
+		style.addProperty( "draw:stroke", "gradient" );
+	else if( m_type == patt )
+		style.addProperty( "draw:stroke", "hatch" );*/
+
+	if( m_lineJoin == joinRound )
+		style.addProperty( "draw:stroke-linejoin", "round" );
+	else if( m_lineJoin == joinBevel )
+		style.addProperty( "draw:stroke-linejoin", "bevel" );
+	else if( m_lineJoin == joinMiter )
+		style.addProperty( "draw:stroke-linejoin", "miter" );
+}
+
+void
+VStroke::loadOasis( const KoStyleStack &stack )
+{
+	if( stack.hasAttributeNS( KoXmlNS::draw, "stroke" ))
+	{
+		if( stack.attributeNS( KoXmlNS::draw, "stroke" ) == "solid" )
+		{
+			setType( VStroke::solid );
+			setColor( QColor( stack.attributeNS( KoXmlNS::svg, "stroke-color" ) ) );
+			if( stack.hasAttributeNS( KoXmlNS::svg, "stroke-opacity" ) )
+				m_color.setOpacity( stack.attributeNS( KoXmlNS::svg, "stroke-opacity" ).remove( '%' ).toFloat() / 100. );
+			QString join = stack.attributeNS( KoXmlNS::draw, "stroke-linejoin" );
+			if( !join.isEmpty() )
+			{
+				if( join == "round" )
+					m_lineJoin = joinRound;
+				else if( join == "bevel" )
+					m_lineJoin = joinBevel;
+				else
+					m_lineJoin = joinMiter;
+			}
+		}
+		else if( stack.attributeNS( KoXmlNS::draw, "stroke" ) == "none" )
+			setType( VStroke::none );
+	}
+	if( stack.hasAttributeNS( KoXmlNS::svg, "stroke-width" ) )
+		m_lineWidth = KoUnit::parseValue( stack.attributeNS( KoXmlNS::svg, "stroke-width" ) );
+	if( m_lineWidth < 0.0 )
+		m_lineWidth = 0.0;
+}
+
 void
 VStroke::load( const QDomElement& element )
 {
