@@ -26,10 +26,11 @@
 class KarbonView;
 class KConfig;
 class KIntNumInput;
+class KColorButton;
+class KoBuggyUnitDoubleSpinBox;
 class QCheckBox;
 class QComboBox;
 
-
 class VConfigInterfacePage : public QObject
 {
 	Q_OBJECT
@@ -67,6 +68,9 @@ public:
 
 	void apply();
 
+signals:
+	void unitChanged( int );
+
 public slots:
 	void slotDefault();
 
@@ -80,7 +84,6 @@ private:
 	QComboBox *m_unit;
 };
 
-
 class VConfigDefaultPage : public QObject
 {
 	Q_OBJECT
@@ -106,6 +109,34 @@ private:
 	bool m_oldSaveAsPath;
 };
 
+class VConfigGridPage : public QObject
+{
+	Q_OBJECT
+
+public:
+	VConfigGridPage(
+		KarbonView* view, QVBox* box, char* name = 0L );
+
+	void apply();
+
+public slots:
+	void slotDefault();
+	void slotUnitChanged( int );
+
+protected slots:
+	void setMaxHorizSnap( double v );
+	void setMaxVertSnap( double v );
+
+private:
+	KarbonView* m_view;
+	KoBuggyUnitDoubleSpinBox* m_spaceHorizUSpin;
+	KoBuggyUnitDoubleSpinBox* m_spaceVertUSpin;
+	KoBuggyUnitDoubleSpinBox* m_snapHorizUSpin;
+	KoBuggyUnitDoubleSpinBox* m_snapVertUSpin;
+	QCheckBox* m_gridChBox;
+	QCheckBox* m_snapChBox;
+	KColorButton* m_gridColorBtn;
+};
 
 class VConfigureDlg : public KDialogBase
 {
@@ -121,6 +152,7 @@ public slots:
 private:
 	VConfigInterfacePage* m_interfacePage;
 	VConfigMiscPage* m_miscPage;
+	VConfigGridPage* m_gridPage;
 	VConfigDefaultPage* m_defaultDocPage;
 };
 
