@@ -50,7 +50,7 @@ VStrokeDlg::VStrokeDlg( KarbonPart* part, QWidget* parent, const char* name )
 
 	QLabel* widthLabel = new QLabel( i18n ( "Width:" ), mainWidget );
 	leftLayout->addWidget ( widthLabel );
-	m_setLineWidth = new KoUnitDoubleSpinBox( mainWidget, 0.0, 1000.0, 0.5, 1.0, KoUnit::U_PT, 1 );
+	m_setLineWidth = new KoBuggyUnitDoubleSpinBox( mainWidget, 0.0, 1000.0, 0.5, 1.0, KoUnit::U_PT, 1 );
 	leftLayout->addWidget ( m_setLineWidth );
 
 	//Dashing ->
@@ -169,7 +169,7 @@ void VStrokeDlg::slotOKClicked()
 {
 	m_stroke.setLineWidth ( m_setLineWidth->value() );
 
-	m_stroke.setColor( m_colortab->getColor() );
+	m_stroke.setColor( m_colortab->Color() );
 
 	if( m_part && m_part->document().selection()->objects().count() > 0 )
 		m_part->addCommand( new VStrokeCmd( &m_part->document(), &m_stroke ), true );
