@@ -23,12 +23,15 @@
 #include <qiconset.h>
 #include <qapplication.h>
 #include <qclipboard.h>
+#include <qpopupmenu.h>
 
 #include <kaction.h>
 #include <kcolordrag.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
+#include <kdeversion.h>
+
 #include <koMainWindow.h>
 #include <koFilterManager.h>
 #include <kstatusbar.h>
@@ -43,6 +46,7 @@
 #include "valigncmd.h"
 #include "vcleanupcmd.h"
 #include "vclipartcmd.h"
+#include "vclosepathcmd.h"
 #include "vdeletecmd.h"
 #include "vfillcmd.h"
 #include "vgroupcmd.h"
@@ -64,6 +68,9 @@
 // ToolBars
 #include "vselecttoolbar.h"
 
+// Statusbar
+#include "vsmallpreview.h"
+
 // The rest.
 #include "karbon_factory.h"
 #include "karbon_part.h"
@@ -72,6 +79,7 @@
 #include "vselection.h"
 #include "vtool.h"
 #include "vtoolcontroller.h"
+#include "vcomposite.h"
 #include "vgroup.h"
 #include "vpainterfactory.h"
 #include "vqpainter.h"
@@ -115,6 +123,8 @@ KarbonView::KarbonView( KarbonPart* p, QWidget* parent, const char* name )
 	m_cursorCoords->setAlignment( AlignLeft | AlignVCenter );
 	m_cursorCoords->setMinimumWidth( 50 );
 	addStatusBarItem( m_cursorCoords, 0 );
+	m_smallPreview = new VSmallPreview( this, name );
+	addStatusBarItem( m_smallPreview );
 
 	initActions();
 
@@ -129,7 +139,8 @@ KarbonView::KarbonView( KarbonPart* p, QWidget* parent, const char* name )
 	if( shell() )
 	{
 		//Create Dockers
-		m_ColorManager = new VColorDocker( part(), this );
+		m_ColorManager = new VColorDocker( this );
+		connect( m_ColorManager, SIGNAL( colorChanged() ), this, SLOT( colorDockerChanged() ) );
 		m_strokeDocker = new VStrokeDocker( part(), this );
 		m_styleDocker = new VStyleDocker( part(), this );
 		m_TransformDocker = new VTransformDocker( part(), this );
@@ -158,6 +169,9 @@ KarbonView::KarbonView( KarbonPart* p, QWidget* parent, const char* name )
 	m_horizRuler->show();
 	m_vertRuler->show();
 
+	m_horizRuler->installEventFilter(m_canvas);
+	m_vertRuler->installEventFilter(m_canvas);
+
 	// set up factory
 	m_painterFactory = new VPainterFactory;
 	m_painterFactory->setPainter( canvasWidget()->pixmap(), width(), height() );
@@ -172,12 +186,15 @@ KarbonView::~KarbonView()
 	if( shell() )
 	{
 		delete( m_ColorManager );
+		disconnect( m_ColorManager, SIGNAL( colorChanged() ), this, SLOT( colorDockerChanged() ) );
 		delete( m_strokeDocker );
 		delete( m_styleDocker );
+		disconnect( this, SIGNAL( selectionChange() ), m_TransformDocker, SLOT( update() ) );
 		delete( m_TransformDocker );
 	}
 
 	// widgets:
+	delete( m_smallPreview );
 	delete( m_status );
 	delete( m_cursorCoords );
 
@@ -564,6 +581,12 @@ KarbonView::ungroupSelection()
 	part()->addCommand( new VUnGroupCmd( &part()->document() ), true );
 }
 
+void
+KarbonView::closePath()
+{
+	part()->addCommand( new VClosePathCmd( &part()->document() ), true );
+}
+
 // TODO: remove this one someday:
 void
 KarbonView::dummyForTesting()
@@ -621,6 +644,18 @@ KarbonView::setZoomAt( double zoom, const KoPoint &p )
 	zoomChanged( p );
 }
 
+void
+KarbonView::viewZoomIn()
+{
+	setZoomAt( zoom() * 1.50 );
+}
+
+void
+KarbonView::viewZoomOut()
+{
+	setZoomAt( zoom() * 0.75 );
+}
+
 void
 KarbonView::zoomChanged( const KoPoint &p )
 {
@@ -662,6 +697,7 @@ KarbonView::zoomChanged( const KoPoint &p )
 	kdDebug(38000) << "centerX : " << centerX << endl;
 	kdDebug(38000) << "centerY : " << centerY << endl;
 	kdDebug(38000) << "zoomFactor : " << zoomFactor << endl;
+	if( zoomFactor == 0.0 ) return;
 
 	// above 2000% probably doesn't make sense... (Rob)
 	if( zoomFactor > 20 )
@@ -795,6 +831,9 @@ KarbonView::initActions()
 	m_zoomAction->setEditable( true );
 	m_zoomAction->setCurrentItem( 7 );
 
+	KStdAction::zoomIn( this, SLOT( viewZoomIn() ), actionCollection(), "view_zoom_in" );
+	KStdAction::zoomOut( this, SLOT( viewZoomOut() ), actionCollection(), "view_zoom_out" );
+
 	// No need for the other actions in read-only (embedded) mode
 	if( !shell() )
 		return;
@@ -806,16 +845,12 @@ KarbonView::initActions()
 					  SLOT( editCopy() ), actionCollection(), "edit_copy" );
 	KStdAction::paste( this,
 					   SLOT( editPaste() ), actionCollection(), "edit_paste" );
-	KStdAction::selectAll( this,
-						   SLOT( editSelectAll() ), actionCollection(), "edit_select_all" );
+	KStdAction::selectAll( this, SLOT( editSelectAll() ), actionCollection(), "edit_select_all" );
+	KStdAction::deselect( this, SLOT( editDeselectAll() ), actionCollection(), "edit_deselect_all" );
 
 	new KAction(
 		i18n( "&Import Graphic..." ), 0, 0, this,
 		SLOT( fileImportGraphic() ), actionCollection(), "file_import" );
-
-	new KAction(
-		i18n( "&Deselect All" ), QKeySequence( "Ctrl+D" ), this,
-		SLOT( editDeselectAll() ), actionCollection(), "edit_deselect_all" );
 	m_deleteSelectionAction = new KAction(
 		i18n( "D&elete" ), "editdelete", QKeySequence( "Del" ), this,
 		SLOT( editDeleteSelection() ), actionCollection(), "edit_delete" );
@@ -864,36 +899,55 @@ KarbonView::initActions()
 		actionCollection(), "object_align_vertical_bottom" );
 
 	m_showRulerAction = new KToggleAction( i18n( "Show Rulers" ), 0, this, SLOT( showRuler() ), actionCollection(), "view_show_ruler" );
+#if KDE_IS_VERSION(3,2,90)
+	m_showRulerAction->setCheckedState(i18n("Hide Rulers"));
+#endif
 	m_showRulerAction->setToolTip( i18n( "Shows or hides rulers." ) );
 	m_showRulerAction->setChecked( true );
+	m_showGridAction = new KToggleAction( i18n( "Show Grid" ), "view_grid", this, SLOT( showGrid() ), actionCollection(), "view_show_grid" );
+#if KDE_IS_VERSION(3,2,90)
+	m_showGridAction->setCheckedState(i18n("Hide Grid"));
+#endif
+	m_showGridAction->setToolTip( i18n( "Shows or hides grid." ) );
+	//m_showGridAction->setChecked( true );
+	m_snapGridAction = new KToggleAction( i18n( "Snap to Grid" ), 0, this, SLOT( snapToGrid() ), actionCollection(), "view_snap_to_grid" );
+	m_snapGridAction->setToolTip( i18n( "Snaps to grid." ) );
+	//m_snapGridAction->setChecked( true );
 	m_groupObjects = new KAction(
-		i18n( "&Group Objects" ), "14_group", QKeySequence( "Ctrl+G" ), this,
+		i18n( "&Group Objects" ), "group", QKeySequence( "Ctrl+G" ), this,
 		SLOT( groupSelection() ), actionCollection(), "selection_group" );
 	m_ungroupObjects = new KAction(
-		i18n( "&Ungroup Objects" ), "14_ungroup", QKeySequence( "Ctrl+U" ), this,
+		i18n( "&Ungroup Objects" ), "ungroup", QKeySequence( "Ctrl+U" ), this,
 		SLOT( ungroupSelection() ), actionCollection(), "selection_ungroup" );
+	m_closePath = new KAction(
+		i18n( "&Close Path" ), 0 /*QKeySequence( "Ctrl+U" )*/, this,
+		SLOT( closePath() ), actionCollection(), "close_path" );
 	// object <-----
 
 	new KAction(
 		i18n( "&Color Manager" ), "colorman", 0, this,
 		SLOT( viewColorManager() ), actionCollection(), "view_color_manager" );
 	new KAction(
-		i18n( "&Transform" ), "14_transform", 0, this,
+		i18n( "&Transform" ), "transform", 0, this,
 		SLOT( objectTransform() ), actionCollection(), "view_transform_docker" );
 	new KAction(
 		i18n( "&Stroke" ), "strokedocker", 0, this,
 		SLOT( viewStrokeDocker() ), actionCollection(), "view_stroke_docker" );
 	new KAction(
-		i18n( "&Style" ), "styledocker", 0, this,
+		i18n( "&Style" ), 0, this,
 		SLOT( viewStyleDocker() ), actionCollection(), "view_style_docker" );
 	// view <-----
 
 	// line width
 	m_setLineWidth = new KoUnitDoubleSpinComboBox( this, 0.0, 1000.0, 0.5, 1.0, KoUnit::U_PT, 1 );
 	new KWidgetAction( m_setLineWidth, i18n( "Set Line Width" ), 0, this, SLOT( setLineWidth() ), actionCollection(), "setLineWidth" );
+	m_setLineWidth->insertItem( 0.25 );
 	m_setLineWidth->insertItem( 0.5 );
+	m_setLineWidth->insertItem( 0.75 );
 	m_setLineWidth->insertItem( 1.0 );
 	m_setLineWidth->insertItem( 2.0 );
+	m_setLineWidth->insertItem( 3.0 );
+	m_setLineWidth->insertItem( 4.0 );
 	m_setLineWidth->insertItem( 5.0 );
 	m_setLineWidth->insertItem( 10.0 );
 	m_setLineWidth->insertItem( 20.0 );
@@ -903,7 +957,7 @@ KarbonView::initActions()
 				i18n( "Configure Karbon..." ), "configure", 0, this,
 				SLOT( configure() ), actionCollection(), "configure" );
 
-	new KAction( i18n( "Configure Page &Layout..." ), 0, this,
+	new KAction( i18n( "Page &Layout..." ), 0, this,
 			SLOT( pageLayout() ), actionCollection(), "page_layout" );
 	m_contextHelpAction = new KoContextHelpAction( actionCollection(), this );
 }
@@ -917,21 +971,24 @@ KarbonView::paintEverything( QPainter& /*p*/, const QRect& /*rect*/, bool /*tran
 bool
 KarbonView::mouseEvent( QMouseEvent* event, const KoPoint &p )
 {
-	if( event->type() == QEvent::Enter )
-	{
-		QMouseEvent* mouseEvent = static_cast<QMouseEvent*>( event );
-		m_horizRuler->setMousePos( mouseEvent->pos().x(), mouseEvent->pos().y() );
-		m_vertRuler->setMousePos( mouseEvent->pos().x(), mouseEvent->pos().y() );
-		m_horizRuler->update();
-		m_vertRuler->update();
-	}
-	else if( event->type() == QEvent::MouseMove )
-	{
-		QMouseEvent* mouseEvent = static_cast<QMouseEvent*>( event );
-		m_horizRuler->setMousePos( mouseEvent->pos().x(), mouseEvent->pos().y() );
-		m_vertRuler->setMousePos( mouseEvent->pos().x(), mouseEvent->pos().y() );
-		m_cursorCoords->setText( QString( "%1, %2" ).arg( p.x(), 0, 'f', 2 ).arg( p.y(), 0, 'f', 2 ) );
-	}
+	int mx = event->pos().x();
+	int my = event->pos().y();
+
+	m_horizRuler->setMousePos( mx, my );
+	m_vertRuler->setMousePos( mx, my );
+
+	m_horizRuler->update();
+	m_vertRuler->update();
+	
+	KoPoint xy;
+	xy.setX((mx + canvasWidget()->contentsX() - canvasWidget()->pageOffsetX())/zoom());
+	xy.setY((my + canvasWidget()->contentsY() - canvasWidget()->pageOffsetY())/zoom());
+
+	xy.setX(KoUnit::toUserValue(xy.x(), part()->unit()));
+	xy.setY(KoUnit::toUserValue(xy.y(), part()->unit()));
+	
+	m_cursorCoords->setText( QString( "%1, %2" ).arg(KGlobal::_locale->formatNumber(xy.x(), 2)).arg(KGlobal::_locale->formatNumber(xy.y(), 2)) );
+	
 	part()->toolController()->setActiveView( this );
 	if( part()->toolController() )
 		return part()->toolController()->mouseEvent( event, p );
@@ -989,6 +1046,33 @@ KarbonView::showRuler()
 	}
 }
 
+void
+KarbonView::showGrid()
+{
+	m_part->document().grid().isShow = m_showGridAction->isChecked();
+}
+
+void
+KarbonView::snapToGrid()
+{
+	m_part->document().grid().isSnap = m_snapGridAction->isChecked();
+}
+
+void
+KarbonView::showSelectionPopupMenu( const QPoint &pos )
+{
+	QPtrList<KAction> actionList;
+	if( m_groupObjects->isEnabled() )
+		actionList.append( m_groupObjects );
+	else if( m_ungroupObjects->isEnabled() )
+		actionList.append( m_ungroupObjects );
+	if( m_closePath->isEnabled() )
+		actionList.append( m_closePath );
+	plugActionList( "selection_type_action", actionList );
+	((QPopupMenu *)factory()->container( "selection_popup", this ) )->exec( pos );
+	unplugActionList( "selection_type_action" );
+}
+
 void
 KarbonView::configure()
 {
@@ -1032,31 +1116,52 @@ KarbonView::canvasContentsMoving( int x, int y )
 	}
 }
 
+void KarbonView::colorDockerChanged()
+{
+	if ( m_ColorManager->isStrokeDocker() && m_part && m_part->document().selection() )
+		m_part->addCommand( new VStrokeCmd( &m_part->document(), m_ColorManager->color() ), true );
+	else if( m_part && m_part->document().selection() )
+		m_part->addCommand( new VFillCmd( &m_part->document(), VFill( m_ColorManager->color() ) ), true );
+}
+
 void
 KarbonView::selectionChanged()
 {
 	int count = part()->document().selection()->objects().count();
+	m_groupObjects->setEnabled( false );
+	m_closePath->setEnabled( false );
+	m_ungroupObjects->setEnabled( false );
 
 	if( count > 0 )
 	{
-		VGroup *group = dynamic_cast<VGroup *>( part()->document().selection()->objects().getFirst() );
-		m_groupObjects->setEnabled( count > 1 );
-		m_ungroupObjects->setEnabled( group && ( count == 1 ) );
 		VObject *obj = part()->document().selection()->objects().getFirst();
 
 		if( count == 1 )
 		{
-			m_strokeFillPreview->update( *obj->stroke(), *obj->fill() );
+			if ( shell() ) {
+				if ( this == shell()->rootView() || koDocument()->isEmbedded() ) {
+					m_strokeFillPreview->update( *obj->stroke(), *obj->fill() );
+					m_smallPreview->update( *obj->stroke(), *obj->fill() );
+				}
+			}
 			m_strokeDocker->setStroke( *( obj->stroke() ) );
+			VGroup *group = dynamic_cast<VGroup *>( part()->document().selection()->objects().getFirst() );
+			m_ungroupObjects->setEnabled( group );
+			VPath *path = dynamic_cast<VPath *>( part()->document().selection()->objects().getFirst() );
+			m_closePath->setEnabled( path && !path->isClosed() );
 		}
 		else
 		{
 			VStroke stroke;
 			stroke.setType( VStroke::none );
 			VFill fill;
-			m_strokeFillPreview->update( stroke, fill );
+			if ( shell() )
+				if ( this == shell()->rootView() || koDocument()->isEmbedded() ) {
+					m_strokeFillPreview->update( stroke, fill );
+					m_smallPreview->update( stroke, fill );
+				}
+			m_groupObjects->setEnabled( true );
 		}
-
 		part()->document().selection()->setStroke( *obj->stroke() );
 		part()->document().selection()->setFill( *obj->fill() );
 		m_setLineWidth->setEnabled( true );
@@ -1067,13 +1172,12 @@ KarbonView::selectionChanged()
 	}
 	else
 	{
-		m_strokeFillPreview->update( *( part()->document().selection()->stroke() ),
+		if ( shell() )
+			if ( this == shell()->rootView() || koDocument()->isEmbedded() )
+			m_strokeFillPreview->update( *( part()->document().selection()->stroke() ),
 									 *( part()->document().selection()->fill() ) );
 		m_setLineWidth->setEnabled( false );
-		m_groupObjects->setEnabled( false );
-		m_ungroupObjects->setEnabled( false );
 	}
-
 	emit selectionChange();
 }
 void
@@ -1106,10 +1210,12 @@ KarbonView::setViewportRect( const KoRect &rect )
 }
 
 void
-KarbonView::setUnit( KoUnit::Unit /*_unit*/ )
+KarbonView::setUnit( KoUnit::Unit _unit )
 {
 	if( part()->toolController()->activeTool() )
 		part()->toolController()->activeTool()->refreshUnit();
+	m_horizRuler->setUnit( _unit );
+	m_vertRuler->setUnit( _unit );
 }
 
 #include "karbon_view.moc"
