@@ -55,10 +55,14 @@
 
 #include <kdebug.h>
 #include <kglobal.h>
+#include <kiconloader.h>
 #include <math.h>
 
 #include <koPoint.h>
 #include <koRect.h>
+#include <karbon_factory.h>
+#include <karbon_resourceserver.h>
+
 
 #define INITIAL_ALLOC	300
 #define ALLOC_INCREMENT	100
@@ -610,14 +614,20 @@ VKoPainter::drawVPath( ArtVpath *vec )
 void
 VKoPainter::applyPattern( ArtSVP *svp, bool fill )
 {
+	if(!svp) {
+		return;
+	}
+
 	int x0, y0, x1, y1;
 	clampToViewport( *svp, x0, y0, x1, y1 );
 
 	ArtRender *render = 0L;
 
 	VPattern pat = fill ? m_fill->pattern() : m_stroke->pattern();
-	if( !pat.isValid() )
-		pat.load( "pics/cr32-app-karbon.png" );
+	if( !pat.isValid() ) {
+		pat.load( KGlobal::iconLoader()->iconPath( "karbon.png", -KIcon::SizeMedium ) ); }
+		if( !pat.isValid() ) {
+			pat = *(dynamic_cast<VPattern *>(KarbonFactory::rServer()->patterns().getFirst() )) ;}
 
 	ArtPattern *pattern = art_new( ArtPattern, 1 );
 
