@@ -22,6 +22,8 @@
 #include "vtransformcmd.h"
 #include <klocale.h>
 #include <koUnit.h>
+#include <koStore.h>
+#include <koxmlwriter.h>
 #include <vglobal.h>
 #include <vdocument.h>
 #include <qdom.h>
@@ -141,10 +143,79 @@ VEllipse::save( QDomElement& element ) const
 		else
 			me.setAttribute( "kind", "full" );
 
-		writeTransform( me );
+		QString transform = buildSvgTransform();
+		if( !transform.isEmpty() )
+			me.setAttribute( "transform", transform );
 	}
 }
 
+void
+VEllipse::saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles ) const
+{
+	docWriter->startElement( "draw:ellipse" );
+
+	//save all into pt
+	docWriter->addAttributePt( "svg:cx", m_center.x() );
+	docWriter->addAttributePt( "svg:cy", m_center.y() );
+	docWriter->addAttributePt( "svg:rx", m_rx );
+	docWriter->addAttributePt( "svg:ry", m_ry );
+
+	if( m_type == full )
+		docWriter->addAttribute( "draw:kind", "full" );
+	else
+	{
+		if( m_type == cut )
+			docWriter->addAttribute( "draw:kind", "cut" );
+		else if( m_type == section )
+			docWriter->addAttribute( "draw:kind", "section" );
+		else
+			docWriter->addAttribute( "draw:kind", "arc" );
+
+		docWriter->addAttribute( "draw:start-angle", m_startAngle );
+		docWriter->addAttribute( "draw:end-angle", m_endAngle );
+	}
+
+	VObject::saveOasis( store, docWriter, mainStyles );
+
+	QString transform = buildSvgTransform();
+	if( !transform.isEmpty() )
+		docWriter->addAttribute( "draw:transform", transform );
+
+	docWriter->endElement();
+}
+
+bool
+VEllipse::loadOasis( const QDomElement &element, KoOasisContext &context )
+{
+	setState( normal );
+
+	m_rx = KoUnit::parseValue( element.attribute( "svg:rx" ) );
+	m_ry = KoUnit::parseValue( element.attribute( "svg:ry" ) );
+
+	m_center.setX( KoUnit::parseValue( element.attribute( "svg:cx" ) ) );
+	m_center.setY( KoUnit::parseValue( element.attribute( "svg:cy" ) ) );
+
+	m_startAngle = element.attribute( "draw:start-angle" ).toDouble();
+	m_endAngle = element.attribute( "draw:end-angle" ).toDouble();
+
+	if( element.attribute( "draw:kind" ) == "cut" )
+		m_type = cut;
+	else if( element.attribute( "draw:kind" ) == "section" )
+		m_type = section;
+	else if( element.attribute( "draw:kind" ) == "arc" )
+		m_type = arc;
+	else
+		m_type = full;
+
+	init();
+
+	QString trafo = element.attribute( "draw:transform" );
+	if( !trafo.isEmpty() )
+		transform( trafo );
+
+	return VObject::loadOasis( element, context );
+}
+
 void
 VEllipse::load( const QDomElement& element )
 {
