@@ -18,7 +18,6 @@
 */
 
 
-#include <qregexp.h>
 #include <qdom.h>
 
 #include "vglobal.h"
@@ -26,6 +25,8 @@
 #include "vtransformcmd.h"
 #include <klocale.h>
 #include <koUnit.h>
+#include <koStore.h>
+#include <koxmlwriter.h>
 #include <vdocument.h>
 
 VPolygon::VPolygon( VObject* parent, VState state ) 
@@ -46,9 +47,9 @@ VPolygon::init()
 	bool bFirst = true;
 
 	QString points = m_points.simplifyWhiteSpace();
-	points.replace( QRegExp( "," ), " " );
-	points.replace( QRegExp( "\r" ), "" );
-	points.replace( QRegExp( "\n" ), "" );
+	points.remove( ',' );
+	points.remove( '\r' );
+	points.remove( '\n' );
 	QStringList pointList = QStringList::split( ' ', points );
 	for( QStringList::Iterator it = pointList.begin(); it != pointList.end(); it++ )
 	{
@@ -100,10 +101,24 @@ VPolygon::save( QDomElement& element ) const
 
 		me.setAttribute( "points", m_points );
 
-		writeTransform( me );
+		QString transform = buildSvgTransform();
+		if( !transform.isEmpty() )
+			me.setAttribute( "transform", transform );
 	}
 }
 
+void
+VPolygon::saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles ) const
+{
+	docWriter->startElement( "draw:polygon" );
+
+	docWriter->addAttribute( "draw:points", m_points );
+
+	VObject::saveOasis( store, docWriter, mainStyles );
+
+	docWriter->endElement();
+}
+
 void
 VPolygon::load( const QDomElement& element )
 {
