@@ -21,8 +21,9 @@
 #define __VRECTANGLE_H__
 
 #include "vcomposite.h"
+#include <koffice_export.h>
 
-class VRectangle : public VPath
+class KARBONBASE_EXPORT VRectangle : public VPath
 {
 public:
 	VRectangle( VObject* parent, VState state = edit );
@@ -32,7 +33,9 @@ public:
 	virtual QString name() const;
 
 	virtual void save( QDomElement& element ) const;
+	virtual void saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles ) const;
 	virtual void load( const QDomElement& element );
+	virtual bool loadOasis( const QDomElement &element, KoOasisContext &context );
 
 protected:
 	void init();
