@@ -136,7 +136,9 @@ VSpiral::save( QDomElement& element ) const
 
 		me.setAttribute( "type", m_type );
 
-		writeTransform( me );
+		QString transform = buildSvgTransform();
+		if( !transform.isEmpty() )
+			me.setAttribute( "transform", transform );
 	}
 }
 
