@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2002, The Karbon Developers
+   Copyright (C) 2002, 2003 The Karbon Developers
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,27 +21,37 @@
 #define __VSELECTNODESTOOL_H__
 
 #include "vtool.h"
-#include "vselection.h"
 
 class VSelectNodesTool : public VTool
 {
 public:
-	VSelectNodesTool( KarbonView* view );
+	VSelectNodesTool( KarbonPart *part, const char* name );
 	virtual ~VSelectNodesTool();
 
 	virtual void activate();
 
+	virtual QString name() { return i18n( "Select Nodes Tool" ); }
+	virtual QString icon() { return "14_selectnodes"; }
+	virtual QString category() { return "manipulation"; }
+	virtual QString statusText();
+	virtual uint priority() { return 2; }
+
 protected:
 	virtual void draw();
 
 	virtual void setCursor() const;
 
 	virtual void mouseButtonPress();
+	virtual void mouseButtonRelease();
 	virtual void mouseDragRelease();
 	virtual void mouseDrag();
 
+	virtual bool keyReleased( Qt::Key );
+
+	virtual void cancel();
+
 private:
-	enum { normal, dragging, moving } m_state;
+	enum { normal, dragging, moving, movingbezier1, movingbezier2 } m_state;
 
 	void recalc();
 
