@@ -61,6 +61,42 @@ VCanvas::pageOffsetY() const
 		return int( ( contentsHeight() - zoomedHeight ) / 2.0 );
 }
 
+KoPoint VCanvas::snapToGrid( const KoPoint &point )
+{
+	if( !m_part->document().grid().isSnap )
+		return point;
+
+	KoPoint p = point;
+
+	KoSize dist = m_part->document().grid().snap;
+	KoSize dxy = m_part->document().grid().freq;
+
+	int dx = qRound( p.x() / dxy.width() );
+	int dy = qRound( p.y() / dxy.height() );
+
+	float distx = QMIN( QABS( p.x() - dxy.width() * dx ), QABS( p.x() - dxy.width() * ( dx + 1 ) ) );
+	float disty = QMIN( QABS( p.y() - dxy.height() * dy ), QABS( p.y() - dxy.height() * ( dy + 1 ) ) );
+
+	if( distx < dist.width() )
+	{
+		if( QABS(p.x() - dxy.width() * dx ) < QABS( p.x() - dxy.width() * ( dx + 1 ) ) )
+			p.rx() = dxy.width() * dx;
+		else
+			p.rx() = dxy.width() * ( dx + 1 );
+	}
+
+	if( disty < dist.height() )
+	{
+		if( QABS( p.y() - dxy.height() * dy ) < QABS( p.y() - dxy.height() * ( dy + 1 ) ) )
+			p.ry() = dxy.height() * dy;
+		else
+			p.ry() = dxy.height() * ( dy + 1 );
+	}
+
+	return p;
+}
+
+
 VCanvas::VCanvas( QWidget *parent, KarbonViewBase* view, KarbonPartBase* part )
     : QScrollView( parent, "canvas", WStaticContents/*WNorthWestGravity*/ | WResizeNoErase  |
 	  WRepaintNoErase ), m_part( part ), m_view( view )
@@ -306,21 +342,9 @@ VCanvas::repaintAll( bool drawVObjects )
 
 /// repaints just a rect area (no scrolling)
 void
-VCanvas::repaintAll( const KoRect & )
+VCanvas::repaintAll( const KoRect &r )
 {
-	//if( m_view->layersDocker() )
-//		m_view->layersDocker()->updatePreviews();
-	VPainter *p = m_view->painterFactory()->painter();
-	KoRect rect = KoRect::fromQRect( this->rect() );
-	p->blit( rect );
-
-	// draw handle:
-	VQPainter qpainter( p->device() );
-	setYMirroring( &qpainter );
-	qpainter.setZoomFactor( m_view->zoom() );
-	m_part->document().selection()->draw( &qpainter, m_view->zoom() );
-
-	bitBlt( viewport(), QPoint( int( rect.x() ), int( rect.y() ) ), p->device(), rect.toQRect() );
+	drawDocument( 0, r );
 }
 
 void
@@ -361,5 +385,5 @@ VCanvas::dropEvent( QDropEvent *e )
 	m_view->dropEvent( e );
 }
 
-#include <vcanvas.moc>
+#include "vcanvas.moc"
 
