@@ -26,6 +26,9 @@
 #include <dcopref.h>
 #include <qstring.h>
 
+namespace KChart
+{
+
 class KChartParams;
 
 class KChartParamsIface : virtual public DCOPObject
@@ -151,4 +154,6 @@ private:
 
 };
 
+}  //KChart namespace
+
 #endif
