@@ -24,6 +24,9 @@
 
 class QRadioButton;
 
+namespace KChart
+{
+
 class KChartParams;
 
 class KChartComboPage : public QWidget
@@ -43,4 +46,6 @@ private:
     QRadioButton *icap;
 };
 
+}  //KChart namespace
+
 #endif
