@@ -1,6 +1,21 @@
-/*
- * Copyright 2001 by Laurent Montel, released under Artistic License.
- */
+/* This file is part of the KDE project
+   Copyright (C) 2001,2002,2003,2004 Laurent Montel <montel@kde.org>
+
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #include "kchartLegendConfigPage.h"
 #include "kchartLegendConfigPage.moc"
@@ -20,6 +35,9 @@
 #include "kchart_params.h"
 #include "kchart_factory.h"
 
+namespace KChart
+{
+
 
 KChartLegendConfigPage::KChartLegendConfigPage( KChartParams* params,
                                                 QWidget* parent ) :
@@ -28,8 +46,22 @@ KChartLegendConfigPage::KChartLegendConfigPage( KChartParams* params,
   //Layout for 4 blocks
   QGridLayout* layout = new QGridLayout( this, 2, 2, KDialog::marginHint(), KDialog::spacingHint() );
 
-  //1. Block: Legend position
-  QButtonGroup* gb = new QButtonGroup( 0, Qt::Vertical, i18n("Legend Position"), this );
+  //1. Block: General settings
+  QButtonGroup* gb = new QButtonGroup( 0, Qt::Vertical, i18n("General"), this );
+  gb->layout()->setSpacing(KDialog::spacingHint());
+  gb->layout()->setMargin(KDialog::marginHint());
+  layout->addWidget( gb, 0, 0 );
+
+  QGridLayout *grid2 = new QGridLayout( gb->layout(), 4, 2 );
+
+  QLabel* lab = new QLabel( i18n("Title:"), gb );
+  grid2->addWidget( lab, 0, 0 );
+
+  title = new QLineEdit( gb );
+  grid2->addWidget( title, 1, 0 );
+
+  // 2. Block: Legend position
+  gb = new QButtonGroup( 0, Qt::Vertical, i18n("Legend Position"), this );
   gb->layout()->setSpacing(KDialog::spacingHint());
   gb->layout()->setMargin(KDialog::marginHint());
   gb->setExclusive( true );
@@ -49,29 +81,40 @@ KChartLegendConfigPage::KChartLegendConfigPage( KChartParams* params,
   lBottomRight = addButton( grid1, gb, i18n("Bottom-Right"), "chart_legend_bottomright", 2, 2 );
 
   gb->setAlignment( Qt::AlignLeft );
-  layout->addWidget( gb, 0, 0 );
-
-
-  //2. Block: Title text
-  gb = new QButtonGroup( 0, Qt::Vertical, i18n("Title"), this );
-  gb->layout()->setSpacing(KDialog::spacingHint());
-  gb->layout()->setMargin(KDialog::marginHint());
   layout->addWidget( gb, 1, 0 );
 
-  QGridLayout *grid2 = new QGridLayout( gb->layout(), 4, 2 );
-
-  QLabel* lab = new QLabel( i18n("Legend title:"), gb );
-  grid2->addWidget( lab, 0, 0 );
-
-  title = new QLineEdit( gb );
-  grid2->addWidget( title, 1, 0 );
-
-  //3. Block: Text Colors
-  gb = new QButtonGroup( 0, Qt::Vertical, i18n("Color"), this );
+  // 3. Block: Font
+  gb = new QButtonGroup( 0, Qt::Vertical, i18n("Font"), this );
   gb->layout()->setSpacing(KDialog::spacingHint());
   gb->layout()->setMargin(KDialog::marginHint());
   layout->addWidget( gb, 0, 1 );
 
+  QGridLayout *grid4 = new QGridLayout( gb->layout(), 4, 2 );
+  titleLegendFontButton = new QPushButton( gb );
+
+  lab = new QLabel( i18n("Legend title font:"), gb );
+  grid4->addWidget( lab, 0 ,0 );
+
+  titleLegendFontButton->setText( i18n("Select Font...") );
+  grid4->addWidget( titleLegendFontButton, 1, 0 );
+
+  lab = new QLabel( i18n("Legend text font:"), gb );
+  grid4->addWidget( lab, 2, 0 );
+  textLegendFontButton = new QPushButton( gb );
+  textLegendFontButton->setText( i18n("Select Font...") );
+  grid4->addWidget( textLegendFontButton, 3, 0 );
+
+  connect( titleLegendFontButton, SIGNAL(clicked()), 
+	   this, SLOT(changeTitleLegendFont()));
+  connect( textLegendFontButton, SIGNAL(clicked()),
+	   this, SLOT(changeTextLegendFont()));
+
+  // 4. Block: Text Colors
+  gb = new QButtonGroup( 0, Qt::Vertical, i18n("Color"), this );
+  gb->layout()->setSpacing(KDialog::spacingHint());
+  gb->layout()->setMargin(KDialog::marginHint());
+  layout->addWidget( gb, 1, 1 );
+
   QGridLayout *grid3 = new QGridLayout( gb->layout(), 4, 2 );
 
   lab = new QLabel( i18n("Legend title color:"), gb );
@@ -88,30 +131,6 @@ KChartLegendConfigPage::KChartLegendConfigPage( KChartParams* params,
 
   grid3->addWidget( legendTextColor, 3, 0 );
 
-  //4. Block: Font
-  gb = new QButtonGroup( 0, Qt::Vertical, i18n("Font"), this );
-  gb->layout()->setSpacing(KDialog::spacingHint());
-  gb->layout()->setMargin(KDialog::marginHint());
-  layout->addWidget( gb, 1, 1 );
-
-  QGridLayout *grid4 = new QGridLayout( gb->layout(), 4, 2 );
-  titleLegendFontButton = new QPushButton( gb );
-
-  lab = new QLabel( i18n("Legend title font:"), gb );
-  grid4->addWidget( lab, 0 ,0 );
-
-  titleLegendFontButton->setText( i18n("Legend...") );
-  grid4->addWidget( titleLegendFontButton, 1, 0 );
-
-  lab = new QLabel( i18n("Legend text font:"), gb );
-  grid4->addWidget( lab, 2, 0 );
-  textLegendFontButton = new QPushButton( gb );
-  textLegendFontButton->setText( i18n("Text Legend...") );
-  grid4->addWidget( textLegendFontButton, 3, 0 );
-
-  connect( titleLegendFontButton, SIGNAL(clicked()), this, SLOT(changeTitleLegendFont()));
-  connect( textLegendFontButton, SIGNAL(clicked()), this, SLOT(changeTextLegendFont()));
-
   //it's not good but I don't know how
   //to reduce space
   layout->addColSpacing( 1, 300 );
@@ -239,3 +258,5 @@ QPushButton* KChartLegendConfigPage::addButton( QGridLayout* layout,
   layout->addWidget( button, posY, posX );
   return button;
 }
+
+}  //KChart namespace
