@@ -23,9 +23,13 @@
 #include <qwidget.h>
 #include <knuminput.h>
 
-class KChartParams;
 class QCheckBox;
 
+namespace KChart
+{
+
+class KChartParams;
+
 class KChartLine3dConfigPage : public QWidget
 {
     Q_OBJECT
@@ -44,6 +48,10 @@ private:
     KIntNumInput* lineWidth;
     KDoubleNumInput* depth;
     QCheckBox* line3d, *drawShadowColor;
+    QCheckBox  *lineMarkers;
 };
 
+
+}  //KChart namespace
+
 #endif
