@@ -8,9 +8,13 @@ class QColor;
 class QLineEdit;
 class QSpinBox;
 class QPushButton;
+class QCheckBox;
+
+namespace KChart
+{
+
 class KChartPart;
 class kchartWidget;
-class QCheckBox;
 
 class KChartWizardSetupAxesPage : public QWidget
 {
@@ -38,7 +42,9 @@ private:
   QLineEdit *y_max;
   QLineEdit *y_min;
   QLineEdit *ylabel_fmt;
+#if 0
   QLineEdit *ylabel2_fmt;
+#endif
   QSpinBox *angle;
   QSpinBox *depth;
   QSpinBox *barWidth;
@@ -52,4 +58,6 @@ private:
   QColor colorBorder;
 };
 
+}  //namespace KChart
+
 #endif
