@@ -5,6 +5,10 @@
 
 class QRadioButton;
 class QCheckBox;
+
+namespace KChart
+{
+
 class kchartWidget;
 class KChartPart;
 class KChartWizard;
@@ -33,4 +37,6 @@ private:
   QCheckBox* coldescript;
 };
 
+}  //namespace KChart
+
 #endif
