@@ -1,9 +1,10 @@
 /**
- * $Id: kchart_factory.cc,v 1.23 2003/08/16 12:22:50 mueller Exp $
+ * $Id: kchart_factory.cc 406510 2005-04-19 09:52:45Z dfaure $
  *
  * Kalle Dalheimer <kalle@kde.org>
  */
 
+
 #include "kchart_factory.h"
 #include "kchart_aboutdata.h"
 #include "kchart_part.h"
@@ -11,17 +12,17 @@
 #include <kinstance.h>
 #include <kdebug.h>
 #include <kiconloader.h>
+#include <kstandarddirs.h>
 
-extern "C"
+namespace KChart
 {
-    void* init_libkchartpart()
-    {
-	return new KChartFactory;
-    }
-}
 
-KInstance* KChartFactory::s_global = 0;
-KAboutData* KChartFactory::s_aboutData = 0;
+K_EXPORT_COMPONENT_FACTORY( libkchart, KChartFactory )
+
+
+KInstance   *KChartFactory::s_global    = 0;
+KAboutData  *KChartFactory::s_aboutData = 0;
+
 
 KChartFactory::KChartFactory( QObject* parent, const char* name )
     : KoFactory( parent, name )
@@ -29,6 +30,7 @@ KChartFactory::KChartFactory( QObject* parent, const char* name )
     global();
 }
 
+
 KChartFactory::~KChartFactory()
 {
     delete s_aboutData;
@@ -37,11 +39,18 @@ KChartFactory::~KChartFactory()
     s_global = 0;
 }
 
-KParts::Part* KChartFactory::createPartObject( QWidget *parentWidget, const char *widgetName, QObject* parent, const char* name, const char *classname, const QStringList & )
+
+KParts::Part* KChartFactory::createPartObject( QWidget *parentWidget,
+					       const char *widgetName,
+					       QObject* parent,
+					       const char* name,
+					       const char *classname,
+					       const QStringList & )
 {
     bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
 
-    KChartPart *part = new KChartPart( parentWidget, widgetName, parent, name, !bWantKoDocument );
+    KChartPart *part = new KChartPart( parentWidget, widgetName, parent, name,
+				       !bWantKoDocument );
 
     if ( !bWantKoDocument )
       part->setReadWrite( false );
@@ -49,6 +58,7 @@ KParts::Part* KChartFactory::createPartObject( QWidget *parentWidget, const char
     return part;
 }
 
+
 KAboutData* KChartFactory::aboutData()
 {
     if( !s_aboutData )
@@ -56,15 +66,20 @@ KAboutData* KChartFactory::aboutData()
     return s_aboutData;
 }
 
+
 KInstance* KChartFactory::global()
 {
     if ( !s_global )
     {
          s_global = new KInstance(aboutData());
+         s_global->dirs()->addResourceType( "kchart_template",
+         KStandardDirs::kde_default("data") + "kchart/templates/");
          // Tell the iconloader about share/apps/koffice/icons
          s_global->iconLoader()->addAppDir("koffice");
     }
     return s_global;
 }
 
+}  //namespace KChart
+
 #include <kchart_factory.moc>
