@@ -1,5 +1,5 @@
 /**
- * $Id: kchart_factory.h,v 1.8 2001/09/09 23:28:24 hausmann Exp $
+ * $Id: kchart_factory.h 376098 2005-01-07 14:13:50Z raphael $
  *
  * Kalle Dalheimer <kalle@kde.org>
  */
@@ -7,11 +7,16 @@
 #ifndef KCHART_FACTORY_H
 #define KCHART_FACTORY_H
 
+
 #include <koFactory.h>
 
+
 class KInstance;
 class KAboutData;
 
+namespace KChart
+{
+
 class KChartFactory : public KoFactory
 {
     Q_OBJECT
@@ -19,7 +24,12 @@ public:
     KChartFactory( QObject* parent = 0, const char* name = 0 );
     virtual ~KChartFactory();
 
-    virtual KParts::Part* createPartObject( QWidget* = 0, const char * = 0, QObject* parent = 0, const char* name = 0, const char* classname = "KoDocument", const QStringList &args = QStringList() );
+    virtual KParts::Part  *createPartObject( QWidget* = 0, 
+					     const char * = 0,
+					     QObject* parent = 0,
+					     const char* name = 0,
+					     const char* classname = "KoDocument",
+					     const QStringList &args = QStringList() );
 
     static KInstance* global();
 
@@ -31,4 +41,6 @@ private:
     static KAboutData *s_aboutData;
 };
 
+}  //namespace KChart
+
 #endif
