@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 Laurent Montel <lmontel@mandrakesoft.com>
+   Copyright (C) 2001,2002,2003,2004 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,27 +17,35 @@
    Boston, MA 02111-1307, USA.
 */
 
+
 #include "kchart_params.h"
 #include "KChartParamsIface.h"
 #include <dcopobject.h>
 #include "kdchart/KDChartParams.h"
+#include "kdchart/KDChartAxisParams.h"
+
+namespace KChart
+{
 
 KChartParams::KChartParams()
     : KDChartParams()
 {
-    dcop = 0;
+    m_dcop = 0;
     //dcopObject(); // build it
 }
 
+
 KChartParams::~KChartParams()
 {
-    delete dcop;
+    delete m_dcop;
 }
 
+
 DCOPObject* KChartParams::dcopObject()
 {
-    if ( !dcop )
-	dcop = new KChartParamsIface( this );
-    return dcop;
+    if ( !m_dcop )
+	m_dcop = new KChartParamsIface( this );
+    return m_dcop;
 }
 
+}  //KChart namespace
