@@ -38,6 +38,8 @@
 
 #include <math.h>
 
+#include <klocale.h>
+
 /**
   \class KDChartPiePainter KDChartPiePainter.h
 
@@ -161,6 +163,8 @@ void KDChartPiePainter::paintData( QPainter* painter,
     }
 
     double sum = data->rowAbsSum( dataset );
+	if (sum==0) //nothing to draw
+		return;
     double sectorsPerValue = 5760.0 / sum; // 5760 == 16*360, number of sections in Qt circle
 
     int currentValue = params()->pieStart() * 16;
@@ -779,7 +783,7 @@ uint KDChartPiePainter::findRightPie( uint pie )
   */
 QString KDChartPiePainter::fallbackLegendText( uint dataset ) const
 {
-    return QObject::tr( "Item " ) + QString::number( dataset + 1 );
+    return i18n( "Item %1" ).arg( dataset + 1 );
 }
 
 
