@@ -34,6 +34,8 @@
 
 #include <stdlib.h>
 
+#include <klocale.h>
+
 #define DEGTORAD(d) (d)*M_PI/180
 
 /**
@@ -379,7 +381,7 @@ void KDChartRingPainter::drawOneSegment( QPainter* painter,
   */
 QString KDChartRingPainter::fallbackLegendText( uint dataset ) const
 {
-    return QObject::tr( "Item " ) + QString::number( dataset + 1 );
+    return i18n( "Item %1" ).arg( dataset + 1 );
 }
 
 
