@@ -30,9 +30,8 @@
 
 #include <koQueryTrader.h>
 #include <koPoint.h>
-
-#include "kivio_point.h"
-#include "kivio_rect.h"
+#include <koRect.h>
+#include <koffice_export.h>
 #include "kivio_intra_stencil_data.h"
 
 class KivioView;
@@ -40,9 +39,6 @@ class KivioCanvas;
 class KivioPage;
 class KivioDoc;
 class KivioRuler;
-namespace Kivio {
-class ToolController;
-}
 class KivioGuideLineData;
 
 class KivioScreenPainter;
@@ -55,17 +51,16 @@ class QScrollBar;
 class QTimer;
 
 class KoSize;
+class KoRect;
 
 #define YBORDER_WIDTH 50
 #define XBORDER_HEIGHT 20
 
-using namespace Kivio;
-
-class KivioCanvas : public QWidget
+class KIVIO_EXPORT KivioCanvas : public QWidget
 { Q_OBJECT
     friend class KivioView;
   public:
-    KivioCanvas( QWidget*, KivioView*, KivioDoc*, ToolController*, QScrollBar*, QScrollBar*/*, KivioRuler*, KivioRuler**/ );
+    KivioCanvas( QWidget*, KivioView*, KivioDoc*, QScrollBar*, QScrollBar* );
     ~KivioCanvas();
     /**
     * Called from @ref KivioView to complete the construction. Has to
@@ -114,15 +109,14 @@ class KivioCanvas : public QWidget
     void eraseGuides();
     void paintGuides(bool=true);
 
-    void setViewCenterPoint(KivioPoint);
+    void setViewCenterPoint(const KoPoint &);
 
-    KivioRect visibleArea();
-    void setVisibleArea(KivioRect, int margin = 0);
-    void setVisibleAreaByWidth(KivioRect, int margin = 0);
-    void setVisibleAreaByHeight(KivioRect, int margin = 0);
+    KoRect visibleArea();
+    void setVisibleArea(KoRect, int margin = 0);
+    void setVisibleAreaByWidth(KoRect, int margin = 0);
+    void setVisibleAreaByHeight(KoRect, int margin = 0);
 
   signals:
-    void zoomChanges();
     void visibleAreaChanged();
 
   public slots:
@@ -141,8 +135,6 @@ class KivioCanvas : public QWidget
 
     void updateScrollBars();
 
-    void setZoom(int);
-
     void startPasteMoving();
 
   protected:
@@ -164,8 +156,6 @@ class KivioCanvas : public QWidget
 
     virtual void keyReleaseEvent( QKeyEvent * );
 
-    KoSize actualGridFrequency();
-
     void beginUnclippedPainter();
     void endUnclippedPainter();
 
@@ -184,8 +174,6 @@ class KivioCanvas : public QWidget
     KivioView* m_pView;
     KivioDoc* m_pDoc;
 
-    ToolController* m_pToolsController;
-
     QScrollBar* m_pVertScrollBar;
     QScrollBar* m_pHorzScrollBar;
 
@@ -217,7 +205,7 @@ class KivioCanvas : public QWidget
     QPoint lastPoint;
 
     bool m_pasteMoving;
-    QPtrList<KivioRect> m_lstOldGeometry;
+    QPtrList<KoRect> m_lstOldGeometry;
     KoPoint m_origPoint;
 };
 
