@@ -236,7 +236,7 @@ void KivioRenameLayerCommand::unexecute()
     m_layer->page()->doc()->resetLayerPanel();
 }
 
-KivioResizeStencilCommand::KivioResizeStencilCommand( const QString &_name, KivioStencil *_stencil, KivioRect _initSize, KivioRect _endSize, KivioPage *_page)
+KivioResizeStencilCommand::KivioResizeStencilCommand( const QString &_name, KivioStencil *_stencil, KoRect _initSize, KoRect _endSize, KivioPage *_page)
     :KNamedCommand( _name ),
      m_stencil( _stencil),
      initSize( _initSize),
@@ -251,20 +251,20 @@ KivioResizeStencilCommand::~KivioResizeStencilCommand()
 
 void KivioResizeStencilCommand::execute()
 {
-    m_stencil->setDimensions( endSize.w(), endSize.h() );
+    m_stencil->setDimensions( endSize.width(), endSize.height() );
     m_stencil->setPosition( endSize.x(), endSize.y() );
     m_page->doc()->updateView(m_page);
 }
 
 void KivioResizeStencilCommand::unexecute()
 {
-    m_stencil->setDimensions( initSize.w(), initSize.h() );
+    m_stencil->setDimensions( initSize.width(), initSize.height() );
     m_stencil->setPosition( initSize.x(), initSize.y() );
     m_page->doc()->updateView(m_page);
 }
 
 
-KivioMoveStencilCommand::KivioMoveStencilCommand( const QString &_name, KivioStencil *_stencil, KivioRect _initSize, KivioRect _endSize, KivioPage *_page)
+KivioMoveStencilCommand::KivioMoveStencilCommand( const QString &_name, KivioStencil *_stencil, KoRect _initSize, KoRect _endSize, KivioPage *_page)
     :KNamedCommand( _name ),
      m_stencil( _stencil),
      initSize( _initSize),
@@ -279,14 +279,14 @@ KivioMoveStencilCommand::~KivioMoveStencilCommand()
 
 void KivioMoveStencilCommand::execute()
 {
-    m_stencil->setDimensions( endSize.w(), endSize.h() );
+    m_stencil->setDimensions( endSize.width(), endSize.height() );
     m_stencil->setPosition( endSize.x(), endSize.y() );
     m_page->doc()->updateView(m_page);
 }
 
 void KivioMoveStencilCommand::unexecute()
 {
-    m_stencil->setDimensions( initSize.w(), initSize.h() );
+    m_stencil->setDimensions( initSize.width(), initSize.height() );
     m_stencil->setPosition( initSize.x(), initSize.y() );
     m_page->doc()->updateView(m_page);
 }
@@ -474,6 +474,62 @@ void KivioChangeLineWidthCommand::unexecute()
     m_page->doc()->slotSelectionChanged();
 }
 
+KivioChangeRotationCommand::KivioChangeRotationCommand( const QString &_name,
+    KivioPage *_page, KivioStencil * _stencil, int _oldValue, int _newValue)
+    :KNamedCommand( _name),
+    m_page(_page),
+    m_stencil( _stencil ),
+    oldValue( _oldValue),
+    newValue( _newValue)
+{
+}
+
+KivioChangeRotationCommand::~KivioChangeRotationCommand()
+{
+}
+
+void KivioChangeRotationCommand::execute()
+{
+    m_stencil->setRotation( newValue );
+    m_page->doc()->updateView(m_page);
+    m_page->doc()->slotSelectionChanged();
+}
+
+void KivioChangeRotationCommand::unexecute()
+{
+    m_stencil->setRotation( oldValue );
+    m_page->doc()->updateView(m_page);
+    m_page->doc()->slotSelectionChanged();
+}
+
+
+KivioChangeLineStyleCommand::KivioChangeLineStyleCommand( const QString &_name,
+    KivioPage *_page, KivioStencil * _stencil, int _oldValue, int _newValue)
+    :KNamedCommand( _name),
+    m_page(_page),
+    m_stencil( _stencil ),
+    oldValue( _oldValue),
+    newValue( _newValue)
+{
+}
+
+KivioChangeLineStyleCommand::~KivioChangeLineStyleCommand()
+{
+}
+
+void KivioChangeLineStyleCommand::execute()
+{
+    m_stencil->setLinePattern( newValue );
+    m_page->doc()->updateView(m_page);
+    m_page->doc()->slotSelectionChanged();
+}
+
+void KivioChangeLineStyleCommand::unexecute()
+{
+    m_stencil->setLinePattern( oldValue );
+    m_page->doc()->updateView(m_page);
+    m_page->doc()->slotSelectionChanged();
+}
 
 KivioChangeBeginEndArrowCommand::KivioChangeBeginEndArrowCommand( const QString &_name, KivioPage *_page, KivioStencil * _stencil, int _oldArrow,  int _newArrow, bool _beginArrow)
     :KNamedCommand( _name),
