@@ -28,7 +28,6 @@
 #include "kivio_view.h"
 #include "kivio_factory.h"
 #include "export_page_dialog.h"
-#include "kivio_config.h"
 #include "kivio_common.h"
 #include "kivio_group_stencil.h"
 #include "kivio_icon_view.h"
@@ -37,9 +36,9 @@
 #include "kivio_screen_painter.h"
 #include "kivio_stencil.h"
 #include "kivio_stencil_spawner_set.h"
-#include "kivio_viewmanager_panel.h"
 #include "kivioglobal.h"
-#include "kivio_rect.h"
+#include "kivio_config.h"
+#include "polylineconnectorspawner.h"
 
 #include "stencilbarbutton.h"
 
@@ -76,10 +75,17 @@
 #include <koTemplateChooseDia.h>
 #include <koFilterManager.h>
 #include <koStoreDevice.h>
-#include <KIvioDocIface.h>
+#include "KIvioDocIface.h"
 #include <kcommand.h>
 #include <kozoomhandler.h>
 #include <koApplication.h>
+#include <kglobal.h>
+#include <kocommandhistory.h>
+#include <koxmlwriter.h>
+#include <koGenStyles.h>
+#include <koOasisSettings.h>
+#include <kodom.h>
+#include <koxmlns.h>
 
 //using namespace std;
 
@@ -95,16 +101,16 @@ int KivioDoc::s_docId = 0;
 KivioDoc::KivioDoc( QWidget *parentWidget, const char* widgetName, QObject* parent, const char* name, bool singleViewMode )
 : KoDocument( parentWidget, widgetName, parent, name, singleViewMode )
 {
-    dcop = 0;
-    if (!s_docs)
-        s_docs = new QPtrList<KivioDoc>;
+  dcop = 0;
+  if (!s_docs)
+    s_docs = new QPtrList<KivioDoc>;
 
   s_docs->append(this);
 
-  m_options = new KivioOptions();
-
   m_pLstSpawnerSets = new QPtrList<KivioStencilSpawnerSet>;
   m_pLstSpawnerSets->setAutoDelete(true);
+  m_loadTimer = 0;
+  m_currentFile = 0;
 
   setInstance( KivioFactory::global(), false );
 
@@ -115,10 +121,7 @@ KivioDoc::KivioDoc( QWidget *parentWidget, const char* widgetName, QObject* pare
     setName( tmp.latin1() );
   }
 
-  m_pClipboard = NULL;
-
   m_iPageId = 1;
-  m_pMap = 0L;
   m_bLoading = false;
   m_pMap = new KivioMap( this, "Map" );
 
@@ -128,17 +131,19 @@ KivioDoc::KivioDoc( QWidget *parentWidget, const char* widgetName, QObject* pare
   QStringList list = instance()->dirs()->findAllResources("data",instance()->instanceName()+"/autoloadStencils/*",true,false);
   QStringList::ConstIterator pIt = list.begin();
   QStringList::ConstIterator pEnd = list.end();
+
   for (; pIt != pEnd; ++pIt )
   {
     m_pInternalSet->loadFile(*pIt);
   }
 
-  m_units = KoUnit::U_MM;
-  m_font = KoGlobal::defaultFont();
+  // Add the polyline connector spawner to the internal stencil set.
+  addInternalStencilSpawner(new Kivio::PolyLineConnectorSpawner(internalSpawnerSet()));
 
-  viewItemList = new ViewItemList(this);
+  initConfig();
 
-  m_commandHistory = new KCommandHistory( actionCollection(),  false ) ;
+  //laurent: Why don't use menu history for undo/redo command ? sync with other koffice application
+  m_commandHistory = new KoCommandHistory( actionCollection(),  /*false*/true  ) ;
   connect( m_commandHistory, SIGNAL( documentRestored() ), this, SLOT( slotDocumentRestored() ) );
   connect( m_commandHistory, SIGNAL( commandExecuted() ), this, SLOT( slotCommandExecuted() ) );
 
@@ -165,39 +170,50 @@ QPtrList<KivioDoc>& KivioDoc::documents()
   return *s_docs;
 }
 
-bool KivioDoc::initDoc()
+bool KivioDoc::initDoc(InitDocFlags flags, QWidget* parentWidget)
 {
+  KivioPage *t = createPage();
+  m_pMap->addPage( t );
+  m_docOpened = false; // Used to for a hack that make kivio not crash if you cancel startup dialog.
+
+  if(flags == KoDocument::InitDocEmpty) {
+    setEmpty();
+    m_docOpened = true; // Used to for a hack that make kivio not crash if you cancel startup dialog.
+    return true;
+  }
+
   QString f;
   KoTemplateChooseDia::ReturnType ret;
   KoTemplateChooseDia::DialogType dlgtype;
 
-  if (initDocFlags() != KoDocument::InitDocFileNew) {
+  if(flags != KoDocument::InitDocFileNew) {
     dlgtype = KoTemplateChooseDia::Everything;
     initConfig();
   } else {
     dlgtype = KoTemplateChooseDia::OnlyTemplates;
   }
 
-  ret = KoTemplateChooseDia::choose(  KivioFactory::global(), f,
-                                      MIME_TYPE, "*.flw", i18n("Kivio"),
-                                      dlgtype, "kivio_template");
+  ret = KoTemplateChooseDia::choose( KivioFactory::global(), f,
+                                     dlgtype, "kivio_template", parentWidget );
 
-  if ( ret == KoTemplateChooseDia::File ) {
+  if( ret == KoTemplateChooseDia::File ) {
     KURL url(f);
-    return openURL(url);
+    bool ok = openURL(url);
+    m_docOpened = ok; // Used to for a hack that make kivio not crash if you cancel startup dialog.
+    return ok;
   } else if ( ret == KoTemplateChooseDia::Template ) {
     QFileInfo fileInfo( f );
-    QString fileName( fileInfo.dirPath( TRUE ) + "/" + fileInfo.baseName() + ".kft" );
+    QString fileName( fileInfo.dirPath(true) + "/" + fileInfo.baseName() + ".kft" );
     resetURL();
     bool ok = loadNativeFormat( fileName );
-    KivioPage *t = createPage();
-    m_pMap->addPage( t );
+    if ( !ok )
+        showLoadingErrorDialog();
     setEmpty();
+    m_docOpened = ok; // Used to for a hack that make kivio not crash if you cancel startup dialog.
     return ok;
   } else if ( ret == KoTemplateChooseDia::Empty ) {
-    KivioPage *t = createPage();
-    m_pMap->addPage( t );
     setEmpty();
+    m_docOpened = true; // Used to for a hack that make kivio not crash if you cancel startup dialog.
     return true;
   } else {
     return false;
@@ -226,11 +242,6 @@ QDomDocument KivioDoc::saveXML()
 
   QDomElement viewItemsElement = doc.createElement("ViewItems");
   kivio.appendChild(viewItemsElement);
-  viewItemList->save(viewItemsElement);
-
-  QDomElement optionsElement = doc.createElement("Options");
-  kivio.appendChild(optionsElement);
-  m_options->save(optionsElement);
 
   doc.appendChild(kivio);
 
@@ -257,18 +268,187 @@ QDomDocument KivioDoc::saveXML()
   QDomElement e = m_pMap->save(doc);
   kivio.appendChild(e);
 
-  // Write it out to a tmp file
-     QFile f("filedump.xml");
-    if ( f.open(IO_WriteOnly) ) {    // file opened successfully
-        QTextStream t( &f );        // use a text stream
-        t << doc.toString();
-        f.close();
-    }
-
   setModified(false);
   return doc;
 }
 
+bool KivioDoc::saveOasis(KoStore* store, KoXmlWriter* manifestWriter)
+{
+    KoStoreDevice storeDev(store);
+    KoGenStyles styles;
+
+    KoGenStyle pageLayout = Kivio::Config::defaultPageLayout().saveOasis();
+    QString layoutName = styles.lookup(pageLayout, "PL");
+    KoGenStyle masterPage(KoGenStyle::STYLE_MASTER);
+    masterPage.addAttribute("style:page-layout-name", layoutName);
+    styles.lookup(masterPage, "Standard", false);
+
+    if(!store->open("content.xml")) {
+        return false;
+    }
+
+    KoXmlWriter* docWriter = createOasisXmlWriter(&storeDev, "office:document-content");
+
+    docWriter->startElement("office:body");
+    docWriter->startElement("office:drawing");
+
+    m_pMap->saveOasis(store, docWriter, &styles); // Save contents
+
+    docWriter->endElement(); // office:drawing
+    docWriter->endElement(); // office:body
+    docWriter->endElement(); // Root element
+    docWriter->endDocument();
+    delete docWriter;
+
+    if(!store->close()) {
+        return false;
+    }
+
+    manifestWriter->addManifestEntry("content.xml", "text/xml");
+
+    if(!store->open("styles.xml")) {
+        return false;
+    }
+
+    KoXmlWriter* styleWriter = createOasisXmlWriter(&storeDev, "office:document-styles");
+
+    styleWriter->startElement("office:automatic-styles");
+
+    QValueList<KoGenStyles::NamedStyle> styleList = styles.styles(KoGenStyle::STYLE_PAGELAYOUT);
+    QValueList<KoGenStyles::NamedStyle>::const_iterator it = styleList.begin();
+
+    for ( ; it != styleList.end(); ++it) {
+        (*it).style->writeStyle(styleWriter, styles, "style:page-layout", (*it).name, "style:page-layout-properties");
+    }
+
+    styleList = styles.styles(Kivio::STYLE_PAGE);
+    it = styleList.begin();
+
+    for ( ; it != styleList.end(); ++it) {
+        (*it).style->writeStyle(styleWriter, styles, "style:style", (*it).name, "style:properties");
+    }
+
+    styleWriter->endElement(); // office:automatic-styles
+
+    styleList = styles.styles(KoGenStyle::STYLE_MASTER);
+    it = styleList.begin();
+    styleWriter->startElement("office:master-styles");
+
+    for ( ; it != styleList.end(); ++it) {
+        (*it).style->writeStyle(styleWriter, styles, "style:master-page", (*it).name, "");
+    }
+
+    styleWriter->endElement(); // office:master-styles
+
+    styleWriter->endElement(); // Root element
+    styleWriter->endDocument();
+    delete styleWriter;
+
+    if(!store->close()) {
+        return false;
+    }
+
+    manifestWriter->addManifestEntry("styles.xml", "text/xml");
+
+    if(!store->open("settings.xml")) {
+        return false;
+    }
+
+
+    KoXmlWriter* settingsWriter = createOasisXmlWriter(&storeDev, "office:document-settings");
+    settingsWriter->startElement("office:settings");
+    settingsWriter->startElement("config:config-item-set");
+    settingsWriter->addAttribute("config:name", "view-settings");
+
+    KoUnit::saveOasis( settingsWriter, units() );
+    saveOasisSettings( *settingsWriter );
+
+    settingsWriter->endElement(); // config:config-item-set
+    settingsWriter->endElement(); // office:settings
+    settingsWriter->endDocument();
+
+    delete settingsWriter;
+
+    if(!store->close()) {
+        return false;
+    }
+
+    manifestWriter->addManifestEntry("settings.xml", "text/xml");
+
+    setModified(false);
+    return true;
+}
+
+void KivioDoc::saveOasisSettings( KoXmlWriter &/*settingsWriter*/ )
+{
+    //todo
+}
+
+bool KivioDoc::loadOasis( const QDomDocument& doc, KoOasisStyles& oasisStyles, const QDomDocument& settings, KoStore* )
+{
+  kdDebug(43000) << "Start loading OASIS document..." << endl;
+  m_bLoading = true;
+
+  QDomElement contents = doc.documentElement();
+  QDomElement body(KoDom::namedItemNS( contents, KoXmlNS::office, "body"));
+
+  if(body.isNull()) {
+    kdDebug(43000) << "No office:body found!" << endl;
+    setErrorMessage(i18n("Invalid OASIS document. No office:body tag found."));
+    m_bLoading = false;
+    return false;
+  }
+
+  body = KoDom::namedItemNS( body, KoXmlNS::office, "drawing");
+
+  if(body.isNull()) {
+    kdDebug(43000) << "No office:drawing found!" << endl;
+    setErrorMessage(i18n("Invalid OASIS document. No office:drawing tag found."));
+    m_bLoading = false;
+    return false;
+  }
+
+  QDomNode node = body.firstChild();
+  QString localName;
+  m_pMap->clear();
+
+  // TODO: port to forEachElement
+  while(!node.isNull()) {
+    localName = node.localName();
+
+    if(localName == "page" /* && and namespace is KoXmlNS::draw*/) {
+      KivioPage* p = createPage();
+      addPage(p);
+
+      if(!p->loadOasis(node.toElement(), oasisStyles)) {
+        m_bLoading = false;
+        return false;
+      }
+    }
+
+    node = node.nextSibling();
+  }
+
+  loadOasisSettings( settings );
+
+  emit updateActivePage(m_pMap->firstPage());
+  return true;
+}
+
+
+void KivioDoc::loadOasisSettings( const QDomDocument&settingsDoc )
+{
+    if ( settingsDoc.isNull() )
+        return ; //not a error some file doesn't have settings.xml
+    KoOasisSettings settings( settingsDoc );
+    KoOasisSettings::Items viewSettings = settings.itemSet( "view-settings" );
+    if ( !viewSettings.isNull() )
+    {
+        setUnits(KoUnit::unit(viewSettings.parseConfigItemString("unit")));
+        //todo add other config here.
+    }
+}
+
 bool KivioDoc::loadXML( QIODevice *, const QDomDocument& doc )
 {
   m_bLoading = true;
@@ -305,20 +485,16 @@ bool KivioDoc::loadXML( QIODevice *, const QDomDocument& doc )
 
         if( id.isEmpty() )
         {
-	   kdDebug(43000) << "KivioDoc::loadXML() - Bad KivioStencilSpawnerSet found, it contains no id!" << endl;
+            kdDebug(43000) << "KivioDoc::loadXML() - Bad KivioStencilSpawnerSet found, it contains no id!" << endl;
         }
         else
         {
             loadStencilSpawnerSet( id );
         }
     }
-    else if( name == "ViewItems" )
-    {
-        viewItemList->load(node.toElement());
-    }
     else if( name == "Options" )
     {
-        m_options->load(node.toElement());
+        // Not used anymore use users default page instead from Settings to create new pages...
     }
     else
     {
@@ -328,15 +504,7 @@ bool KivioDoc::loadXML( QIODevice *, const QDomDocument& doc )
     node = node.nextSibling();
   }
 
-  // <map>
-  //QDomElement mymap = kivio.namedItem( "map" ).toElement();
-  //if ( !mymap.isNull() )
-  //  if ( !m_pMap->loadXML(mymap) ) {
-  //    m_bLoading = false;
-  //    return false;
-  //  }
-
-  QString us = kivio.attribute("units","mm");
+  QString us = kivio.attribute("units", Kivio::Config::unit());
   bool isInt = false;
   int u = us.toInt(&isInt);
 
@@ -350,80 +518,74 @@ bool KivioDoc::loadXML( QIODevice *, const QDomDocument& doc )
     gridData.load(kivio,"grid");
   }
 
+  emit updateActivePage(m_pMap->firstPage());
   return true;
 }
 
 bool KivioDoc::loadStencilSpawnerSet( const QString &id )
 {
-    KStandardDirs *dirs = KGlobal::dirs();
-    QStringList dirList = dirs->findDirs("data", "kivio/stencils");
-    QString rootDir;
+  KStandardDirs *dirs = KGlobal::dirs();
+  QStringList dirList = dirs->findDirs("data", "kivio/stencils");
+  QString rootDir;
 
-    // Iterate through all data directories
-    for( QStringList::Iterator it = dirList.begin(); it != dirList.end(); ++it )
+  // Iterate through all data directories
+  for( QStringList::Iterator it = dirList.begin(); it != dirList.end(); ++it )
+  {
+    rootDir = (*it);
+
+    // Within each data directory, iterate through all directories looking
+    // for a filename (dir) that matches the parameter
+    QDir d(rootDir);
+    d.setFilter( QDir::Dirs );
+    d.setSorting( QDir::Name );
+
+    const QFileInfoList *list = d.entryInfoList();
+    QFileInfoListIterator listIT( *list );
+    QFileInfo *fi;
+
+    // Loop through the outer directories (like BasicFlowcharting)
+    while( (fi=listIT.current()) )
     {
-        rootDir = (*it);
+      if( fi->fileName() != "." &&
+          fi->fileName() != ".." )
+      {
+        QDir innerD(fi->absFilePath() );
+        innerD.setFilter( QDir::Dirs );
+        innerD.setSorting( QDir::Name );
 
-        // Within each data directory, iterate through all directories looking
-        // for a filename (dir) that matches the parameter
-        QDir d(rootDir);
-        d.setFilter( QDir::Dirs );
-        d.setSorting( QDir::Name );
+        const QFileInfoList *innerList = innerD.entryInfoList();
+        QFileInfoListIterator innerIT( *innerList );
+        QFileInfo *innerFI;
 
-        const QFileInfoList *list = d.entryInfoList();
-        QFileInfoListIterator listIT( *list );
-        QFileInfo *fi;
-
-        // Loop through the outer directories (like BasicFlowcharting)
-        while( (fi=listIT.current()) )
+        // Loop through the inner directories (like FlowChartingShapes1)
+        while( (innerFI = innerIT.current()) )
         {
-            if( fi->fileName() != "." &&
-                fi->fileName() != ".." )
+          if( innerFI->fileName() != ".." &&
+              innerFI->fileName() != "." )
+          {
+            // Compare the descriptions
+            QString foundId;
+
+            // TODO: use ID system here for loading
+            foundId = KivioStencilSpawnerSet::readId(innerFI->absFilePath());
+            if( foundId == id)
             {
-                QDir innerD(fi->absFilePath() );
-                innerD.setFilter( QDir::Dirs );
-                innerD.setSorting( QDir::Name );
 
-                const QFileInfoList *innerList = innerD.entryInfoList();
-                QFileInfoListIterator innerIT( *innerList );
-                QFileInfo *innerFI;
-
-                // Loop through the inner directories (like FlowChartingShapes1)
-                while( (innerFI = innerIT.current()) )
-                {
-                    if( innerFI->fileName() != ".." &&
-                        innerFI->fileName() != "." )
-                    {
-                        // Compare the descriptions
-                        QString foundId;
-
-			// TODO: use ID system here for loading
-                        foundId = KivioStencilSpawnerSet::readId(innerFI->absFilePath());
-                        if( foundId == id)
-                        {
-
-                            // Load the spawner set with  rootDir + "/" + fi.fileName()
-                            KivioStencilSpawnerSet *pSet = addSpawnerSetDuringLoad( innerFI->absFilePath() );
-                            if( pSet )
-                            {
-			       ;
-                            }
-                            else
-                            {
-			       kdDebug(43000) << "KivioDoc::loadStencilSpawnerSet() - Failed to load stencil:  "
-					 << innerFI->absFilePath() << endl;
-                            }
-                            return true;
-                        }
-                    }
-                    ++innerIT;
-                }
+              // Load the spawner set with  rootDir + "/" + fi.fileName()
+              addSpawnerSetDuringLoad( innerFI->absFilePath() );
+              return true;
             }
-            ++listIT;
-        }
-    }
+          }
 
-    return false;
+          ++innerIT;
+        }
+      }
+
+      ++listIT;
+    }
+  }
+
+  return false;
 }
 
 bool KivioDoc::completeLoading( KoStore* )
@@ -469,22 +631,22 @@ void KivioDoc::takePage( KivioPage * page )
 
 void KivioDoc::paintContent( QPainter& painter, const QRect& rect, bool transparent, double /*zoomX*/, double /*zoomY*/ )
 {
-  // ## TODO - otherwise kivio isn't embeddable
   KivioPage* page = m_pMap->firstPage();
   if ( !page )
     return;
 
   KoZoomHandler zoom;
-  zoom.setZoomAndResolution(100, QPaintDevice::x11AppDpiX(),
-    QPaintDevice::x11AppDpiY());
-  KivioRect r = page->getRectForAllStencils();
+  zoom.setZoomAndResolution(100, KoGlobal::dpiX(),
+    KoGlobal::dpiY());
+  KoRect r = page->getRectForAllStencils();
 
-  float zw = (float) rect.width() / (float)zoom.zoomItX(r.w());
-  float zh = (float) rect.height() / (float)zoom.zoomItY(r.h());
+  float zw = (float) rect.width() / (float)zoom.zoomItX(r.width());
+  float zh = (float) rect.height() / (float)zoom.zoomItY(r.height());
   float z = QMIN(zw, zh);
+  //kdDebug(43000) << "paintContent: w = " << rect.width() << " h = " << rect.height() << endl;
 
-  zoom.setZoomAndResolution(qRound(z * 100), QPaintDevice::x11AppDpiX(),
-    QPaintDevice::x11AppDpiY());
+  zoom.setZoomAndResolution(qRound(z * 100), KoGlobal::dpiX(),
+    KoGlobal::dpiY());
   KivioScreenPainter ksp(&painter);
   ksp.painter()->translate( - zoom.zoomItX(r.x()), - zoom.zoomItY(r.y()) );
   paintContent(ksp,rect,transparent,page, QPoint(zoom.zoomItX(r.x()), zoom.zoomItY(r.y())), &zoom, false);
@@ -509,8 +671,8 @@ void KivioDoc::printContent( KPrinter &prn )
   // No koffice app supports zooming in paintContent currently.
   // Disable in ALL cases now
   bool doZoom = false;
-  int dpiX = doZoom ? 300 : QPaintDevice::x11AppDpiX();
-  int dpiY = doZoom ? 300 : QPaintDevice::x11AppDpiY();
+  int dpiX = doZoom ? 300 : KoGlobal::dpiX();
+  int dpiY = doZoom ? 300 : KoGlobal::dpiY();
 
   p.start(&prn);
 
@@ -540,18 +702,18 @@ void KivioDoc::printContent( KPrinter &prn )
 bool KivioDoc::exportPage(KivioPage *pPage,const QString &fileName, ExportPageDialog *dlg)
 {
   KoZoomHandler zoom;
-  zoom.setZoomAndResolution(100, QPaintDevice::x11AppDpiX(),
-    QPaintDevice::x11AppDpiY());
+  zoom.setZoomAndResolution(100, KoGlobal::dpiX(),
+    KoGlobal::dpiY());
   QPixmap buffer;
 
   if(dlg->crop())
   {
     if(dlg->fullPage()) {
-      buffer.resize(zoom.zoomItX(pPage->getRectForAllStencils().w()) + dlg->border()*2,
-        zoom.zoomItY(pPage->getRectForAllStencils().h()) + dlg->border()*2);
+      buffer.resize(zoom.zoomItX(pPage->getRectForAllStencils().width()) + dlg->border()*2,
+        zoom.zoomItY(pPage->getRectForAllStencils().height()) + dlg->border()*2);
     } else {
-      buffer.resize(zoom.zoomItX(pPage->getRectForAllSelectedStencils().w()) + dlg->border()*2,
-        zoom.zoomItY(pPage->getRectForAllSelectedStencils().h()) + dlg->border()*2);
+      buffer.resize(zoom.zoomItX(pPage->getRectForAllSelectedStencils().width()) + dlg->border()*2,
+        zoom.zoomItY(pPage->getRectForAllSelectedStencils().height()) + dlg->border()*2);
     }
   }
   else
@@ -575,7 +737,7 @@ bool KivioDoc::exportPage(KivioPage *pPage,const QString &fileName, ExportPageDi
       p.setTranslation(-zoom.zoomItX(pPage->getRectForAllStencils().x()),
         -zoom.zoomItY(pPage->getRectForAllStencils().y()));
     }
-    
+
     pPage->printContent(p);
   }
   else
@@ -584,7 +746,7 @@ bool KivioDoc::exportPage(KivioPage *pPage,const QString &fileName, ExportPageDi
       p.setTranslation(-zoom.zoomItX(pPage->getRectForAllSelectedStencils().x()),
         -zoom.zoomItY(pPage->getRectForAllSelectedStencils().y()));
     }
-    
+
     pPage->printSelected(p);
   }
 
@@ -614,118 +776,93 @@ bool KivioDoc::setIsAlreadyLoaded( QString dirName, QString id )
     return false;
 }
 
-KivioStencilSpawnerSet *KivioDoc::addSpawnerSet( const QString &dirName )
+void KivioDoc::addSpawnerSet( const QString &dirName )
 {
-    KivioStencilSpawnerSet *set;
+  QString id = KivioStencilSpawnerSet::readId( dirName );
 
-    QString id = KivioStencilSpawnerSet::readId( dirName );
-
-    if( setIsAlreadyLoaded( dirName, id ) )
-    {
-       kdDebug(43000) << "KivioDoc::addSpawnerSet() - Cannot load duplicate stencil sets" << endl;
-        return NULL;
-    }
+  if( setIsAlreadyLoaded( dirName, id ) )
+  {
+      kdDebug(43000) << "KivioDoc::addSpawnerSet() - Cannot load duplicate stencil sets" << endl;
+      return;
+  }
 
 
-    set = new KivioStencilSpawnerSet();
+  KivioStencilSpawnerSet* set = new KivioStencilSpawnerSet();
 
-    if( set->loadDir(dirName)==false )
-    {
-       kdDebug(43000) << "KivioDoc::addSpawnerSet() - Error loading dir set" << endl;
-        delete set;
-        return NULL;
-    }
+  if( set->loadDir(dirName)==false )
+  {
+      kdDebug(43000) << "KivioDoc::addSpawnerSet() - Error loading dir set" << endl;
+      delete set;
+      return;
+  }
 
+  // Queue set for loading stencils
+  m_stencilSetLoadQueue.append(set);
 
-    m_pLstSpawnerSets->append( set );
-    setModified(true);
+  if(!m_loadTimer) {
+    m_loadTimer = new QTimer(this);
+    connect(m_loadTimer, SIGNAL(timeout()), this, SLOT(loadStencil()));
+  }
 
-    emit sig_addSpawnerSet( set );
-
-    return set;
+  if(!m_loadTimer->isActive()) {
+    emit initProgress();
+    m_loadTimer->start(0, false);
+  }
 }
 
-KivioStencilSpawnerSet *KivioDoc::addSpawnerSetDuringLoad( const QString &dirName )
+void KivioDoc::addSpawnerSetDuringLoad( const QString &dirName )
 {
-    KivioStencilSpawnerSet *set;
+  KivioStencilSpawnerSet *set;
 
-    set = new KivioStencilSpawnerSet();
-    if( set->loadDir(dirName)==false )
-    {
-       kdDebug(43000) << "KivioDoc::addSpawnerSetDuringLoad() - Error loading dir set" << endl;
-        delete set;
-        return NULL;
-    }
+  set = new KivioStencilSpawnerSet();
+  if( set->loadDir(dirName)==false )
+  {
+    kdDebug(43000) << "KivioDoc::addSpawnerSetDuringLoad() - Error loading dir set" << endl;
+    delete set;
+    return;
+  }
 
-    m_pLstSpawnerSets->append( set );
+  QStringList::iterator it;
+  QStringList files = set->files();
 
-    return set;
+  for(it = files.begin(); it != files.end(); ++it) {
+    QString fileName = set->dir() + "/" + (*it);
+    set->loadFile(fileName);
+  }
+
+  m_pLstSpawnerSets->append(set);
 }
 
 KivioDoc::~KivioDoc()
 {
+  if(m_docOpened) {
     saveConfig();
-    // ***MUST*** Delete the pages first because they may
-    // contain plugins which will be unloaded soon.  The stencils which are
-    // spawned by plugins NEED the plugins still loaded when their destructor
-    // is called or the program will slit it's throat.
-    delete m_pMap;
-    delete dcop;
-    delete m_commandHistory;
-    if( m_pClipboard )
-    {
-        delete m_pClipboard;
-        m_pClipboard = NULL;
-    }
+  }
 
-    if( m_pLstSpawnerSets )
-    {
-        delete m_pLstSpawnerSets;
-        m_pLstSpawnerSets = NULL;
-    }
+  // ***MUST*** Delete the pages first because they may
+  // contain plugins which will be unloaded soon.  The stencils which are
+  // spawned by plugins NEED the plugins still loaded when their destructor
+  // is called or the program will slit it's throat.
+  delete m_pMap;
+  delete dcop;
+  delete m_commandHistory;
 
-    s_docs->removeRef(this);
+  delete m_pLstSpawnerSets;
+  m_pLstSpawnerSets = 0;
 
-    delete m_options;
+  s_docs->removeRef(this);
 }
 
 void KivioDoc::saveConfig()
 {
-    // Only save the config that is manipulated by the UI directly.
-    // The config from the config dialog is saved by the dialog itself.
-    KConfig *config = KivioFactory::global()->config();
-    config->setGroup( "Interface" );
-    config->writeEntry("ShowGrid", grid().isShow );
-    config->writeEntry("SnapGrid",grid().isSnap);
-    config->writeEntry("GridColor",grid().color);
-    config->writeEntry("GridXSpacing", grid().freq.width());
-    config->writeEntry("GridYSpacing", grid().freq.height());
-    config->writeEntry("GridXSnap", grid().snap.width());
-    config->writeEntry("GridYSnap", grid().snap.height());
-    config->writeEntry("Unit", KoUnit::unitName(m_units));
-    config->writeEntry("Font", m_font);
+  Kivio::Config::self()->writeConfig();
 }
 
 void KivioDoc::initConfig()
 {
-    KConfig *config = KivioFactory::global()->config();
-    if( config->hasGroup("Interface" ) )
-    {
-        config->setGroup( "Interface" );
-        KivioGridData d = grid();
-        d.isShow = config->readBoolEntry( "ShowGrid", true );
-        d.isSnap = config->readBoolEntry( "SnapGrid", true);
-        QColor color = QColor(200,200,200);
-        d.color = config->readColorEntry( "GridColor", &color );
-        d.freq.setWidth(config->readDoubleNumEntry("GridXSpacing", 10.0));
-        d.freq.setHeight(config->readDoubleNumEntry("GridYSpacing", 10.0));
-        d.snap.setWidth(config->readDoubleNumEntry("GridXSnap", 10.0));
-        d.snap.setHeight(config->readDoubleNumEntry("GridYSnap", 10.0));
-        setGrid(d);
-        m_units = KoUnit::unit(config->readEntry("Unit", "mm"));
-        QFont def = KoGlobal::defaultFont();
-        m_font = config->readFontEntry("Font", &def);
-    }
+  m_units = KoUnit::unit(Kivio::Config::unit());
+  m_font = KoGlobal::defaultFont();
+  m_pageLayout = Kivio::Config::defaultPageLayout();
 }
 
 bool KivioDoc::removeSpawnerSet( KivioStencilSpawnerSet *pSet )
@@ -756,23 +893,6 @@ void KivioDoc::slotDeleteStencilSet( DragBarButton *pBtn, QWidget *w, KivioStack
             return;
         }
 
-        // Now check the clipboard against this spawner
-        if( m_pClipboard )
-        {
-            if( checkGroupForSpawner( m_pClipboard, pSpawner )==true )
-            {
-                if( KMessageBox::questionYesNo(NULL, i18n("The clipboard contains stencils which belong to the set you are trying to remove.\nWould you like to delete what is on the clipboard?\n(Saying no will cause this stencil set to not be removed.)"),
-                    i18n("Clear the clipboard?"))==KMessageBox::Yes )
-                {
-                    delete m_pClipboard;
-                    m_pClipboard = NULL;
-                }
-                else    // abort because the user aborted
-                    return;
-            }
-        }
-
-
         pSpawner = pSet->spawners()->next();
     }
 
@@ -854,19 +974,6 @@ bool KivioDoc::checkGroupForSpawner( KivioStencil *pGroup, KivioStencilSpawner *
     return false;
 }
 
-void KivioDoc::setClipboard( KivioGroupStencil *p )
-{
-    if( m_pClipboard )
-        delete m_pClipboard;
-
-    m_pClipboard = p;
-}
-
-KivioGroupStencil *KivioDoc::clipboard()
-{
-    return m_pClipboard;
-}
-
 void KivioDoc::slotSelectionChanged()
 {
     emit sig_selectionChanged();
@@ -898,6 +1005,11 @@ KivioStencilSpawner* KivioDoc::findInternalStencilSpawner( const QString& stenci
     return m_pInternalSet->find(stencilId);
 }
 
+void KivioDoc::addInternalStencilSpawner(KivioStencilSpawner* spawner)
+{
+  m_pInternalSet->addSpawner(spawner);
+}
+
 void KivioDoc::setUnits(KoUnit::Unit unit)
 {
   if (m_units == unit)
@@ -958,8 +1070,36 @@ void KivioDoc::updateProtectPanelCheckBox()
 {
     QPtrListIterator<KoView> it( views() );
     for (; it.current(); ++it )
-	((KivioView*)it.current())->updateProtectPanelCheckBox();
+      ((KivioView*)it.current())->updateProtectPanelCheckBox();
 }
 
+void KivioDoc::loadStencil()
+{
+  KivioStencilSpawnerSet* set = m_stencilSetLoadQueue.first();
+  QString fileName = set->dir() + "/" + set->files()[m_currentFile];
+  set->loadFile(fileName);
+  m_currentFile++;
+  emit progress(qRound(((float)m_currentFile / (float)set->files().count()) * 100.0));
+
+  if(m_currentFile >= set->files().count()) {
+    m_pLstSpawnerSets->append(set);
+
+    if(!m_bLoading) {
+      setModified(true);
+      emit sig_addSpawnerSet(set);
+    }
+
+    m_currentFile = 0;
+    set = 0;
+    m_stencilSetLoadQueue.pop_front();
+
+    if(m_stencilSetLoadQueue.isEmpty()) {
+      m_loadTimer->stop();
+      emit endProgress();
+    } else {
+      emit initProgress();
+    }
+  }
+}
 
 #include "kivio_doc.moc"
