@@ -27,12 +27,14 @@
 #include <koDocument.h>
 #include <koMainWindow.h>
 #include <koUnit.h>
+#include <koGlobal.h>
 
+#include "kivio_config.h"
+#include <koffice_export.h>
 class KivioDoc;
 class KivioView;
 class KivioMap;
 class KivioPage;
-class KivioOptions;
 
 class ExportPageDialog;
 class KivioGroupStencil;
@@ -44,13 +46,12 @@ class KivioStencil;
 
 namespace Kivio {
   class DragBarButton;
-  class ViewItemList;
 }
 
 class KoStore;
 class QDomDocument;
 class DCOPObject;
-class KCommandHistory;
+class KoCommandHistory;
 
 class QPainter;
 class KPrinter;
@@ -62,7 +63,7 @@ class QFont;
 
 using namespace Kivio;
 
-class KivioDoc : public KoDocument
+class KIVIO_EXPORT KivioDoc : public KoDocument
 {
   Q_OBJECT
   friend class KivioPage;
@@ -73,12 +74,12 @@ class KivioDoc : public KoDocument
     virtual DCOPObject* dcopObject();
 
     virtual QDomDocument saveXML();
+    virtual bool saveOasis(KoStore* store, KoXmlWriter* manifestWriter);
 
     virtual bool loadXML( QIODevice *, const QDomDocument& doc );
+    virtual bool loadOasis( const QDomDocument& doc, KoOasisStyles& oasisStyles, const QDomDocument& settings, KoStore* );
 
-    virtual bool initDoc();
-
-    KivioOptions* config()const { return m_options; }
+    virtual bool initDoc(InitDocFlags flags, QWidget* parentWidget=0);
 
     virtual QCString mimeType() const { return MIME_TYPE; }
 
@@ -100,14 +101,17 @@ class KivioDoc : public KoDocument
     * Adds a KivioStencilSpawnerSet to the list of spawner sets and make it active.
     *
     */
-    KivioStencilSpawnerSet *addSpawnerSet( const QString& );
-    KivioStencilSpawnerSet *addSpawnerSetDuringLoad( const QString& );
+    void addSpawnerSet( const QString& );
+    void addSpawnerSetDuringLoad( const QString& );
     bool removeSpawnerSet( KivioStencilSpawnerSet * );
 
     QPtrList<KivioStencilSpawnerSet> *spawnerSets()const { return m_pLstSpawnerSets; }
 
     KivioStencilSpawner *findStencilSpawner( const QString& setId, const QString& stencilId );
     KivioStencilSpawner *findInternalStencilSpawner( const QString& title );
+    
+    void addInternalStencilSpawner(KivioStencilSpawner* spawner);
+    KivioStencilSpawnerSet* internalSpawnerSet() { return m_pInternalSet; }
 
     KivioMap* map() const { return m_pMap; }
 
@@ -124,15 +128,9 @@ class KivioDoc : public KoDocument
 
     static QPtrList<KivioDoc>& documents();
 
-    KivioGroupStencil *clipboard();
-    void setClipboard( KivioGroupStencil * );
-
     KoUnit::Unit units()const { return m_units; }
 
-    KivioGridData grid() { return gridData; }
-    void setGrid(KivioGridData g) { gridData = g; emit sig_updateGrid();}
-
-    ViewItemList* viewItems()const { return viewItemList; }
+    KivioGridData grid() { return Kivio::Config::grid(); }
 
     void initConfig();
     void saveConfig();
@@ -141,14 +139,14 @@ class KivioDoc : public KoDocument
 
     int undoRedoLimit() const;
     void setUndoRedoLimit(int val);
-    KCommandHistory * commandHistory()const { return m_commandHistory; }
+    KoCommandHistory * commandHistory()const { return m_commandHistory; }
 
     void insertPage( KivioPage * page );
     void takePage( KivioPage * page );
     void resetLayerPanel();
     void updateProtectPanelCheckBox();
 
-    QFont defaultFont() { return m_font; }
+    QFont defaultFont() const { return m_font; }
 
   public slots:
     void updateView(KivioPage*);
@@ -162,6 +160,7 @@ class KivioDoc : public KoDocument
   protected slots:
     void slotDocumentRestored();
     void slotCommandExecuted();
+    void loadStencil();
 
   signals:
     void sig_selectionChanged();
@@ -174,11 +173,20 @@ class KivioDoc : public KoDocument
 
     void unitsChanged(KoUnit::Unit);
 
+    void initProgress();
+    void progress(int);
+    void endProgress();
+
+    void updateActivePage(KivioPage*);
+
   protected:
     bool checkStencilsForSpawner( KivioStencilSpawner * );
     bool checkGroupForSpawner( KivioStencil *, KivioStencilSpawner *);
     bool setIsAlreadyLoaded( QString dirName, QString name );
 
+    void saveOasisSettings( KoXmlWriter &/*settingsWriter*/ );
+    void loadOasisSettings( const QDomDocument&settingsDoc );
+
     KoView* createViewInstance( QWidget* parent, const char* name );
 
     /**
@@ -225,8 +233,6 @@ class KivioDoc : public KoDocument
     */
     bool m_bLoading;
 
-    KivioGroupStencil *m_pClipboard;
-
     static QPtrList<KivioDoc>* s_docs;
     static int s_docId;
 
@@ -235,13 +241,17 @@ class KivioDoc : public KoDocument
     KoUnit::Unit m_units;
     KivioGridData gridData;
 
-    ViewItemList* viewItemList;
-
-    KivioOptions* m_options;
     DCOPObject *dcop;
-    KCommandHistory * m_commandHistory;
+    KoCommandHistory * m_commandHistory;
 
     QFont m_font;
+
+    QTimer* m_loadTimer;
+    unsigned int m_currentFile;
+    KivioStencilSpawnerSet* m_currentSet;
+    QValueList<KivioStencilSpawnerSet*> m_stencilSetLoadQueue;
+
+    bool m_docOpened; // Used to for a hack that make kivio not crash if you cancel startup dialog.
 };
 
 #endif
