@@ -25,15 +25,6 @@
 #include <kstandarddirs.h>
 #include <kiconloader.h>
 
-#include "kivio_config.h"
-
-extern "C"
-{
-  void* init_libkiviopart()
-  {
-    return new KivioFactory;
-  }
-}
 
 KInstance* KivioFactory::s_global = 0;
 KAboutData* KivioFactory::s_aboutData = 0;
@@ -50,12 +41,6 @@ KivioFactory::~KivioFactory()
   s_aboutData=0;
   delete s_global;
   s_global = 0L;
-
-  // FIXME: Is this the right place to do this?
-  if( KivioConfig::config() )
-  {
-    KivioConfig::deleteConfig();
-  }
 }
 
 KParts::Part* KivioFactory::createPartObject( QWidget *parentWidget, const char *widgetName, QObject* parent, const char* name, const char* classname, const QStringList & )
@@ -87,13 +72,6 @@ KInstance* KivioFactory::global()
     s_global->iconLoader()->addAppDir("koffice");
   }
 
-  // FIXME: Is this the place to do it?
-  // Also load the config information here
-  if( KivioConfig::config() == NULL )
-  {
-    KivioConfig::readUserConfig();
-  }
-
   return s_global;
 }
 
