@@ -3,15 +3,17 @@
 
 #include <qwidget.h>
 #include <koUnit.h>
-#include <koGlobal.h>
 
-class KoUnitDoubleSpinBox;
+class KoPageLayout;
+class KoBuggyUnitDoubleSpinBox;
+class KIntSpinBox;
 
 class KivioStencilGeometryPanel : public QWidget
 {
   Q_OBJECT
   protected:
-    KoUnitDoubleSpinBox *m_pX, *m_pY, *m_pW, *m_pH;
+    KoBuggyUnitDoubleSpinBox *m_pX, *m_pY, *m_pW, *m_pH;
+    KIntSpinBox* m_rotationSBox;
     KoUnit::Unit m_unit;
     bool m_emitSignals;
 
@@ -20,6 +22,7 @@ class KivioStencilGeometryPanel : public QWidget
     void setPosition(double, double);
     void setSize(double, double);
     void setPageLayout(const KoPageLayout& l);
+    void setRotation(int d);
 
     void setEmitSignals(bool e);
 
@@ -28,10 +31,12 @@ class KivioStencilGeometryPanel : public QWidget
     void yChange(double);
     void wChange(double);
     void hChange(double);
+    void rotationChange(int);
 
   signals:
     void positionChanged(double, double);
     void sizeChanged(double, double);
+    void rotationChanged(int);
 
   public:
     KivioStencilGeometryPanel(QWidget* parent);
