@@ -8,6 +8,8 @@
 #include <qdom.h>
 #include <qptrlist.h>
 
+#include <koffice_export.h>
+
 #include "kivio_stencil.h"
 #include "kivio_text_style.h"
 
@@ -20,7 +22,7 @@ class KivioIntraStencilData;
 class KivioStencil;
 
 
-class Kivio1DStencil : public KivioStencil
+class KIVIO_EXPORT Kivio1DStencil : public KivioStencil
 {
 protected:
     QPtrList <KivioConnectorPoint> *m_pConnectorPoints;
@@ -90,6 +92,11 @@ public:
     virtual void setLineWidth( double f );
     virtual double lineWidth();
 
+    virtual void setLinePattern(int p);
+    virtual int linePattern();
+
+    virtual void setFillPattern(int p);
+    virtual int fillPattern();
 
     // position functions
     virtual void setX( double );
@@ -110,7 +117,7 @@ public:
 
 
     // collision detection
-    virtual KivioCollisionType checkForCollision( KivioPoint *, double );
+    virtual KivioCollisionType checkForCollision( KoPoint *, double );
 
 
     // custom dragging
@@ -140,6 +147,8 @@ public:
     virtual int resizeHandlePositions();
 
     virtual void disconnectFromTargets();
+    virtual KivioLineStyle lineStyle();
+    virtual void setLineStyle(KivioLineStyle ls);
 };
 
 
