@@ -23,7 +23,6 @@
 #include "kivio_intra_stencil_data.h"
 #include "kivio_layer.h"
 #include "kivio_painter.h"
-#include "kivio_point.h"
 #include "kivio_stencil.h"
 #include "kivio_stencil_spawner.h"
 #include "kivio_stencil_spawner_info.h"
@@ -37,6 +36,9 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <kozoomhandler.h>
+#include <koPoint.h>
+#include <koStore.h>
+#include <koxmlwriter.h>
 
 KivioLayer::KivioLayer( KivioPage *pPage )
     :m_pStencilList(NULL)
@@ -77,7 +79,7 @@ KivioLayer::~KivioLayer()
 
 bool KivioLayer::addStencil( KivioStencil *pStencil )
 {
-    int pos=m_pDeletedStencilList->findRef(pStencil);
+    int pos = m_pDeletedStencilList->findRef(pStencil);
     if ( pos != -1 )
         m_pDeletedStencilList->take( pos);
 
@@ -226,7 +228,7 @@ bool KivioLayer::loadXML( const QDomElement &layerE )
             }
             else
             {
-	       kdWarning() << "KivioLayer::loadXML() - Unknown KivioSMLStencil (id=" <<
+	       kdWarning(43000) << "KivioLayer::loadXML() - Unknown KivioSMLStencil (id=" <<
 		  XmlReadString( node.toElement(), "id", "" ) << " set=" <<
 		  XmlReadString( node.toElement(), "setId", "" ) << ") found." << endl;
             }
@@ -240,7 +242,7 @@ bool KivioLayer::loadXML( const QDomElement &layerE )
             }
             else
             {
-	       kdWarning() << "KivioLayer::loadXML() - Unable to load KivioGroupStencil" << endl;
+	       kdWarning(43000) << "KivioLayer::loadXML() - Unable to load KivioGroupStencil" << endl;
             }
         }
         else if( name == "KivioPluginStencil" )
@@ -252,8 +254,8 @@ bool KivioLayer::loadXML( const QDomElement &layerE )
             }
             else
             {
-	       kdWarning() << "KivioLayer - Unable to load KivioPluginStencil" << endl;
-	       kdWarning() << "KivioLayer::loadXML() - Unable to load KivioPluginStencil (id=" <<
+	       kdWarning(43000) << "KivioLayer - Unable to load KivioPluginStencil" << endl;
+	       kdWarning(43000) << "KivioLayer::loadXML() - Unable to load KivioPluginStencil (id=" <<
 		  XmlReadString( node.toElement(), "id", "" ) << " set=" <<
 		  XmlReadString( node.toElement(), "setId", "" ) << ") found." << endl;
             }
@@ -265,6 +267,13 @@ bool KivioLayer::loadXML( const QDomElement &layerE )
     return true;
 }
 
+void KivioLayer::loadOasis(const QDomElement& layer)
+{
+  m_name = layer.attribute("draw:name");
+  // TODO OASIS Load flags
+}
+
+
 QDomElement KivioLayer::saveXML( QDomDocument &doc )
 {
     QDomElement e = doc.createElement("KivioLayer");
@@ -283,7 +292,16 @@ QDomElement KivioLayer::saveXML( QDomDocument &doc )
     return e;
 }
 
-void KivioLayer::paintContent( KivioPainter& painter, const QRect&, bool , QPoint , KoZoomHandler* zoom )
+void KivioLayer::saveOasis(KoXmlWriter* layerWriter)
+{
+  layerWriter->startElement("draw:layer");
+  layerWriter->addAttribute("draw:name", m_name);
+  // TODO OASIS Save flags
+  layerWriter->endElement(); // draw:layer
+}
+
+void KivioLayer::paintContent( KivioPainter& painter, const QRect&, bool, QPoint, 
+  KoZoomHandler* zoom )
 {
     KivioStencil *pStencil = m_pStencilList->first();
     KivioIntraStencilData data;
@@ -295,7 +313,9 @@ void KivioLayer::paintContent( KivioPainter& painter, const QRect&, bool , QPoin
 
     while( pStencil )
     {
-        pStencil->paint( &data );
+        if(!pStencil->hidden()) {
+          pStencil->paint( &data );
+        }
 
         pStencil = m_pStencilList->next();
     }
@@ -304,17 +324,16 @@ void KivioLayer::paintContent( KivioPainter& painter, const QRect&, bool , QPoin
 void KivioLayer::printContent( KivioPainter& painter, int xdpi, int ydpi )
 {
   if(!xdpi) {
-    xdpi = QPaintDevice::x11AppDpiX();
+    xdpi = KoGlobal::dpiX();
   }
 
   if(!ydpi) {
-    ydpi = QPaintDevice::x11AppDpiY();
+    ydpi = KoGlobal::dpiY();
   }
 
   KivioStencil *pStencil = m_pStencilList->first();
   KivioIntraStencilData data;
   KoZoomHandler zoomHandler;
-  // FIXME: Hmmm... resolution sucks ;)
   zoomHandler.setZoomAndResolution(100, xdpi, ydpi);
 
   painter.setFGColor( QColor(0,0,0) );
@@ -331,7 +350,8 @@ void KivioLayer::printContent( KivioPainter& painter, int xdpi, int ydpi )
   }
 }
 
-void KivioLayer::paintConnectorTargets( KivioPainter& painter, const QRect&, bool, QPoint, KoZoomHandler* zoom )
+void KivioLayer::paintConnectorTargets( KivioPainter& painter, const QRect&, bool, QPoint,
+  KoZoomHandler* zoom )
 {
     KivioIntraStencilData data;
 
@@ -343,7 +363,9 @@ void KivioLayer::paintConnectorTargets( KivioPainter& painter, const QRect&, boo
     KivioStencil *pStencil = m_pStencilList->first();
     while( pStencil )
     {
-        pStencil->paintConnectorTargets( &data );
+        if(!pStencil->hidden()) {
+          pStencil->paintConnectorTargets( &data );
+        }
 
         pStencil = m_pStencilList->next();
     }
@@ -361,14 +383,14 @@ void KivioLayer::paintSelectionHandles( KivioPainter& painter, const QRect&, boo
     KivioStencil *pStencil = m_pStencilList->first();
     while( pStencil )
     {
-        if( pStencil->isSelected() )
+        if( pStencil->isSelected() && !pStencil->hidden() )
             pStencil->paintSelectionHandles( &data );
 
         pStencil = m_pStencilList->next();
     }
 }
 
-KivioStencil *KivioLayer::checkForStencil( KivioPoint *pPoint, int *collisionType, float threshold, bool selectedOnly )
+KivioStencil *KivioLayer::checkForStencil( KoPoint *pPoint, int *collisionType, float threshold, bool selectedOnly )
 {
     KivioStencil *pStencil;
     int colType;
