@@ -1,6 +1,7 @@
 /*
  * Kivio - Visual Modelling and Flowcharting
- * Copyright (C) 2000-2001 theKompany.com & Dave Marotti
+ * Copyright (C) 2000-2003 theKompany.com & Dave Marotti,
+ *                         Peter Simonsson
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,16 +26,20 @@
 #include <qptrlist.h>
 #include <qbitarray.h>
 #include <koPoint.h>
+#include <kglobalsettings.h>
+#include <koRect.h>
+#include <koffice_export.h>
+
+#include "kivio_line_style.h"
 
 class KivioCustomDragData;
 class KivioConnectorPoint;
 class KivioConnectorTarget;
 class KivioFillStyle;
 class KivioIntraStencilData;
-class KivioLineStyle;
 class KivioPage;
-class KivioPoint;
-class KivioRect;
+class KoPoint;
+class KoRect;
 class KivioStencilSpawner;
 class KivioStencil;
 class KivioStencilIface;
@@ -109,19 +114,19 @@ typedef enum
 
 
 
-class KivioStencil
+class KIVIO_EXPORT KivioStencil
 {
-protected:
+  protected:
     // Dimensions, size
     double m_x, m_y, m_w, m_h;
 
+    // Rotation
+    int m_rotation;
+    KoPoint m_pinPoint;
+
     // The spawner that created this stencil
     KivioStencilSpawner *m_pSpawner;
 
-
-    // Indicates if this stencil is selected
-    bool m_selected;
-
     // The protection bits of the stencil
     QBitArray *m_pProtection;
     QBitArray *m_pCanProtect;
@@ -130,7 +135,17 @@ protected:
     KivioStencilType m_type;
     bool m_connected;
 
-public:
+    // Indicates if this stencil is selected
+    bool m_selected;
+    
+    // Indicates if the stencil is hidden
+    bool m_hidden;
+
+  protected:
+    void rotatePainter(KivioIntraStencilData *);
+    KoRect calculateBoundingBox();
+
+  public:
     KivioStencil();
     virtual ~KivioStencil();
 
@@ -152,8 +167,10 @@ public:
 
     virtual double h() { return m_h; }
     virtual void setH( double f ) { if( f > 0 ) { m_h=f;  updateGeometry(); } }
+    
+    virtual void move(double xOffset, double yOffset);
 
-    virtual KivioRect rect();
+    virtual KoRect rect();
 
     virtual void setPosition( double f1, double f2 ) { m_x=f1; m_y=f2;  updateGeometry(); }
     virtual void setDimensions( double f1, double f2 ) { m_w=f1; m_h=f2;  updateGeometry(); }
@@ -163,17 +180,24 @@ public:
 
     virtual void setBGColor( QColor ) { ; }
     virtual QColor bgColor() { return QColor(0,0,0); }
+    virtual void setFillPattern(int) { ; }
+    virtual int fillPattern() { return 1; }
 
     virtual KivioFillStyle *fillStyle() { return NULL; }
+    virtual KivioLineStyle lineStyle() { return KivioLineStyle(); }
+    virtual void setLineStyle(KivioLineStyle) { ; }
 
     virtual void setLineWidth( double ) { ; }
     virtual double lineWidth() { return 1.0f; }
 
+    virtual void setLinePattern(int) { ; }
+    virtual int linePattern() { return 1; }
+
     // FOnt stuff
     virtual QColor textColor() { return QColor(0,0,0); }
     virtual void setTextColor( QColor ) {;}
 
-    virtual QFont textFont() { return QFont("times",12); }
+    virtual QFont textFont() { return KGlobalSettings::generalFont(); }
     virtual void setTextFont( const QFont & ) {;}
 
     virtual int hTextAlign() { return -1; }
@@ -185,6 +209,8 @@ public:
     virtual void setText( const QString & ) { ; }
     virtual QString text() { return QString(""); }
 
+    virtual void setRotation(int d);
+    virtual int rotation() { return m_rotation; }
 
     virtual KivioStencilSpawner *spawner() { return m_pSpawner; }
     virtual void setSpawner( KivioStencilSpawner *s ) { m_pSpawner=s; }
@@ -194,7 +220,7 @@ public:
     virtual void paintConnectorTargets( KivioIntraStencilData * );
     virtual void paintSelectionHandles( KivioIntraStencilData * );
 
-    virtual KivioCollisionType checkForCollision( KivioPoint *, double );
+    virtual KivioCollisionType checkForCollision( KoPoint *, double );
     virtual void customDrag( KivioCustomDragData * );
 
 
@@ -230,7 +256,28 @@ public:
     virtual int generateIds( int );
 
     virtual int resizeHandlePositions() { return krhpNone; }
+    
+    /**
+      Returns the name of the text box that is at the specified point.
+      If there exist no text box at the specified point then it returns QString::null.
+    */
+    virtual QString getTextBoxName(const KoPoint& /*p*/) { return QString::null; }
 
+    virtual void setText(const QString& /*text*/, const QString& /*name*/) { ; }
+    virtual QString text(const QString& /*name*/) { return QString(""); }
+
+    /// Returns true if the stencil has a text box
+    virtual bool hasTextBox() const { return false; }
+    
+    virtual void setPinPoint(const KoPoint& p) { m_pinPoint = p; }
+    virtual KoPoint pinPoint() const { return m_pinPoint; }
+    
+    virtual void addConnectorTarget(const KoPoint&) {}
+    
+    virtual bool isInRect(const KoRect& rect);
+    
+    virtual void setHidden(bool hide) { m_hidden = hide; }
+    virtual bool hidden() { return m_hidden; }
 
     /****** ARROW HEAD STUFF *******/
     virtual void setStartAHType( int ) { ; }
@@ -247,10 +294,8 @@ public:
     virtual double endAHWidth() { return 0.0f; }
     virtual double endAHLength() { return 0.0f; }
 
-    private:
-    	KivioStencilIface *iface;
+  private:
+    KivioStencilIface *iface;
 };
 
 #endif
-
-
