@@ -32,7 +32,7 @@ class QLabel;
 class QRadioButton;
 class KColorButton;
 class KURLRequester;
-class KoUnitDoubleSpinBox;
+class KoBuggyUnitDoubleSpinBox;
 class KivioGuideLineData;
 class QGroupBox;
 class QFont;
@@ -105,17 +105,17 @@ class KivioOptionsDialog : public KDialogBase
     KoPageLayout m_layout;
     QLabel* m_fontTxtLbl;
     QFont m_font;
-    KoUnitDoubleSpinBox* m_spaceHorizUSpin;
-    KoUnitDoubleSpinBox* m_spaceVertUSpin;
-    KoUnitDoubleSpinBox* m_snapHorizUSpin;
-    KoUnitDoubleSpinBox* m_snapVertUSpin;
+    KoBuggyUnitDoubleSpinBox* m_spaceHorizUSpin;
+    KoBuggyUnitDoubleSpinBox* m_spaceVertUSpin;
+    KoBuggyUnitDoubleSpinBox* m_snapHorizUSpin;
+    KoBuggyUnitDoubleSpinBox* m_snapVertUSpin;
     QCheckBox* m_gridChBox;
     QCheckBox* m_snapChBox;
     KColorButton* m_gridColorBtn;
     KListView* m_guideList;
     QRadioButton* m_orientHorizRBtn;
     QRadioButton* m_orientVertRBtn;
-    KoUnitDoubleSpinBox* m_posUSpin;
+    KoBuggyUnitDoubleSpinBox* m_posUSpin;
     QCheckBox* m_snapGuideChBox;
     QCheckBox* m_guidesChBox;
     KColorButton* m_guideColorBtn;
