@@ -51,7 +51,7 @@ K_EXPORT_COMPONENT_FACTORY( straight_connector, KGenericFactory<KivioConnectorFa
 KivioConnectorFactory::KivioConnectorFactory(QObject *parent, const char* name, const QStringList& args) :
 	KivioStencilFactory(parent, name, args)
 {
-	kdDebug() << "new straight line connector factory: " << endl;
+	kdDebug(43000) << "new straight line connector factory: " << endl;
 }
 
 KivioStencil *KivioConnectorFactory::NewStencil()
@@ -105,29 +105,28 @@ KivioStraightConnector::~KivioStraightConnector()
 {
    delete m_startAH;
    delete m_endAH;
-    // FIXME: THe parents destructor gets called right?
 }
 
 void KivioStraightConnector::setStartPoint( double x, double y )
 {
     m_pStart->setPosition( x, y, false );
     m_pStart->disconnect();
-
-    if( m_needsText )
-    {
-       m_pTextConn->setPosition( (m_pEnd->x()+m_pStart->x())/2.0f,
-        (m_pEnd->y()+m_pStart->y())/2.0f,
-        false );
-    }
 }
 
 void KivioStraightConnector::setEndPoint( double x, double y )
 {
     m_pEnd->setPosition( x, y, false );
     m_pEnd->disconnect();
+
+    if( m_needsText )
+    {
+       m_pTextConn->setPosition( (m_pStart->x()+m_pEnd->x())/2.0f,
+        (m_pStart->y()+m_pEnd->y())/2.0f,
+        false );
+    }
 }
 
-KivioCollisionType KivioStraightConnector::checkForCollision( KivioPoint *p, double threshold )
+KivioCollisionType KivioStraightConnector::checkForCollision( KoPoint *p, double threshold )
 {
     const double end_thresh = 4.0f;
 
@@ -194,8 +193,9 @@ void KivioStraightConnector::paint( KivioIntraStencilData *pData )
   double len;
 
 
-  painter->setFGColor( m_pLineStyle->color() );
-  painter->setLineWidth(zoomHandler->zoomItY(m_pLineStyle->width()));
+  painter->setLineStyle(m_pLineStyle);
+  double lineWidth = m_pLineStyle->width();
+  painter->setLineWidth(zoomHandler->zoomItY(lineWidth));
 
   x1 = zoomHandler->zoomItX(m_pStart->x());
   x2 = zoomHandler->zoomItX(m_pEnd->x());
@@ -250,8 +250,9 @@ void KivioStraightConnector::paintOutline( KivioIntraStencilData *pData )
   double len;
 
 
-  painter->setFGColor( m_pLineStyle->color() );
-  painter->setLineWidth(zoomHandler->zoomItY(m_pLineStyle->width()));
+  painter->setLineStyle(m_pLineStyle);
+  double lineWidth = m_pLineStyle->width();
+  painter->setLineWidth(zoomHandler->zoomItY(lineWidth));
 
   x1 = zoomHandler->zoomItX(m_pStart->x());
   x2 = zoomHandler->zoomItX(m_pEnd->x());
@@ -295,7 +296,7 @@ void KivioStraightConnector::paintOutline( KivioIntraStencilData *pData )
 
   // Text
   // Don't paint text in outline mode as it makes moving harder
-  //drawText(pData);
+  drawText(pData);
 }
 
 bool KivioStraightConnector::saveCustom( QDomElement &e, QDomDocument &doc )
@@ -370,4 +371,9 @@ bool KivioStraightConnector::loadArrowHeads( const QDomElement &e )
     return true;
 }
 
+bool KivioStraightConnector::hasTextBox() const
+{
+  return true;
+}
+
 #include "straight_connector.moc"
