@@ -38,21 +38,21 @@ class KivioPage;
 
 class KivioStraightConnector : public Kivio1DStencil
 {
-protected:
+  protected:
     KivioArrowHead *m_startAH;
     KivioArrowHead *m_endAH;
 
     bool loadArrowHeads( const QDomElement & );
     QDomElement saveArrowHeads( QDomDocument & );
 
-public:
+  public:
     KivioStraightConnector();
     virtual ~KivioStraightConnector();
 
     virtual void setStartPoint( double, double );
     virtual void setEndPoint( double, double );
 
-    virtual KivioCollisionType checkForCollision( KivioPoint *, double );
+    virtual KivioCollisionType checkForCollision( KoPoint *, double );
 
     virtual KivioStencil* duplicate();
 
@@ -77,17 +77,18 @@ public:
     virtual double endAHWidth()                  { return m_endAH->width(); }
     virtual double endAHLength()                 { return m_endAH->length(); }
 
+    virtual bool hasTextBox() const;
 };
 
-class KivioConnectorFactory : public KivioStencilFactory
+class KIVIOPLUGINS_EXPORT KivioConnectorFactory : public KivioStencilFactory
 {
-	Q_OBJECT
-    public:
-    	KivioConnectorFactory(QObject *parent=0, const char* name=0, const QStringList& args = QStringList());
-	KivioStencil *NewStencil(const QString& name);
-	KivioStencil *NewStencil();
-    	QPixmap *GetIcon();
-    	KivioStencilSpawnerInfo *GetSpawnerInfo();
+  Q_OBJECT
+  public:
+    KivioConnectorFactory(QObject *parent=0, const char* name=0, const QStringList& args = QStringList());
+    KivioStencil *NewStencil(const QString& name);
+    KivioStencil *NewStencil();
+    QPixmap *GetIcon();
+    KivioStencilSpawnerInfo *GetSpawnerInfo();
 };
 
 #endif
