@@ -1,7 +1,8 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
    Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
-   Copyright (C) 2000 David Faure <faure@kde.org>
+   Copyright (C) 2000-2005 David Faure <faure@kde.org>
+   Copyright (C) 2005 Sven Lppken <sven@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,25 +20,35 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <qhbox.h>
+#include <qcursor.h>
+#include <qsplitter.h>
+#include <qiconview.h>
+#include <qlabel.h>
+#include <qvbox.h>
+
 #include <assert.h>
 
 #include "koshell_shell.h"
+#include "koshellsettings.h"
 
+#include <kapplication.h>
 #include <ktempfile.h>
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kiconloader.h>
+#include <kkeydialog.h>
 #include <kstandarddirs.h>
 #include <klibloader.h>
+#include <kpopupmenu.h>
 #include <kservice.h>
 #include <kmessagebox.h>
 #include <krecentdocument.h>
 #include <kparts/partmanager.h>
 #include <kaction.h>
+#include <kdeversion.h>
 
 #include <koQueryTrader.h>
-#include <koKoolBar.h>
 #include <koDocumentInfo.h>
 #include <koDocument.h>
 #include <koView.h>
@@ -50,28 +61,42 @@ KoShellWindow::KoShellWindow()
 {
   m_activePage = m_lstPages.end();
 
-  m_pLayout = new QHBox( centralWidget() );
+  m_pLayout = new QSplitter( centralWidget() );
 
-  m_pKoolBar = new KoKoolBar( m_pLayout );
+  m_pSidebar = new IconSidePane( m_pLayout );
+  m_pSidebar->setSizePolicy( QSizePolicy( QSizePolicy::Maximum,
+                             QSizePolicy::Preferred ) );
+  m_pSidebar->setActionCollection( actionCollection() );
+  m_grpFile = m_pSidebar->insertGroup(i18n("Components"), false, this, SLOT( slotSidebar_Part(int )));
+  m_grpDocuments = m_pSidebar->insertGroup(i18n("Documents"), true, this, SLOT(slotSidebar_Document(int)));
+  m_pLayout->setResizeMode(m_pSidebar,QSplitter::FollowSizeHint);
 
-  m_pFrame = new KoShellFrame( m_pLayout );
+  m_pFrame = new KTabWidget( m_pLayout );
+  m_pFrame->setSizePolicy( QSizePolicy( QSizePolicy::Minimum,
+                            QSizePolicy::Preferred ) );
+  m_pFrame->setTabPosition( KTabWidget::Bottom );
+
+  m_tabCloseButton = new QToolButton( m_pFrame );
+  connect( m_tabCloseButton, SIGNAL( clicked() ),
+           this, SLOT( slotFileClose() ) );
+  m_tabCloseButton->setIconSet( SmallIconSet( "tab_remove" ) );
+  m_tabCloseButton->adjustSize();
+  QToolTip::add(m_tabCloseButton, i18n("Close"));
+  m_pFrame->setCornerWidget( m_tabCloseButton, BottomRight );
+  m_tabCloseButton->hide();
 
-  m_grpFile = m_pKoolBar->insertGroup(i18n("Parts"));
   QValueList<KoDocumentEntry> lstComponents = KoDocumentEntry::query(false,QString());
   QValueList<KoDocumentEntry>::Iterator it = lstComponents.begin();
+  int id = 0;
+
   for( ; it != lstComponents.end(); ++it )
   {
-      //kdDebug() << "Inserting into koolbar : " << (*it).name() << endl;
-      int id;
       if (!(*it).service()->genericName().isEmpty()) //skip the unavailable part
-          id = m_pKoolBar->insertItem( m_grpFile,
-                                       DesktopIcon((*it).service()->icon()),
-                                       (*it).name(),
-                                       this, SLOT( slotKoolBar( int, int ) ) );
+          id = m_pSidebar->insertItem(m_grpFile, (*it).service()->icon(), (*it).service()->genericName());
       else
           continue;
 
-      m_mapComponents[ id ] = *it;
+      m_mapComponents[ id++ ] = *it;
 
       // Build list of patterns for all supported KOffice documents...
       QString nativeMimeType = (*it).service()->property( "X-KDE-NativeMimeType" ).toString();
@@ -87,19 +112,17 @@ KoShellWindow::KoShellWindow()
         }
       }
   }
-
-  m_grpDocuments = m_pKoolBar->insertGroup(i18n("Documents"));
-  //m_pKoolBar->insertGroup("Snippets"); //?
-
-  m_pKoolBar->setFixedWidth( 80 );
-  m_pKoolBar->setMinimumHeight( 300 );
+   QValueList<int> list;
+   list.append( KoShellSettings::sidebarWidth() );
+   list.append( this->width() - KoShellSettings::sidebarWidth() );
+   m_pLayout->setSizes( list );
 
   connect( this, SIGNAL( documentSaved() ),
            this, SLOT( slotNewDocumentName() ) );
 
-  // Not implemented yet
-  actionCollection()->action("view_split")->setEnabled(false);
-  actionCollection()->action("view_splitter_orientation")->setEnabled(false);
+  connect( m_pFrame, SIGNAL( currentChanged( QWidget* ) ),
+           this, SLOT( slotUpdatePart( QWidget* ) ) );
+  connect( m_pFrame, SIGNAL( contextMenu(QWidget * ,const QPoint &)), this, SLOT( tab_contextMenu(QWidget * ,const QPoint &)) );
 
   m_client = new KoShellGUIClient( this );
   createShellGUI();
@@ -126,6 +149,7 @@ KoShellWindow::~KoShellWindow()
   m_lstPages.clear();
 
   setRootDocumentDirect( 0L, QPtrList<KoView>() ); // prevent our parent destructor from doing stupid things
+  saveSettings(); // Now save our settings before exiting
 }
 
 bool KoShellWindow::openDocumentInternal( const KURL &url, KoDocument* )
@@ -136,6 +160,15 @@ bool KoShellWindow::openDocumentInternal( const KURL &url, KoDocument* )
   // The second case is a non-native file. Here we have to create a
   // filter manager, ask it to convert the file to the "closest" available
   // KOffice part and open the temporary file.
+  
+  /*if (!KIO::NetAccess::exists(url,true,0) )
+  {
+    KMessageBox::error(0L, i18n("The file %1 doesn't exist.").arg(url.url()) );
+    recentAction()->removeURL(url); //remove the file from the recent-opened-file-list
+    saveRecentFiles();
+    return false;
+  }*/
+  
   KMimeType::Ptr mimeType = KMimeType::findByURL( url );
   m_documentEntry = KoDocumentEntry::queryByMimeType( mimeType->name().latin1() );
 
@@ -169,7 +202,7 @@ bool KoShellWindow::openDocumentInternal( const KURL &url, KoDocument* )
     tmpUrl.setPath( tmpFile->name() );
   }
 
-  m_recent->addURL( url );
+  recentAction()->addURL( url );
 
   KoDocument* newdoc = m_documentEntry.createDoc();
 
@@ -180,6 +213,7 @@ bool KoShellWindow::openDocumentInternal( const KURL &url, KoDocument* )
   bool openRet = (!isImporting ()) ? newdoc->openURL(tmpUrl) : newdoc->import(tmpUrl);
   if ( !newdoc || !openRet )
   {
+      newdoc->removeShell(this);
       delete newdoc;
       if ( tmpFile ) {
         tmpFile->unlink();
@@ -189,36 +223,61 @@ bool KoShellWindow::openDocumentInternal( const KURL &url, KoDocument* )
   }
 
   if ( tmpFile ) {
-    //if the laoded file has been a temporary file
+    //if the loaded file has been a temporary file
     //we need to correct a few document settings
     //see description of bug #77574 for additional information
-  
+
     //correct (output) mime type: we need to set it to the non-native format
     //to make sure the user knows about saving to a non-native mime type
     //setConfirmNonNativeSave is set to true below
     newdoc->setMimeType( mimeType->name().latin1() );
     newdoc->setOutputMimeType( mimeType->name().latin1() );
-    
+
     //the next time the user saves the document he should be warned
     //because of mime type settings done above;
     newdoc->setConfirmNonNativeSave(true,true); //exporting,warn_on
     newdoc->setConfirmNonNativeSave(false,true); //save/save as,warn_on
-    
+
     //correct document file (should point to URL)
     newdoc->setFile( url.path() );
-    
+
     //correct document URL
     newdoc->setURL( url );
-    
+
     //update caption to represent the correct URL in the window titlebar
     updateCaption();
-  
+
     tmpFile->unlink();
     delete tmpFile;
   }
   return true;
 }
 
+void KoShellWindow::slotSidebarItemClicked( QIconViewItem *item )
+{
+  //kdDebug() << "slotSidebarItemClicked called!" << endl;
+  if( item != 0 )
+  {
+    int index = item->index();
+  
+    // Create new document from a KoDocumentEntry
+    m_documentEntry = m_mapComponents[ index ];
+    KoDocument *doc = m_documentEntry.createDoc();
+    if (doc)
+    {
+        // koshell isn't starting, but this is like starting a new app:
+        // offer both "open existing file" and "open new file".
+        if ( doc->initDoc( KoDocument::InitDocAppStarting) )
+        {
+            partManager()->addPart( doc, false );
+            setRootDocument( doc );
+        }
+        else
+            delete doc;
+    }
+  }
+}
+
 // Separate from openDocument to handle async loading (remote URLs)
 void KoShellWindow::slotKSLoadCompleted()
 {
@@ -248,6 +307,22 @@ void KoShellWindow::slotKSLoadCanceled( const QString & errMsg )
     disconnect(newdoc, SIGNAL(canceled( const QString & )), this, SLOT(slotKSLoadCanceled( const QString & )));
 }
 
+void KoShellWindow::saveAll()
+{
+  KoView *currentView = (*m_activePage).m_pView;
+  for (QValueList<Page>::iterator it=m_lstPages.begin(); it != m_lstPages.end(); it++)
+  {
+    if ( (*it).m_pDoc->isModified() )
+    {
+      m_pFrame->showPage( (*it).m_pView );
+      (*it).m_pView->shell()->slotFileSave();
+      if ( (*it).m_pDoc->isModified() )
+        break;
+    }
+  }
+  m_pFrame->showPage( currentView );
+}
+
 void KoShellWindow::setRootDocument( KoDocument * doc )
 {
   kdDebug() << "KoShellWindow::setRootDocument this=" << this << " doc=" << doc << endl;
@@ -260,28 +335,29 @@ void KoShellWindow::setRootDocument( KoDocument * doc )
   {
     if ( !doc->shells().contains( this ) )
         doc->addShell( this );
-    KoView *v = doc->createView( m_pFrame );
+
+    KoView *v = doc->createView(this);
     QPtrList<KoView> views;
     views.append(v);
     setRootDocumentDirect( doc, views );
-
-    v->show();
+    
     v->setGeometry( 0, 0, m_pFrame->width(), m_pFrame->height() );
     v->setPartManager( partManager() );
-
+    m_pFrame->addTab( v, KGlobal::iconLoader()->loadIcon( m_documentEntry.service()->icon(), KIcon::Small ), i18n("Untitled") );
+    
     // Create a new page for this doc
     Page page;
     page.m_pDoc = doc;
     page.m_pView = v;
-    page.m_id = m_pKoolBar->insertItem( m_grpDocuments,
-                                        DesktopIcon( m_documentEntry.service()->icon() ),
-                                        i18n("Untitled"),
-                                        this, SLOT( slotKoolBar( int, int ) ) );
-    kdDebug() << " New page has id " << page.m_id << " doc is " << doc << endl;
-
+    // insert the new document in the sidebar
+    page.m_id = m_pSidebar->insertItem( m_grpDocuments,
+                                       m_documentEntry.service()->icon(),
+                                       i18n("Untitled"));
     m_lstPages.append( page );
+    v->show();
 
     switchToPage( m_lstPages.fromLast() );
+    mnuSaveAll->setEnabled(true);
   } else
   {
     setRootDocumentDirect( 0L, QPtrList<KoView>() );
@@ -319,12 +395,13 @@ void KoShellWindow::updateCaption()
 
         if ( !name.isEmpty() ) // else keep Untitled
         {
-	    if ( name.length() > 20 )
-	    {
-	        name.truncate( 17 );
-	        name += "...";
-	    }
-            m_pKoolBar->renameItem( m_grpDocuments, (*it).m_id, name );
+          if ( name.length() > 20 )
+          {
+            name.truncate( 17 );
+            name += "...";
+          }
+          m_pFrame->changeTab( m_pFrame->currentPage(), name );
+          m_pSidebar->renameItem(m_grpDocuments, (*m_activePage).m_id, name); //remove the document from the sidebar
         }
 
         return;
@@ -332,69 +409,82 @@ void KoShellWindow::updateCaption()
     }
 }
 
-void KoShellWindow::slotKoolBar( int _grp, int _item )
-{
-  kdDebug() << "KoShellWindow::slotKoolBar "  << _grp << " " << _item << endl;
-  if ( _grp == m_grpFile )
-  {
-    // Create new document from a KoDocumentEntry
-    m_documentEntry = m_mapComponents[ _item ];
-    kdDebug() << m_documentEntry.service() << endl;
-    kdDebug() << m_documentEntry.name() << endl;
-    KoDocument *doc = m_documentEntry.createDoc();
-    if (doc)
-    {
-        // koshell isn't starting, but this is like starting a new app:
-        // offer both "open existing file" and "open new file".
-        doc->setInitDocFlags( KoDocument::InitDocAppStarting );
-        if ( doc->initDoc() )
-        {
-            partManager()->addPart( doc, false );
-            setRootDocument( doc );
-        }
-        else
-            delete doc;
-    }
-  }
-  else if ( _grp == m_grpDocuments )
-  {
-    // Switch to an existing document
-    if ( m_activePage != m_lstPages.end() &&
-         (*m_activePage).m_id == _item )
-      return;
 
-    QValueList<Page>::Iterator it = m_lstPages.begin();
-    while( it != m_lstPages.end() )
+void KoShellWindow::slotSidebar_Part(int _item)
+{
+  //kdDebug() << "Component part choosed:" << _item << endl;
+  kapp->setOverrideCursor( QCursor(Qt::WaitCursor) );
+  m_documentEntry = m_mapComponents[ _item ];
+  kdDebug() << m_documentEntry.service() << endl;
+  kdDebug() << m_documentEntry.name() << endl;
+  KoDocument *doc = m_documentEntry.createDoc();
+  kapp->restoreOverrideCursor();
+  if (doc)
+  {
+    if ( doc->initDoc( KoDocument::InitDocAppStarting) )
     {
-      if ( (*it).m_id == _item )
-      {
-        switchToPage( it );
-        return;
-      }
-      ++it;
+      partManager()->addPart( doc, false );
+      setRootDocument( doc );
+      m_tabCloseButton->show();
     }
+    else
+      delete doc;
+  }
+}
+
+void KoShellWindow::slotSidebar_Document(int _item)
+{
+    // Switch to an existing document
+  if ( m_activePage != m_lstPages.end() &&
+       (*m_activePage).m_id == _item )
+    return;
+    
+  QValueList<Page>::Iterator it = m_lstPages.begin();
+  while( it != m_lstPages.end() )
+  {
+    if ( (*it).m_id == _item )
+    {
+      switchToPage( it );
+      return;
+    }
+    ++it;
   }
 }
 
 void KoShellWindow::slotShowSidebar()
 {
-	if( m_pKoolBar->isShown() )
-		m_pKoolBar->hide();
-	else
-		m_pKoolBar->show();
+  if( m_pSidebar->isShown() )
+  {
+    m_pSidebar->hide();
+    m_pComponentsLabel->hide();
+  }
+  else
+  {
+    m_pSidebar->show();
+    m_pComponentsLabel->show();
+  }
+}
+
+void KoShellWindow::slotUpdatePart( QWidget* widget )
+{
+  KoView* v = dynamic_cast<KoView*>(widget);
+  if ( v != 0 ) 
+  {
+    QValueList<Page>::Iterator it = m_lstPages.begin();
+    for( ; it != m_lstPages.end(); ++it )
+    {
+      if( (*it).m_pView == v )
+        switchToPage(it);
+    }
+  }
 }
 
 void KoShellWindow::switchToPage( QValueList<Page>::Iterator it )
 {
-  // Move away current page (view)
-  if ( m_activePage != m_lstPages.end() )
-    (*m_activePage).m_pView->reparent( 0L, 0, QPoint( 0, 0 ), FALSE );
   // Select new active page (view)
   m_activePage = it;
   KoView *v = (*m_activePage).m_pView;
-  // Show it here
-  v->reparent( m_pFrame, 0, QPoint( 0, 0 ), TRUE );
-  m_pFrame->setView( v );
+
   kdDebug() << " setting active part to " << (*m_activePage).m_pDoc << endl;
   // Make it active (GUI etc.)
   partManager()->setActivePart( (*m_activePage).m_pDoc, v );
@@ -402,6 +492,10 @@ void KoShellWindow::switchToPage( QValueList<Page>::Iterator it )
   QPtrList<KoView> views;
   views.append(v);
   setRootDocumentDirect( (*m_activePage).m_pDoc, views );
+  // Select the item in the sidebar
+  m_pSidebar->group(m_grpDocuments)->setSelected((*m_activePage).m_id,true);
+  // Raise the new page
+  m_pFrame->showPage( v );
   // Fix caption and set focus to the new view
   updateCaption();
   v->setFocus();
@@ -415,8 +509,7 @@ void KoShellWindow::slotFileNew()
     KoDocument* newdoc = m_documentEntry.createDoc();
     if ( !newdoc )
         return;
-    newdoc->setInitDocFlags( KoDocument::InitDocFileNew );
-    if ( !newdoc->initDoc() )
+    if ( !newdoc->initDoc(KoDocument::InitDocFileNew) )
     {
       delete newdoc;
       return;
@@ -424,6 +517,7 @@ void KoShellWindow::slotFileNew()
 
     partManager()->addPart( newdoc, false );
     setRootDocument( newdoc );
+    m_tabCloseButton->show();
 }
 
 void KoShellWindow::slotFileOpen()
@@ -438,7 +532,7 @@ void KoShellWindow::slotFileOpen()
     KURL url;
     if(dialog->exec()==QDialog::Accepted) {
         url=dialog->selectedURL();
-        m_recent->addURL( url );
+        recentAction()->addURL( url );
         if ( url.isLocalFile() )
             KRecentDocument::add(url.path(-1));
         else
@@ -452,6 +546,7 @@ void KoShellWindow::slotFileOpen()
         return;
 
     (void) openDocumentInternal( url );
+    m_tabCloseButton->show();
 }
 
 void KoShellWindow::slotFileClose()
@@ -463,6 +558,9 @@ void KoShellWindow::slotFileClose()
     close(); // close window
   else
     closeDocument(); // close only doc
+
+  if ( m_pFrame->count() == 0 )
+    m_tabCloseButton->hide();
 }
 
 void KoShellWindow::closeDocument()
@@ -476,12 +574,12 @@ void KoShellWindow::closeDocument()
   if ( KoMainWindow::queryClose() )
   {
     kdDebug() << "Ok for closing document" << endl;
-    m_pFrame->setView( 0L ); // safety measure
-    m_pKoolBar->removeItem( m_grpDocuments, (*m_activePage).m_id );
+    m_pSidebar->removeItem(m_grpDocuments, (*m_activePage).m_id ); //remove the document from the sidebar
     (*m_activePage).m_pDoc->removeShell(this);
     Page oldPage = (*m_activePage); // make a copy of the struct
     m_lstPages.remove( m_activePage );
     m_activePage = m_lstPages.end(); // no active page right now
+    m_pSidebar->group(m_grpDocuments)->setSelected((*m_activePage).m_id, true); //select the new document in the sidebar
 
     kdDebug() << "m_lstPages has " << m_lstPages.count() << " documents" << endl;
     if ( m_lstPages.count() > 0 )
@@ -494,6 +592,7 @@ void KoShellWindow::closeDocument()
       kdDebug() << "Revert to initial state (no docs)" << endl;
       setRootDocument( 0L );
       partManager()->setActivePart( 0L, 0L );
+      mnuSaveAll->setEnabled(false);
     }
 
     // Now delete the old view and page
@@ -520,7 +619,6 @@ bool KoShellWindow::queryClose()
 
       // This one is called by slotFileQuit and by the X button.
       // We have to check for unsaved docs...
-
       QValueList<Page>::Iterator it = m_lstPages.begin();
       for( ; it != m_lstPages.end(); ++it )
       {
@@ -550,12 +648,47 @@ bool KoShellWindow::saveAllPages()
 }
 */
 
+void KoShellWindow::saveSettings()
+{
+  KoShellSettings::setSidebarWidth( m_pLayout->sizes().first() );
+  KoShellSettings::writeConfig();
+}
+
 QString KoShellWindow::configFile() const
 {
   //return readConfigFile( locate( "data", "koshell/koshell_shell.rc" ) );
   return QString::null; // use UI standards only for now
 }
 
+void KoShellWindow::tab_contextMenu(QWidget * w,const QPoint &p)
+{
+  KPopupMenu menu;
+  int const mnuClose = menu.insertItem( i18n("Close") );
+  int const choice = menu.exec(p);
+
+  if ( choice == mnuClose )
+  {
+    const int index = m_pFrame->currentPageIndex();
+    m_pFrame->setCurrentPage( m_pFrame->indexOf(w) );
+    slotFileClose();
+    if ( index > m_pFrame->currentPageIndex() )
+        m_pFrame->setCurrentPage(index-1);
+    else
+        m_pFrame->setCurrentPage(index);
+  }
+}
+void KoShellWindow::slotConfigureKeys()
+{
+  KoView *view = rootView();
+  KKeyDialog dlg( this );
+  dlg.insert( actionCollection() );
+  if ( view )
+     dlg.insert( view->actionCollection() );
+  if ( rootDocument() )
+    dlg.insert( rootDocument()->actionCollection() );
+  dlg.configure();
+}
+
 /*
 void KoShellWindow::slotFilePrint()
 {
@@ -565,37 +698,18 @@ void KoShellWindow::slotFilePrint()
 }
 */
 
-void KoShellWindow::createShellGUI()
+void KoShellWindow::createShellGUI( bool  )
 {
 	guiFactory()->addClient( m_client );
 }
 
-///////
-
-KoShellFrame::KoShellFrame( QWidget *parent )
- : QWidget( parent )
-{
-  m_pView = 0L;
-}
-
-void KoShellFrame::setView( KoView *view )
-{
-  m_pView = view;
-}
-
-void KoShellFrame::resizeEvent( QResizeEvent * )
-{
-  if ( m_pView )
-    m_pView->setGeometry( 0, 0, width(), height() );
-}
 
+///////////////////
 KoShellGUIClient::KoShellGUIClient( KoShellWindow *window ) : KXMLGUIClient()
 {
-	setXMLFile( "koshellui.rc", true, false );
-
-	sidebar = new KToggleAction(i18n("Show Sidebar"), "view_choose", 0, window,
-			SLOT( slotShowSidebar() ), actionCollection(), "show_sidebar");
-	sidebar->setChecked( true );
+	setXMLFile( "koshellui.rc", true, true );
+    window->mnuSaveAll = new KAction(i18n("Save All"), 0, window, SLOT(saveAll() ), actionCollection(), "save_all");
+    window->mnuSaveAll->setEnabled(false);
 }
 
 #include "koshell_shell.moc"
