@@ -41,6 +41,12 @@ KoView* KoUnavailPart::createViewInstance( QWidget* parent, const char* name )
     return new KoUnavailView( this, parent, name );
 }
 
+bool KoUnavailPart::loadOasis( const QDomDocument& doc, KoOasisStyles&, const QDomDocument&, KoStore* )
+{
+    m_doc = doc;
+    return true;
+}
+
 bool KoUnavailPart::loadXML( QIODevice *, const QDomDocument &doc )
 {
     // Simply keep a copy of the whole document ;)
@@ -62,6 +68,13 @@ QDomDocument KoUnavailPart::saveXML()
     return m_doc;
 }
 
+
+bool KoUnavailPart::saveOasis(KoStore*, KoXmlWriter*)
+{
+    // TODO
+    return false;
+}
+
 void KoUnavailPart::setMimeType( const QCString& mime )
 {
     kdDebug() << "KoUnavailPart::setMimeType " << mime << endl;
@@ -112,13 +125,7 @@ void KoUnavailView::paintEvent( QPaintEvent* ev )
     painter.end();
 }
 
-extern "C"
-{
-    void* init_libkounavailpart()
-    {
-        return new KoUnavailFactory;
-    }
-}
+K_EXPORT_COMPONENT_FACTORY( libkounavailpart, KoUnavailFactory )
 
 KInstance* KoUnavailFactory::s_global = 0L;
 KAboutData* KoUnavailFactory::s_aboutData = 0L;
