@@ -22,6 +22,7 @@
 #include "kptextobject.h"
 #include "kpresenter_doc.h"
 #include "kpresenter_view.h"
+#include "kprpage.h"
 
 #include <kapplication.h>
 #include <dcopclient.h>
@@ -48,10 +49,10 @@ DCOPRef KPresenterDocIface::page( int num )
                     doc->pageList().at( num )->dcopObject()->objId() );
 }
 
-DCOPRef KPresenterDocIface::stickyPage()
+DCOPRef KPresenterDocIface::masterPage()
 {
     return DCOPRef( kapp->dcopClient()->appId(),
-                    doc->stickyPage()->dcopObject()->objId() );
+                    doc->masterPage()->dcopObject()->objId() );
 }
 
 void KPresenterDocIface::setShowRuler(bool b)
@@ -177,15 +178,6 @@ void KPresenterDocIface::recalcPageNum()
     doc->recalcPageNum();
 }
 
-void KPresenterDocIface::setHeader( bool b )
-{
-    doc->setHeader(b);
-}
-
-void KPresenterDocIface::setFooter( bool b )
-{
-    doc->setFooter(b);
-}
 
 void KPresenterDocIface::initConfig()
 {
@@ -209,16 +201,6 @@ bool KPresenterDocIface::isSlideSelected( int pgNum)
     return doc->isSlideSelected(pgNum);
 }
 
-bool KPresenterDocIface::hasFooter() const
-{
-    return doc->hasFooter();
-}
-
-bool KPresenterDocIface::hasHeader() const
-{
-    return doc->hasHeader();
-}
-
 //Return a reference to header textobj
 DCOPRef KPresenterDocIface::header()
 {
@@ -653,17 +635,17 @@ double KPresenterDocIface::helpPointPosY( int index ) const
 
 void KPresenterDocIface::addIgnoreWordAll( const QString &word)
 {
-    doc->addIgnoreWordAll( word );
+    doc->addSpellCheckIgnoreWord( word );
 }
 
 void KPresenterDocIface::clearIgnoreWordAll( )
 {
-    doc->clearIgnoreWordAll();
+    doc->setSpellCheckIgnoreList( QStringList() );
 }
 
 QStringList KPresenterDocIface::spellListIgnoreAll() const
 {
-    return doc->spellListIgnoreAll();
+    return doc->spellCheckIgnoreList();
 }
 
 bool KPresenterDocIface::displayFieldCode()const
@@ -692,3 +674,34 @@ void KPresenterDocIface::setConfigCapitalizeNameOfDays( bool b)
 {
     doc->getAutoFormat()->configCapitalizeNameOfDays( b );
 }
+
+QString KPresenterDocIface::presentationName() const
+{
+    return doc->presentationName();
+}
+
+void KPresenterDocIface::setPresentationName( const QString &_name )
+{
+    doc->setPresentationName( _name );
+}
+
+
+QStringList KPresenterDocIface::presentationList()
+{
+    return doc->presentationList();
+}
+
+void KPresenterDocIface::repaint()
+{
+    doc->repaint( false );
+}
+
+void KPresenterDocIface::setConfigToolTipCompletion( bool b )
+{
+    doc->getAutoFormat()->configToolTipCompletion( b );
+}
+
+bool KPresenterDocIface::configToolTipCompletion() const
+{
+    return doc->getAutoFormat()->getConfigToolTipCompletion();
+}
