@@ -1,6 +1,6 @@
 // -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
-   Copyright (C) 2002 Laurent MONTEL <lmontel@mandrakesoft.com>
+   Copyright (C) 2002,2003,2004 Laurent MONTEL <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,8 +32,10 @@
 #include <kcommand.h>
 #include "kprcommand.h"
 
-KPresenterPageIface::KPresenterPageIface( KPrPage *_page )
-    : DCOPObject()
+KPresenterPageIface::KPresenterPageIface( KPrPage *_page, int pgnum )
+    // Make up a nice DCOPObject name like "Document-0 Page-1".
+    // ### But the page number will be stale if pages are added/removed/moved around....
+    : DCOPObject( QCString( _page->kPresenterDoc()->dcopObject()->objId() ) + " Page-" + QString::number( pgnum ).latin1() )
 {
     m_page = _page;
 }
@@ -79,8 +81,7 @@ QString KPresenterPageIface::manualTitle()const
 void KPresenterPageIface::insertManualTitle(const QString & title)
 {
     m_page->insertManualTitle(title);
-    int pos=m_page->kPresenterDoc()->pageList().findRef(m_page);
-    m_page->kPresenterDoc()->updateSideBarItem(pos);
+    m_page->kPresenterDoc()->updateSideBarItem( m_page );
 }
 
 QString KPresenterPageIface::pageTitle( const QString &_title ) const
@@ -116,7 +117,8 @@ DCOPRef KPresenterPageIface::groupObjects()
 
 void KPresenterPageIface::ungroupObjects()
 {
-    m_page->ungroupObjects();
+    //FIXME
+    //m_page->ungroupObjects();
 }
 
 void KPresenterPageIface::raiseObjs()
@@ -145,42 +147,6 @@ void KPresenterPageIface::copyObjs()
     //m_page->copyObjs();
 }
 
-void KPresenterPageIface::alignObjsLeft()
-{
-    KCommand *cmd=m_page->alignObjsLeft();
-    delete cmd;
-}
-
-void KPresenterPageIface::alignObjsCenterH()
-{
-    KCommand *cmd=m_page->alignObjsCenterH();
-    delete cmd;
-}
-
-void KPresenterPageIface::alignObjsRight()
-{
-    KCommand *cmd=m_page->alignObjsRight();
-    delete cmd;
-}
-
-void KPresenterPageIface::alignObjsTop()
-{
-    KCommand *cmd=m_page->alignObjsTop();
-    delete cmd;
-}
-
-void KPresenterPageIface::alignObjsCenterV()
-{
-    KCommand *cmd=m_page->alignObjsCenterV();
-    delete cmd;
-}
-
-void KPresenterPageIface::alignObjsBottom()
-{
-    KCommand *cmd=m_page->alignObjsBottom();
-    delete cmd;
-}
-
 void KPresenterPageIface::slotRepaintVariable()
 {
     m_page->slotRepaintVariable();
@@ -492,26 +458,11 @@ bool KPresenterPageIface::backUnbalanced() const
     return (int)m_page->getBackUnbalanced();
 }
 
-bool KPresenterPageIface::setRectSettings( int _rx, int _ry )
-{
-    return m_page->setRectSettings(_rx,_ry, RectValueCmd::All);
-}
-
 QString KPresenterPageIface::pageSoundFileName() const
 {
     return m_page->getPageSoundFileName();
 }
 
-int KPresenterPageIface::pieAngle( int pieAngle ) const
-{
-    return m_page->getPieAngle(pieAngle);
-}
-
-int KPresenterPageIface::pieLength( int pieLength ) const
-{
-    return m_page->getPieLength(pieLength);
-}
-
 QRect KPresenterPageIface::pageRect() const
 {
     return m_page->getZoomPageRect();
@@ -525,20 +476,21 @@ bool KPresenterPageIface::isSlideSelected()
 void KPresenterPageIface::slideSelected(bool _b)
 {
     m_page->slideSelected(_b);
-    int pos=m_page->kPresenterDoc()->pageList().findRef(m_page);
-    m_page->kPresenterDoc()->updateSideBarItem(pos);
+    m_page->kPresenterDoc()->updateSideBarItem( m_page );
     m_page->kPresenterDoc()->updatePresentationButton();
 }
 
 void KPresenterPageIface::changePicture( const QString & filename )
 {
-    m_page->changePicture(filename);
+    // TODO: find a better parent
+    m_page->changePicture(filename, 0);
 }
 
 //create a rectangle and return a dcop reference!
 DCOPRef KPresenterPageIface::insertRectangle(int x, int y, int h, int w)
 {
     KPresenterView *view=m_page->kPresenterDoc()->firstView();
+    m_page->kPresenterDoc()->deSelectAllObj();
     if ( !view  )
         return DCOPRef();
     view->getCanvas()->insertRect( QRect(x,y,h,w) );
@@ -548,6 +500,7 @@ DCOPRef KPresenterPageIface::insertRectangle(int x, int y, int h, int w)
 DCOPRef KPresenterPageIface::insertEllipse( int x, int y, int h, int w )
 {
     KPresenterView *view=m_page->kPresenterDoc()->firstView();
+    m_page->kPresenterDoc()->deSelectAllObj();
     if ( !view  )
         return DCOPRef();
 
@@ -558,6 +511,7 @@ DCOPRef KPresenterPageIface::insertEllipse( int x, int y, int h, int w )
 DCOPRef KPresenterPageIface::insertPie( int x, int y, int h, int w )
 {
     KPresenterView *view=m_page->kPresenterDoc()->firstView();
+    m_page->kPresenterDoc()->deSelectAllObj();
     if ( !view  )
         return DCOPRef();
 
@@ -568,6 +522,7 @@ DCOPRef KPresenterPageIface::insertPie( int x, int y, int h, int w )
 DCOPRef KPresenterPageIface::insertLineH( int x, int y, int h, int w, bool rev )
 {
     KPresenterView *view=m_page->kPresenterDoc()->firstView();
+    m_page->kPresenterDoc()->deSelectAllObj();
     if ( !view  )
         return DCOPRef();
 
@@ -578,6 +533,7 @@ DCOPRef KPresenterPageIface::insertLineH( int x, int y, int h, int w, bool rev )
 DCOPRef KPresenterPageIface::insertLineV( int x, int y, int h, int w, bool rev )
 {
     KPresenterView *view=m_page->kPresenterDoc()->firstView();
+    m_page->kPresenterDoc()->deSelectAllObj();
     if ( !view  )
         return DCOPRef();
 
@@ -588,6 +544,7 @@ DCOPRef KPresenterPageIface::insertLineV( int x, int y, int h, int w, bool rev )
 DCOPRef KPresenterPageIface::insertLineD1( int x, int y, int h, int w, bool rev )
 {
     KPresenterView *view=m_page->kPresenterDoc()->firstView();
+    m_page->kPresenterDoc()->deSelectAllObj();
     if ( !view  )
         return DCOPRef();
 
@@ -598,6 +555,7 @@ DCOPRef KPresenterPageIface::insertLineD1( int x, int y, int h, int w, bool rev
 DCOPRef KPresenterPageIface::insertLineD2( int x, int y, int h, int w, bool rev )
 {
     KPresenterView *view=m_page->kPresenterDoc()->firstView();
+    m_page->kPresenterDoc()->deSelectAllObj();
     if ( !view  )
         return DCOPRef();
 
@@ -608,6 +566,7 @@ DCOPRef KPresenterPageIface::insertLineD2( int x, int y, int h, int w, bool rev
 DCOPRef KPresenterPageIface::insertTextObject( int x, int y, int h, int w )
 {
     KPresenterView *view=m_page->kPresenterDoc()->firstView();
+    m_page->kPresenterDoc()->deSelectAllObj();
     if ( !view  )
         return DCOPRef();
 
@@ -619,6 +578,7 @@ DCOPRef KPresenterPageIface::insertPicture( const QString & file, int x, int y,
 {
     m_page->setInsPictureFile(file);
     KPresenterView *view=m_page->kPresenterDoc()->firstView();
+    m_page->kPresenterDoc()->deSelectAllObj();
     if ( !view  )
         return DCOPRef();
 
@@ -671,20 +631,6 @@ void KPresenterPageIface::setBackGroundColorType(const QString &type)
                           backXFactor(), backYFactor() );
 }
 
-int KPresenterPageIface::rndY() const
-{
-    int ret=-1;
-    m_page->getRndY( ret );
-    return ret;
-}
-
-int KPresenterPageIface::rndX() const
-{
-    int ret=-1;
-    m_page->getRndX( ret );
-    return ret;
-}
-
 void KPresenterPageIface::deSelectAllObj()
 {
     m_page->deSelectAllObj();
@@ -712,7 +658,7 @@ bool KPresenterPageIface::haveASelectedGroupObj() const
 
 void KPresenterPageIface::rotateAllObjSelected(float _newAngle)
 {
-    KCommand *cmd= m_page->rotateObj( _newAngle);
+    KCommand *cmd= m_page->rotateSelectedObjects( _newAngle);
     delete cmd;
 }
 
@@ -734,6 +680,37 @@ void KPresenterPageIface::moveAllObjectSelected( int diffx,int diffy)
 
 void KPresenterPageIface::deleteAllObjectSelected()
 {
-    KCommand * cmd=m_page->deleteObjs();
+    KCommand * cmd=m_page->deleteSelectedObjects();
     delete cmd;
 }
+
+bool KPresenterPageIface::hasHeader()const
+{
+    return m_page->hasHeader();
+}
+
+bool KPresenterPageIface::hasFooter()const
+{
+    return m_page->hasFooter();
+}
+
+void KPresenterPageIface::setHeader( bool b )
+{
+    m_page->setHeader( b );
+}
+
+void KPresenterPageIface::setFooter( bool b )
+{
+    m_page->setFooter( b );
+}
+
+
+void KPresenterPageIface::setUseMasterBackground( bool useMasterBackground )
+{
+    m_page->setUseMasterBackground( useMasterBackground );
+}
+
+bool KPresenterPageIface::useMasterBackground() const
+{
+    return m_page->useMasterBackground();
+}
