@@ -23,6 +23,7 @@
 #include "kpresenter_view.h"
 #include "kprcanvas.h"
 #include "kprpage.h"
+#include "kpresenter_doc.h"
 
 #include <kapplication.h>
 #include <dcopclient.h>
@@ -175,9 +176,13 @@ void KPresenterViewIface::toolsConvexOrConcavePolygon()
 
 void KPresenterViewIface::extraPenBrush()
 {
-    view->extraPenBrush();
+    view->extraProperties();
 }
 
+void KPresenterViewIface::extraProperties()
+{
+    view->extraProperties();
+}
 
 void KPresenterViewIface::extraRaise()
 {
@@ -229,6 +234,11 @@ void KPresenterViewIface::extraWebPres()
     view->extraWebPres();
 }
 
+void KPresenterViewIface::extraMSPres()
+{
+    view->extraMSPres();
+}
+
 void KPresenterViewIface::extraAlignObjLeft()
 {
     view->extraAlignObjLeft();
@@ -454,11 +464,6 @@ int KPresenterViewIface::getCurrentPageNum() const
     return view->getCurrPgNum();
 }
 
-double KPresenterViewIface::getCurrentFaktor() const
-{
-    return (double)view->getCurrentFaktor();
-}
-
 void KPresenterViewIface::insertSpecialChar()
 {
     view->insertSpecialChar();
@@ -504,6 +509,12 @@ void KPresenterViewIface::viewShowNoteBar()
     view->viewShowNoteBar();
 }
 
+void KPresenterViewIface::viewSlideMaster()
+{
+    view->viewSlideMaster();
+}
+
+
 void KPresenterViewIface::formatParagraph()
 {
     view->formatParagraph();
@@ -588,6 +599,17 @@ void KPresenterViewIface::savePicture()
     view->savePicture();
 }
 
+void KPresenterViewIface::viewFooter()
+{
+    view->viewFooter();
+}
+
+void KPresenterViewIface::viewHeader()
+{
+    view->viewHeader();
+}
+
+
 // note: _nPage is the user visible 1-based page number
 // if 0 < _verbose exportPage() returns the title and notes of the page
 // if not verbose it returns an empty string
@@ -658,3 +680,43 @@ void KPresenterViewIface::addWordToDictionary()
 {
     view->addWordToDictionary();
 }
+
+void KPresenterViewIface::customSlideShow()
+{
+    view->customSlideShow();
+}
+
+void KPresenterViewIface::insertLineBreak()
+{
+    view->slotLineBreak();
+}
+
+void KPresenterViewIface::increaseNumberingLevel()
+{
+    view->slotIncreaseNumberingLevel();
+}
+
+void KPresenterViewIface::decreaseNumberingLevel()
+{
+    view->slotDecreaseNumberingLevel();
+}
+
+void KPresenterViewIface::increaseFontSize()
+{
+    view->increaseFontSize();
+}
+
+void KPresenterViewIface::decreaseFontSize()
+{
+    view->decreaseFontSize();
+}
+
+void KPresenterViewIface::flipHorizontal()
+{
+    view->flipHorizontal();
+}
+
+void KPresenterViewIface::flipVertical()
+{
+    view->flipVertical();
+}
