@@ -50,6 +50,9 @@ k_dcop:
     virtual void newView();
     virtual void viewShowSideBar();
     virtual void viewShowNoteBar();
+    virtual void viewSlideMaster();
+    virtual void viewFooter();
+    virtual void viewHeader();
 
     // insert menu
     virtual void insertPage();
@@ -81,7 +84,8 @@ k_dcop:
 
 
     // extra menu
-    virtual void extraPenBrush();
+    virtual void extraProperties();
+    virtual void extraPenBrush(); /** * @deprecated */
     virtual void extraRaise();
     virtual void extraLower();
     virtual void extraRotate();
@@ -92,6 +96,7 @@ k_dcop:
     virtual void extraLineBegin();
     virtual void extraLineEnd();
     virtual void extraWebPres();
+    virtual void extraMSPres();
     virtual void extraGroup();
     virtual void extraUnGroup();
     virtual void extraPenStyle();
@@ -158,8 +163,6 @@ k_dcop:
     virtual int getCurrentPageNum() const;
 
     // in both modes
-    virtual double getCurrentFaktor()const;
-
     virtual void insertCustomVariable();
     virtual void insertNewCustomVariable();
     virtual void insertVariable();
@@ -180,14 +183,14 @@ k_dcop:
     virtual void closeObject();
 
     void savePicture();
-    
+
     /**
      \brief Save page to bitmap file.
-     
+
      Export a page of the currently open presentation to disk
      using a bitmap format like e.g. PNG.
      This method uses a QPixmap::save() call.
-      
+
      \param _nPage the user visible <b>1-based</b> page number
      \param _nWidth the desired image width in px
      \param _nHeight the desired image height in px
@@ -197,9 +200,9 @@ k_dcop:
      \param _verbose the verbosity of the method's return value:
        if 0 < _verbose exportPage() returns the title and the notes of the page
        if not _verbose it returns an empty string
-      
+
      \returns Page title and page notes if the file was written successfully.
-     
+
      \sa KPrCanvas::exportPage
      */
     QStringList exportPage( int _nPage,
@@ -215,6 +218,20 @@ k_dcop:
     void insertFile( const QString & file );
     void addWordToDictionary();
 
+    void customSlideShow();
+
+    void insertLineBreak();
+    void increaseNumberingLevel();
+    void decreaseNumberingLevel();
+
+    void increaseFontSize();
+    void decreaseFontSize();
+
+    void flipHorizontal();
+    void flipVertical();
+
+
+
 private:
     KPresenterView *view;
 
