@@ -19,8 +19,10 @@
 */
 
 #include "kpresenter_view.h"
+#include "kpresenter_doc.h"
 #include "effectdia.h"
 #include "kprcommand.h"
+#include "kpobject.h"
 #include "kpresenter_sound_player.h"
 
 #include <qpushbutton.h>
@@ -63,15 +65,15 @@ EffectDia::EffectDia( QWidget* parent, const char* name, const QPtrList<KPObject
     grp1->layout()->setSpacing(KDialog::spacingHint());
     grp1->layout()->setMargin(KDialog::marginHint());
     topLayout->addWidget(grp1);
-    QGridLayout *upperRow = new QGridLayout(grp1->layout(), 5, 4);
+    QGridLayout *upperRow = new QGridLayout(grp1->layout(), 6, 4);
 
-    lNum = new QLabel( i18n( "Order of appearance:" ), grp1 );
-    lNum->setAlignment( AlignVCenter );
-    upperRow->addWidget(lNum, 0, 0);
+    lAppear = new QLabel( i18n( "Order of appearance:" ), grp1 );
+    lAppear->setAlignment( AlignVCenter );
+    upperRow->addWidget(lAppear, 0, 0);
 
-    eNum = new QSpinBox( 0, 100, 1, grp1 );
-    eNum->setValue( obj->getPresNum() );
-    upperRow->addWidget(eNum, 0, 1);
+    eAppearStep = new QSpinBox( 0, 100, 1, grp1 );
+    eAppearStep->setValue( obj->getAppearStep() );
+    upperRow->addWidget(eAppearStep, 0, 1);
 
     //( void )new QWidget( grp1 );
     //( void )new QWidget( grp1 );
@@ -99,13 +101,25 @@ EffectDia::EffectDia( QWidget* parent, const char* name, const QPtrList<KPObject
 
     connect( cEffect, SIGNAL( activated( int ) ), this, SLOT( appearEffectChanged( int ) ) );
 
+    lAppearSpeed = new QLabel( i18n( "Speed:" ), grp1 );
+    lAppearSpeed->setAlignment( AlignVCenter );
+    upperRow->addWidget(lAppearSpeed, 2, 0);
+
+    cAppearSpeed = new QComboBox( false, grp1, "cEffect" );
+    cAppearSpeed->insertItem( i18n( "Slow" ) );
+    cAppearSpeed->insertItem( i18n( "Medium" ) );
+    cAppearSpeed->insertItem( i18n( "Fast" ) );
+    cAppearSpeed->setCurrentItem( static_cast<int>( obj->getAppearSpeed() ) );
+    upperRow->addWidget(cAppearSpeed, 2, 1);
+    appearEffectChanged( cEffect->currentItem() );
+
     lEffect2 = new QLabel( i18n( "Effect (object specific):" ), grp1 );
     lEffect2->setAlignment( AlignVCenter );
-    upperRow->addWidget(lEffect2, 2, 0);
+    upperRow->addWidget(lEffect2, 3, 0);
 
     cEffect2 = new QComboBox( false, grp1, "cEffect2" );
     cEffect2->insertItem( i18n( "No Effect" ) );
-    upperRow->addWidget(cEffect2, 2, 1);
+    upperRow->addWidget(cEffect2, 3, 1);
 
     switch ( obj->getType() ) {
     case OT_TEXT: {
@@ -131,12 +145,12 @@ EffectDia::EffectDia( QWidget* parent, const char* name, const QPtrList<KPObject
 
     QLabel *lTimerOfAppear = new QLabel( i18n( "Timer of the object:" ), grp1 );
     lTimerOfAppear->setAlignment( AlignVCenter );
-    upperRow->addWidget( lTimerOfAppear, 3, 0 );
+    upperRow->addWidget( lTimerOfAppear, 4, 0 );
 
     timerOfAppear = new KIntNumInput( obj->getAppearTimer(), grp1 );
     timerOfAppear->setRange( 1, 600, 1 );
     timerOfAppear->setSuffix( i18n( " seconds" ) );
-    upperRow->addWidget( timerOfAppear, 3, 1 );
+    upperRow->addWidget( timerOfAppear, 4, 1 );
 
     if ( view->kPresenterDoc()->spManualSwitch() )
         timerOfAppear->setEnabled( false );
@@ -145,21 +159,17 @@ EffectDia::EffectDia( QWidget* parent, const char* name, const QPtrList<KPObject
     // setup the Sound Effect stuff
     appearSoundEffect = new QCheckBox( i18n( "Sound effect" ), grp1 );
     appearSoundEffect->setChecked( obj->getAppearSoundEffect() );
-    upperRow->addWidget( appearSoundEffect, 4, 0 );
-    QWhatsThis::add( appearSoundEffect, i18n("If you use sound effect, please do not select 'No Effect'.") );
-
-    if ( static_cast<int>( obj->getEffect() ) == 0 )
-        appearSoundEffect->setEnabled( false );
+    upperRow->addWidget( appearSoundEffect, 5, 0 );
 
     connect( appearSoundEffect, SIGNAL( clicked() ), this, SLOT( appearSoundEffectChanged() ) );
 
     lSoundEffect1 = new QLabel( i18n( "File name:" ), grp1 );
     lSoundEffect1->setAlignment( AlignVCenter );
-    upperRow->addWidget( lSoundEffect1, 5, 0 );
+    upperRow->addWidget( lSoundEffect1, 6, 0 );
 
     requester1 = new KURLRequester( grp1 );
     requester1->setURL( obj->getAppearSoundEffectFileName() );
-    upperRow->addWidget( requester1, 5, 1 );
+    upperRow->addWidget( requester1, 6, 1 );
 
     connect( requester1, SIGNAL( openFileDialog( KURLRequester * ) ),
              this, SLOT( slotRequesterClicked( KURLRequester * ) ) );
@@ -168,16 +178,16 @@ EffectDia::EffectDia( QWidget* parent, const char* name, const QPtrList<KPObject
              this, SLOT( slotAppearFileChanged( const QString& ) ) );
 
     buttonTestPlaySoundEffect1 = new QPushButton( grp1 );
-    buttonTestPlaySoundEffect1->setPixmap( BarIcon("1rightarrow", KIcon::SizeSmall) );
+    buttonTestPlaySoundEffect1->setIconSet( SmallIconSet("1rightarrow") );
     QToolTip::add( buttonTestPlaySoundEffect1, i18n("Play") );
-    upperRow->addWidget( buttonTestPlaySoundEffect1, 5, 2 );
+    upperRow->addWidget( buttonTestPlaySoundEffect1, 6, 2 );
 
     connect( buttonTestPlaySoundEffect1, SIGNAL( clicked() ), this, SLOT( playSound1() ) );
 
     buttonTestStopSoundEffect1 = new QPushButton( grp1 );
-    buttonTestStopSoundEffect1->setPixmap( BarIcon("player_stop", KIcon::SizeSmall) );
+    buttonTestStopSoundEffect1->setIconSet( SmallIconSet("player_stop") );
     QToolTip::add( buttonTestStopSoundEffect1, i18n("Stop") );
-    upperRow->addWidget( buttonTestStopSoundEffect1, 5, 3 );
+    upperRow->addWidget( buttonTestStopSoundEffect1, 6, 3 );
 
     connect( buttonTestStopSoundEffect1, SIGNAL( clicked() ), this, SLOT( stopSound1() ) );
 
@@ -190,15 +200,15 @@ EffectDia::EffectDia( QWidget* parent, const char* name, const QPtrList<KPObject
     grp2->layout()->setSpacing(KDialog::spacingHint());
     grp2->layout()->setMargin(KDialog::marginHint());
     topLayout->addWidget(grp2);
-    QGridLayout *lowerRow = new QGridLayout(grp2->layout(), 4, 4);
+    QGridLayout *lowerRow = new QGridLayout(grp2->layout(), 5, 4);
 
     lDisappear = new QLabel( i18n( "Order of disappearance:" ), grp2 );
     lDisappear->setAlignment( AlignVCenter );
     lowerRow->addWidget(lDisappear, 0, 0);
 
-    eDisappear = new QSpinBox( 0, 100, 1, grp2 );
-    eDisappear->setValue( obj->getDisappearNum() );
-    lowerRow->addWidget(eDisappear, 0, 1);
+    eDisappearStep = new QSpinBox( 0, 100, 1, grp2 );
+    eDisappearStep->setValue( obj->getDisappearStep() );
+    lowerRow->addWidget(eDisappearStep, 0, 1);
 
     lDEffect = new QLabel( i18n( "Effect (disappearing):" ), grp2 );
     lDEffect->setAlignment( AlignVCenter );
@@ -223,14 +233,27 @@ EffectDia::EffectDia( QWidget* parent, const char* name, const QPtrList<KPObject
 
     connect( cDisappear, SIGNAL( activated( int ) ), this, SLOT( disappearEffectChanged( int ) ) );
 
+    lDisappearSpeed = new QLabel( i18n( "Speed:" ), grp2 );
+    lDisappearSpeed->setAlignment( AlignVCenter );
+    lowerRow->addWidget(lDisappearSpeed, 2, 0);
+
+    cDisappearSpeed = new QComboBox( false, grp2, "cEffect" );
+    cDisappearSpeed->insertItem( i18n( "Slow" ) );
+    cDisappearSpeed->insertItem( i18n( "Medium" ) );
+    cDisappearSpeed->insertItem( i18n( "Fast" ) );
+    cDisappearSpeed->setCurrentItem( static_cast<int>( obj->getDisappearSpeed() ) );
+    lowerRow->addWidget(cDisappearSpeed, 2, 1);
+    
+    //appearEffectChanged( cEffect->currentItem() );
+
     QLabel *lTimerOfDisappear = new QLabel( i18n( "Timer of the object:" ), grp2 );
     lTimerOfDisappear->setAlignment( AlignVCenter );
-    lowerRow->addWidget( lTimerOfDisappear, 2, 0 );
+    lowerRow->addWidget( lTimerOfDisappear, 3, 0 );
 
     timerOfDisappear = new KIntNumInput( obj->getDisappearTimer(), grp2 );
     timerOfDisappear->setRange( 1, 600, 1 );
     timerOfDisappear->setSuffix( i18n( " seconds" ) );
-    lowerRow->addWidget( timerOfDisappear, 2, 1 );
+    lowerRow->addWidget( timerOfDisappear, 3, 1 );
 
     if ( view->kPresenterDoc()->spManualSwitch() )
         timerOfDisappear->setEnabled( false );
@@ -239,21 +262,18 @@ EffectDia::EffectDia( QWidget* parent, const char* name, const QPtrList<KPObject
     // setup the Sound Effect stuff
     disappearSoundEffect = new QCheckBox( i18n( "Sound effect" ), grp2 );
     disappearSoundEffect->setChecked( obj->getDisappearSoundEffect() );
-    lowerRow->addWidget( disappearSoundEffect, 3, 0 );
-    QWhatsThis::add( disappearSoundEffect, i18n("If you use sound effect, please do not select 'No Effect'.") );
-
-    if ( static_cast<int>( obj->getEffect3() ) == 0 )
-        disappearSoundEffect->setEnabled( false );
+    lowerRow->addWidget( disappearSoundEffect, 4, 0 );
+    disappearSoundEffect->setEnabled( disappear->isChecked() );
 
     connect( disappearSoundEffect, SIGNAL( clicked() ), this, SLOT( disappearSoundEffectChanged() ) );
 
     lSoundEffect2 = new QLabel( i18n( "File name:" ), grp2 );
     lSoundEffect2->setAlignment( AlignVCenter );
-    lowerRow->addWidget( lSoundEffect2, 4, 0 );
+    lowerRow->addWidget( lSoundEffect2, 5, 0 );
 
     requester2 = new KURLRequester( grp2 );
     requester2->setURL( obj->getDisappearSoundEffectFileName() );
-    lowerRow->addWidget( requester2, 4, 1 );
+    lowerRow->addWidget( requester2, 5, 1 );
 
     connect( requester2, SIGNAL( openFileDialog( KURLRequester * ) ),
              this, SLOT( slotRequesterClicked( KURLRequester * ) ) );
@@ -262,16 +282,16 @@ EffectDia::EffectDia( QWidget* parent, const char* name, const QPtrList<KPObject
              this, SLOT( slotDisappearFileChanged( const QString& ) ) );
 
     buttonTestPlaySoundEffect2 = new QPushButton( grp2 );
-    buttonTestPlaySoundEffect2->setPixmap( BarIcon("1rightarrow", KIcon::SizeSmall) );
+    buttonTestPlaySoundEffect2->setIconSet( SmallIconSet("1rightarrow") );
     QToolTip::add( buttonTestPlaySoundEffect2, i18n("Play") );
-    lowerRow->addWidget( buttonTestPlaySoundEffect2, 4, 2 );
+    lowerRow->addWidget( buttonTestPlaySoundEffect2, 5, 2 );
 
     connect( buttonTestPlaySoundEffect2, SIGNAL( clicked() ), this, SLOT( playSound2() ) );
 
     buttonTestStopSoundEffect2 = new QPushButton( grp2 );
-    buttonTestStopSoundEffect2->setPixmap( BarIcon("player_stop", KIcon::SizeSmall) );
+    buttonTestStopSoundEffect2->setIconSet( SmallIconSet("player_stop") );
     QToolTip::add( buttonTestStopSoundEffect2, i18n("Stop") );
-    lowerRow->addWidget( buttonTestStopSoundEffect2, 4, 3 );
+    lowerRow->addWidget( buttonTestStopSoundEffect2, 5, 3 );
 
     connect( buttonTestStopSoundEffect2, SIGNAL( clicked() ), this, SLOT( stopSound2() ) );
 
@@ -283,7 +303,6 @@ EffectDia::EffectDia( QWidget* parent, const char* name, const QPtrList<KPObject
     connect( disappear, SIGNAL( clicked() ), this, SLOT( disappearChanged() ) );
     disappearChanged();
     appearSoundEffectChanged();
-    disappearSoundEffectChanged();
 }
 
 EffectDia::~EffectDia()
@@ -301,11 +320,13 @@ void EffectDia::slotEffectDiaOk()
     for ( unsigned int i = 0; i < objs.count(); ++i ) {
         KPObject *o = objs.at( i );
         EffectCmd::EffectStruct e;
-        e.presNum = o->getPresNum();
-        e.disappearNum = o->getDisappearNum();
+        e.appearStep = o->getAppearStep();
+        e.disappearStep = o->getDisappearStep();
         e.effect = o->getEffect();
         e.effect2 = o->getEffect2();
         e.effect3 = o->getEffect3();
+        e.m_appearSpeed = o->getAppearSpeed();
+        e.m_disappearSpeed = o->getDisappearSpeed();
         e.disappear = o->getDisappear();
         e.appearTimer = o->getAppearTimer();
         e.disappearTimer = o->getDisappearTimer();
@@ -317,11 +338,13 @@ void EffectDia::slotEffectDiaOk()
     }
 
     EffectCmd::EffectStruct eff;
-    eff.presNum = eNum->value();
-    eff.disappearNum = eDisappear->value();
+    eff.appearStep = eAppearStep->value();
+    eff.disappearStep = eDisappearStep->value();
     eff.effect = ( Effect )cEffect->currentItem();
     eff.effect2 = ( Effect2 )cEffect2->currentItem();
     eff.effect3 = ( Effect3 )cDisappear->currentItem();
+    eff.m_appearSpeed = ( EffectSpeed )cAppearSpeed->currentItem();
+    eff.m_disappearSpeed = ( EffectSpeed )cDisappearSpeed->currentItem();
     eff.disappear = disappear->isChecked();
     eff.appearTimer = timerOfAppear->value();
     eff.disappearTimer = timerOfDisappear->value();
@@ -345,7 +368,10 @@ void EffectDia::resizeEvent( QResizeEvent *e )
 void EffectDia::disappearChanged()
 {
     cDisappear->setEnabled( disappear->isChecked() );
-    eDisappear->setEnabled( disappear->isChecked() );
+    eDisappearStep->setEnabled( disappear->isChecked() );
+    disappearSoundEffect->setEnabled( disappear->isChecked() );
+    disappearSoundEffectChanged();
+    disappearEffectChanged( cDisappear->currentItem() );
 
     if ( !view->kPresenterDoc()->spManualSwitch() )
         timerOfDisappear->setEnabled( disappear->isChecked() );
@@ -353,32 +379,16 @@ void EffectDia::disappearChanged()
 
 void EffectDia::appearEffectChanged( int num )
 {
-    if ( num == 0 ) {
-        appearSoundEffect->setEnabled( false );
-        lSoundEffect1->setEnabled( false );
-        requester1->setEnabled( false );
-        buttonTestPlaySoundEffect1->setEnabled( false );
-        buttonTestStopSoundEffect1->setEnabled( false );
-    }
-    else {
-        appearSoundEffect->setEnabled( true );
-        appearSoundEffectChanged();
-    }
+    bool b = ( cEffect->currentItem() != 0 );
+    lAppearSpeed->setEnabled( b );
+    cAppearSpeed->setEnabled( b );
 }
 
 void EffectDia::disappearEffectChanged( int num )
 {
-    if ( num == 0 ) {
-        disappearSoundEffect->setEnabled( false );
-        lSoundEffect2->setEnabled( false );
-        requester2->setEnabled( false );
-        buttonTestPlaySoundEffect2->setEnabled( false );
-        buttonTestStopSoundEffect2->setEnabled( false );
-    }
-    else {
-        disappearSoundEffect->setEnabled( true );
-        disappearSoundEffectChanged();
-    }
+    bool b = ( cDisappear->currentItem() !=0 && disappear->isChecked() );
+    lDisappearSpeed->setEnabled( b );
+    cDisappearSpeed->setEnabled( b );
 }
 
 void EffectDia::appearSoundEffectChanged()
@@ -398,12 +408,12 @@ void EffectDia::appearSoundEffectChanged()
 
 void EffectDia::disappearSoundEffectChanged()
 {
-    lSoundEffect2->setEnabled( disappearSoundEffect->isChecked() );
-    requester2->setEnabled( disappearSoundEffect->isChecked() );
+    lSoundEffect2->setEnabled( disappear->isChecked() && disappearSoundEffect->isChecked() );
+    requester2->setEnabled( disappear->isChecked() && disappearSoundEffect->isChecked() );
 
     if ( !requester2->url().isEmpty() ) {
-        buttonTestPlaySoundEffect2->setEnabled( disappearSoundEffect->isChecked() );
-        buttonTestStopSoundEffect2->setEnabled( disappearSoundEffect->isChecked() );
+        buttonTestPlaySoundEffect2->setEnabled( disappear->isChecked() && disappearSoundEffect->isChecked() );
+        buttonTestStopSoundEffect2->setEnabled( disappear->isChecked() && disappearSoundEffect->isChecked() );
     }
     else {
         buttonTestPlaySoundEffect2->setEnabled( false );
