@@ -54,9 +54,9 @@ protected:
 
     QString getSoundFileFilter() const;
 
-    QComboBox *cEffect, *cEffect2, *cDisappear;
-    QLabel *lEffect, *lEffect2, *lNum, *lDisappear, *lDEffect;
-    QSpinBox *eNum,*eDisappear;
+    QComboBox *cEffect, *cEffect2, *cDisappear, *cAppearSpeed, *cDisappearSpeed;
+    QLabel *lEffect, *lEffect2, *lAppear, *lDisappear, *lDEffect, * lAppearSpeed, *lDisappearSpeed;
+    QSpinBox *eAppearStep,*eDisappearStep;
     QCheckBox *disappear;
     QBoxLayout *topLayout;
     KIntNumInput *timerOfAppear, *timerOfDisappear;
