@@ -27,11 +27,22 @@
 #define MAX_UNDO_REDO 100
 
 // types
+enum AlignType {
+    AT_LEFT = 0,
+    AT_TOP,
+    AT_RIGHT,
+    AT_BOTTOM,
+    AT_HCENTER,
+    AT_VCENTER
+};
+
 enum BackType {
     BT_COLOR = 0,
     BT_PICTURE = 1,
-    BT_CLIPART = 2
+    BT_CLIPART = 2,
+    BT_BRUSH = 3
 };
+
 enum BackView {
     BV_ZOOM = 0,
     BV_CENTER = 1,
@@ -230,6 +241,12 @@ enum FillType
 
 typedef int PresSpeed;
 
+enum EffectSpeed {
+  ES_SLOW = 0,
+  ES_MEDIUM = 1,
+  ES_FAST = 2
+};
+
 enum InsertPos {
     IP_BEFORE = 0,
     IP_AFTER = 1
@@ -289,4 +306,6 @@ enum VerticalAlignmentType {
 // offsets of the effects in the Effect2 enum accoording to a objType
 const int TxtObjOffset = 0;
 
+typedef QMap<QString, QStringList> CustomListMap;
+
 #endif //GLOBAL_H
