@@ -29,6 +29,7 @@
 #include <kdialog.h>
 
 #include "kpresenter_doc.h"
+#include "kprpage.h"
 
 KPGotoPage::KPGotoPage( const KPresenterDoc *doc,
                         const QValueList<int> &slides, int start,
@@ -53,7 +54,7 @@ KPGotoPage::KPGotoPage( const KPresenterDoc *doc,
     QPtrList<KPrPage> pageList = doc->getPageList(); // because of const doc, we can't do doc->pageList()->at()
     QValueList<int>::ConstIterator it = slides.begin();
     for ( ; it != slides.end(); ++it ) {
-        QString t(pageList.at((*it)-1)->pageTitle( i18n( "Slide %1" ).arg( *it ) ));
+        QString t( pageList.at( (*it) - 1 )->pageTitle() );
         // cut ultra long titles...
         if(t.length() > 30) {
             t.truncate(30);
