@@ -1,6 +1,7 @@
 // -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
+   Copyright (C) 2004 Thorsten Zachmann <zachmann@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,6 +24,9 @@
 
 #include <qsize.h>
 #include <qdatetime.h>
+#include <koStyleStack.h>
+#include <koOasisStyles.h>
+#include <kooasiscontext.h>
 
 #include <koPictureCollection.h>
 
@@ -36,10 +40,43 @@ class QDomDocument;
 class QDomElement;
 class KoZoomHandler;
 class KPrPage;
+class KoXmlWriter;
+class KoGenStyles;
+class KoGenStyle;
+
 
 class KPBackGround
 {
 public:
+    struct Settings
+    {
+        Settings( const BackType backType, const QColor backColor1, const QColor backColor2,
+                  const BCType bcType, const bool unbalanced, const int xfactor, const int yfactor, 
+                  const KoPictureKey &key, const BackView backView )
+        : m_backType( backType )
+        , m_backColor1( backColor1 )
+        , m_backColor2( backColor2 )
+        , m_bcType( bcType )
+        , m_unbalanced( unbalanced )
+        , m_xfactor( xfactor )
+        , m_yfactor( yfactor )
+        , m_backPictureKey( key )
+        , m_backView( backView ) 
+        {}
+
+        BackType m_backType;
+        QColor m_backColor1;
+        QColor m_backColor2;
+        // Gradient setting
+        BCType m_bcType;
+        bool m_unbalanced;
+        // Gradient factors
+        int m_xfactor, m_yfactor;
+
+        KoPictureKey m_backPictureKey;
+        BackView m_backView;
+    };
+
     KPBackGround( KPrPage *_page );
     ~KPBackGround() {}
 
@@ -66,16 +103,10 @@ public:
     /// set the back picture to a new KoPicture
     void setBackPicture( const KoPicture& picture );
     void setBackPicture ( const KoPictureKey& key );
-    void setPageEffect( PageEffect _pageEffect )
-        { pageEffect = _pageEffect; }
-    void setPageTimer( int _pageTimer )
-        { pageTimer = _pageTimer; }
-    void setPageSoundEffect( bool _soundEffect )
-        { soundEffect = _soundEffect; }
-    void setPageSoundFileName( const QString &_soundFileName )
-        { soundFileName = _soundFileName; }
-
-    KoPicture picture()const { return backPicture;}
+    void setBackGround( const struct Settings &settings );
+    struct Settings getBackGround() const;
+    
+    KoPicture picture() const { return backPicture;}
 
     BackType getBackType() const
         { return backType; }
@@ -92,33 +123,27 @@ public:
     KoPicture getBackPicture() const
         { return backPicture;}
 
-    PageEffect getPageEffect() const
-        { return pageEffect; }
     bool getBackUnbalanced() const
         { return unbalanced; }
     int getBackXFactor() const
         { return xfactor; }
     int getBackYFactor() const
         { return yfactor; }
-    int getPageTimer() const
-        { return pageTimer; }
-    bool getPageSoundEffect() const
-        { return soundEffect; }
-    QString getPageSoundFileName() const
-        { return soundFileName; }
 
     // Draw the background.
     // Uses the @p zoomHandler to determine the size of the background
-    void draw( QPainter *_painter, const KoZoomHandler* zoomHandler,
-               const QRect& crect, bool _drawBorders );
+    void drawBackground( QPainter *_painter, const KoZoomHandler* zoomHandler,
+                         const QRect& crect, bool _drawBorders );
     // Draw the background. The size of the background is passed explicitly
-    void draw( QPainter *_painter, const QSize& ext,
-               const QRect& crect, bool _drawBorders );
+    void drawBackground( QPainter *_painter, const QSize& ext,
+                         const QRect& crect, bool _drawBorders );
 
     void reload();
 
     QDomElement save( QDomDocument &doc, const bool saveAsKOffice1Dot1 );
     void load( const QDomElement &element );
+    void loadOasis( KoOasisContext & context );
+    void saveOasisBackgroundPageStyle( KoGenStyle &stylepageauto, KoGenStyles &mainStyles );
 
 protected:
     void drawBackColor( QPainter *_painter, const QSize& ext, const QRect& crect );
@@ -132,15 +157,15 @@ protected:
     KoPictureCollection *pictureCollection() const;
     KPGradientCollection *gradientCollection() const;
 
+    QString saveOasisGradientStyle( KoGenStyles& mainStyles );
+    QString saveOasisPictureStyle( KoGenStyles& mainStyles );
+
 private:
     BackType backType;
     BackView backView;
     QColor backColor1;
     QColor backColor2;
     BCType bcType;
-    PageEffect pageEffect;
-    // Sound played when showing this page
-    QString soundFileName;
 
     // Background picture
     KoPicture backPicture;
@@ -155,10 +180,7 @@ private:
 
     // Gradient factors
     int xfactor, yfactor;
-    // ### Not related to the background, but to the page: delay for the page
-    int pageTimer;
-    // ### This could be simply !soundFileName.isEmpty()...
-    bool soundEffect;
+
     // Gradient setting
     bool unbalanced;
 };
