@@ -53,13 +53,14 @@ public:
     virtual QDomDocumentFragment save( QDomDocument& doc, double offset );
     virtual double load( const QDomElement &element );
     virtual void loadOasis( const QDomElement &element, KoOasisContext & context, KPRLoadingInfo *info );
-    virtual bool saveOasis( KoXmlWriter &xmlWriter, KoSavingContext& context, int indexObj ) const;
 
     virtual void flip(bool horizontal );
     virtual KoSize getRealSize() const;
     virtual KoPoint getRealOrig() const;
 
 protected:
+    virtual const char * getOasisElementName() const;
+    virtual bool saveOasisObjectAttributes( KPOasisSaveContext &sc ) const;
     virtual void paint( QPainter *_painter,KoZoomHandler*_zoomHandler,
                         int /* pageNum */, bool drawingShadow, bool drawContour );
 
