@@ -344,7 +344,7 @@ void KPObject::saveOasisPosObject( KoXmlWriter &xmlWriter, int indexObj ) const
     xmlWriter.addAttributePt( "svg:width", ext.width() );
     xmlWriter.addAttributePt( "svg:height", ext.height() );
 
-    if ( angle!=0.0 )
+    if ( kAbs( angle ) > 1E-6 )
     {
         double value = -1 * ( ( double )angle* M_PI )/180.0;
         QString str=QString( "rotate (%1)" ).arg( value );
@@ -362,6 +362,40 @@ void KPObject::saveOasisObjectProtectStyle( KoGenStyle &styleobjectauto ) const
     }
 }
 
+QString KPObject::getStyle( KPOasisSaveContext &sc ) const
+{
+    kdDebug(33001) << "KPObject::getStyle" << endl;
+    KoGenStyle styleObjectAuto;
+    KoGenStyles &mainStyles( sc.context.mainStyles() );
+    if ( sc.onMaster )
+    {
+        styleObjectAuto = KoGenStyle( KPresenterDoc::STYLE_PRESENTATIONSTICKYOBJECT, "presentation" );
+    }
+    else
+    {
+        styleObjectAuto = KoGenStyle( KoGenStyle::STYLE_GRAPHICAUTO, "graphic" );
+    }
+    fillStyle( styleObjectAuto, mainStyles );
+    if ( sc.onMaster )
+    {
+        return mainStyles.lookup( styleObjectAuto, "pr" );
+    }
+    return mainStyles.lookup( styleObjectAuto, "gr" );
+}
+
+void KPObject::fillStyle( KoGenStyle& styleObjectAuto, KoGenStyles& /* mainStyles */ ) const
+{
+    kdDebug(33001) << "KPObject::fillStyle" << endl;
+    saveOasisObjectProtectStyle( styleObjectAuto ); 
+    saveOasisShadowElement( styleObjectAuto );
+}
+
+bool KPObject::saveOasisObjectAttributes( KPOasisSaveContext &/* sc */ ) const
+{
+    kdDebug()<<"bool saveOasisObjectAttributes not implemented";
+    return true;
+}
+
 bool KPObject::haveAnimation() const
 {
     //kdDebug()<<" effect :"<<effect<<" effect3 :"<<effect3<<" a_fileName :"<<a_fileName<<" d_fileName :"<<d_fileName<<" appearTimer :"<<appearTimer<<" disappearTimer :"<<disappearTimer<<endl;
@@ -849,6 +883,20 @@ void KPObject::loadOasis(const QDomElement &element, KoOasisContext & context, K
     }
 }
 
+bool KPObject::saveOasisObject( KPOasisSaveContext &sc ) const
+{
+    sc.xmlWriter.startElement( getOasisElementName() );
+    sc.xmlWriter.addAttribute( "draw:style-name", getStyle( sc ) );
+    saveOasisPosObject( sc.xmlWriter, sc.indexObj );
+    if( !objectName.isEmpty())
+        sc.xmlWriter.addAttribute( "draw:name", objectName );
+
+    saveOasisObjectAttributes( sc );
+    
+    sc.xmlWriter.endElement();
+    return true;
+}
+
 void KPObject::saveOasisShadowElement( KoGenStyle &styleobjectauto ) const
 {
     //FIXME default value
@@ -1628,6 +1676,99 @@ QString KPShadowObject::saveOasisStrokeStyle( KoGenStyles& mainStyles ) const
     //    <draw:stroke-dash draw:name="Fine Dotted" draw:style="rect" draw:dots1="1" draw:distance="0.457cm"/>
 }
 
+bool KPShadowObject::saveOasisDrawPoints( const KoPointArray &points, KPOasisSaveContext &sc )
+{
+    QString listOfPoint;
+    int maxX=0;
+    int maxY=0;
+    KoPointArray::ConstIterator it( points.begin() );
+    for ( ; it != points.end(); ++it ) 
+    {
+        int tmpX = int( ( *it ).x() * 10000 );
+        int tmpY = int( ( *it ).y() * 10000 );
+        //if ( !listOfPoint.isEmpty() )
+            listOfPoint += QString( " %1,%2" ).arg( tmpX ).arg( tmpY );
+        //else
+        //    listOfPoint = QString( "%1,%2" ).arg( tmpX ).arg( tmpY );
+        maxX = QMAX( maxX, tmpX );
+        maxY = QMAX( maxY, tmpY );
+    }
+    sc.xmlWriter.addAttribute("draw:points", listOfPoint );
+    sc.xmlWriter.addAttribute("svg:viewBox", QString( "0 0 %1 %2" ).arg( maxX ).arg( maxY ) );
+    return true;
+}
+
+bool KPShadowObject::loadOasisDrawPoints( KoPointArray &points, const QDomElement &element, 
+                                          KoOasisContext & context, KPRLoadingInfo *info )
+{
+    QStringList ptList = QStringList::split(' ', element.attributeNS( KoXmlNS::draw, "points", QString::null));
+    QStringList viewBox = QStringList::split( ' ', element.attributeNS( KoXmlNS::svg, "viewBox", QString::null ) );
+    //for ( QStringList::Iterator it = viewBox.begin(); it != viewBox.end(); ++it )
+    //{
+    //    kdDebug(33001) << "viewBox = " << *it << endl;
+    //}
+
+    int left = 0;
+    int top = 0;
+    int right = 0;
+    int bottom = 0;
+
+    if ( viewBox.size() == 4 )
+    {
+        QStringList::Iterator it = viewBox.begin();
+        left = ( *it++ ).toInt();
+        top = ( *it++ ).toInt();
+        right = ( *it++ ).toInt();
+        bottom = ( *it ).toInt();
+        //kdDebug(33001) << "left = " << left
+        //               << "top = " << top
+        //               << "right =" << right
+        //               << "bottom =" << bottom << endl;
+    }
+    else
+    {
+        //if no viewBox is found
+        for (QStringList::Iterator it = ptList.begin(); it != ptList.end(); ++it)
+        {
+            right = QMAX( (*it).section( ',', 0, 0 ).toInt(), right );
+            bottom = QMAX( (*it).section( ',', 1, 1 ).toInt(), bottom );
+        }
+    }
+    
+    if ( right - left != 0 && bottom - top != 0 )
+    {
+        double tmp_x, tmp_y;
+        unsigned int index = 0;
+        for (QStringList::Iterator it = ptList.begin(); it != ptList.end(); ++it)
+        {
+            tmp_x = double( (*it).section( ',', 0, 0 ).toInt() + left ) / ( right - left ) * ext.width();
+            tmp_y = double( (*it).section( ',', 1, 1 ).toInt() + top ) / ( bottom - top ) * ext.height();
+
+            //kdDebug(33001) << "p" << index << " x: " << tmp_x << endl;
+            //kdDebug(33001) << "p" << index << " y: " << tmp_y << endl;
+
+            points.putPoints( index, 1, tmp_x, tmp_y );
+            ++index;
+        }
+    }
+    else
+    {
+        kdDebug(33001) << "problem in viewBox values are: "
+                       << "left = " << left << ", "
+                       << "top = " << top << ", "
+                       << "right =" << right << ", "
+                       << "bottom =" << bottom << endl;
+    }
+    return true;
+}
+
+void KPShadowObject::fillStyle( KoGenStyle& styleObjectAuto, KoGenStyles& mainStyles ) const
+{
+    kdDebug(33001) << "KPShadowObject::fillStyle" << endl;
+    KPObject::fillStyle( styleObjectAuto, mainStyles );
+    saveOasisStrokeElement( mainStyles, styleObjectAuto );
+}
+
 void KPShadowObject::loadOasis(const QDomElement &element, KoOasisContext & context, KPRLoadingInfo *info)
 {
     //kdDebug()<<"void KPShadowObject::loadOasis(const QDomElement &element)**********************\n";
@@ -1822,14 +1963,15 @@ QDomDocumentFragment KP2DObject::save( QDomDocument& doc,double offset )
     return fragment;
 }
 
-QString KP2DObject::saveOasisBackgroundStyle( KoXmlWriter &xmlWriter, KoGenStyles& mainStyles, int indexObj ) const
+void KP2DObject::fillStyle( KoGenStyle& styleObjectAuto, KoGenStyles& mainStyles ) const
+{
+    kdDebug(33001) << "KP2DObject::fillStyle" << endl;
+    KPShadowObject::fillStyle( styleObjectAuto, mainStyles );
+    saveOasisBackgroundElement( styleObjectAuto, mainStyles );
+}
+
+void KP2DObject::saveOasisBackgroundElement( KoGenStyle& styleObjectAuto, KoGenStyles& mainStyles ) const
 {
-    saveOasisPosObject( xmlWriter,indexObj );
-    KoGenStyle styleobjectauto;
-    if ( sticky )
-        styleobjectauto = KoGenStyle( KPresenterDoc::STYLE_PRESENTATIONSTICKYOBJECT, "presentation" );
-    else
-        styleobjectauto = KoGenStyle( KoGenStyle::STYLE_GRAPHICAUTO, "graphic" );
     switch ( getFillType() )
     {
         case FT_BRUSH:
@@ -1838,34 +1980,22 @@ QString KP2DObject::saveOasisBackgroundStyle( KoXmlWriter &xmlWriter, KoGenStyle
             //todo FIXME when text object doesn't have a background
             if( brush != QBrush() )
             {
-                KoOasisStyles::saveOasisFillStyle( styleobjectauto, mainStyles, brush );
+                KoOasisStyles::saveOasisFillStyle( styleObjectAuto, mainStyles, brush );
             }
             else
             {
-                styleobjectauto.addProperty( "draw:fill","none" );
+                styleObjectAuto.addProperty( "draw:fill","none" );
             }
             break;
         }
         case FT_GRADIENT:
-            styleobjectauto.addProperty( "draw:fill","gradient" );
-            styleobjectauto.addProperty( "draw:fill-gradient-name", saveOasisGradientStyle( mainStyles ) );
+            styleObjectAuto.addProperty( "draw:fill","gradient" );
+            styleObjectAuto.addProperty( "draw:fill-gradient-name", saveOasisGradientStyle( mainStyles ) );
             break;
     }
-    saveOasisObjectProtectStyle( styleobjectauto );
-
-    saveOasisStrokeElement( mainStyles, styleobjectauto );
-    saveOasisMarginElement( styleobjectauto );
-    saveOasisShadowElement( styleobjectauto );
-    saveOasisPictureElement( styleobjectauto );
-
-    if ( sticky )
-        return mainStyles.lookup( styleobjectauto, "pr" );
-    else
-        return mainStyles.lookup( styleobjectauto, "gr" );
 }
 
 
-
 QString KP2DObject::saveOasisGradientStyle( KoGenStyles& mainStyles ) const
 {
     KoGenStyle gradientStyle( KPresenterDoc::STYLE_GRADIENT /*no family name*/);
@@ -2170,6 +2300,56 @@ double KP2DObject::load(const QDomElement &element)
     return offset;
 }
 
+void KP2DObject::draw( QPainter *_painter, KoZoomHandler*_zoomHandler,
+                           int pageNum, SelectionMode selectionMode, bool drawContour )
+{
+    double ox = orig.x();
+    double oy = orig.y();
+    _painter->save();
+
+    // Draw the shadow if any
+    if ( shadowDistance > 0 && !drawContour )
+    {
+        _painter->save();
+        QPen tmpPen( pen );
+        pen.setColor( shadowColor );
+        QBrush tmpBrush( m_brush.getBrush() );
+        QBrush shadowBrush( tmpBrush );
+        shadowBrush.setColor( shadowColor );
+        m_brush.setBrush( shadowBrush );
+
+        if ( angle == 0 )
+        {
+            double sx = ox;
+            double sy = oy;
+            getShadowCoords( sx, sy );
+
+            _painter->translate( _zoomHandler->zoomItX( sx ), _zoomHandler->zoomItY( sy ) );
+            paint( _painter, _zoomHandler, pageNum, true, drawContour );
+        }
+        else
+        {
+            _painter->translate( _zoomHandler->zoomItX(ox), _zoomHandler->zoomItY(oy) );
+            rotateObjectWithShadow(_painter, _zoomHandler);
+            paint( _painter, _zoomHandler, pageNum, true, drawContour );
+        }
+
+        pen = tmpPen;
+        m_brush.setBrush( tmpBrush );
+        _painter->restore();
+    }
+
+    _painter->translate( _zoomHandler->zoomItX(ox), _zoomHandler->zoomItY(oy) );
+
+    if ( angle != 0 )
+        rotateObject(_painter,_zoomHandler);
+    paint( _painter, _zoomHandler, pageNum, false, drawContour );
+
+    _painter->restore();
+
+    KPObject::draw( _painter, _zoomHandler, pageNum, selectionMode, drawContour );
+}
+
 void KP2DObject::flip( bool horizontal ) {
     KPObject::flip( horizontal );
 
