@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
+   Copyright (C) 2005 Thorsten Zachmann <zachmann@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -79,7 +80,6 @@ public:
         { return lineEnd; }
 
     virtual QDomDocumentFragment save( QDomDocument& doc, double offset );
-    virtual bool saveOasis( KoXmlWriter &xmlWriter, KoSavingContext& context, int indexObj ) const;
 
     virtual double load(const QDomElement &element);
     virtual void flip(bool horizontal );
@@ -89,6 +89,9 @@ public:
     virtual KoPoint getRealOrig() const;
 
 protected:
+    virtual const char * getOasisElementName() const;
+    virtual bool saveOasisObjectAttributes( KPOasisSaveContext &sc ) const;
+
     virtual void paint( QPainter *_painter, KoZoomHandler*_zoomHandler,
                         int /* pageNum */, bool drawingShadow, bool drawContour );
 
