@@ -45,13 +45,8 @@ public:
 
     static const char * selectionMimeType();
 
-    void setTextObjectNumber( int number );
-
-    static int decodeTextObjectNumber( QMimeSource *e );
-
 protected:
     QCString kpresenter;
-    int m_textObjectNumber;
 };
 
 #endif
