@@ -28,13 +28,13 @@ class QLineEdit;
 class QListBox;
 class KPresenterDoc;
 class QPushButton;
-class KoStyle;
+class KoParagStyle;
 
 class KPrImportStyleDia : public KoImportStyleDia
 {
     Q_OBJECT
 public:
-    KPrImportStyleDia( KPresenterDoc *_doc,const QStringList & _list, QWidget *parent, const char *name );
+    KPrImportStyleDia( KPresenterDoc *_doc, KoStyleCollection* currentCollection, QWidget *parent, const char *name = 0 );
     ~KPrImportStyleDia();
 
 protected:
