@@ -28,7 +28,7 @@
 #include "kprtextdocument.h"
 class KPresenterDoc;
 class KoVariable;
-class KoPgNumVariable;
+class KoPageVariable;
 class KoTextFormat;
 class KoVariableSettings;
 
@@ -38,13 +38,14 @@ public:
     KPrVariableCollection(KoVariableSettings *_setting, KoVariableFormatCollection* coll);
     virtual KoVariable *createVariable( int type, short int subtype, KoVariableFormatCollection * coll,
                                         KoVariableFormat *varFormat,KoTextDocument *textdoc, KoDocument * doc,
-                                        int _correct, bool _forceDefaultFormat=false );
+                                        int _correct, bool _forceDefaultFormat=false , bool loadFootNote= true);
+    virtual KoVariable* loadOasisField( KoTextDocument* textdoc, const QDomElement& tag, KoOasisContext& context );
 };
 
 /**
  * "current page number" and "number of pages" variables
  */
-class KPrPgNumVariable : public KoPgNumVariable
+class KPrPgNumVariable : public KoPageVariable
 {
 public:
     KPrPgNumVariable( KoTextDocument *textdoc, short int subtype, KoVariableFormat *varFormat,
@@ -56,4 +57,15 @@ private:
     KPresenterDoc *m_doc;
 };
 
+
+class KPrStatisticVariable : public KoStatisticVariable
+{
+public:
+    KPrStatisticVariable( KoTextDocument *textdoc, int subtype, KoVariableFormat *varFormat,KoVariableCollection *_varColl, KPresenterDoc *doc );
+    virtual void recalc();
+    virtual QString text(bool realValue=false);
+
+protected:
+    KPresenterDoc *m_doc;
+};
 #endif
