@@ -1,6 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
    Copyright (C) 2002, 2003 Ariya Hidayat <ariya@kde.org>
+   Copyright (C) 2004 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,10 +21,14 @@
 
 #include "pgconfdia.h"
 #include "kpresenter_doc.h"
+#include "kprpage.h"
 
 #include <qbuttongroup.h>
+#include <qhbuttongroup.h>
 #include <qcheckbox.h>
+#include <qcombobox.h>
 #include <qhbox.h>
+#include <qvbox.h>
 #include <qgroupbox.h>
 #include <qheader.h>
 #include <qlabel.h>
@@ -31,7 +36,10 @@
 #include <qlistview.h>
 #include <qpen.h>
 #include <qpushbutton.h>
+#include <qradiobutton.h>
 #include <qvaluelist.h>
+#include <qvbuttongroup.h>
+#include <qwhatsthis.h>
 
 #include <kcolorbutton.h>
 #include <kglobal.h>
@@ -54,36 +62,65 @@ PgConfDia::PgConfDia( QWidget* parent, KPresenterDoc* doc )
 void PgConfDia::setupPageGeneral()
 {
     QFrame* generalPage = addPage( i18n("&General") );
+    QWhatsThis::add( generalPage, i18n("<p>This dialog allows you to configure how the slideshow "
+				       "will be displayed, including whether the slides are "
+				       "automatically sequenced or manually controlled, and also "
+				       "allows you to configure a <em>drawing pen</em> that can "
+				       "be used during the display of the presentation to add "
+				       "additional information or to emphasise particular points.</p>") );
     QVBoxLayout *generalLayout = new QVBoxLayout( generalPage, KDialog::marginHint(), KDialog::spacingHint() );
     generalLayout->setAutoAdd( true );
 
-    manualSwitch = new QCheckBox( i18n( "&Manual switch to next step" ), generalPage );
-    manualSwitch->setChecked( m_doc->spManualSwitch() );
-    connect( manualSwitch, SIGNAL( toggled(bool) ), this, SLOT( manualSwitchToggled(bool) ) );
+    QVButtonGroup *switchGroup = new QVButtonGroup( i18n("&Transition Type"), generalPage );
+    QWhatsThis::add( switchGroup, i18n("<li><p>If you select <b>Manual transition to next step or slide</b> "
+					  "then each transition and effect on a slide, or transition from "
+					  "one slide to the next, will require an action. Typically this "
+					  "action will be a mouse click, or the space bar.</p></li>"
+					  "<li><p>If you select <b>Automatic transition to next step or slide</b> "
+					  "then the presentation will automatically sequence each transition "
+					  "and effect on a slide, and will automatically transition to the "
+					  "next slide when the current slide is fully displayed. The speed "
+					  "of sequencing is controlled using the slider below. This also "
+					  "enables the option to automatically loop back to the first "
+					  "slide after the last slide has been shown.</p></li>") );
+    m_manualButton = new QRadioButton( i18n("&Manual transition to next step or slide"), switchGroup );
+    m_manualButton->setChecked( m_doc->spManualSwitch() );
+    m_autoButton = new QRadioButton( i18n("&Automatic transition to next step or slide"), switchGroup );
+    m_autoButton->setChecked( !m_doc->spManualSwitch() );
 
     infiniteLoop = new QCheckBox( i18n( "&Infinite loop" ), generalPage );
+    QWhatsThis::add( infiniteLoop, i18n("<p>If this checkbox is selected, then the slideshow "
+					"will restart at the first slide after the last slide "
+					"has been displayed. It is only available if the "
+					"<b>Automatic transition to next step or slide</b> "
+					"button is selected above.</p> <p>This option may be "
+					"useful if you are running a promotional display.</p>") );
     infiniteLoop->setChecked( m_doc->spInfiniteLoop() );
     infiniteLoop->setEnabled( !m_doc->spManualSwitch() );
+    connect( m_autoButton, SIGNAL( toggled(bool) ), infiniteLoop, SLOT( setEnabled(bool) ) );
 
-    presentationDuration = new QCheckBox( i18n( "Show presentation &duration" ), generalPage );
+    presentationDuration = new QCheckBox( i18n( "Measure presentation &duration" ), generalPage );
+    QWhatsThis::add( presentationDuration, i18n("<p>If this checkbox is selected, the time that "
+						"each slide was displayed for, and the total time "
+						"for the presentation will be measured.</p> "
+						"<p>The times will be displayed at the end of the "
+						"presentation.</p> "
+						"<p>This can be used during rehearsal to check "
+						"coverage for each issue in the presentation, "
+						"and to verify that the presentation duration "
+						"is correct.</p>" ) );
     presentationDuration->setChecked( m_doc->presentationDuration() );
 
-    new QLabel( i18n("Speed:"), generalPage );
-
-    QWidget* sp = new QWidget( generalPage );
-    QBoxLayout* speedLayout = new QHBoxLayout( sp, 0, spacingHint() );
-    speedLayout->setAutoAdd( true );
-
-    new QLabel( i18n("Slow"), sp );
-    speedSlider = new QSlider( 1, 10, 1, 1, Qt::Horizontal, sp );
-    speedSlider->setValue( m_doc->getPresSpeed() );
-    speedSlider->setTickmarks( QSlider::Below );
-    speedSlider->setTickInterval( 1 );
-    new QLabel( i18n("Fast"), sp );
-
     // presentation pen (color and width)
 
     QGroupBox* penGroup = new QGroupBox( 1, Qt::Horizontal, i18n("Presentation Pen") , generalPage );
+    QWhatsThis::add( penGroup, i18n("<p>This part of the dialog allows you to configure the "
+				    "<em>drawing mode</em>, which allows you to add additional "
+				    "information, emphasise particular content, or to correct "
+				    "errors during the presentation by drawing on the slides "
+				    "using the mouse.</p>"
+				    "<p>You can configure the color of the drawing pen and the "
+				    "width of the pen.</p>" ) );
     penGroup->setInsideSpacing( KDialog::spacingHint() );
     penGroup->setInsideMargin( KDialog::marginHint() );
     penGroup->setFlat(true);
@@ -104,10 +141,33 @@ void PgConfDia::setupPageGeneral()
 void PgConfDia::setupPageSlides()
 {
     QFrame* slidesPage = addPage( i18n("&Slides") );
-    QVBoxLayout *slidesLayout = new QVBoxLayout( slidesPage, 0, spacingHint() );
-    slidesLayout->setAutoAdd( true );
+    QWhatsThis::add( slidesPage, i18n("<p>This dialog allows you to configure which slides "
+				      "are used in the presentation. Slides that are not "
+				      "selected will not be displayed during the slide "
+				      "show.</p>") );
+    QGridLayout *slidesLayout = new QGridLayout( slidesPage,7 , 2 );
+
+
+    QButtonGroup *group=new QVButtonGroup( slidesPage );
+    group->setRadioButtonExclusive( true );
+
+    m_customSlide = new QRadioButton( i18n( "Custom slide show" ), group, "customslide" );
+
+    connect( m_customSlide, SIGNAL( clicked () ), this, SLOT( radioButtonClicked() ) );
+
+    QHBox *box = new QHBox( group );
+
+    ( void )new QLabel( i18n( "Custom slide:" ),box );
+
+    m_customSlideCombobox = new QComboBox( box );
+    m_customSlideCombobox->insertStringList( m_doc->presentationList() );
+
+    m_selectedSlide = new QRadioButton( i18n( "Selected pages:" ), group, "selectedslide" );
+    slidesLayout->addMultiCellWidget( group, 0,2,0,1 );
+    connect( m_selectedSlide, SIGNAL( clicked () ), this, SLOT( radioButtonClicked() ) );
 
     slides = new QListView( slidesPage );
+    slidesLayout->addMultiCellWidget( slides, 3, 6, 0, 1 );
     slides->addColumn( i18n("Slide") );
     slides->setSorting( -1 );
     slides->header()->hide();
@@ -116,7 +176,7 @@ void PgConfDia::setupPageSlides()
     {
         KPrPage *page=m_doc->pageList().at( i );
         QCheckListItem* item = new QCheckListItem( slides,
-                                                   page->pageTitle( i18n( "Slide %1" ).arg( i + 1 ) ),
+                                                   page->pageTitle(),
                                                    QCheckListItem::CheckBox );
         item->setOn( page->isSlideSelected() );
     }
@@ -131,13 +191,44 @@ void PgConfDia::setupPageSlides()
     connect( deselectAllButton, SIGNAL( clicked() ), this, SLOT( deselectAllSlides() ) );
 
     QWidget* spacer = new QWidget( buttonGroup );
+
     spacer->setSizePolicy( QSizePolicy( QSizePolicy::Minimum, QSizePolicy::Expanding ) );
+    slidesLayout->addMultiCellWidget( buttonGroup, 6, 6, 0, 1 );
+
+    if ( !m_doc->presentationName().isEmpty() )
+    {
+        m_customSlide->setChecked( true );
+        m_customSlideCombobox->setCurrentText( m_doc->presentationName() );
+    }
+    else
+        m_selectedSlide->setChecked( true );
+
+    if ( m_customSlideCombobox->count()==0 )
+    {
+        m_customSlide->setEnabled( false );
+        m_customSlideCombobox->setEnabled( false );
+    }
+    radioButtonClicked();
 }
 
 PgConfDia::~PgConfDia()
 {
 }
 
+void PgConfDia::radioButtonClicked()
+{
+    if ( m_customSlide->isChecked() )
+    {
+        m_customSlideCombobox->setEnabled( true );
+        slides->setEnabled( false );
+    }
+    else
+    {
+        m_customSlideCombobox->setEnabled( false );
+        slides->setEnabled( true );
+    }
+}
+
 bool PgConfDia::getInfiniteLoop() const
 {
     return infiniteLoop->isChecked();
@@ -145,7 +236,7 @@ bool PgConfDia::getInfiniteLoop() const
 
 bool PgConfDia::getManualSwitch() const
 {
-    return manualSwitch->isChecked();
+    return m_manualButton->isChecked();
 }
 
 bool PgConfDia::getPresentationDuration() const
@@ -196,16 +287,13 @@ void PgConfDia::deselectAllSlides()
     }
 }
 
-void PgConfDia::manualSwitchToggled( bool state )
+QString PgConfDia::presentationName() const
 {
-    infiniteLoop->setEnabled( !state );
-}
-
-PresSpeed PgConfDia::getPresSpeed() const
-{
-    int value = speedSlider->value();
-    if( value <= 0 ) value = 1;
-    return static_cast<PresSpeed>(value);
+    if ( m_customSlide->isChecked() )
+        return m_customSlideCombobox->currentText();
+    else
+        return QString::null;
 }
 
+#include "kpgradient.h"
 #include "pgconfdia.moc"
