@@ -20,6 +20,7 @@
 
 #include "presdurationdia.h"
 #include "kprcanvas.h"
+#include "kprpage.h"
 #include "kpresenter_doc.h"
 #include <qlabel.h>
 #include <qheader.h>
@@ -27,6 +28,7 @@
 #include <qlayout.h>
 #include <klistview.h>
 #include <kdebug.h>
+#include <klocale.h>
 
 KPPresDurationDia::KPPresDurationDia( QWidget *parent, const char *name,
                                       KPresenterDoc *_doc, QStringList _durationListString,
@@ -57,8 +59,8 @@ KPPresDurationDia::KPPresDurationDia( QWidget *parent, const char *name,
 void KPPresDurationDia::setupSlideList( QWidget *_page )
 {
     slides = new KListView( _page );
-    slides->addColumn( i18n( "Slide No." ) );
-    slides->addColumn( i18n( "Slide Time" ) );
+    slides->addColumn( i18n( "No." ) );
+    slides->addColumn( i18n( "Display Duration" ) );
     slides->addColumn( i18n( "Slide Title" ) );
     slides->header()->setMovingEnabled( false );
     slides->setAllColumnsShowFocus( true );
@@ -66,11 +68,13 @@ void KPPresDurationDia::setupSlideList( QWidget *_page )
     slides->setSorting( -1 );
 
     for ( int i = doc->getPageNums() - 1; i >= 0; --i ) {
-        KListViewItem *item = new KListViewItem( slides );
-        item->setPixmap( 0, KPBarIcon( "newslide" ) );
-        item->setText( 0, QString( "%1" ).arg( i + 1 ) );
-        item->setText( 1, *m_durationListString.at( i ) );
-        item->setText( 2, doc->pageList().at( i )->pageTitle( i18n( "Slide %1" ).arg( i + 1 ) ) );
+        if ( doc->pageList().at( i )->isSlideSelected() ) {
+            KListViewItem *item = new KListViewItem( slides );
+            item->setPixmap( 0, KPBarIcon( "slide" ) );
+            item->setText( 0, QString( "%1" ).arg( i + 1 ) );
+            item->setText( 1, *m_durationListString.at( i ) );
+            item->setText( 2, doc->pageList().at( i )->pageTitle() );
+        }
     }
 }
 
