@@ -3,6 +3,7 @@
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
    Copyright (C) 2001 Lukas Tinkl <lukas@kde.org>
    Copyright (C) 2002 Ariya Hidayat <ariya@kde.org>
+   Copyright (C) 2005 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,14 +31,17 @@
 #include <kwordwrap.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <knotifyclient.h>
 #include <kiconview.h>
 #include <kdebug.h>
 
 #include "sidebar.h"
 #include "kpresenter_view.h"
+#include "kpresenter_doc.h"
 #include "kprcanvas.h"
+#include "kprpage.h"
+#include "kpobject.h"
 #include <qapplication.h>
 #include "kprcommand.h"
 #include <qvalidator.h>
@@ -45,55 +49,42 @@
 class ThumbToolTip : public QToolTip
 {
 public:
-    ThumbToolTip(QWidget *parent)
-        : QToolTip(parent)
+    ThumbToolTip( ThumbBar *parent )
+        : QToolTip( parent->viewport() )
+        , m_thumbBar( parent )
         {}
 
 protected:
     void maybeTip(const QPoint &pos)
     {
         QString title;
-        QRect r(((ThumbBar*)parentWidget())->tip(pos, title));
+        QRect r( m_thumbBar->tip( pos, title ) );
         if (!r.isValid())
             return;
 
         tip(r, title);
     }
+private:
+    ThumbBar *m_thumbBar;
 };
 
-class OutlineToolTip : public QToolTip
-{
-public:
-    OutlineToolTip(QWidget *parent)
-        : QToolTip(parent)
-        {}
-
-protected:
-    void maybeTip( const QPoint &pos )
-    {
-        QString title;
-        Outline* outline = dynamic_cast<Outline*>(parentWidget());
-        QRect r( outline->tip(pos, title) );
-        if (!r.isValid())
-            return;
-        tip(r, title);
-    }
-};
 
 class OutlineSlideItem: public KListViewItem
 {
 public:
-    OutlineSlideItem( KListView * parent, KPrPage* page );
-    OutlineSlideItem( KListView * parent, OutlineSlideItem *after, KPrPage* page );
+    OutlineSlideItem( KListView * parent, KPrPage* page, bool _masterPage );
+    OutlineSlideItem( KListView * parent, OutlineSlideItem *after, KPrPage* page, bool _masterPage );
 
-    KPrPage* page(){ return m_page; }
+    KPrPage* page() const { return m_page; }
 
     void setPage( KPrPage* p );
 
     void update();
+    void updateTitle();
 
 private:
     KPrPage* m_page;
+    bool m_masterPage;
 };
 
 class OutlineObjectItem: public KListViewItem
@@ -102,7 +93,7 @@ public:
     OutlineObjectItem( OutlineSlideItem * parent, KPObject* object,
                        bool sticky, const QString& name = QString::null );
 
-    KPObject* object(){ return m_object; }
+    KPObject* object() const { return m_object; }
 
     void setObject( KPObject* o );
 
@@ -128,29 +119,29 @@ private:
 };
 
 SideBar::SideBar(QWidget *parent, KPresenterDoc *d, KPresenterView *v)
-    :QTabWidget(parent), doc(d), view(v)
+    :QTabWidget(parent), m_doc(d), m_view(v)
 {
     setTabPosition(QTabWidget::Top);
     setTabShape(QTabWidget::Triangular);
 
-    _outline = new Outline(this, doc, view);
-    addTab(_outline, i18n("Outline"));
+    m_outline = new Outline(this, m_doc, m_view);
+    addTab(m_outline, i18n("Outline"));
 
-    _thb = new ThumbBar(this, doc, view);
-    addTab(_thb,i18n("Preview"));
+    m_thb = new ThumbBar(this, m_doc, m_view);
+    addTab(m_thb,i18n("Preview"));
 
 
     //TODO find a better way
-    connect(_outline, SIGNAL(showPage(int)),
+    connect(m_outline, SIGNAL(showPage(int)),
             this, SIGNAL(showPage(int)));
 
-    connect(_thb, SIGNAL(showPage(int)),
+    connect(m_thb, SIGNAL(showPage(int)),
             this, SIGNAL(showPage(int)));
 
-    connect(_outline, SIGNAL(movePage(int,int)),
+    connect(m_outline, SIGNAL(movePage(int,int)),
             this, SIGNAL(movePage(int,int)));
 
-    connect(_outline, SIGNAL(selectPage(int,bool)),
+    connect(m_outline, SIGNAL(selectPage(int,bool)),
             this, SIGNAL(selectPage(int,bool)));
 
     connect(this, SIGNAL(currentChanged(QWidget *)),
@@ -160,44 +151,74 @@ SideBar::SideBar(QWidget *parent, KPresenterDoc *d, KPresenterView *v)
 
 void SideBar::currentChanged(QWidget *tab)
 {
-    if (tab == _thb) {
-        if (!_thb->uptodate && _thb->isVisible())
-            _thb->rebuildItems();
+    if (tab == m_thb) {
+        if (!m_thb->uptodate && m_thb->isVisible())
+            m_thb->rebuildItems();
         else
-            _thb->refreshItems();
+            m_thb->refreshItems();
     }
 }
 
 void SideBar::addItem( int pos )
 {
-    _outline->addItem( pos );
-    _thb->addItem( pos );
+    m_outline->addItem( pos );
+    m_thb->addItem( pos );
 }
 
 void SideBar::moveItem( int oldPos, int newPos )
 {
-    _outline->moveItem( oldPos, newPos );
-    _thb->moveItem( oldPos, newPos );
+    m_outline->moveItem( oldPos, newPos );
+    m_thb->moveItem( oldPos, newPos );
 }
 
 void SideBar::removeItem( int pos )
 {
-    _outline->removeItem( pos );
-    _thb->removeItem( pos );
+    m_outline->removeItem( pos );
+    m_thb->removeItem( pos );
 }
 
-void SideBar::updateItem( int pos, bool sticky )
+void SideBar::updateItem( KPrPage *page )
 {
-    _outline->updateItem( pos, sticky );
-    _thb->updateItem( pos, sticky );
+    bool sticky = false;
+    int pos = 0;
+    if ( page == m_doc->masterPage() )
+    {
+        pos = -1;
+        sticky = true;
+    }
+    else
+    {
+        pos = m_doc->pageList().findRef( page );
+    }
+
+    m_outline->updateItem( pos, sticky );
+    m_thb->updateItem( pos, sticky );
+}
+
+void SideBar::setViewMasterPage( bool _masterPage )
+{
+    m_outline->setViewMasterPage( _masterPage );
+    m_thb->setViewMasterPage( _masterPage );
+    m_outline->rebuildItems();
+    m_thb->rebuildItems();
+}
+
+SideBarBase::SideBarBase(KPresenterDoc *_doc, KPresenterView *_view)
+    : m_doc( _doc ), m_view( _view ), m_viewMasterPage( false )
+{
+}
+
+void SideBarBase::setViewMasterPage( bool _b )
+{
+    m_viewMasterPage = _b;
 }
 
 ThumbBar::ThumbBar(QWidget *parent, KPresenterDoc *d, KPresenterView *v)
-    :KIconView(parent), doc(d), view(v)
+    :KIconView(parent), SideBarBase( d,v)
 {
     uptodate = false;
-    offsetX = 0;
-    offsetY = 0;
+    m_offsetX = 0;
+    m_offsetY = 0;
 
     setArrangement(QIconView::LeftToRight);
     setAutoArrange(true);
@@ -205,7 +226,7 @@ ThumbBar::ThumbBar(QWidget *parent, KPresenterDoc *d, KPresenterView *v)
     setItemsMovable(false);
     setResizeMode(QIconView::Adjust);
 
-    thumbTip = new ThumbToolTip(this);
+    m_thumbTip = new ThumbToolTip(this);
 
     connect(this, SIGNAL(currentChanged(QIconViewItem *)),
             this, SLOT(itemClicked(QIconViewItem *)));
@@ -215,7 +236,7 @@ ThumbBar::ThumbBar(QWidget *parent, KPresenterDoc *d, KPresenterView *v)
 
 ThumbBar::~ThumbBar()
 {
-    delete thumbTip;
+    delete m_thumbTip;
 }
 
 void ThumbBar::setCurrentPage( int pg )
@@ -223,10 +244,12 @@ void ThumbBar::setCurrentPage( int pg )
     for ( QIconViewItem *it = firstItem(); it; it = it->nextItem() )
     {
         if ( it->text().toInt() - 1 == pg ) {
+            blockSignals( true );
             setCurrentItem( it );
             setSelected( it, FALSE ); // to avoid the blue "selected"-mark
             ensureItemVisible(it);
             refreshItems();
+            blockSignals( false );
             return;
         }
     }
@@ -239,7 +262,7 @@ QRect ThumbBar::tip(const QPoint &pos, QString &title)
         return QRect(0, 0, -1, -1);
 
     int pagenr =  item->index();
-    title = doc->pageList().at(pagenr)->pageTitle(i18n("Slide %1").arg(pagenr + 1));
+    title = m_doc->pageList().at(pagenr)->pageTitle();
 
     QRect r = item->pixmapRect(FALSE);
     r = QRect(contentsToViewport(QPoint(r.x(), r.y())), QSize(r.width(), r.height()));
@@ -248,6 +271,7 @@ QRect ThumbBar::tip(const QPoint &pos, QString &title)
 
 void ThumbBar::rebuildItems()
 {
+    kdDebug()<<" void ThumbBar::rebuildItems() beofre \n";
     if( !isVisible())
         return;
     kdDebug(33001) << "ThumbBar::rebuildItems" << endl;
@@ -255,52 +279,57 @@ void ThumbBar::rebuildItems()
     QApplication::setOverrideCursor( Qt::waitCursor );
 
     clear();
-    for ( unsigned int i = 0; i < doc->getPageNums(); i++ ) {
-        // calculate the size of the thumb
-        QRect rect = view->kPresenterDoc()->pageList().at(i)->getZoomPageRect( );
+    if ( m_viewMasterPage )
+    {
+    }
+    else
+    {
+        for ( unsigned int i = 0; i < m_doc->getPageNums(); i++ ) {
+            // calculate the size of the thumb
+            QRect rect = m_doc->pageList().at(i)->getZoomPageRect( );
 
-        int w = rect.width();
-        int h = rect.height();
-        if ( w > h ) {
-            w = 130;
-            float diff = (float)rect.width() / (float)w;
-            h = (int) (rect.height() / diff);
-            if ( h > 120 ) {
-                h = 120;
-                float diff = (float)rect.height() / (float)h;
-                w = (int) (rect.width() / diff);
-            }
-        }
-        else if ( w < h ) {
-            h = 130;
-            float diff = (float)rect.height() / (float)h;
-            w = (int) (rect.width() / diff);
-            if ( w > 120 ) {
-                w = 120;
+            int w = rect.width();
+            int h = rect.height();
+            if ( w > h ) {
+                w = 130;
                 float diff = (float)rect.width() / (float)w;
                 h = (int) (rect.height() / diff);
+                if ( h > 120 ) {
+                    h = 120;
+                    float diff = (float)rect.height() / (float)h;
+                    w = (int) (rect.width() / diff);
+                }
             }
-        }
-        else if ( w == h ) {
-            w = 130;
-            h = 130;
+            else if ( w < h ) {
+                h = 130;
+                float diff = (float)rect.height() / (float)h;
+                w = (int) (rect.width() / diff);
+                if ( w > 120 ) {
+                    w = 120;
+                    float diff = (float)rect.width() / (float)w;
+                    h = (int) (rect.height() / diff);
+                }
+            }
+            else if ( w == h ) {
+                w = 130;
+                h = 130;
+            }
+
+            // draw an empty thumb
+            QPixmap pix(w, h);
+            pix.fill( Qt::white );
+
+            QPainter p(&pix);
+            p.setPen(Qt::black);
+            p.drawRect(pix.rect());
+
+            ThumbItem *item = new ThumbItem(static_cast<QIconView *>(this), QString::number(i+1), pix);
+            item->setUptodate( false );
+            item->setDragEnabled(false);  //no dragging for now
         }
 
-        // draw an empty thumb
-        QPixmap pix(w, h);
-        pix.fill( Qt::white );
-
-        QPainter p(&pix);
-        p.setPen(Qt::black);
-        p.drawRect(pix.rect());
-
-        ThumbItem *item = new ThumbItem(static_cast<QIconView *>(this), QString::number(i+1), pix);
-        item->setUptodate( false );
-        item->setDragEnabled(false);  //no dragging for now
+        QTimer::singleShot( 10, this, SLOT( slotRefreshItems() ) );
     }
-
-    QTimer::singleShot( 10, this, SLOT( slotRefreshItems() ) );
-
     uptodate = true;
 
     QApplication::restoreOverrideCursor();
@@ -310,7 +339,7 @@ void ThumbBar::refreshItems(bool offset)
 {
     QRect vRect = visibleRect();
     if ( offset )
-        vRect.moveBy( offsetX, offsetY );
+        vRect.moveBy( m_offsetX, m_offsetY );
     else
         vRect.moveBy( contentsX(), contentsY() );
 
@@ -329,12 +358,14 @@ void ThumbBar::refreshItems(bool offset)
         it = it->nextItem();
     }
 
-    offsetX = 0;
-    offsetY = 0;
+    m_offsetX = 0;
+    m_offsetY = 0;
 }
 
 void ThumbBar::updateItem( int pagenr /* 0-based */, bool sticky )
 {
+    if ( m_viewMasterPage )
+        return;
     if ( !uptodate )
         return;
     int pagecnt = 0;
@@ -370,7 +401,7 @@ void ThumbBar::updateItem( int pagenr /* 0-based */, bool sticky )
         pagecnt++;
         it = it->nextItem();
     } while ( it );
-    
+
     if ( ! sticky )
         kdWarning(33001) << "Item for page " << pagenr << " not found" << endl;
 }
@@ -477,7 +508,7 @@ QPixmap ThumbBar::getSlideThumb(int slideNr) const
     //kdDebug(33001) << "ThumbBar::getSlideThumb: " << slideNr << endl;
     QPixmap pix( 10, 10 );
 
-    view->getCanvas()->drawPageInPix( pix, slideNr, 60 );
+    m_view->getCanvas()->drawPageInPix( pix, slideNr, 60 );
 
     int w = pix.width();
     int h = pix.height();
@@ -515,8 +546,8 @@ void ThumbBar::itemClicked(QIconViewItem *i)
 
 void ThumbBar::slotContentsMoving(int x, int y)
 {
-    offsetX = x;
-    offsetY = y;
+    m_offsetX = x;
+    m_offsetY = y;
     kdDebug(33001) << "offset x,y = " << x << ", " << y << endl;
     refreshItems( true );
 }
@@ -526,20 +557,20 @@ void ThumbBar::slotRefreshItems()
     refreshItems();
 }
 
-OutlineSlideItem::OutlineSlideItem( KListView* parent, KPrPage* _page )
-    : KListViewItem( parent ), m_page( _page )
+OutlineSlideItem::OutlineSlideItem( KListView* parent, KPrPage* _page, bool _masterPage )
+    : KListViewItem( parent ), m_page( _page ), m_masterPage( _masterPage )
 {
     setDragEnabled(true);
     setPage( _page );
-    setPixmap( 0, KPBarIcon( "newslide" ) );
+    setPixmap( 0, KPBarIcon( "slide" ) );
 }
 
-OutlineSlideItem::OutlineSlideItem( KListView* parent, OutlineSlideItem * after, KPrPage* _page )
-    : KListViewItem( parent, after ), m_page( _page )
+OutlineSlideItem::OutlineSlideItem( KListView* parent, OutlineSlideItem * after, KPrPage* _page, bool _masterPage )
+    : KListViewItem( parent, after ), m_page( _page ), m_masterPage( _masterPage )
 {
     setDragEnabled(true);
     setPage( _page );
-    setPixmap( 0, KPBarIcon( "newslide" ) );
+    setPixmap( 0, KPBarIcon( "slide" ) );
 }
 
 void OutlineSlideItem::setPage( KPrPage* p )
@@ -552,9 +583,8 @@ void OutlineSlideItem::setPage( KPrPage* p )
 void OutlineSlideItem::update()
 {
     if( !m_page ) return;
-    int index = m_page->kPresenterDoc()->pageList().findRef( m_page );
-    QString title = m_page->pageTitle( i18n( "Slide %1" ).arg( index + 1 ) );
-    setText( 0, title );
+    KPresenterDoc *doc = m_page->kPresenterDoc();
+    updateTitle();
 
     // add all objects
     OutlineObjectItem *ooi = 0;
@@ -566,47 +596,51 @@ void OutlineSlideItem::update()
 
     QPtrListIterator<KPObject> it( m_page->objectList() );
 
-    for ( ; it.current(); ++it ) {
-        OutlineObjectItem *item = new OutlineObjectItem( this, it.current(), 
-                                                         it.current()->isSticky() );
-        item->setDragEnabled( false );
-        if ( it.current()->isSelected() )
-            ooi = item;
-    }
-
-    KPObject* header = 0;
-    KPObject* footer = 0;
-
-    KPresenterDoc *doc = m_page->kPresenterDoc();
-    // add sticky objects, exclude header and footer
-    it = doc->stickyPage()->objectList();
-    for ( ; it.current() ; ++it )
+    if ( !m_masterPage )
     {
-        KPObject* object = it.current();
+        for ( ; it.current(); ++it ) {
+            OutlineObjectItem *item = new OutlineObjectItem( this, it.current(),
+                                                             it.current()->isSticky() );
+            item->setDragEnabled( false );
+            if ( it.current()->isSelected() )
+                ooi = item;
+        }
+    }
+    else
+    {
+        KPObject* header = 0;
+        KPObject* footer = 0;
 
-        if( doc->hasHeader() && doc->isHeader( object ) )
-            header = object;
-        else if( doc->hasFooter() && doc->isFooter( object ) )
-            footer = object;
-        else if( !doc->isHeader( object ) && !doc->isFooter( object ) ) {
-            OutlineObjectItem *item = new OutlineObjectItem( this, object, true );
-            if ( object->isSelected() )
+        // add sticky objects, exclude header and footer
+        it = doc->masterPage()->objectList();
+        for ( ; it.current() ; ++it )
+        {
+            KPObject* object = it.current();
+
+            if( m_page->hasHeader() && doc->isHeader( object ) )
+                header = object;
+            else if( m_page->hasFooter() && doc->isFooter( object ) )
+                footer = object;
+            else if( !doc->isHeader( object ) && !doc->isFooter( object ) ) {
+                OutlineObjectItem *item = new OutlineObjectItem( this, object, true );
+                if ( object->isSelected() )
+                    ooi = item;
+            }
+
+        }
+
+        // add header and footer (if any)
+        if ( footer ) {
+            OutlineObjectItem *item = new OutlineObjectItem( this, footer, true, i18n("Footer") );
+            if ( footer->isSelected() )
                 ooi = item;
         }
 
-    }
-
-    // add header and footer (if any)
-    if ( footer ) {
-        OutlineObjectItem *item = new OutlineObjectItem( this, footer, true, i18n("Footer") );
-        if ( footer->isSelected() )
-            ooi = item;
-    }
-
-    if ( header ) {
-        OutlineObjectItem *item = new OutlineObjectItem( this, header, true, i18n("Header") );
-        if ( header->isSelected() )
-            ooi = item;
+        if ( header ) {
+            OutlineObjectItem *item = new OutlineObjectItem( this, header, true, i18n("Header") );
+            if ( header->isSelected() )
+                ooi = item;
+        }
     }
 
     // select selected object the page is necessary that a
@@ -615,6 +649,13 @@ void OutlineSlideItem::update()
         (ooi->listView())->setSelected( ooi, true );
 }
 
+void OutlineSlideItem::updateTitle()
+{
+    QString title = m_page->pageTitle();
+    if ( ! m_page->isSlideSelected() )
+        title = i18n( "(%1)" ).arg( title );
+    setText( 0, title );
+}
 
 OutlineObjectItem::OutlineObjectItem( OutlineSlideItem* parent, KPObject* _object,
                                       bool sticky, const QString& name )
@@ -623,7 +664,7 @@ OutlineObjectItem::OutlineObjectItem( OutlineSlideItem* parent, KPObject* _objec
     setObject( m_object );
 
     QString objectName = name.isEmpty() ? m_object->getObjectName() : name;
-    if( sticky ) objectName += i18n(" (Sticky)" );
+    //if( sticky ) objectName += i18n(" (Sticky)" );
     setText( 0, objectName );
 }
 
@@ -695,7 +736,7 @@ void OutlineObjectItem::setObject( KPObject* object )
 }
 
 Outline::Outline( QWidget *parent, KPresenterDoc *d, KPresenterView *v )
-    : KListView( parent ), doc( d ), view( v )
+    : KListView( parent ), SideBarBase( d, v)
 {
     rebuildItems();
     setSorting( -1 );
@@ -703,17 +744,17 @@ Outline::Outline( QWidget *parent, KPresenterDoc *d, KPresenterView *v )
     addColumn( i18n( "Slide" ) );
     setSizePolicy( QSizePolicy( QSizePolicy::Minimum, QSizePolicy::Expanding ) );
 
-    outlineTip = new OutlineToolTip(this);
-
     connect( this, SIGNAL( currentChanged( QListViewItem * ) ), this, SLOT( itemClicked( QListViewItem * ) ) );
-    connect( this, SIGNAL( moved( QListViewItem *, QListViewItem *, QListViewItem * ) ),
-             this, SLOT( movedItems( QListViewItem *, QListViewItem *, QListViewItem * ) ) );
     connect( this, SIGNAL( rightButtonPressed( QListViewItem *, const QPoint &, int ) ),
              this, SLOT( rightButtonPressed( QListViewItem *, const QPoint &, int ) ) );
 
     connect( this, SIGNAL( doubleClicked ( QListViewItem * )),
              this, SLOT(renamePageTitle()));
+    connect( this, SIGNAL( dropped( QDropEvent*, QListViewItem*, QListViewItem* ) ),
+             this, SLOT( slotDropped( QDropEvent*, QListViewItem*, QListViewItem*  ) ));
 
+    setItemsMovable( false );
+    setDragEnabled( true );
     setAcceptDrops( true );
     setDropVisualizer( true );
     setFullWidth( true );
@@ -722,17 +763,23 @@ Outline::Outline( QWidget *parent, KPresenterDoc *d, KPresenterView *v )
 
 Outline::~Outline()
 {
-    delete outlineTip;
 }
 
 void Outline::rebuildItems()
 {
     clear();
-
-    // Rebuild all the items
-    for ( int i = doc->getPageNums() - 1; i >= 0; --i ) {
-        KPrPage *page=doc->pageList().at( i );
-        new OutlineSlideItem( this, page );
+    if ( m_viewMasterPage )
+    {
+        KPrPage *page=m_doc->masterPage();
+        new OutlineSlideItem( this, page, true );
+    }
+    else
+    {
+        // Rebuild all the items
+        for ( int i = m_doc->getPageNums() - 1; i >= 0; --i ) {
+            KPrPage *page=m_doc->pageList().at( i );
+            new OutlineSlideItem( this, page, false );
+        }
     }
 }
 
@@ -772,19 +819,20 @@ void Outline::addItem( int pos )
 {
     kdDebug(33001)<< "Outline::addItem" << endl;
 
-    KPrPage *page=doc->pageList().at( pos );
+    KPrPage *page=m_doc->pageList().at( pos );
     OutlineSlideItem *item;
     if ( pos == 0 ) {
-        item = new OutlineSlideItem( this, page );
+        item = new OutlineSlideItem( this, page,m_viewMasterPage );
     }
     else {
         OutlineSlideItem *after = slideItem( pos - 1 );
-        item = new OutlineSlideItem( this, after, page );
+        item = new OutlineSlideItem( this, after, page,m_viewMasterPage );
     }
 
+    item = dynamic_cast<OutlineSlideItem*>( item->nextSibling() );
     // update title
-    for( ; item; item = dynamic_cast<OutlineSlideItem*>(item->nextSibling()) )
-        item->update();
+    for( ; item; item = dynamic_cast<OutlineSlideItem*>( item->nextSibling() ) )
+        item->updateTitle();
 }
 
 // move an Outline Item so that not the hole list has to be recreated
@@ -795,15 +843,25 @@ void Outline::moveItem( int oldPos, int newPos )
     int lowPage = oldPos > newPos ? newPos : oldPos;
     int highPage = oldPos < newPos ? newPos : oldPos;
 
-    // update, for all between lowPage & highPage
-    int page = lowPage;
-    OutlineSlideItem* item = slideItem( page );
-    for( ; item ; ++page ) {
-        KPrPage* newPage = doc->pageList().at( page );
-        item->setPage( newPage );
-        item = dynamic_cast<OutlineSlideItem*>( item->nextSibling() );
-        if ( page == highPage ) break;
+    OutlineSlideItem *item = dynamic_cast<OutlineSlideItem*>( firstChild() );
+    QListViewItem *itemToMove = 0;
+    QListViewItem *itemAfter = 0;
+
+    // moving backwards
+    if ( newPos < oldPos )
+        newPos--;
+
+    for ( int index = 0; item; ++index, item = dynamic_cast<OutlineSlideItem*>( item->nextSibling() ) )
+    {
+        if ( index == oldPos )
+            itemToMove = item;
+        if ( index == newPos )
+            itemAfter = item;
+        if ( index >= lowPage && index <= highPage )
+            item->updateTitle();
     }
+
+    KListView::moveItem( itemToMove, 0, itemAfter );
 }
 
 void Outline::removeItem( int pos )
@@ -816,25 +874,8 @@ void Outline::removeItem( int pos )
 
     delete item;
 
-    for( item = temp; item; ++pos ) {
-        KPrPage* newPage = doc->pageList().at( pos );
-        item->setPage( newPage );
-        item = dynamic_cast<OutlineSlideItem*>( item->nextSibling() );
-    }
-}
-
-QRect Outline::tip(const QPoint &pos, QString &title)
-{
-    QListViewItem *item = itemAt( pos );
-    if (!item)
-        return QRect(0, 0, -1, -1);
-
-    OutlineSlideItem* slideItem = dynamic_cast<OutlineSlideItem*>(item);
-    if( !slideItem )
-        return QRect(0, 0, -1, -1);
-    title = slideItem->text( 0 );
-
-    return itemRect(item);
+    for ( item = temp; item; item = dynamic_cast<OutlineSlideItem*>( item->nextSibling() ) )
+        item->updateTitle();
 }
 
 void Outline::itemClicked( QListViewItem *item )
@@ -847,7 +888,8 @@ void Outline::itemClicked( QListViewItem *item )
     {
         KPrPage* page = slideItem->page();
         if( !page ) return;
-        emit showPage( page->kPresenterDoc()->pageList().findRef( page ) );
+        if ( !m_viewMasterPage )
+            emit showPage( m_doc->pageList().findRef( page ) );
     }
 
     // check if we need to show chosen object
@@ -859,26 +901,72 @@ void Outline::itemClicked( QListViewItem *item )
 
         // ensure the owner slide is shown first
         OutlineSlideItem* slideItem = dynamic_cast<OutlineSlideItem*>(objectItem->parent());
-        if( slideItem && doc->activePage() != slideItem->page() )
+        if( slideItem && m_doc->activePage() != slideItem->page() )
         {
             KPrPage* page = slideItem->page();
             if( !page ) return;
-            emit showPage( page->kPresenterDoc()->pageList().findRef( page ) );
+            if ( !m_viewMasterPage )
+                emit showPage( m_doc->pageList().findRef( page ) );
         }
 
         // select the object, make sure it's visible
-        doc->deSelectAllObj();
-        view->getCanvas()->selectObj( object );
-        QRect rect( doc->zoomHandler()->zoomRect( object->getBoundingRect() ) );
+        m_doc->deSelectAllObj();
+        m_view->getCanvas()->selectObj( object );
+        QRect rect( m_doc->zoomHandler()->zoomRect( object->getBoundingRect() ) );
         rect.setLeft( rect.left() - 20 );
         rect.setTop( rect.top() - 20 );
         rect.setRight( rect.right() + 20 );
         rect.setBottom( rect.bottom() + 20 );
-        view->makeRectVisible( rect );
-        doc->repaint( false );
+        m_view->makeRectVisible( rect );
+        m_doc->repaint( false );
     }
 }
 
+/**
+ * The listview no longer moves the item by itself. It just calls m_doc->movePage
+ * which then moves the item. At the moment the method only works as long as
+ * only one object is moves.
+ * When an item is about to move (using drag-and-drop), it makes shure that
+ * it's not moved right after an object.
+ */
+void Outline::slotDropped( QDropEvent * /* e */, QListViewItem *parent, QListViewItem *target )
+{
+    kdDebug(33001) << "slotDropped" << endl;
+    /* slide doesn't have parent (always 0)
+     * Only slides can move at the moment, objects can't. */
+    if ( parent )
+        return;
+
+    // This code is taken from KListView
+    for (QListViewItem *i = firstChild(), *iNext = 0; i != 0; i = iNext)
+    {
+        iNext = i->itemBelow();
+        if ( !i->isSelected() )
+            continue;
+
+        // don't drop an item after itself, or else
+        // it moves to the top of the list
+        if ( i == target )
+            continue;
+
+        i->setSelected( false );
+
+        // don't move the item as it is allready
+        moveItem(i, parent, target );
+
+        // Only one item can be moved
+        break;
+    }
+}
+
+// We have to overwrite this method as it checks if an item is movable
+// and we have disabled it.
+bool Outline::acceptDrag( QDropEvent* e ) const
+{
+    return acceptDrops() && (e->source()==viewport());
+}
+
+
 void Outline::setCurrentPage( int pg )
 {
     OutlineSlideItem *item = slideItem( pg );
@@ -899,46 +987,33 @@ void Outline::contentsDropEvent( QDropEvent *e )
     connect( this, SIGNAL( currentChanged( QListViewItem * ) ), this, SLOT( itemClicked( QListViewItem * ) ) );
 }
 
-// when item is about to move (using drag-and-drop), make sure:
-// it's not moved right after object. only slides can move, objects can't.
-void Outline::movableDropEvent( QListViewItem* parent, QListViewItem* target )
+void Outline::moveItem( QListViewItem *i, QListViewItem *, QListViewItem *newAfter )
 {
-    // slide doesn't have parent (always 0)
-    if( parent ) return;
+    OutlineSlideItem* srcItem = dynamic_cast<OutlineSlideItem*>( i );
+    if ( !srcItem )
+        return;
 
-    KListView::movableDropEvent( parent, target );
-}
+    int num = m_doc->pageList().findRef( srcItem->page() );
 
-void Outline::movedItems( QListViewItem *i, QListViewItem *, QListViewItem *newAfter )
-{
-    movedItem = i;
-    movedAfter = newAfter;
-    QTimer::singleShot( 300, this, SLOT( doMoveItems() ) );
-}
+    int numNow = 0;
+    if ( newAfter )
+    {
+        OutlineSlideItem* dstItem = dynamic_cast<OutlineSlideItem*>( newAfter );
+        if( !dstItem )
+            return;
 
-void Outline::doMoveItems()
-{
-    OutlineSlideItem* srcItem = dynamic_cast<OutlineSlideItem*>(movedItem);
-    if( !srcItem ) return;
-
-    int num = doc->pageList().findRef( srcItem->page() );
-
-    OutlineSlideItem* dstItem = dynamic_cast<OutlineSlideItem*>(movedAfter);
-    if( movedAfter && !dstItem ) return;
-
-    int numNow = movedAfter ? doc->pageList().findRef( dstItem->page() ) : -1;
-    if ( numNow < num ) numNow++;
-
-    if(num!=numNow) {
-        emit movePage( num, numNow );
-        // this has to be done because moving a page is take + insert the page
-        setSelected( movedItem, true );
+        numNow = m_doc->pageList().findRef( dstItem->page() );
+        if ( numNow < num )
+            numNow++;
     }
+
+    if ( num!=numNow )
+        m_doc->movePage( num, numNow );
 }
 
 void Outline::rightButtonPressed( QListViewItem *, const QPoint &pnt, int )
 {
-    if ( !doc->isReadWrite()) return;
+    if ( !m_doc->isReadWrite() || m_viewMasterPage ) return;
 
     QListViewItem *item = QListView::selectedItem();
     if( !item ) return;
@@ -946,13 +1021,13 @@ void Outline::rightButtonPressed( QListViewItem *, const QPoint &pnt, int )
     OutlineSlideItem* slideItem = dynamic_cast<OutlineSlideItem*>(item);
     if( !slideItem ) return;
 
-    view->openPopupMenuSideBar(pnt);
+    m_view->openPopupMenuSideBar(pnt);
 }
 
 void Outline::renamePageTitle()
 {
     QListViewItem *item = QListView::selectedItem();
-    if( !item ) return;
+    if( !item || m_viewMasterPage) return;
 
     OutlineSlideItem* slideItem = dynamic_cast<OutlineSlideItem*>(item);
     if( !slideItem ) return;
@@ -963,18 +1038,17 @@ void Outline::renamePageTitle()
     bool ok = false;
     QString activeTitle = item->text( 0 );
     QRegExpValidator validator( QRegExp( ".*" ), 0 ); // we want to allow empty titles. Empty == automatic.
-    QString newTitle = KLineEditDlg::getText( i18n("Rename Slide"),
-                                              i18n("Slide title:"), activeTitle, &ok, this,
+    QString newTitle = KInputDialog::getText( i18n("Rename Slide"),
+                                              i18n("Slide title:"), activeTitle, &ok, this, 0,
                                               &validator );
 
     // Have a different name ?
     if ( ok ) { // User pushed an OK button.
         if ( newTitle != activeTitle ) { // Title changed.
-            KPresenterDoc *doc=view->kPresenterDoc();
             KPrChangeTitlePageNameCommand *cmd=new KPrChangeTitlePageNameCommand( i18n("Rename Slide"),
-                                                                                  doc, activeTitle, newTitle, page  );
+                                                                                  m_doc, activeTitle, newTitle, page  );
             cmd->execute();
-            doc->addCommand(cmd);
+            m_doc->addCommand(cmd);
         }
     }
 }
