@@ -24,8 +24,10 @@
 #include "kpobject.h"
 #include "kptextobject.h"
 #include "kpresenter_view.h"
+#include "kpresenter_doc.h"
 #include "kprcanvas.h"
-#include "kppageeffects.h"
+#include "kprpage.h"
+#include "pageeffects.h"
 #include "kpresenter_sound_player.h"
 
 #include <qsplitter.h>
@@ -40,6 +42,8 @@
 #include <qtooltip.h>
 #include <qwhatsthis.h>
 #include <qframe.h>
+#include <qlabel.h>
+#include <qcombobox.h>
 
 #include <kdebug.h>
 #include <kurlrequester.h>
@@ -50,8 +54,9 @@
 #include <kstandarddirs.h>
 #include <kfiledialog.h>
 
+
 KPEffectPreview::KPEffectPreview( QWidget *parent, KPresenterDoc *_doc, KPresenterView *_view )
-    : QLabel( parent ), doc( _doc ), view( _view )
+    : QLabel( parent ), doc( _doc ), view( _view ), m_pageEffect( 0 )
 {
     setFrameStyle( StyledPanel | Sunken );
 }
@@ -84,21 +89,62 @@ void KPEffectPreview::setPixmap( const QPixmap& pixmap )
     QLabel::setPixmap( m_pixmap );
 }
 
-void KPEffectPreview::run( PageEffect effect, PresSpeed speed )
+void KPEffectPreview::run( PageEffect effect, EffectSpeed speed )
 {
     QRect rect = m_pixmap.rect();
-    QPixmap target( rect.size() );
-    target.fill( Qt::black );
+    m_target.resize( rect.size() );
+    m_target.fill( Qt::black );
 
-    kPchangePages( this, m_pixmap, target, effect, speed );
+    //kPchangePages( this, m_pixmap, m_target, effect, speed );
+    if ( m_pageEffect )
+    {
+        m_pageEffectTimer.stop();
+        QObject::disconnect( &m_pageEffectTimer, SIGNAL( timeout() ), this, SLOT( slotDoPageEffect() ) );
 
-    QLabel::update();
+        m_pageEffect->finish();
+
+        delete m_pageEffect;
+        m_pageEffect = 0;
+        QLabel::repaint();
+    }
+
+    m_pageEffect = new KPPageEffects( this, m_target, effect, speed );
+    if ( m_pageEffect->doEffect() )
+    {
+        delete m_pageEffect;
+        m_pageEffect = 0;
+        QLabel::update();
+    }
+    else
+    {
+        connect( &m_pageEffectTimer, SIGNAL( timeout() ), SLOT( slotDoPageEffect() ) );
+        m_pageEffectTimer.start( 50, true );
+    }
+
+    //QLabel::update();
+}
+
+
+void KPEffectPreview::slotDoPageEffect()
+{
+    if ( m_pageEffect->doEffect() )
+    {
+        m_pageEffectTimer.stop();
+        QObject::disconnect( &m_pageEffectTimer, SIGNAL( timeout() ), this, SLOT( slotDoPageEffect() ) );
+        delete m_pageEffect;
+        m_pageEffect = 0;
+        QLabel::update();
+    }
+    else
+    {
+        m_pageEffectTimer.start( 50, true );
+    }
 }
 
 
 KPTransEffectDia::KPTransEffectDia( QWidget *parent, const char *name,
                                     KPresenterDoc *_doc, KPresenterView *_view )
-    : KDialogBase( parent, name, true, "", Ok|Cancel ),
+    : KDialogBase( parent, name, true, "", KDialogBase::User1|Ok|Cancel ),
       doc( _doc ), view( _view ), soundPlayer( 0 )
 {
     enableButtonSeparator( true );
@@ -130,7 +176,7 @@ KPTransEffectDia::KPTransEffectDia( QWidget *parent, const char *name,
     effectPreview->setPixmap( pix );
 
     pageEffect = pg->getPageEffect();
-    speed = doc->getPresSpeed();
+    speed = pg->getPageEffectSpeed();
 
     QVBoxLayout *leftlayout = new QVBoxLayout( leftpart, KDialog::marginHint(), KDialog::spacingHint() );
     leftlayout->setAutoAdd( true );
@@ -187,6 +233,7 @@ KPTransEffectDia::KPTransEffectDia( QWidget *parent, const char *name,
         effectList->setCurrentItem( effectList->count()-1 );
 
     connect( effectList, SIGNAL(highlighted(int)), this, SLOT(effectChanged(int)) );
+    connect( effectList, SIGNAL( doubleClicked ( QListBoxItem *) ), this, SLOT( effectChanged()) );
 
     new QLabel( i18n("Speed:"), leftpart );
 
@@ -194,14 +241,15 @@ KPTransEffectDia::KPTransEffectDia( QWidget *parent, const char *name,
     QBoxLayout* speedLayout = new QHBoxLayout( sp, KDialog::marginHint(), KDialog::spacingHint() );
     speedLayout->setAutoAdd( true );
 
-    new QLabel( i18n("Slow"), sp );
-    speedSlider = new QSlider( 1, 10, 1, 1, Qt::Horizontal, sp );
-    speedSlider->setValue( speed );
-    speedSlider->setTickmarks( QSlider::Below );
-    speedSlider->setTickInterval( 1 );
-    new QLabel( i18n("Fast"), sp );
+    speedCombo = new QComboBox( sp );
+    speedCombo->insertItem(i18n("Slow") );
+    speedCombo->insertItem(i18n("Medium") );
+    speedCombo->insertItem(i18n("Fast") );
 
-    connect( speedSlider, SIGNAL(valueChanged(int)), this, SLOT(speedChanged(int)) );
+
+    speedCombo->setCurrentItem( speed );
+    
+    connect( speedCombo, SIGNAL(activated(int)), this, SLOT(speedChanged(int)) );
 
 
     QWidget* previewgrp = new QWidget( leftpart );
@@ -227,7 +275,6 @@ KPTransEffectDia::KPTransEffectDia( QWidget *parent, const char *name,
 
     checkSoundEffect = new QCheckBox( i18n( "Sound effect" ), leftpart );
     checkSoundEffect->setChecked( soundEffect );
-    QWhatsThis::add( checkSoundEffect, i18n("If you use a sound effect, please do not select 'No Effect'.") );
     connect( checkSoundEffect, SIGNAL( clicked() ), this, SLOT( soundEffectChanged() ) );
 
     QWidget* soundgrp = new QWidget( leftpart );
@@ -255,8 +302,7 @@ KPTransEffectDia::KPTransEffectDia( QWidget *parent, const char *name,
     connect( buttonTestStopSoundEffect, SIGNAL( clicked() ), this, SLOT( stopSound() ) );
 
     soundEffect = pg->getPageSoundEffect();
-    connect( this, SIGNAL( okClicked() ), this, SLOT( slotTransEffectDiaOK() ) );
-    //connect( this, SIGNAL( okClicked() ), this, SLOT( accept() ) );
+    setButtonText(KDialogBase::User1,i18n( "Apply &Global" ));
 
     slideTime = pg->getPageTimer();
 
@@ -283,6 +329,11 @@ void KPTransEffectDia::preview()
     effectPreview->run( pageEffect, speed );
 }
 
+void KPTransEffectDia::effectChanged()
+{
+    effectChanged( effectList->currentItem() );
+}
+
 void KPTransEffectDia::effectChanged( int index )
 {
     if( effectList->currentText() == i18n( "Random Transition" ) )
@@ -295,8 +346,7 @@ void KPTransEffectDia::effectChanged( int index )
 
 void KPTransEffectDia::speedChanged( int value )
 {
-    if( value <= 0 ) value = 1;
-    speed = static_cast<PresSpeed>(value);
+    speed = static_cast<EffectSpeed>(value);
 }
 
 void KPTransEffectDia::timeChanged( int value )
@@ -400,4 +450,16 @@ void KPTransEffectDia::stopSound()
     }
 }
 
+void KPTransEffectDia::slotOk()
+{
+    // TODO: only if changed. And pass flags for which settings changed
+    emit apply( false );
+}
+
+void KPTransEffectDia::slotUser1()
+{
+    // TODO: only if changed. And pass flags for which settings changed
+    emit apply( true );
+}
+
 #include "transeffectdia.moc"
