@@ -23,7 +23,9 @@
 #include "webpresentation.h"
 
 #include "kpresenter_view.h"
+#include "kpresenter_doc.h"
 #include "kprcanvas.h"
+#include "kprpage.h"
 
 #include <kstandarddirs.h>
 #include <unistd.h>
@@ -48,6 +50,8 @@
 #include <qregexp.h>
 #include <qimage.h>
 #include <qlayout.h>
+#include <qwhatsthis.h>
+#include <qcheckbox.h>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -170,7 +174,7 @@ KPWebPresentation::KPWebPresentation( KPresenterDoc *_doc, KPresenterView *_view
 }
 
 KPWebPresentation::KPWebPresentation( const QString &_config, KPresenterDoc *_doc, KPresenterView *_view )
-    : config( _config ), xml( false )
+    : config( _config ), xml( false ), m_bWriteHeader( true ), m_bWriteFooter( true ), m_bLoopSlides( false )
 {
     doc = _doc;
     view = _view;
@@ -181,8 +185,10 @@ KPWebPresentation::KPWebPresentation( const QString &_config, KPresenterDoc *_do
 KPWebPresentation::KPWebPresentation( const KPWebPresentation &webPres )
     : config( webPres.config ), author( webPres.author ), title( webPres.title ), email( webPres.email ),
       slideInfos( webPres.slideInfos ), backColor( webPres.backColor ), titleColor( webPres.titleColor ),
-      textColor( webPres.textColor ), path( webPres.path ),
-      xml( webPres.xml), zoom( webPres.zoom ), m_encoding( webPres.m_encoding )
+      textColor( webPres.textColor ), path( webPres.path ), xml( webPres.xml),
+      m_bWriteHeader( webPres.m_bWriteHeader ),
+      m_bWriteFooter( webPres.m_bWriteFooter ), m_bLoopSlides( webPres.m_bLoopSlides ),
+      timeBetweenSlides ( webPres.timeBetweenSlides ), zoom( webPres.zoom ), m_encoding( webPres.m_encoding )
 {
     doc = webPres.doc;
     view = webPres.view;
@@ -220,7 +226,11 @@ void KPWebPresentation::loadConfig()
     textColor = cfg.readColorEntry( "TextColor", &textColor );
     path = cfg.readPathEntry( "Path", path );
     xml = cfg.readBoolEntry( "XML", xml );
+    m_bWriteHeader = cfg.readBoolEntry( "WriteHeader", m_bWriteHeader );
+    m_bWriteFooter = cfg.readBoolEntry( "WriteFooter", m_bWriteFooter );
+    m_bLoopSlides = cfg.readBoolEntry( "LoopSlides", m_bLoopSlides );
     zoom = cfg.readNumEntry( "Zoom", zoom );
+    timeBetweenSlides = cfg.readNumEntry("TimeBetweenSlides", timeBetweenSlides );
     m_encoding = cfg.readEntry( "Encoding", m_encoding );
 }
 
@@ -246,7 +256,11 @@ void KPWebPresentation::saveConfig()
     cfg.writeEntry( "Path", path );
 #endif
     cfg.writeEntry( "XML", xml );
+    cfg.writeEntry( "WriteHeader", m_bWriteHeader );
+    cfg.writeEntry( "WriteFooter", m_bWriteFooter );
+    cfg.writeEntry( "LoopSlides", m_bLoopSlides );
     cfg.writeEntry( "Zoom", zoom );
+    cfg.writeEntry( "TimeBetweenSlides", timeBetweenSlides );
     cfg.writeEntry( "Encoding", m_encoding );
 }
 
@@ -255,15 +269,14 @@ void KPWebPresentation::initCreation( KProgress *progressBar )
     QString cmd;
     int p;
     KURL str(  path + "/html"  );
-    KIO::NetAccess::mkdir( str  );
+    KIO::NetAccess::mkdir( str,( QWidget* )0L  );
 
     p = progressBar->progress();
     progressBar->setProgress( ++p );
     kapp->processEvents();
 
     str = path + "/pics";
-    KIO::NetAccess::mkdir( str );
-
+    KIO::NetAccess::mkdir( str,( QWidget* )0L );
 
     p = progressBar->progress();
     progressBar->setProgress( ++p );
@@ -280,12 +293,7 @@ void KPWebPresentation::initCreation( KProgress *progressBar )
         srcurl.setPath( locate( "slideshow", filename, KPresenterFactory::global() ) );
         desturl = path;
         desturl.addPath( "/pics/" + filename );
-#if KDE_IS_VERSION(3,1,90 )
-       KIO::NetAccess::file_move( srcurl, desturl, -1, true /*overwrite*/);
-#else
-       KIO::NetAccess::del( desturl ); // Copy does not remove existing destination file
-       KIO::NetAccess::copy( srcurl, desturl );
-#endif
+        KIO::NetAccess::file_copy( srcurl, desturl, -1, true /*overwrite*/);
         p = progressBar->progress();
         progressBar->setProgress( ++p );
         kapp->processEvents();
@@ -303,13 +311,12 @@ void KPWebPresentation::createSlidesPictures( KProgress *progressBar )
         int pgNum = slideInfos[i].pageNumber;
         view->getCanvas()->drawPageInPix( pix, pgNum, zoom, true /*force real variable value*/ );
         filename = QString( "%1/pics/slide_%2.png" ).arg( path ).arg( i + 1 );
-#if KDE_IS_VERSION(3,1,90)
+
         KTempFile tmp;
         pix.save( tmp.name(), "PNG" );
+
         KIO::NetAccess::file_move( tmp.name(), filename, -1, true /*overwrite*/);
-#else
-        pix.save( filename, "PNG" );
-#endif
+
         p = progressBar->progress();
         progressBar->setProgress( ++p );
         kapp->processEvents();
@@ -323,7 +330,7 @@ QString KPWebPresentation::escapeHtmlText( QTextCodec *codec, const QString& str
     return EscapeSgmlText( codec, strText, true, false );
 }
 
-void KPWebPresentation::writeStartOfHeader(QTextStream& streamOut, QTextCodec *codec, const QString& subtitle)
+void KPWebPresentation::writeStartOfHeader(QTextStream& streamOut, QTextCodec *codec, const QString& subtitle, const QString& dest, const QString& next)
 {
     QString mimeName ( codec->mimeName() );
     if ( isXML() )
@@ -356,7 +363,7 @@ void KPWebPresentation::writeStartOfHeader(QTextStream& streamOut, QTextCodec *c
     streamOut << mimeName << '"' << ( isXML() ?" /":"") << ">\n" ;
 
     // Tell who we are (with the CVS revision number) in case we have a bug in our output!
-    QString strVersion("$Revision: 1.103.2.8 $");
+    QString strVersion("$Revision: 408785 $");
     // Eliminate the dollar signs
     //  (We don't want that the version number changes if the HTML file is itself put in a CVS storage.)
     streamOut << "<meta name=\"Generator\" content=\"KPresenter's Web Presentation "
@@ -364,6 +371,15 @@ void KPWebPresentation::writeStartOfHeader(QTextStream& streamOut, QTextCodec *c
               << "\""<< ( isXML() ?" /":"") // X(HT)ML closes empty elements, HTML not!
               << ">\n";
 
+    // Load the next slide after time elapsed
+    if ( (timeBetweenSlides > 0) && ( QString::compare(dest,next) !=0 ) )
+    {
+        streamOut << "<meta http-equiv=\"refresh\" content=\""
+                  << timeBetweenSlides
+                  << ";url=" << next
+                  << "\">\n";
+    }
+
     streamOut << "<title>"<< escapeHtmlText( codec, title ) << " - " << escapeHtmlText( codec, subtitle ) << "</title>\n";
 
     // ### TODO: transform documentinfo.xml into many <META> elements (at least the author!)
@@ -377,21 +393,17 @@ void KPWebPresentation::createSlidesHTML( KProgress *progressBar )
 
     for ( unsigned int i = 0; i < slideInfos.count(); i++ ) {
 
-        unsigned int pgNum = i + 1;
-#if KDE_IS_VERSION(3,1,90)
+        unsigned int pgNum = i + 1; // pgquiles # elpauer . org - I think this is a bug, seems to be an overflow if we have max_unsigned_int slides
         KTempFile tmp;
         QString dest= QString( "%1/html/slide_%2.html" ).arg( path ).arg( pgNum );
+        QString next= QString( "%1/html/slide_%2.html" ).arg( path ).arg( pgNum<slideInfos.count() ? pgNum+1 : (m_bLoopSlides ? 1 : pgNum ) ); // Ugly, but it works
 
         QFile file( tmp.name() );
         file.open( IO_WriteOnly );
-#else
-        QFile file( QString( "%1/html/slide_%2.html" ).arg( path ).arg( pgNum ) );
-        file.open( IO_WriteOnly );
-#endif
         QTextStream streamOut( &file );
         streamOut.setCodec( codec );
 
-        writeStartOfHeader( streamOut, codec, slideInfos[ i ].slideTitle );
+        writeStartOfHeader( streamOut, codec, slideInfos[ i ].slideTitle, dest, next ); // It would be probably better to pass pgNum instead of dest, next
 
         // ### TODO: transform documentinfo.xml into many <META> elements (at least the author!)
 
@@ -408,97 +420,108 @@ void KPWebPresentation::createSlidesHTML( KProgress *progressBar )
         streamOut << "</head>\n";
         streamOut << "<body bgcolor=\"" << backColor.name() << "\" text=\"" << textColor.name() << "\">\n";
 
-        streamOut << "  <center>\n";
+        if (m_bWriteHeader) {
+            streamOut << "  <center>\n";
 
-        if ( i > 0 )
-            streamOut << "    <a href=\"slide_1.html\">";
-        streamOut << "<img src=\"../pics/first.png\" border=\"0\" alt=\"" << i18n( "First" )
-                  << "\" title=\"" << i18n( "First" ) << "\"" << ( isXML() ?" /":"") << ">";
-        if ( i > 0 )
-            streamOut << "</a>";
+            if ( i > 0 )
+                streamOut << "    <a href=\"slide_1.html\">";
+                streamOut << "<img src=\"../pics/first.png\" border=\"0\" alt=\"" << i18n( "First" )
+                              << "\" title=\"" << i18n( "First" ) << "\"" << ( isXML() ?" /":"") << ">";
+            if ( i > 0 )
+                streamOut << "</a>";
 
-        streamOut << "\n";
+            streamOut << "\n";
 
-        if ( i > 0 )
-            streamOut << "    <a href=\"slide_" << pgNum - 1 << ".html\">";
-        streamOut << "<img src=\"../pics/prev.png\" border=\"0\" alt=\"" << i18n( "Previous" )
-                  << "\" title=\"" << i18n( "Previous" ) << "\"" << ( isXML() ?" /":"") << ">";
-        if ( i > 0 )
-            streamOut << "</a>";
+            if ( i > 0 )
+                streamOut << "    <a href=\"slide_" << pgNum - 1 << ".html\">";
+                streamOut << "<img src=\"../pics/prev.png\" border=\"0\" alt=\"" << i18n( "Previous" )
+                              << "\" title=\"" << i18n( "Previous" ) << "\"" << ( isXML() ?" /":"") << ">";
+            if ( i > 0 )
+                streamOut << "</a>";
 
-        streamOut << "\n";
+            streamOut << "\n";
 
-        if ( i < slideInfos.count() - 1 )
-            streamOut << "    <a href=\"slide_" << pgNum + 1 << ".html\">";
-        streamOut << "<img src=\"../pics/next.png\" border=\"0\" alt=\"" << i18n( "Next" )
-                  << "\" title=\"" << i18n( "Next" ) << "\"" << ( isXML() ?" /":"") << ">";
-        if ( i < slideInfos.count() - 1 )
-            streamOut << "</a>";
+            if ( (m_bLoopSlides) || (i < slideInfos.count() - 1 ) )
+                streamOut << "    <a href=\"" << next << "\">";
+                streamOut << "<img src=\"../pics/next.png\" border=\"0\" alt=\"" << i18n( "Next" )
+                          << "\" title=\"" << i18n( "Next" ) << "\"" << ( isXML() ?" /":"") << ">";
+            if ( (m_bLoopSlides) || (i < slideInfos.count() - 1 ) )
+                streamOut << "</a>";
 
-        streamOut << "\n";
+            streamOut << "\n";
 
-        if ( i < slideInfos.count() - 1 )
-            streamOut << "    <a href=\"slide_" << slideInfos.count() << ".html\">";
-        streamOut << "<img src=\"../pics/last.png\" border=\"0\" alt=\"" << i18n( "Last" )
-                  << "\" title=\"" << i18n( "Last" ) << "\"" << ( isXML() ?" /":"") << ">";
-        if ( i < slideInfos.count() - 1 )
-            streamOut << "</a>";
+            if ( i < slideInfos.count() - 1 )
+                streamOut << "    <a href=\"slide_" << slideInfos.count() << ".html\">";
+                streamOut << "<img src=\"../pics/last.png\" border=\"0\" alt=\"" << i18n( "Last" )
+                      << "\" title=\"" << i18n( "Last" ) << "\"" << ( isXML() ?" /":"") << ">";
+            if ( i < slideInfos.count() - 1 )
+                streamOut << "</a>";
 
-        streamOut << "\n" << "    &nbsp; &nbsp; &nbsp; &nbsp;\n";
+            streamOut << "\n" << "    &nbsp; &nbsp; &nbsp; &nbsp;\n";
 
-        streamOut << "    <a href=\"../index.html\">";
-        streamOut << "<img src=\"../pics/home.png\" border=\"0\" alt=\"" << i18n( "Home" )
-                  << "\" title=\"" << i18n( "Home" ) << "\"" << ( isXML() ?" /":"") << ">";
-        streamOut << "</a>\n";
+            streamOut << "    <a href=\"../index.html\">";
+            streamOut << "<img src=\"../pics/home.png\" border=\"0\" alt=\"" << i18n( "Home" )
+                      << "\" title=\"" << i18n( "Home" ) << "\"" << ( isXML() ?" /":"") << ">";
+            streamOut << "</a>\n";
 
-        streamOut << " </center>" << brtag << "<hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">\n"; // ### TODO: is noshade W3C?
+            streamOut << " </center>" << brtag << "<hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">\n"; // ### TODO: is noshade W3C?
 
-        streamOut << "  <center>\n    <font color=\"" << escapeHtmlText( codec, titleColor.name() ) << "\">\n";
-        streamOut << "    <b>" << escapeHtmlText( codec, title ) << "</b> - <i>" << escapeHtmlText( codec, slideInfos[ i ].slideTitle ) << "</i>\n";
+            streamOut << "  <center>\n    <font color=\"" << escapeHtmlText( codec, titleColor.name() ) << "\">\n";
+            streamOut << "    <b>" << escapeHtmlText( codec, title ) << "</b> - <i>" << escapeHtmlText( codec, slideInfos[ i ].slideTitle ) << "</i>\n";
 
-        streamOut << "    </font>\n  </center><hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">" << brtag << "\n";
+            streamOut << "    </font>\n  </center>\n";
+
+            streamOut << "<hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">" << brtag << "\n";
+	}
 
         streamOut << "  <center>\n    ";
 
-        if ( i < slideInfos.count() - 1 )
-            streamOut << "<a href=\"slide_" << pgNum + 1 << ".html\">";
-        streamOut << "<img src=\"../pics/slide_" << pgNum << ".png\" border=\"0\" alt=\""
-                  << i18n( "Slide %1" ).arg( pgNum ) << "\"" << ( isXML() ?" /":"") << ">";
-        if ( i < slideInfos.count() - 1 )
-            streamOut << "</a>";
+	if ( (m_bLoopSlides) || (i < slideInfos.count() - 1) )
+            streamOut << "<a href=\"" << next << "\">";
 
-        streamOut << "\n";
+	    streamOut << "<img src=\"../pics/slide_" << pgNum << ".png\" border=\"0\" alt=\""
+                      << i18n( "Slide %1" ).arg( pgNum ) << "\"" << ( isXML() ?" /":"") << ">";
 
-        streamOut << "    </center>" << brtag << "<hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">\n";
+	    if ( i < slideInfos.count() - 1 )
+                streamOut << "</a>";
 
-        QPtrList<KPrPage> _tmpList( doc->getPageList() );
-        QString note ( escapeHtmlText( codec, _tmpList.at(i)->noteText() ) );
-        if ( !note.isEmpty() ) {
-            streamOut << "  <b>" << escapeHtmlText( codec, i18n( "Note" ) ) << "</b>\n";
-            streamOut << " <blockquote>\n";
+            streamOut << "\n";
 
-            streamOut << note.replace( "\n", brtag );
+            streamOut << "    </center>\n";
 
-            streamOut << "  </blockquote><hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">\n";
-        }
+	if (m_bWriteFooter) {
+	    	streamOut << brtag << "<hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">\n";
 
-        streamOut << "  <center>\n";
+            QPtrList<KPrPage> _tmpList( doc->getPageList() );
+            QString note ( escapeHtmlText( codec, _tmpList.at(i)->noteText() ) );
+            if ( !note.isEmpty() ) {
+                streamOut << "  <b>" << escapeHtmlText( codec, i18n( "Note" ) ) << "</b>\n";
+                streamOut << " <blockquote>\n";
 
-        QString htmlAuthor;
-        if (email.isEmpty())
-            htmlAuthor=escapeHtmlText( codec, author );
-        else
-            htmlAuthor=QString("<a href=\"mailto:%1\">%2</a>").arg( escapeHtmlText( codec, email )).arg( escapeHtmlText( codec, author ));
-        streamOut << EscapeEncodingOnly ( codec, i18n( "Created on %1 by <i>%2</i> with <a href=\"http://www.koffice.org/kpresenter\">KPresenter</a>" )
+                streamOut << note.replace( "\n", brtag );
+
+                streamOut << "  </blockquote><hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">\n";
+            }
+
+            streamOut << "  <center>\n";
+
+            QString htmlAuthor;
+            if (email.isEmpty())
+                htmlAuthor=escapeHtmlText( codec, author );
+            else
+                htmlAuthor=QString("<a href=\"mailto:%1\">%2</a>").arg( escapeHtmlText( codec, email )).arg( escapeHtmlText( codec, author ));
+            streamOut << EscapeEncodingOnly ( codec, i18n( "Created on %1 by <i>%2</i> with <a href=\"http://www.koffice.org/kpresenter\">KPresenter</a>" )
                                           .arg( KGlobal::locale()->formatDate ( QDate::currentDate() ) ).arg( htmlAuthor ) );
 
-        streamOut << "    </center><hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">\n";
+            streamOut << "    </center><hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">\n";
+        }
+
         streamOut << "</body>\n</html>\n";
 
         file.close();
-#if KDE_IS_VERSION(3,1,90)
+
         KIO::NetAccess::file_move( tmp.name(), dest, -1, true /*overwrite*/);
-#endif
+
         int p = progressBar->progress();
         progressBar->setProgress( ++p );
         kapp->processEvents();
@@ -508,20 +531,14 @@ void KPWebPresentation::createSlidesHTML( KProgress *progressBar )
 void KPWebPresentation::createMainPage( KProgress *progressBar )
 {
     QTextCodec *codec = KGlobal::charsets()->codecForName( m_encoding );
-#if KDE_IS_VERSION(3,1,90)
     KTempFile tmp;
     QString dest = QString( "%1/index.html" ).arg( path );
     QFile file( tmp.name() );
-
     file.open( IO_WriteOnly );
-#else
-    QFile file( QString( "%1/index.html" ).arg( path ) );
-    file.open( IO_WriteOnly );
-#endif
     QTextStream streamOut( &file );
     streamOut.setCodec( codec );
 
-    writeStartOfHeader( streamOut, codec, i18n("Table of Contents") );
+    writeStartOfHeader( streamOut, codec, i18n("Table of Contents"), dest, dest );
     streamOut << "</head>\n";
 
     streamOut << "<body bgcolor=\"" << backColor.name() << "\" text=\"" << textColor.name() << "\">\n";
@@ -549,9 +566,9 @@ void KPWebPresentation::createMainPage( KProgress *progressBar )
 
     streamOut << "</body>\n</html>\n";
     file.close();
-#if KDE_IS_VERSION(3,1,90)
+
     KIO::NetAccess::file_move( tmp.name(), dest, -1, true /*overwrite*/);
-#endif
+
 
     progressBar->setProgress( progressBar->totalSteps() );
     kapp->processEvents();
@@ -578,7 +595,7 @@ void KPWebPresentation::init()
         {
             SlideInfo info;
             info.pageNumber = i;
-            info.slideTitle = doc->pageList().at(i)->pageTitle( i18n( "Slide %1" ).arg( i+1 ) );
+            info.slideTitle = doc->pageList().at(i)->pageTitle();
             slideInfos.append( info );
         }
     }
@@ -591,6 +608,9 @@ void KPWebPresentation::init()
     path = KGlobalSettings::documentPath() + "www";
 
     zoom = 100;
+
+    timeBetweenSlides = 0;
+
     m_encoding = QTextCodec::codecForLocale()->name();
 }
 
@@ -605,6 +625,7 @@ KPWebPresentationWizard::KPWebPresentationWizard( const QString &_config, KPrese
     setupPage2();
     setupPage3();
     setupPage4();
+    setupPage5();
 
     connect( nextButton(), SIGNAL( clicked() ), this, SLOT( pageChanged() ) );
     connect( backButton(), SIGNAL( clicked() ), this, SLOT( pageChanged() ) );
@@ -628,6 +649,10 @@ void KPWebPresentationWizard::createWebPresentation( const QString &_config, KPr
 void KPWebPresentationWizard::setupPage1()
 {
     page1 = new QHBox( this );
+    QWhatsThis::add( page1, i18n("This page allows you to specify some of the key"
+                                 " values for how your presentation will be shown"
+                                 " in HTML. Select individual items for more help"
+                                 " on what they do.") );
     page1->setSpacing( KDialog::spacingHint() );
     page1->setMargin( KDialog::marginHint() );
 
@@ -654,32 +679,56 @@ void KPWebPresentationWizard::setupPage1()
 
     QLabel *label1 = new QLabel( i18n("Author:"), canvas );
     label1->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
+    QWhatsThis::add( label1, i18n("This is where you enter the name of the person or "
+                                  "organization that should be named as the author of "
+                                  "the presentation.") );
     layout->addWidget( label1, 2, 0 );
 
     QLabel *label2 = new QLabel( i18n("Title:"), canvas );
     label2->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
+    QWhatsThis::add( label2, i18n("This is where you enter the title of the overall "
+                                  "presentation." ) );
     layout->addWidget( label2, 3, 0 );
 
-    QLabel *label3 = new QLabel( i18n("E-mail address:"), canvas );
+    QLabel *label3 = new QLabel( i18n("Email address:"), canvas );
     label3->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
+    QWhatsThis::add( label3, i18n("This is where you enter the email address of the "
+                                  "person or organization that is responsible for "
+                                  "the presentation.") );
     layout->addWidget( label3, 4, 0 );
 
     QLabel *label4 = new QLabel( i18n("Path:"), canvas );
     label4->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
+    QWhatsThis::add( label4, i18n("The value entered for the path is the directory "
+                                  "where the presentation will be saved. If it does "
+                                  "not exist, you'll be asked if you want to create "
+                                  "the directory or abort the creation.") );
     layout->addWidget( label4, 5, 0 );
 
     author = new KLineEdit( webPres.getAuthor(), canvas );
+    QWhatsThis::add( author, i18n("This is where you enter the name of the person or "
+                                  "organization that should be named as the author of "
+                                  "the presentation.") );
     layout->addWidget( author, 2, 1 );
 
     title = new KLineEdit( webPres.getTitle(), canvas );
+    QWhatsThis::add( title, i18n("This is where you enter the title of the overall "
+                                 "presentation." ) );
     layout->addWidget( title, 3, 1 );
 
     email = new KLineEdit( webPres.getEmail(), canvas );
+    QWhatsThis::add( email, i18n("This is where you enter the email address of the "
+                                 "person or organization that is responsible for "
+                                 "the presentation.") );
     layout->addWidget( email, 4, 1 );
 
     path=new KURLRequester( canvas );
     path->setMode( KFile::Directory);
     path->lineEdit()->setText(webPres.getPath());
+    QWhatsThis::add( path, i18n("The value entered for the path is the directory "
+                                "where the presentation will be saved. If it does "
+                                "not exist, you'll be asked if you want to create "
+                                "the directory or abort the creation.") );
     layout->addWidget( path, 5, 1 );
 
     QSpacerItem* spacer = new QSpacerItem( 1, 10,
@@ -699,6 +748,9 @@ void KPWebPresentationWizard::setupPage1()
 void KPWebPresentationWizard::setupPage2()
 {
     page2 = new QHBox( this );
+    QWhatsThis::add( page2, i18n("This page allows you to specify how the HTML "
+                                 "for your presentation will be displayed. Select "
+                                 "individual items for more help on what they do.") );
     page2->setSpacing( KDialog::spacingHint() );
     page2->setMargin( KDialog::marginHint() );
 
@@ -725,10 +777,13 @@ void KPWebPresentationWizard::setupPage2()
 
     QLabel *label1 = new QLabel( i18n("Zoom:"), canvas );
     label1->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
+    QWhatsThis::add( label1, i18n( "This selection allows you to specify "
+                                   "the size of the slide image." ) );
     layout->addWidget( label1, 2, 0 );
 
-    QLabel *label2 = new QLabel( i18n( "Default encoding:" ), canvas );
+    QLabel *label2 = new QLabel( i18n( "Encoding:" ), canvas );
     label2->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
+
     layout->addWidget( label2, 3, 0 );
 
     QLabel *label3 = new QLabel( i18n( "Document type:" ), canvas );
@@ -736,22 +791,40 @@ void KPWebPresentationWizard::setupPage2()
     layout->addWidget( label3, 4, 0 );
 
     zoom = new KIntNumInput( webPres.getZoom(), canvas );
+    QWhatsThis::add( zoom, i18n( "This selection allows you to specify "
+                                 "the size of the slide image." ) );
     layout->addWidget( zoom, 2, 1 );
     zoom->setSuffix( " %" );
     zoom->setRange( 25, 1000, 5 );
 
     encoding = new KComboBox( false, canvas );
     layout->addWidget( encoding, 3, 1 );
-    QStringList _strList = KGlobal::charsets()->availableEncodingNames();
-    encoding->insertStringList( _strList );
-    QString _name = webPres.getEncoding();
-    encoding->setCurrentItem( _strList.findIndex( _name.lower() ) );
+
+    // Fill encoding combo
+    // Stolen from kdelibs/kate/part/katedialogs.cpp
+    QStringList encodings(KGlobal::charsets()->descriptiveEncodingNames());
+    int idx = 0;
+    for (uint i = 0; i < encodings.count(); i++)
+    {
+      bool found = false;
+      QTextCodec *codecForEnc = KGlobal::charsets()->codecForName(KGlobal::charsets()->encodingForName(encodings[i]), found);
+      if (found)
+      {
+        encoding->insertItem(encodings[i]);
+
+        if ( codecForEnc->name() == webPres.getEncoding() )
+          encoding->setCurrentItem(idx);
+        idx++;
+      }
+    }
 
     doctype = new KComboBox( false, canvas );
     layout->addWidget( doctype, 4, 1 );
     doctype->insertItem( "HTML 4.01", -1 );
     doctype->insertItem( "XHTML 1.0", -1 );
 
+    doctype->setCurrentItem( webPres.isXML() ? 1 : 0 );
+
     QSpacerItem* spacer = new QSpacerItem( 1, 10,
                                            QSizePolicy::Minimum, QSizePolicy::Expanding );
     layout->addMultiCell( spacer, 5, 5, 0, 1 );
@@ -764,6 +837,10 @@ void KPWebPresentationWizard::setupPage2()
 void KPWebPresentationWizard::setupPage3()
 {
     page3 = new QHBox( this );
+    QWhatsThis::add( page3, i18n("This page allows you to specify the colors for "
+                                 "your presentation display. Select individual "
+                                 "items for more help on what they do.") );
+
     page3->setSpacing( KDialog::spacingHint() );
     page3->setMargin( KDialog::marginHint() );
 
@@ -818,6 +895,9 @@ void KPWebPresentationWizard::setupPage3()
 void KPWebPresentationWizard::setupPage4()
 {
     page4 = new QHBox( this );
+    QWhatsThis::add( page4, i18n("This page allows you to modify the titles of "
+                                 "each slide, if required. You normally do not need "
+                                 "to do this, but it is available if required.") );
     page4->setSpacing( KDialog::spacingHint() );
     page4->setMargin( KDialog::marginHint() );
 
@@ -854,7 +934,7 @@ void KPWebPresentationWizard::setupPage4()
 
     slideTitles = new KListView( canvas );
     layout->addMultiCellWidget( slideTitles, 2, 2, 0, 1 );
-    slideTitles->addColumn( i18n( "Slide No." ) );
+    slideTitles->addColumn( i18n( "No." ) );
     slideTitles->addColumn( i18n( "Slide Title" ) );
     connect( slideTitles, SIGNAL( selectionChanged( QListViewItem * ) ), this,
              SLOT( slideTitleChanged( QListViewItem * ) ) );
@@ -876,10 +956,88 @@ void KPWebPresentationWizard::setupPage4()
     addPage( page4, i18n( "Step 4: Customize Slide Titles" ) );
 
     setHelpEnabled(page4, false);  //doesn't do anything currently
-
-    setFinish( page4, true );
 }
 
+void KPWebPresentationWizard::setupPage5()
+{
+    page5 = new QHBox( this );
+    QWhatsThis::add( page5, i18n("This page allows you to specify some options for "
+                                 "presentations which run unattended, such as time "
+                                 "elapsed before advancing to the next slide, looping "
+                                 "and the presence of headers. If you do not want "
+                                 "an unattended presentation, just leave defaults unchanged.") );
+    page5->setSpacing( KDialog::spacingHint() );
+    page5->setMargin( KDialog::marginHint() );
+
+    QLabel* sidebar = new QLabel( page5 );
+    sidebar->setMinimumSize( 106, 318 );
+    sidebar->setMaximumSize( 106, 318 );
+    sidebar->setFrameShape( QFrame::Panel );
+    sidebar->setFrameShadow( QFrame::Sunken );
+    sidebar->setPixmap(locate("data", "kpresenter/pics/webslideshow-sidebar.png"));
+
+    QWidget* canvas = new QWidget( page5 );
+    QGridLayout *layout = new QGridLayout( canvas, 6, 2,
+                                           KDialog::marginHint(), KDialog::spacingHint() );
+
+    QLabel *helptext = new QLabel( canvas );
+    helptext->setAlignment( Qt::WordBreak | Qt::AlignVCenter| Qt::AlignLeft );
+    QString help = i18n("Here you can configure some options for unattended "
+                        "presentations, such as time elapsed before automatically advance to "
+                        "the next slide, looping and the presence of headers.");
+    helptext->setText(help);
+
+    layout->addMultiCellWidget( helptext, 0, 0, 0, 1 );
+
+    layout->addMultiCell( new QSpacerItem( 1, 50 ), 1, 1, 0, 1 );
+
+    QLabel *label1 = new QLabel( i18n("Advance after:"), canvas );
+    label1->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
+    QWhatsThis::add( label1, i18n( "This selection allows you to specify "
+                                   "the time between slides." ) );
+    layout->addWidget( label1, 2, 0 );
+
+    timeBetweenSlides = new KIntNumInput( webPres.getTimeBetweenSlides(), canvas );
+    timeBetweenSlides->setSpecialValueText(i18n( "Disabled" ));
+    QWhatsThis::add( timeBetweenSlides, i18n( "This selection allows you to specify "
+                                 "the time between slides." ) );
+    layout->addWidget( timeBetweenSlides, 2, 1 );
+    timeBetweenSlides->setSuffix( " seconds" );
+    timeBetweenSlides->setRange( 0, 900, 1 );
+
+    layout->addMultiCell( new QSpacerItem( 1, 10 ), 1, 1, 0, 1 );
+
+    writeHeader=new QCheckBox( i18n("Write header to the slides"), canvas);
+    QWhatsThis::add( writeHeader, i18n( "This checkbox allows you to specify if you "
+                                       "want to write the navigation buttons on top "
+                                       "of the slide." ) );
+    writeHeader->setChecked( webPres.wantHeader() );
+    layout->addWidget( writeHeader, 3, 1);
+
+    writeFooter=new QCheckBox( i18n("Write footer to the slides"), canvas);
+    QWhatsThis::add( writeFooter, i18n( "This checkbox allows you to specify if you "
+                                       "want to write an imprint consisting on the author "
+                                       "and the software used to create these slides." ) );
+    writeFooter->setChecked( webPres.wantFooter() );
+    layout->addWidget( writeFooter, 4, 1);
+
+    loopSlides=new QCheckBox( i18n("Loop presentation"), canvas);
+    QWhatsThis::add( loopSlides, i18n( "This checkbox allows you to specify if you "
+                                       "want the presentation to start again once "
+                                       "the latest slide is reached." ) );
+    loopSlides->setChecked( webPres.wantLoopSlides() );
+    layout->addWidget( loopSlides, 5, 1);
+
+    QSpacerItem* spacer = new QSpacerItem( 1, 10,
+                                           QSizePolicy::Minimum, QSizePolicy::Expanding );
+    layout->addMultiCell( spacer, 5, 5, 0, 1 );
+
+    addPage( page5, i18n( "Step 5: Options for Unattended Presentations" ) );
+
+    setHelpEnabled(page5, false);  //doesn't do anything currently
+
+    setFinish( page5, true );
+}
 
 void KPWebPresentationWizard::finish()
 {
@@ -896,8 +1054,17 @@ void KPWebPresentationWizard::finish()
     webPres.setTextColor( textColor->color() );
     webPres.setPath( path->lineEdit()->text() );
     webPres.setZoom( zoom->value() );
+    webPres.setTimeBetweenSlides( timeBetweenSlides->value() );
+    webPres.setWriteHeader( writeHeader->isChecked() );
+    webPres.setWriteFooter( writeFooter->isChecked() );
+    webPres.setLoopSlides( loopSlides->isChecked() );
     webPres.setXML( doctype->currentItem() != 0 );
-    webPres.setEncoding( encoding->currentText() );
+    bool found = false;
+    QTextCodec *codecForEnc = KGlobal::charsets()->codecForName(KGlobal::charsets()->encodingForName(encoding->currentText()), found);
+    if ( found )
+    {
+        webPres.setEncoding( codecForEnc->name() );
+    }
 
     close();
     KPWebPresentationCreateDialog::createWebPresentation( doc, view, webPres );
@@ -905,24 +1072,24 @@ void KPWebPresentationWizard::finish()
 
 void KPWebPresentationWizard::pageChanged()
 {
-    if ( currentPage() != page4 )
+    if ( currentPage() != page5 )
     {
         QString pathname = path->lineEdit()->text();
 
         // path doesn't exist. ask user if it should be created.
-        if ( !KIO::NetAccess::exists( pathname, true/*write*/ ) )
-	{
+        if ( !KIO::NetAccess::exists( pathname, true/*write*/,this ) )
+        {
             QString msg = i18n( "<qt>The directory <b>%1</b> does not exist.<br>"
                                 "Do you want create it?</qt>" );
             if( KMessageBox::questionYesNo( this, msg.arg( pathname ),
                                             i18n( "Directory Not Found" ) )
                 == KMessageBox::Yes)
             {
-                bool ok = KIO::NetAccess::mkdir( pathname );
+                bool ok = KIO::NetAccess::mkdir( pathname, this );
                 if( !ok )
                 {
                     KMessageBox::sorry( this,
-                                        i18n( "Can't create directory!" ) );
+                                        i18n( "Cannot create directory." ) );
                     // go back to first step
                     showPage( page1 );
                     path->setFocus();
@@ -936,7 +1103,6 @@ void KPWebPresentationWizard::pageChanged()
                 path->setFocus();
             }
         }
-
     } else
         finishButton()->setEnabled( true );
 }
@@ -1084,6 +1250,7 @@ void KPWebPresentationCreateDialog::setupGUI()
     step2 = new QLabel( i18n( "Create Pictures of the Slides" ), back );
     step3 = new QLabel( i18n( "Create HTML Pages for the Slides" ), back );
     step4 = new QLabel( i18n( "Create Main Page (Table of Contents)" ), back );
+    step5 = new QLabel( i18n( "Options for Unattended Presentations" ), back);
 
     line = new QFrame( back );
     line->setFrameStyle( QFrame::HLine | QFrame::Sunken );
@@ -1121,27 +1288,18 @@ void KPWebPresentationCreateDialog::saveConfig()
     else
         filename = QString::null;
 
-    KURL url = KFileDialog::getOpenURL( filename, i18n("*.kpweb|KPresenter Web-Presentation (*.kpweb)") );
+    KFileDialog fd (filename, i18n("*.kpweb|KPresenter Web-Presentation (*.kpweb)"),
+                    0/*parent*/, 0/*name*/, true/*modal*/);
+    fd.setCaption (i18n ("Save Web Presentation Configuration"));
+    fd.setOperationMode (KFileDialog::Saving);
+    fd.setMode (KFile::File | KFile::LocalOnly);
 
-    if( url.isEmpty() )
-        return;
-
-    // ### TODO: use KIO::NetAccess for remote files (floppy: is remote!)
-    if( !url.isLocalFile() )
+    if (fd.exec ())
     {
-        KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
-        return;
-    }
-
-    filename = url.path();
-
-    if ( !filename.isEmpty() ) {
-        if (filename.endsWith(".kpweb"))
-            webPres.setConfig( filename );
-        else
-            webPres.setConfig( filename + ".kpweb" );
+        webPres.setConfig( fd.selectedFile () );
         webPres.saveConfig();
     }
 }
 
+#include "kpgradient.h"
 #include "webpresentation.moc"
