@@ -74,7 +74,6 @@
 #include "kis_doc.h"
 #include "kis_factory.h"
 #include "kis_filter_registry.h"
-#include "kis_guide.h"
 #include "kis_gradient.h"
 #include "kis_image_magick_converter.h"
 #include "kis_imagepipe_brush.h"
@@ -97,6 +96,7 @@
 #include "strategy/kis_strategy_move.h"
 #include "kis_button_press_event.h"
 #include "kis_button_release_event.h"
+#include "kis_double_click_event.h"
 #include "kis_move_event.h"
 #include "kis_colorspace_registry.h"
 #include "kis_profile.h"
@@ -181,8 +181,6 @@ KisView::KisView(KisDoc *doc, KisUndoAdapter *adapter, QWidget *parent, const ch
 	m_pattern = 0;
 	m_gradient = 0;
 
-	m_currentGuide = 0;
-
 	m_progress = 0;
 	m_statusBarZoomLabel = 0;
 	m_statusBarSelectionLabel = 0;
@@ -218,8 +216,7 @@ KisView::~KisView()
 {
 	delete m_dcop;
 	delete m_dockerManager;
-
-
+	delete m_selectionManager;
 }
 
 DCOPObject* KisView::dcopObject()
@@ -396,15 +393,15 @@ void KisView::setupActions()
 	m_zoomOut = KStdAction::zoomOut(this, SLOT(slotZoomOut()), actionCollection(), "zoom_out");
 
 	// layer actions
-	m_layerAdd = new KAction(i18n("&Add Layer..."), "newlayer", 0, this, SLOT(layerAdd()), actionCollection(), "insert_layer");
+	m_layerAdd = new KAction(i18n("&Add Layer..."), "newlayer", "Ctrl+Shift+N", this, SLOT(layerAdd()), actionCollection(), "insert_layer");
 	m_layerRm = new KAction(i18n("&Remove Layer"), "deletelayer", 0, this, SLOT(layerRemove()), actionCollection(), "remove_layer");
 	m_layerDup = new KAction(i18n("Duplicate Layer"), 0, this, SLOT(layerDuplicate()), actionCollection(), "duplicate_layer");
 	m_layerLink = new KAction(i18n("&Link/Unlink Layer"), 0, this, SLOT(layerToggleLinked()), actionCollection(), "link_layer");
 	m_layerHide = new KAction(i18n("&Hide/Show Layer"), 0, this, SLOT(layerToggleVisible()), actionCollection(), "hide_layer");
-	m_layerRaise = new KAction(i18n("Raise Layer"), "raiselayer", 0, this, SLOT(layerRaise()), actionCollection(), "raiselayer");
-	m_layerLower = new KAction(i18n("Lower Layer"), "lowerlayer", 0, this, SLOT(layerLower()), actionCollection(), "lowerlayer");
-	m_layerTop = new KAction(i18n("Layer to Top"), 0, this, SLOT(layerFront()), actionCollection(), "toplayer");
-	m_layerBottom = new KAction(i18n("Layer to Bottom"), 0, this, SLOT(layerBack()), actionCollection(), "bottomlayer");
+	m_layerRaise = new KAction(i18n("Raise Layer"), "raiselayer", "Ctrl+]", this, SLOT(layerRaise()), actionCollection(), "raiselayer");
+	m_layerLower = new KAction(i18n("Lower Layer"), "lowerlayer", "Ctrl+[", this, SLOT(layerLower()), actionCollection(), "lowerlayer");
+	m_layerTop = new KAction(i18n("Layer to Top"), "Ctrl+Shift+]", this, SLOT(layerFront()), actionCollection(), "toplayer");
+	m_layerBottom = new KAction(i18n("Layer to Bottom"), "Ctrl+Shift+[", this, SLOT(layerBack()), actionCollection(), "bottomlayer");
 	m_layerProperties = new KAction(i18n("Layer Properties"), 0, this, SLOT(layerProperties()), actionCollection(), "layer_properties");
 	(void)new KAction(i18n("I&nsert Image as Layer..."), 0, this, SLOT(slotInsertImageAsLayer()), actionCollection(), "insert_image_as_layer");
 	m_layerSaveAs = new KAction(i18n("Save Layer as Image..."), 0, this, SLOT(saveLayerAsImage()), actionCollection(), "save_layer_as_image");
@@ -418,9 +415,9 @@ void KisView::setupActions()
 
 	// image actions
 	m_imgFlatten = new KAction(i18n("Flatten Image"), 0, this, SLOT(flattenImage()), actionCollection(), "flatten_image");
-	m_imgMergeVisible = new KAction(i18n("Merge &Visible Layers"), 0, this, SLOT(mergeVisibleLayers()), actionCollection(), "merge_visible_layers");
+	m_imgMergeVisible = new KAction(i18n("Merge &Visible Layers"), "Ctrl+Shift+E", this, SLOT(mergeVisibleLayers()), actionCollection(), "merge_visible_layers");
 	m_imgMergeLinked = new KAction(i18n("Merge &Linked Layers"), 0, this, SLOT(mergeLinkedLayers()), actionCollection(), "merge_linked_layers");
-	m_imgMergeLayer = new KAction(i18n("&Merge Layer"), 0, this, SLOT(mergeLayer()), actionCollection(), "merge_layer");
+	m_imgMergeLayer = new KAction(i18n("&Merge Layer"), "Ctrl+E", this, SLOT(mergeLayer()), actionCollection(), "merge_layer");
 
 	// setting actions
 	KStdAction::preferences(this, SLOT(preferences()), actionCollection(), "preferences");
@@ -439,11 +436,6 @@ void KisView::resizeEvent(QResizeEvent *)
 	Q_INT32 docW;
 	Q_INT32 docH;
 
-	if (img) {
-		KisGuideMgr *mgr = img -> guides();
-		mgr -> resize(size());
-	}
-
 	docW = static_cast<Q_INT32>(ceil(docWidth() * zoom()));
 	docH = static_cast<Q_INT32>(ceil(docHeight() * zoom()));
 
@@ -718,7 +710,8 @@ void KisView::paintView(const KisRect& r)
 
 				for (unsigned int i = 0; i < rects.count(); i++) {
 					QRect er = rects[i];
-					gc.fillRect(er, backgroundColor());
+					if (er.isValid())
+						gc.fillRect(er, backgroundColor());
 				}
 
 				wr &= QRect(0, 0, img -> width(), img -> height());
@@ -736,7 +729,7 @@ void KisView::paintView(const KisRect& r)
 				m_doc -> setCurrentImage(0);
 			}
 
-			paintGuides();
+
 			m_canvas -> update(vr.qRect());
 		}
 	} else {
@@ -1621,39 +1614,6 @@ void KisView::canvasGotButtonPressEvent(KisButtonPressEvent *e)
 		}
 	}
 
-	KisImageSP img = currentImg();
-
-	if (img) {
-		QPoint pt = mapToScreen(e -> pos().floorQPoint());
-		KisGuideMgr *mgr = img -> guides();
-
-		m_lastGuidePoint = mapToScreen(e -> pos().floorQPoint());
-		m_currentGuide = 0;
-
-		if ((e -> state() & ~Qt::ShiftButton) == Qt::NoButton) {
-			KisGuideSP gd = mgr -> find(static_cast<Q_INT32>(pt.x() / zoom()), static_cast<Q_INT32>(pt.y() / zoom()), QMAX(2.0, 2.0 / zoom()));
-
-			if (gd) {
-				m_currentGuide = gd;
-
-				if ((e -> button() == Qt::RightButton) || ((e -> button() & Qt::ShiftButton) == Qt::ShiftButton)) {
-					if (gd -> isSelected())
-						mgr -> unselect(gd);
-					else
-						mgr -> select(gd);
-				} else {
-					if (!gd -> isSelected()) {
-						mgr -> unselectAll();
-						mgr -> select(gd);
-					}
-				}
-
-				updateGuides();
-				return;
-			}
-		}
-	}
-
 	if (e -> device() == currentInputDevice() && currentTool()) {
 		KisPoint p = viewToWindow(e -> pos());
 		KisButtonPressEvent ev(e -> device(), p, e -> globalPos(), e -> pressure(), e -> xTilt(), e -> yTilt(), e -> button(), e -> state());
@@ -1688,30 +1648,12 @@ void KisView::canvasGotMoveEvent(KisMoveEvent *e)
 
 	KisPoint wp = viewToWindow(e -> pos());
 
-	if (img && m_currentGuide) {
-		QPoint p = mapToScreen(e -> pos().floorQPoint());
-		KisGuideMgr *mgr = img -> guides();
-
-		if (((e -> state() & Qt::LeftButton) == Qt::LeftButton) && mgr -> hasSelected()) {
-			eraseGuides();
-			p -= m_lastGuidePoint;
-
-			if (p.x())
-				mgr -> moveSelectedByX(p.x() / zoom());
-
-			if (p.y())
-				mgr -> moveSelectedByY(p.y() / zoom());
-
-			m_doc -> setModified(true);
-			paintGuides();
-		}
-	} else if (e -> device() == currentInputDevice() && currentTool()) {
+	if (e -> device() == currentInputDevice() && currentTool()) {
 		KisMoveEvent ev(e -> device(), wp, e -> globalPos(), e -> pressure(), e -> xTilt(), e -> yTilt(), e -> state());
 
 		currentTool() -> move(&ev);
 	}
 
-	m_lastGuidePoint = mapToScreen(e -> pos().floorQPoint());
 	emit cursorPosition(wp.floorX(), wp.floorY());
 }
 
@@ -1734,11 +1676,7 @@ void KisView::canvasGotButtonReleaseEvent(KisButtonReleaseEvent *e)
 		}
 	}
 
-	KisImageSP img = currentImg();
-
-	if (img && m_currentGuide) {
-		m_currentGuide = 0;
-	} else if (e -> device() == currentInputDevice() && currentTool()) {
+	if (e -> device() == currentInputDevice() && currentTool()) {
 		KisPoint p = viewToWindow(e -> pos());
 		KisButtonReleaseEvent ev(e -> device(), p, e -> globalPos(), e -> pressure(), e -> xTilt(), e -> yTilt(), e -> button(), e -> state());
 
@@ -1748,6 +1686,35 @@ void KisView::canvasGotButtonReleaseEvent(KisButtonReleaseEvent *e)
 	}
 }
 
+void KisView::canvasGotDoubleClickEvent(KisDoubleClickEvent *e)
+{
+#if defined(EXTENDED_X11_TABLET_SUPPORT)
+	// The event filter doesn't see tablet events going to the canvas.
+	if (e -> device() != INPUT_DEVICE_MOUSE) {
+		m_tabletEventTimer.start();
+	}
+#endif // EXTENDED_X11_TABLET_SUPPORT
+
+	if (e -> device() != currentInputDevice()) {
+		if (e -> device() == INPUT_DEVICE_MOUSE) {
+			if (m_tabletEventTimer.elapsed() > MOUSE_CHANGE_EVENT_DELAY) {
+				setInputDevice(INPUT_DEVICE_MOUSE);
+			}
+		} else {
+			setInputDevice(e -> device());
+		}
+	}
+
+	if (e -> device() == currentInputDevice() && currentTool()) {
+		KisPoint p = viewToWindow(e -> pos());
+		KisDoubleClickEvent ev(e -> device(), p, e -> globalPos(), e -> pressure(), e -> xTilt(), e -> yTilt(), e -> button(), e -> state());
+
+		if (currentTool()) {
+			currentTool() -> doubleClick(&ev);
+		}
+	}
+}
+
 void KisView::canvasGotEnterEvent(QEvent *e)
 {
 	if (currentTool())
@@ -2197,6 +2164,7 @@ void KisView::setupCanvas()
 
 	QObject::connect(m_canvas, SIGNAL(gotButtonPressEvent(KisButtonPressEvent*)), this, SLOT(canvasGotButtonPressEvent(KisButtonPressEvent*)));
 	QObject::connect(m_canvas, SIGNAL(gotButtonReleaseEvent(KisButtonReleaseEvent*)), this, SLOT(canvasGotButtonReleaseEvent(KisButtonReleaseEvent*)));
+	QObject::connect(m_canvas, SIGNAL(gotDoubleClickEvent(KisDoubleClickEvent*)), this, SLOT(canvasGotDoubleClickEvent(KisDoubleClickEvent*)));
 	QObject::connect(m_canvas, SIGNAL(gotMoveEvent(KisMoveEvent*)), this, SLOT(canvasGotMoveEvent(KisMoveEvent*)));
 	QObject::connect(m_canvas, SIGNAL(gotPaintEvent(QPaintEvent*)), this, SLOT(canvasGotPaintEvent(QPaintEvent*)));
 	QObject::connect(m_canvas, SIGNAL(gotEnterEvent(QEvent*)), this, SLOT(canvasGotEnterEvent(QEvent*)));
@@ -2500,93 +2468,9 @@ bool KisView::eventFilter(QObject *o, QEvent *e)
 		break;
 	}
 
-	if ((o == m_hRuler || o == m_vRuler) && (e -> type() == QEvent::MouseMove || e -> type() == QEvent::MouseButtonRelease)) {
-		QMouseEvent *me = dynamic_cast<QMouseEvent*>(e);
-		QPoint pt = mapFromGlobal(me -> globalPos());
-		KisImageSP img = currentImg();
-		KisGuideMgr *mgr;
-
-		if (!img)
-			return super::eventFilter(o, e);
-
-		mgr = img -> guides();
-
-		if (e -> type() == QEvent::MouseMove && (me -> state() & Qt::LeftButton)) {
-			bool flag = geometry().contains(pt);
-			KisGuideSP gd;
-
-			if (m_currentGuide == 0 && flag) {
-				// No guide is being edited and moving mouse over the canvas.
-				// Create a new guide.
-				enterEvent(0);
-				eraseGuides();
-				mgr -> unselectAll();
-
-				if (o == m_vRuler)
-					gd = mgr -> add((pt.x() - m_vRuler -> width() + horzValue()) / zoom(), Qt::Vertical);
-				else
-					gd = mgr -> add((pt.y() - m_hRuler -> height() + vertValue()) / zoom(), Qt::Horizontal);
-
-				m_currentGuide = gd;
-				mgr -> select(gd);
-				m_lastGuidePoint = mapToScreen(pt);
-			} else if (m_currentGuide) {
-				if (flag) {
-					// moved an existing guide.
-					KisMoveEvent kme(currentInputDevice(), pt, me -> globalPos(), PRESSURE_DEFAULT, 0, 0, me -> state());
-					canvasGotMoveEvent(&kme);
-				} else {
-					//  moved a guide out of the frame, destroy it
-					leaveEvent(0);
-					eraseGuides();
-					mgr -> remove(m_currentGuide);
-					paintGuides();
-					m_currentGuide = 0;
-				}
-			}
-		} else if (e -> type() == QEvent::MouseButtonRelease && m_currentGuide) {
-			eraseGuides();
-			mgr -> unselect(m_currentGuide);
-			paintGuides();
-			m_currentGuide = 0;
-			enterEvent(0);
-			KisMoveEvent kme(currentInputDevice(), pt, me -> globalPos(), PRESSURE_DEFAULT, 0, 0, Qt::NoButton);
-			canvasGotMoveEvent(&kme);
-		}
-	}
-
 	return super::eventFilter(o, e);
 }
 
-void KisView::eraseGuides()
-{
-	KisImageSP img = currentImg();
-
-	if (img) {
-		KisGuideMgr *mgr = img -> guides();
-
-		if (mgr)
-			mgr -> erase(&m_canvasPixmap, this, horzValue(), vertValue(), zoom());
-	}
-}
-
-void KisView::paintGuides()
-{
-	KisImageSP img = currentImg();
-
-	if (img) {
-		KisGuideMgr *mgr = img -> guides();
-
-		if (mgr)
-			mgr -> paint(&m_canvasPixmap, this, horzValue(), vertValue(), zoom());
-	}
-}
-
-void KisView::updateGuides()
-{
-	eraseGuides();
-	paintGuides();
-}
 
 QPoint KisView::mapToScreen(const QPoint& pt)
 {
