@@ -1,3 +1,27 @@
+/* This file is part of the KDE project
+   
+   
+   Copyright 2002-2003 Joseph Wenninger <jowenn@kde.org>
+   Copyright 2002 John Dailey <dailey@vt.edu>
+   Copyright 2001-2002 Laurent Montel <montel@kde.org>
+   Copyright 2000 Simon Hausmann <hausmann@kde.org>
+   Copyright 1999 Torben Weis <weis@kde.org>
+
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #ifndef KSPREAD_VIEW_IFACE_H
 #define KSPREAD_VIEW_IFACE_H
@@ -21,7 +45,7 @@ public:
 k_dcop:
     virtual DCOPRef doc() const;
     virtual DCOPRef map() const;
-    virtual DCOPRef table() const;
+    virtual DCOPRef sheet() const;
 
     virtual void changeNbOfRecentFiles(int _nb);
 
@@ -39,9 +63,9 @@ k_dcop:
     virtual void gotoCell();
     virtual void changeAngle();
     virtual void preference();
-    virtual void nextTable();
-    virtual void previousTable();
-    virtual bool showTable(QString tableName);
+    virtual void nextSheet();
+    virtual void previousSheet();
+    virtual bool showSheet(QString sheetName);
     virtual void sortList();
     virtual void setAreaName();
     virtual void showAreaName();
