@@ -1,5 +1,19 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
+
+   Copyright 2004 Tomas Mecir <mecirt@gmail.com>
+   Copyright 1999-2002,2004 Laurent Montel <montel@kde.org>
+   Copyright 2002,2004 Ariya Hidayat <ariya@kde.org>
+   Copyright 2002-2003 Norbert Andres <nandres@web.de>
+   Copyright 2003 Stefan Hetzl <shetzl@chello.at>
+   Copyright 2001-2002 Philipp Mueller <philipp.mueller@gmx.de>
+   Copyright 2002 Harri Porten <porten@kde.org>
+   Copyright 2002 John Dailey <dailey@vt.edu>
+   Copyright 1999-2001 David Faure <faure@kde.org>
+   Copyright 2000-2001 Werner Trobin <trobin@kde.org>
+   Copyright 2000 Simon Hausmann <hausmann@kde.org
+   Copyright 1998-1999 Torben Weis <weis@kde.org>
+   Copyright 1999 Michael Reiher <michael.reiher.gmx.de>
+   Copyright 1999 Reginald Stadlbauer <reggie@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,122 +31,187 @@
    Boston, MA 02111-1307, USA.
 */
 
-#ifndef __kspread_cell_h__
-#define __kspread_cell_h__
+#ifndef KSPREAD_CELL
+#define KSPREAD_CELL
 
 class KSpreadCell;
-class KSpreadTable;
+class KSpreadSheet;
 class KSpreadCanvas;
 class KSpreadView;
 
-class QSimpleRichText;
+class KLocale;
 class QDomElement;
 class QDomDocument;
-
+class KoXmlWriter;
+class KoGenStyles;
+class KoGenStyle;
 class KSParseNode;
+class KSpreadGenValidationStyles;
 
 
 #include <qpainter.h>
 #include <qptrlist.h>
-#include <qstrlist.h>
 #include <qdatetime.h>
 
-#include "kspread_layout.h"
+#include "kspread_format.h"
 #include "kspread_global.h"
-#include "kspread_depend.h"
 #include "kspread_condition.h"
+#include "kspread_value.h"
 
+#include <koOasisStyles.h>
+#include <koRect.h>
 struct KSpreadValidity
 {
- QString message;
- QString title;
- double valMin;
- double valMax;
- Conditional m_cond;
- Action m_action;
- Allow m_allow;
- QTime  timeMin;
- QTime  timeMax;
- QDate  dateMin;
- QDate  dateMax;
+    KSpreadValidity()
+	{
+	    valMin = 0.0;
+	    valMax = 0.0;
+	    m_cond = None;
+	    m_action = Stop;
+	    m_allow = Allow_All;
+	    displayMessage = true;
+	    allowEmptyCell = false;
+            displayValidationInformation = false;
+	};
+    QString message;
+    QString title;
+    QString titleInfo;
+    QString messageInfo;
+    double valMin;
+    double valMax;
+    Conditional m_cond;
+    Action m_action;
+    Allow m_allow;
+    QTime  timeMin;
+    QTime  timeMax;
+    QDate  dateMin;
+    QDate  dateMax;
+    bool displayMessage;
+    bool allowEmptyCell;
+    bool displayValidationInformation;
+    QStringList listValidity;
 };
 
+class CellPrivate;
 
-class KSpreadCellPrivate : public QObject
-{
-    Q_OBJECT
-public:
-    KSpreadCellPrivate( KSpreadCell* _cell ) { m_pCell = _cell; }
-    virtual ~KSpreadCellPrivate() { }
-
-    /**
-     * Used in @ref KSpreadCell::copyAll to make a copy
-     * of some cell.
-     */
-    virtual KSpreadCellPrivate* copy( KSpreadCell* cell ) = 0;
-
-protected:
-    KSpreadCell* m_pCell;
-};
-
-class SelectPrivate : public KSpreadCellPrivate
-{
-    Q_OBJECT
-public:
-    SelectPrivate( KSpreadCell* _cell ) : KSpreadCellPrivate( _cell ) { m_iIndex = -1; }
-    virtual ~SelectPrivate() { }
-
-    KSpreadCellPrivate* copy( KSpreadCell* cell );
-
-    QString text() const;
-
-    void parse( const QString& _text );
-
-    QStringList m_lstItems;
-    int m_iIndex;
-
-public slots:
-    void slotItemSelected( int _id );
-};
 
 /**
  * For every cell in the spread sheet there is a KSpreadCell object.
  *
- * KSpreadCell contains layout information and algorithm and it
+ * KSpreadCell contains format information and algorithm and it
  * contains the calculation algorithm.
  *
  * However, all empty cells are represented by one instace, called the
  * default cell. @ref #isDefault tells wether a cell is the default one
  * or not.
  */
-class KSpreadCell : public KSpreadLayout
+class KSPREAD_EXPORT KSpreadCell : public KSpreadFormat
 {
   friend class SelectPrivate;
   friend class KSpreadConditions;
 public:
-    /** The type of content in the cell */
-    enum Content { Text, RichText, Formula, VisualFormula };
-    /**
-     * The type of data in the cell, for Content == Text or Formula.
-     * RichText always is StringData, and VisualFormula is OtherData
-     * If you edit this, keep s_dataTypeToString uptodate.
-     */
-    enum DataType { StringData = 0, BoolData, NumericData, DateData, TimeData,
-                    OtherData, // see docu
-                    LastDataType = OtherData };
-    /** */
-    enum Style { ST_Normal, ST_Button, ST_Undef, ST_Select };
 
-    KSpreadCell( KSpreadTable *_table, int _column, int _row );
+  KSpreadCell (KSpreadSheet *_sheet, int _column, int _row);
+  KSpreadCell (KSpreadSheet *_sheet, KSpreadStyle * _style, int _column, int _row);
+
     /**
-     * @see #tableDies
+     * @see #sheetDies
      */
     ~KSpreadCell();
 
-    KSpreadCell* previousCell()const { return m_previousCell; }
-    KSpreadCell* nextCell()const { return m_nextCell; }
-    void setPreviousCell( KSpreadCell* c ) { m_previousCell = c; }
-    void setNextCell( KSpreadCell* c ) { m_nextCell = c; }
+    /**
+     * Returns the worksheet which owns this cell.
+     */
+    KSpreadSheet* sheet() const;
+
+    /**
+     * Returns true if this is a default cell (with row and column equal to zero).
+     * Normally, cell constructed within a sheet can't be a default cell.
+     */
+    bool isDefault() const;
+
+    /**
+     * Returns true if this cell has no content, i.e no text and no formula.
+     */
+    bool isEmpty() const;
+
+    /**
+     * Returns the cell's column. This could be 0 if the cell is the default cell.
+     */
+    int column() const;
+
+    /**
+     * Returns the cell's row. This could be 0 if the cell is the default cell.
+     */
+    int row() const;
+
+    /**
+     * Returns the name of the cell. For example, the cell in first column and
+     * first row is "A1".
+     */
+    QString name() const;
+
+    /**
+     * Returns the full name of the cell, i.e. including the worksheet name.
+     * Example: "Sheet1!A1"
+     */
+    QString fullName() const;
+
+    /**
+     * Returns the column name of the cell.
+     */
+    QString columnName() const;
+
+    /**
+     * Given the cell position, this static function returns the name of the cell.
+     * Example: name(5,4) will return "E4".
+     */
+    static QString name( int col, int row );
+
+    /**
+     * Given the sheet and cell position, this static function returns the full name
+     * of the cell, i.e. with the name of the sheet.
+     */
+    static QString fullName( const KSpreadSheet *s, int col, int row );
+
+    /**
+     * Given the column number, this static function returns the corresponding
+     * column name, i.e. the first column is "A", the second is "B", and so on.
+     */
+    static QString columnName( uint column );
+
+    /**
+     * Returns the locale setting of this cell.
+     */
+    KLocale* locale();
+    /**
+     * Returns true if this cell holds a formula.
+     */
+    bool isFormula() const;
+
+    /**
+     * Return the text the user entered. This could be a value (e.g. "14.03")
+     * or a formula (e.g. "=SUM(A1:A10)")
+     */
+    QString text() const;
+
+    QString strOutText() const;
+
+    /**
+     * Returns the value that this cell holds. It could be from the user
+     * (i.e. when s/he enters a value) or a result of formula.
+     */
+    const KSpreadValue value() const;
+
+    /**
+     * Sets the value for this cell.
+     */
+    void setValue( const KSpreadValue& value );
+
+    KSpreadCell* previousCell() const;
+    KSpreadCell* nextCell() const;
+    void setPreviousCell( KSpreadCell* c );
+    void setNextCell( KSpreadCell* c );
 
     /**
      * Moves around the cell. It cares about obscured and obscuring cells and
@@ -141,51 +220,62 @@ public:
     void move( int column, int row );
 
     /**
-     * The @ref KSpreadTable calls this method if the table becomes deleted.
+     * The @ref KSpreadSheet calls this method if the sheet becomes deleted.
      * At the time this method is called other cells may already be deleted or
      * in some inconsistent state.
      *
      * The purpose of this method is to clear up some variables so that the destructor
      * runs without any crash. Especially all variables referencing other cells
-     * must be voided. This method may not call any other method since the whole table
+     * must be voided. This method may not call any other method since the whole sheet
      * and all remaining cells are in an inconsistent state now.
      */
-    void tableDies();
+    void sheetDies();
 
     /**
      * Save this cell.
      * @param _x_offset ...
      * @param _y_offset ...
-     * @param force if set to true, all the properties of the layout are stored (used for "Copy")
-     * Usually this is false, to only store the properties explicitely set.
+     * @param force if set to true, all the properties of the format are stored (used for "Copy")
+     * @param era set this to true if you want to encode relative references as absolutely (they will be switched
+     *            back to relative references during decoding) - is used for cutting to clipboard
+     * Usually this is false, to only store the properties explicitly set.
      */
-    QDomElement save( QDomDocument& doc, int _x_offset = 0, int _y_offset = 0, bool force = false );
+    QDomElement save( QDomDocument& doc, int _x_offset = 0, int _y_offset = 0, bool force = false, bool copy = false, bool era = false );
+
+    virtual bool saveOasis( KoXmlWriter& xmlwriter , KoGenStyles &mainStyles, int row, int column, int maxCol, int &repeated, KSpreadGenValidationStyles &valStyle );
+
+    void saveOasisValue (KoXmlWriter &xmlWriter);
+
+    QString saveOasisCellStyle( KoGenStyle &currentCellStyle,KoGenStyles &mainStyles, bool force = false, bool copy = false );
 
     bool load( const QDomElement& cell, int _xshift, int _yshift, PasteMode pm = Normal,
-	       Operation op = OverWrite );
+	       Operation op = OverWrite, bool paste = false );
+
+    bool loadOasis( const QDomElement & element, const KoOasisStyles &oasisStyles );
+    void loadOasisValidation( const QString& validationName );
 
     QTime toTime(const QDomElement &element) ;
     QDate toDate(const QDomElement &element);
 
     /**
-     * Copyies the layout from the cell at the position (_column|_row).
+     * Copyies the format from the cell at the position (_column|_row).
      *
      * @see #copyAll
      */
-    void copyLayout( int _column, int _row );
+    void copyFormat( int _column, int _row );
     /**
      * A convenience function.
      *
      * @see #copyAll
      */
-    void copyLayout( KSpreadCell *_cell );
+    void copyFormat( KSpreadCell *_cell );
     void copyContent( KSpreadCell *_cell );
     /**
-     * Copies the layout and the content. It does not copy the @ref #m_row and @ref #m_column attributes.
+     * Copies the format and the content. It does not copy the @ref #m_row and @ref #m_column attributes.
      * Besides that all persistent attributes are copied. @ref #setCellText is called to set the real
      * content.
      *
-     * @see #copyLayout
+     * @see #copyFormat
      */
     void copyAll( KSpreadCell *cell);
 
@@ -199,20 +289,22 @@ public:
      * @param coordinates coordinates on the painter where the top left corner
      *                    of the cell should be painted plus width and height
      * @param cellRef the column/row coordinates of the cell.
+     * @param paintBorderRight whether to draw the right border too.
+     * @param paintBorderBottom whether to draw the bottom border too.
      * @param drawCursor whether to draw the cursor and selection or not
      */
-    void paintCell( const QRect& rect, QPainter &painter,
-		    KSpreadView* view, const QPair<double, double> &coordinate,
-		    const QPoint &cellRef, bool drawCursor=true );
-
-  /**
-     * @return the column this cell is in. May return 0 if the cell is the default cell.
-     */
-    int column() const;
-    /**
-     * @return the row this cell is in. May return 0 if the cell is the default cell.
-     */
-    int row() const;
+    void paintCell( const KoRect & rect, QPainter & painter,
+                    KSpreadView * view, const KoPoint & coordinate,
+                    const QPoint & cellRef,
+                    bool paintBorderRight,
+                    bool paintBorderBottom,
+                    bool paintBorderLeft,
+                    bool paintBorderTop,
+                    QPen & rightPen,
+                    QPen & bottomPen,
+                    QPen & leftPen,
+                    QPen & topPen,
+                    bool drawCursor = true );
 
     /**
      * @param _col the column this cell is assumed to be in.
@@ -245,48 +337,19 @@ public:
     double dblHeight( int _row = -1, const KSpreadCanvas *_canvas = 0L ) const;
 
     /**
-     * @reimp
+     * @return a QRect for this cell (i.e., a 1x1 rect)
      */
-    bool isDefault() const;
-
-    /**
-     * Tells whether this cell has any content.
-     * An cell has no content if is has no text and no formula.
-     *
-     * @return TRUE if there is no content.
-     */
-    bool isEmpty() const;
+    QRect cellRect();
 
     /**
      * @return TRUE if the cell should be printed in a print out.
      *         That si the case if it has any content, border, backgroundcolor,
      *         or background brush.
      *
-     * @see KSpreadTable::print
+     * @see KSpreadSheet::print
      */
     bool needsPrinting() const;
 
-    /**
-     * Tells what is the content of the cell (its nature).
-     * Text, formula, richtext, or visual formula.
-     * Set by @ref setDisplayText().
-     */
-    Content content() const { return m_content; }
-
-    /**
-     * Tells what is the type of data in the cell:
-     * string, numeric, date, time etc.
-     * Set by @ref checkTextInput(), and by @ref load().
-     */
-    DataType dataType() const { return m_dataType; }
-
-    /**
-     * Tells what is the type of data in the cell:
-     * string, numeric, date, time etc.
-     * Set by @ref checkTextInput(), and by @ref load().
-     */
-    void setDataType(DataType const & d) { m_dataType = d; }
-
     /**
      * Increases the precison of the
      * value displayed. Precision means here the amount of
@@ -307,32 +370,49 @@ public:
     /**
      * The high-level method for setting text, when the user inputs it.
      * It will revert back to the old text if testValidity() returns action==stop.
-     * @param updateDepends whether to recalculate the dependent cells (always true nowadays)
      */
-    void setCellText( const QString& _text, bool updateDepends = true );
+    void setCellText( const QString& _text, bool asString = false );
 
     /**
      * Sets the text in the cell when the user inputs it.
      * Will determine the type of contents automatically.
      * Called by setCellText.
      */
-    void setDisplayText( const QString& _text, bool updateDepends = true );
+    void setDisplayText( const QString& _text );
 
     /**
-     * @return the text the user entered.
+     * Sets a link for this cell. For example, setLink( "mailto:joe@somewhere.com" )
+     * will open a new e-mail if this cell is clicked.
+     * Possible choices for link are URL (web, ftp), e-mail address, local file,
+     * or another cell.
      */
-    QString text() const { return m_strText; }
+    void setLink( const QString& link );
 
-    QString strOutText() const {return m_strOutText;}
-
-    void setAction( const QString& _action ) { m_strAction = _action; }
+    /**
+     * Returns the link associated with cell. It is empty if this cell
+     * contains no link.
+     */
+    QString link() const;
 
     ////////////////////////////////
     //
-    // Methods for querying layout stuff.
+    // Methods for querying format stuff.
     //
     ////////////////////////////////
 
+    const QPen & effLeftBorderPen( int col, int row ) const;
+    const QPen & effTopBorderPen( int col, int row ) const;
+    const QPen & effRightBorderPen( int col, int row ) const;
+    const QPen & effBottomBorderPen( int col, int row ) const;
+    const QPen & effGoUpDiagonalPen( int col, int row ) const;
+    const QPen & effFallDiagonalPen( int col, int row ) const;
+    const QColor & effTextColor( int col, int row ) const;
+
+    uint effBottomBorderValue( int col, int row ) const;
+    uint effRightBorderValue( int col, int row ) const;
+    uint effLeftBorderValue( int col, int row ) const;
+    uint effTopBorderValue( int col, int row ) const;
+
     /**
      * @reimp
      */
@@ -365,7 +445,7 @@ public:
 
     ////////////////////////////////
     //
-    // Methods for setting layout stuff.
+    // Methods for setting format stuff.
     //
     ////////////////////////////////
 
@@ -389,67 +469,45 @@ public:
      */
     void setBottomBorderPen( const QPen& p );
 
+    /**
+     * @reimp
+     */
+    virtual void setCurrency( int type, QString const & symbol );
+
     //////////////////////
     //
     // Other stuff
     //
     //////////////////////
 
-    /**
-     * @see #setStyle
-     * @see #m_style
-     */
-    Style style() const { return m_style; }
-
-    void setStyle( Style _s );
-    /**
-     * @see #setAction
-     * @see #m_strAction
-     */
-    QString action() const { return m_strAction; }
-
     /**
      * Return the format of this cell.
-     * Convenience method for KSpreadLayout::getFormatType
+     * Convenience method for KSpreadFormat::getFormatType
      * Note that this is "how the user would like the data to be displayed if possible".
      * If he selects a date format, and the cell contains a string, we won't apply that format.
      */
-    FormatType formatType() const { return getFormatType( m_iColumn, m_iRow ); }
+    FormatType formatType() const;
 
-    bool isString() const { return m_dataType == StringData; }
-    bool isNumeric() const { return m_dataType == NumericData; }
-    bool isBool() const { return m_dataType == BoolData; }
-    bool isDate() const { return m_dataType == DateData; }
-    bool isTime() const { return m_dataType == TimeData; }
+    bool isDate() const;
+    bool isTime() const;
 
-    bool valueBool() const { return ( m_dValue != 0.0 ); }
-    double valueDouble() const { return m_dValue; }
-    QString valueString() const;
-    QDate valueDate() const { return m_Date; }
-    QTime valueTime() const { return m_Time; }
+    void setNumber( double number );
 
-    void setValue( double _d );
+    /** return the cell's value as a double */
+    double getDouble ();
+
+    void convertToDouble ();
+    void convertToPercent ();
+    void convertToMoney ();
+    void convertToTime ();
+    void convertToDate ();
 
     /**
      * return size of the text
      */
-    int textWidth()const {return m_iOutTextWidth; }
-    int textHeight()const {return m_iOutTextHeight; }
+    double textWidth() const;
+    double textHeight() const;
 
-    /**
-     * Like @ref updateDepending, but the cells content will be refreshed
-     * on all views.
-     */
-    void update();
-    /**
-     * If the contents of this cell changed, then this function has
-     * to be called so that all depending cells/charts etc.
-     * become updated. This does even work if the cell was already
-     * removed from the table.
-     *
-     * The cells content is not redisplayed and no flag of this cell is altered.
-     */
-    void updateDepending();
 
     /**
     * Refreshing chart
@@ -484,34 +542,23 @@ public:
 
     bool calcDirtyFlag();
 
-    /**
-     * Test to see if this cell depends on the given cell
-     *
-     * @param table table of the cell we're curious about
-     * @param col column of the cell we're curious about
-     * @param row row of the cell we're curious about
-     *
-     * @return TRUE if this cell depends on the given cell
-     */
-    bool cellDependsOn(KSpreadTable *table, int col, int row);
-
     /**
      * Notify this cell that another cell is depending, or no longer depending on this cell's value
      *
      * @param col the column of the cell
      * @param row the row of the cell
-     * @param table the table that the cell is on
+     * @param sheet the sheet that the cell is on
      * @param isDepending true if the cell is now depending on this one, false if it is not any longer
      *                    depending on it.
      */
-    void NotifyDepending( int col, int row, KSpreadTable* table, bool isDepending );
+    void NotifyDepending( int col, int row, KSpreadSheet* sheet, bool isDepending );
 
     /**
-     * Causes the layout to be recalculated when the cell is drawn next time.
+     * Causes the format to be recalculated when the cell is drawn next time.
      * This flag is for example set if the width of the column changes or if
-     * some cell specific layout value like font or text change.
+     * some cell specific format value like font or text change.
      */
-    virtual void setLayoutDirtyFlag();
+    virtual void setLayoutDirtyFlag( bool format = false );
     bool layoutDirtyFlag() const;
 
     void clearDisplayDirtyFlag();
@@ -543,11 +590,18 @@ public:
      */
     bool isObscuringForced() const;
 
+    /**
+     * Return the cell that is obscuring this one (merged cells only).
+     * If no obscuring, return the cell itself.
+     *
+     * @return the cell that decides the format for the cell in question.
+     */
+    KSpreadCell *KSpreadCell::ultimateObscuringCell() const;
+
     /**
      * @return the obscuring cell list (might be empty)
      */
-    QValueList<KSpreadCell*> const obscuringCells() const
-      { return m_ObscuringCells; }
+    QValueList<KSpreadCell*> obscuringCells() const;
 
     void clearObscuringCells();
 
@@ -573,28 +627,34 @@ public:
      * @return the number of obscured cells in the horizontal direction as a
      *         result of cell merging (forced obscuring)
      */
-    int mergedXCells()const {return m_iMergedXCells; }
+    int mergedXCells() const;
 
     /**
      * @return the number of obscured cells in the vertical direction as a
      *         result of cell merging (forced obscuring)
      */
-    int mergedYCells()const {return m_iMergedYCells; }
+    int mergedYCells() const;
 
     /**
      * @return the amount of obscured cells in the horizontal direction
      */
-    int extraXCells() const { return m_iExtraXCells; }
+    int extraXCells() const;
     /**
      * @return the amount of obscured cells in the vertical direction
      */
-    int extraYCells() const { return m_iExtraYCells; }
-    double extraWidth() const { return m_dExtraWidth; }
-    double extraHeight() const { return m_dExtraHeight; }
+    int extraYCells() const;
 
-    bool isFormula() const { return m_content == Formula; }
+    double extraWidth() const;
+    double extraHeight() const;
 
-    QString encodeFormula( int _col = -1, int _row = -1 );
+    /**
+     * encode a formula into a text representation
+     *
+     * @param _era encode relative references absolutely (this is used for copying
+     *             a cell to make the paste operation create a formula that points
+     *             to the original cells, not the cells at the same relative position)
+     */
+    QString encodeFormula( bool _era = false, int _col = -1, int _row = -1 );
     QString decodeFormula( const QString &_text, int _col = -1, int _row = -1 );
 
     /**
@@ -645,29 +705,25 @@ public:
      */
     void setConditionList(const QValueList<KSpreadConditional> &newList);
 
-    KSpreadValidity * getValidity(int newStruct=-1)
-    	{
-    	if((m_Validity==0)&&(newStruct==-1))
-    		m_Validity=new KSpreadValidity;
-    	return  m_Validity;
-    	}
-    void removeValidity()
-    	{
-            delete m_Validity;
-            m_Validity=0;
-    	}
+    KSpreadValidity * getValidity( int newStruct = -1 );
 
-     /**
+    void removeValidity();
+
+    /**
      * return true if value is good
      * else show a messagebox
      */
     bool testValidity() const;
 
-    void conditionAlign(QPainter &painter,int _col,int _row);
+    /**
+     * Calculates the text parameters stored in cell
+     * Applies font to use to @param painter
+     */
+    void calculateTextParameters( QPainter &painter, int _col, int _row );
 
     /**
-    * return align X when align is undefined
-    */
+     * return align X when align is undefined
+     */
     int defineAlignX();
 
 
@@ -679,12 +735,9 @@ public:
 
     void freeAllObscuredCells();
 
-    QString dataTypeToString( DataType dt ) const;
-    DataType stringToDataType( const QString& str ) const;
-
     /* descriptions of the flags are just below */
     enum CellFlags{
-    /* this uses the same flags variable as KSpreadLayout.  The least significant
+    /* this uses the same flags variable as KSpreadFormat.  The least significant
        16 bits are reserved for the base class, and the most significant 16
        have been left for this subclass to use. */
       Flag_LayoutDirty           = 0x00010000,
@@ -693,11 +746,13 @@ public:
       Flag_UpdatingDeps          = 0x00080000,
       Flag_DisplayDirty          = 0x00100000,
       Flag_ForceExtra            = 0x00200000,
-      Flag_CellTooShort          = 0x00400000,
-      Flag_ParseError            = 0x00800000,
-      Flag_CircularCalculation   = 0x01000000,
-      Flag_DependancyError       = 0x02000000,
-      Flag_PaintingCell          = 0x04000000
+      Flag_CellTooShortX         = 0x00400000,
+      Flag_CellTooShortY         = 0x00800000,
+      Flag_ParseError            = 0x01000000,
+      Flag_CircularCalculation   = 0x02000000,
+      Flag_DependancyError       = 0x04000000,
+      Flag_PaintingCell          = 0x08000000, // On during painting
+      Flag_TextFormatDirty       = 0x10000000
     };
 
     void clearFlag( CellFlags flag );
@@ -733,14 +788,14 @@ public:
    * in the reverse direction.
    * @see updateDependancies()
    *
-   * DisplayDirty
+   * DisplayDirty - TODO - is this unused now??
    * If this flag is set, then it is known that this cell has to be updated
    * on the display. This means that somewhere in the calling stack there is a
-   * function which will call @ref KSpreadTable::updateCell once it retains
+   * function which will call @ref KSpreadSheet::updateCell once it retains
    * the control. If a function changes the contents/layout of this cell and this
    * flag is not set, then the function must set it at once. After the changes
-   * are done the function must call <tt>m_pTable->updateCell(...).
-   * The flag is cleared by the function m_pTable->updateCell.
+   * are done the function must call <tt>m_pSheet->updateCell(...).
+   * The flag is cleared by the function m_pSheet->updateCell.
    *
    * ForceExtra
    * Tells whether the cell is forced to exceed its size.
@@ -748,40 +803,38 @@ public:
    * a cell to do so by setting this flag. Forcing the cell to have
    * no extra size will disable this flag!
    *
-   * CellTooShort
-   * When it's True displays **
+   * CellTooShortX
+   * When it's True displays ** and/or the red triangle and when the
+   * mouse is over it, the tooltip displays the full value
    * it's true when text size is bigger that cell size
    * and when Align is center or left
+   *
+   * CellTooShortY
+   * When it's True when mouseover it, the tooltip displays the full value
+   * it's true when text size is bigger that cell height
    */
 
 protected:
     /**
      * @reimp
      */
-    void layoutChanged();
+    void formatChanged();
     /**
      * @reimp
      */
-    KSpreadLayout* fallbackLayout( int col, int row );
+    KSpreadFormat* fallbackFormat( int col, int row );
     /**
      * @reimp
      */
-    const KSpreadLayout* fallbackLayout( int col, int row ) const;
+    const KSpreadFormat* fallbackFormat( int col, int row ) const;
 
     /**
-     * Format a numeric value (isNumeric()==true) using the user-specified format
+     * Applies the font to use to @param painter
      */
-    QString createFormat( double value, int col, int row );
+    void applyZoomedFont( QPainter &painter, int _col, int _row );
 
     /**
-     * When you insert a cell at bottom or right
-     * and the size is not the same so text offset
-     * will not good => recalc offset
-     */
-    void offsetAlign( int _col, int _row );
-
-    /**
-     * Called from @ref #makeLayout to determine the space
+     * Called from @ref #makeFormat to determine the space
      * needed for the text.
      */
     void textSize( QPainter &_paint );
@@ -809,216 +862,64 @@ protected:
      */
     void checkTextInput();
 
-    // Try to parse the text as a bool/number/date/time/etc.
-    // Helpers for checkTextInput.
-    bool tryParseBool( const QString& str );
-    bool tryParseNumber( const QString& str );
-    bool tryParseDate( const QString& str );
-    bool tryParseTime( const QString& str );
-
     /**
      * Automatically chooses between a number format and
      * a scientific format (if the number is too big)
      */
     void checkNumberFormat();
 
-    void NotifyDependancyList(QPtrList<KSpreadDependency> lst, bool isDepending);
+    void loadOasisValidationCondition( QString &valExpression );
+    void saveOasisAnnotation( KoXmlWriter &xmlwriter );
+    void loadOasisConditional( QDomElement * style );
 
 private:
-    /**
-     * This cell's row.
-     * If it is 0, this is the default cell and its row/column can
-     * not be determined.
-     *
-     * @persistent
-     */
-    int m_iRow;
-    /**
-     * This cell's column.
-     * If it is 0, this is the default cell and its row/column can
-     * not be determined.
-     *
-     * @persistent
-     */
-    int m_iColumn;
 
-    /**
-     * Holds the user's input
-     *
-     * @persistent
-     */
-    QString m_strText;
+    CellPrivate* d;
+    // static const char* s_dataTypeToString[];
 
-    /**
-     * This is the text we want to display
-     * Not necessarily the same as m_strText, e.g. m_strText="1" and m_strOutText="1.00".
-     */
-    QString m_strOutText;
-    int m_iOutTextWidth;
-    int m_iOutTextHeight;
-    int m_iTextX, m_iTextY;
-    /**
-     * Result of "fm.ascent()" in makeLayout.
-     * used in offsetAlign.
-     */
-    int m_fmAscent;
-
-  int m_iMergedXCells;
-  int m_iMergedYCells;
-
-    /**
-     * The amount of additional cells horizontal
-     *
-     * @persistent
-     */
-    int m_iExtraXCells;
-    /**
-     * The amount of additional cells vertical
-     *
-     * @persistent
-     */
-    int m_iExtraYCells;
-
-    /**
-     * If a cell overlapps other cells, then we have the cells width stored here.
-     * This value does not mean anything unless @ref #m_iExtraXCells is different from 0.
-     */
-    double m_dExtraWidth;
-    /**
-     * If a cell overlapps other cells, then we have the cells height stored here.
-     * This value does not mean anything unless @ref m_iExtraYCells is different from 0.
-     */
-    double m_dExtraHeight;
-
-    /**
-     * A list of @ref KSpreadCell type pointers that obscure this one.
-     * If this list is not empty, then this cell is obscured by another
-     * enlarged object. This means that we have to call this object in order
-     * of painting it for example instead of painting 'this'.
-     */
-    QValueList<KSpreadCell*> m_ObscuringCells;
-
-    /**
-     * Tells wether the cell is a button, combobox etc.
-     *
-     * @persistent
-     */
-    Style m_style;
-
-    /**
-     * Used for example if the cell is displayed as a button.
-     * It tells which command has to be executed.
-     *
-     * @see #action
-     * @see #setAction
-     *
-     * @persistent
-     */
-    QString m_strAction;
+    /* helper functions to the paintCell(...) function */
+    void paintCellBorders( QPainter& painter, const KoRect &rect,
+                           const KoRect &cellRect, 
+			   const QPoint &cellRef,
+                           bool paintBorderRight, bool paintBorderBottom,
+                           bool paintBorderLeft, bool paintBorderTop,
+                           QPen & rightPen, QPen & bottomPen,
+                           QPen & leftPen, QPen & topPen );
+    void paintPageBorders( QPainter& painter, const KoRect &cellRect,
+                           const QPoint &cellRef,
+                           bool paintBorderRight, bool paintBorderBottom );
+    void paintText( QPainter& painter, const KoRect &cellRect,
+                    const QPoint &cellRef );
+    void paintMoreTextIndicator( QPainter& painter, const KoRect &cellRect,
+                                 QColor &backgroundColor );
+    void paintCommentIndicator( QPainter& painter, const KoRect &cellRect,
+                                const QPoint &cellRef, QColor &backgroundColor );
+    void paintFormulaIndicator( QPainter& painter, const KoRect &cellRect,
+                                QColor &backgroundColor );
+    void paintDefaultBorders( QPainter& painter, const KoRect &rect,
+                              const KoRect &cellRect, const QPoint &cellRef,
+                              bool paintBorderRight, bool paintBorderBottom,
+                              bool paintBorderLeft, bool paintBorderTop,
+                              QPen const & rightPen, QPen const & bottomPen,
+                              QPen const & leftPen, QPen const & topPen );
+    void paintBackground( QPainter& painter, const KoRect &cellRect,
+                          const QPoint &cellRef, bool selected,
+                          QColor &backgroundColor );
+    void paintObscuredCells( const KoRect& rect, QPainter& painter,
+                             KSpreadView* view, const KoRect &cellRect,
+                             const QPoint &cellRef,
+                             bool paintBorderRight, bool paintBorderBottom,
+                             bool paintBorderLeft, bool paintBorderTop,
+                             QPen & rightPen, QPen & bottomPen,
+                             QPen & leftPen, QPen & topPen );
+    void paintCellDiagonalLines( QPainter& painter, const KoRect &cellRect,
+                                 const QPoint &cellRef );
 
 
-    /**
-     * list of cells that must be calculated in order to calculate this cell
-     */
-    QPtrList<KSpreadDependency> m_lstDepends;
-
-    /**
-     * list of cells that require this cell's value to be calculated
-     */
-    QPtrList<KSpreadDependency> m_lstDependingOnMe;
-
-
-    /**
-     * The value we got from calculation.
-     * If @ref isFormula() is TRUE, @ref makeLayout() will use @ref m_strFormulaOut
-     * instead of @ref m_strText since m_strText stores the formula the user entered.
-     */
-    QString m_strFormulaOut;
-
-    KSpreadCellPrivate *m_pPrivate;
-
-    /**
-     * Tells which kind of content the cell holds.
-     *
-     * @see #content
-     * @see #setCellText
-     */
-    Content m_content;
-
-    /**
-     * Tells which kind of data is present in the cell, assuming m_content == Text
-     */
-    DataType m_dataType;
-
-    /* no union -- classes can't be in a union */
-    double m_dValue;
-    QDate m_Date;
-    QTime m_Time;
-
-    QSimpleRichText *m_pQML; // Set when the cell contains QML
-
-    /**
-     * The parse tree of the real formula (e.g: "=A1*A2").
-     */
-    KSParseNode* m_pCode;
-
-
-    KSpreadConditions conditions;
-
-#if 0
-    /**
-     * if true: "Shrink to fit" for cell values
-     */
-    bool m_bShrinkToSize;
-#endif
-
-    /**
-    * Store the number of line when you used multirow
-    * default is 0
-    */
-    int m_nbLines;
-
-    KSpreadValidity * m_Validity;
-
-    KSpreadCell* m_nextCell;
-    KSpreadCell* m_previousCell;
-
-    /**
-     * A pointer to the decimal separator
-     */
-    static QChar decimal_point;
-    static const char* s_dataTypeToString[];
-
-  /* helper functions to the paintCell(...) function */
-    void paintCellBorders( QPainter& painter, KSpreadView* view,
-                           const QRect &rect, const QPoint &corner, const QPoint &cellRef,
-                           int width, int height );
-    void paintPageBorders( QPainter& painter,
-                           const QPoint &corner, const QPoint &cellRef,
-                           int width, int height );
-    void paintText( QPainter& painter,
-                    const QPoint &corner, const QPoint &cellRef,
-                    int width, int height );
-    void paintMoreTextIndicator( QPainter& painter,
-                                 const QPoint &corner,
-                                 int width, int height );
-    void paintCommentIndicator( QPainter& painter,
-                                const QPoint &corner, const QPoint &cellRef,
-                                int width, int height );
-    void paintFormulaIndicator( QPainter& painter, const QPoint &corner, int height );
-    void paintDefaultBorders( QPainter& painter, KSpreadView* view,
-                              const QRect &rect, const QPoint &corner, const QPoint &cellRef,
-                              int width, int height );
-    void paintBackground( QPainter& painter, KSpreadView* view,
-                          const QPoint &corner, const QPoint &cellRef,
-                          int width, int height, bool selected );
-    void paintObscuredCells( const QRect& rect, QPainter& painter,
-                             KSpreadView* view, const QPoint &corner, const QPoint &cellRef );
-    void paintCellDiagonalLines( QPainter& painter,
-                                 const QPoint &corner, const QPoint &cellRef,
-                                 int width, int height );
-
 
+  /** handle the fact that a cell has been updated - calls cellUpdated()
+  in the parent Sheet object */
+  void valueChanged ();
 
   /* helper functions to the makeLayout(...) function */
   /* (more to come) */
@@ -1028,8 +929,22 @@ private:
   /* helper functions to the load/save routines */
   bool loadCellData(const QDomElement &text, Operation op);
   bool saveCellResult( QDomDocument& doc, QDomElement& result,
-                       QString defaultStr );
+                       QString str );
+  void update();
+  int effAlignX();
+
+  /**
+   * When you insert a cell at bottom or right
+   * and the size is not the same so text offset
+   * will not good => recalc offset
+   */
+  void offsetAlign( int _col, int _row );
+
+    void checkForNamedAreas( QString & formula ) const;
+    void convertFormula( QString & text, const QString & f ) const;
+    QString convertFormulaToOasisFormat( const QString & formula ) const;
+    void loadOasisValidationValue( const QStringList &listVal );
 
 };
 
-#endif
+#endif  // KSPREAD_CELL
