@@ -1,4 +1,5 @@
 /* This file is part of the KDE project
+   Copyright (C) 2005 Tomas Mecir <mecirt@gmail.com>
    Copyright (C) 2000 Torben Weis <weis@kde.org>
 
    This library is free software; you can redistribute it and/or
@@ -32,7 +33,7 @@
 
 /* Generate a matrix LEVEL1 with the size LEVEL1*LEVEL1 */
 KSpreadCluster::KSpreadCluster()
-    : m_first( 0 ), m_autoDelete( FALSE )
+    : m_first( 0 ), m_autoDelete( FALSE ), m_biggestX(0), m_biggestY(0)
 {
     m_cluster = (KSpreadCell***)malloc( KSPREAD_CLUSTER_LEVEL1 * KSPREAD_CLUSTER_LEVEL1 * sizeof( KSpreadCell** ) );
 
@@ -95,6 +96,7 @@ void KSpreadCluster::clear()
     }
 
     m_first = 0;
+    m_biggestX = m_biggestY = 0;
 }
 
 KSpreadCell* KSpreadCluster::lookup( int x, int y ) const
@@ -154,6 +156,9 @@ void KSpreadCluster::insert( KSpreadCell* cell, int x, int y )
 	m_first->setPreviousCell( cell );
     }
     m_first = cell;
+    
+    if (x > m_biggestX) m_biggestX = x;
+    if (y > m_biggestY) m_biggestY = y;
 }
 
 /* Removes the cell of a matrix, the matrix itself keeps unchanged */
@@ -572,83 +577,141 @@ void KSpreadCluster::removeRow( int row )
     }
 }
 
-void KSpreadCluster::clearColumn( int col, bool preserveDoM )
+void KSpreadCluster::clearColumn( int col )
 {
-    if ( col >= KSPREAD_CLUSTER_MAX || col < 0 )
-    {
-	kdDebug(36001) << "KSpreadCluster::clearColumn: invalid column value (col: "
-		       << col << ")" << endl;
-	return;
-    }
+  if ( col >= KSPREAD_CLUSTER_MAX || col < 0 )
+  {
+    kdDebug(36001) << "KSpreadCluster::clearColumn: invalid column value (col: "
+    << col << ")" << endl;
+    return;
+  }
 
-    int cx = col / KSPREAD_CLUSTER_LEVEL2;
-    int dx = col % KSPREAD_CLUSTER_LEVEL2;
+  int cx = col / KSPREAD_CLUSTER_LEVEL2;
+  int dx = col % KSPREAD_CLUSTER_LEVEL2;
 
-    for( int cy = 0; cy < KSPREAD_CLUSTER_LEVEL1; ++cy )
-    {
-        KSpreadCell** cl = m_cluster[ cy * KSPREAD_CLUSTER_LEVEL1 + cx ];
-        if ( cl ) {
-            for( int dy = 0; dy < KSPREAD_CLUSTER_LEVEL2; ++dy ) {
-                if ( cl[ dy * KSPREAD_CLUSTER_LEVEL2 + dx ] ) {
-                    int row = cy * KSPREAD_CLUSTER_LEVEL2 + dy ;
-                    if ( preserveDoM ) {
-                        KSpreadCell* c = cl [ dy * KSPREAD_CLUSTER_LEVEL2 + dx ] ;
-                        QPtrList<KSpreadDependency> dep = c->getDepending() ;
-                        if ( dep.isEmpty() )
-                            remove( col, row );
-                        else {
-                            cl [ dy * KSPREAD_CLUSTER_LEVEL2 + dx ] = new KSpreadCell (c->table(), dep, col, row) ;
-                            cl [ dy * KSPREAD_CLUSTER_LEVEL2 + dx ]->setCalcDirtyFlag() ;
-                        }
-                    }
-                    else {
-                        remove( col, row );
-                    }
-                }
-            }
+  for( int cy = 0; cy < KSPREAD_CLUSTER_LEVEL1; ++cy )
+  {
+    KSpreadCell** cl = m_cluster[ cy * KSPREAD_CLUSTER_LEVEL1 + cx ];
+    if ( cl )
+      for( int dy = 0; dy < KSPREAD_CLUSTER_LEVEL2; ++dy )
+        if ( cl[ dy * KSPREAD_CLUSTER_LEVEL2 + dx ] )
+        {
+          int row = cy * KSPREAD_CLUSTER_LEVEL2 + dy ;
+          remove( col, row );
         }
-    }
+  }
 }
 
-void KSpreadCluster::clearRow( int row, bool preserveDoM )
-//TODO: bei column genauso
+void KSpreadCluster::clearRow( int row )
 {
-    if ( row >= KSPREAD_CLUSTER_MAX || row < 0 )
-    {
-	kdDebug(36001) << "KSpreadCluster::clearRow: invalid row value (row: "
-		       << row << ")" << endl;
-	return;
-    }
+  if ( row >= KSPREAD_CLUSTER_MAX || row < 0 )
+  {
+    kdDebug(36001) << "KSpreadCluster::clearRow: invalid row value (row: "
+        << row << ")" << endl;
+    return;
+  }
 
-    int cy = row / KSPREAD_CLUSTER_LEVEL2;
-    int dy = row % KSPREAD_CLUSTER_LEVEL2;
+  int cy = row / KSPREAD_CLUSTER_LEVEL2;
+  int dy = row % KSPREAD_CLUSTER_LEVEL2;
 
-    for( int cx = 0; cx < KSPREAD_CLUSTER_LEVEL1; ++cx )
-    {
-        KSpreadCell** cl = m_cluster[ cy * KSPREAD_CLUSTER_LEVEL2 + cx ];
-        if ( cl ) {
-            for( int dx = 0; dx < KSPREAD_CLUSTER_LEVEL2; ++dx ) {
-                if ( cl[ dy * KSPREAD_CLUSTER_LEVEL2 + dx ] ) {
-                    int column = cx * KSPREAD_CLUSTER_LEVEL2 + dx ;
-                    if ( preserveDoM ) {
-                        KSpreadCell* c = cl [ dy * KSPREAD_CLUSTER_LEVEL2 + dx ] ;
-                        QPtrList<KSpreadDependency> dep = c->getDepending() ;
-                        if ( dep.isEmpty() )
-                            remove( column, row );
-                        else {
-                            cl [ dy * KSPREAD_CLUSTER_LEVEL2 + dx ] = new KSpreadCell (c->table(), dep, column, row) ;
-                            cl [ dy * KSPREAD_CLUSTER_LEVEL2 + dx ]->setCalcDirtyFlag() ;
-                        }
-                    }
-                    else {
-                        remove( column, row );
-                    }
-                }
-            }
+  for( int cx = 0; cx < KSPREAD_CLUSTER_LEVEL1; ++cx )
+  {
+    KSpreadCell** cl = m_cluster[ cy * KSPREAD_CLUSTER_LEVEL2 + cx ];
+    if ( cl )
+      for( int dx = 0; dx < KSPREAD_CLUSTER_LEVEL2; ++dx )
+        if ( cl[ dy * KSPREAD_CLUSTER_LEVEL2 + dx ] )
+        {
+          int column = cx * KSPREAD_CLUSTER_LEVEL2 + dx ;
+          remove( column, row );
         }
-    }
+  }
 }
 
+KSpreadValue KSpreadCluster::valueRange (int col1, int row1,
+    int col2, int row2) const
+{
+  KSpreadValue empty;
+  
+  //swap first/second values if needed
+  if (col1 > col2)
+  {
+    int p = col1; col1 = col2; col2 = p;
+  }
+  if (row1 > row2)
+  {
+    int p = row1; row1 = col2; row2 = p;
+  }
+  if ((row1 < 0) || (col1 < 0) || (row2 > KSPREAD_CLUSTER_MAX) ||
+      (col2 > KSPREAD_CLUSTER_MAX))
+    return empty;
+
+  //return nothing if we are out of range occupied by cells
+  if ((row1 > m_biggestY) || (col1 > m_biggestX))
+    return empty;
+
+  //split the requested range into cluster-sized sections
+  int x1, y1, x2, y2;
+  x1 = col1 / KSPREAD_CLUSTER_LEVEL2;
+  y1 = row1 / KSPREAD_CLUSTER_LEVEL2;
+  x2 = col2 / KSPREAD_CLUSTER_LEVEL2;
+  y2 = row2 / KSPREAD_CLUSTER_LEVEL2;
+  
+  if ((x1 == x2) && (y1 == y2))  //start/end in the same chunk
+  {
+    return makeArray (col1, row1, col2, row2);
+  }
+  
+  KSpreadValue result (x2 - x1 + 1, y2 - y1 + 1);
+  
+  //fill up each section with cell values - if a cell contains a range,
+  //we only take one its element - or else we'd have problems with
+  //matrix functions and expansion of returned matrices to nearby cells
+  for (int y = y1; y <= y2; ++y)
+    for (int x = x1; x <= x2; ++x)
+      //check whether the current element contains anything
+      if (m_cluster[y * KSPREAD_CLUSTER_LEVEL1 + x])
+      {
+        //compute start/end indexes
+        int xx1, xx2, yy1, yy2;
+        xx1 = x * KSPREAD_CLUSTER_LEVEL2;
+        xx2 = (x + 1) * KSPREAD_CLUSTER_LEVEL2 - 1;
+        yy1 = y * KSPREAD_CLUSTER_LEVEL2;
+        yy2 = (y + 1) * KSPREAD_CLUSTER_LEVEL2 - 1;
+        if (xx1 < col1) xx1 = col1;
+        if (yy1 < row1) yy1 = row1;
+        if (xx2 > col2) xx2 = col2;
+        if (yy2 > row2) yy2 = row2;
+        
+        //fill the array element
+        result.setElement (x, y, makeArray (xx1, yy1, xx2, yy2));
+      }
+  //now return the result
+  return result;
+}
+
+KSpreadValue KSpreadCluster::makeArray (int col1, int row1,
+    int col2, int row2) const
+{
+  //this generates a simple, one-dimensional array
+  int cols = col2 - col1 + 1;
+  int rows = row2 - row1 + 1;
+  KSpreadValue array (cols, rows);
+  for (int row = row1; row <= row2; ++row)
+    for (int col = col1; col <= col2; ++col)
+    {
+      KSpreadCell *cell = lookup (col, row);
+      if (cell)
+      {
+        KSpreadValue val = cell->value();
+        while (val.isArray ())
+          val = val.element (0, 0);
+        array.setElement (col-col1, row-row1, val); 
+      }
+    }
+  
+  //return the result
+  return array;
+}
 
 KSpreadCell* KSpreadCluster::getFirstCellColumn(int col) const
 {
