@@ -1,5 +1,13 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
+   Copyright (C) 2004 Ariya Hidayat <ariya@kde.org>
+             (C) 2002-2003 Norbert Andres <nandres@web.de>
+             (C) 2000-2005 Laurent Montel <montel@kde.org>
+             (C) 2002 John Dailey <dailey@vt.edu>
+             (C) 2002 Phillip Mueller <philipp.mueller@gmx.de>
+             (C) 2000 Werner Trobin <trobin@kde.org>
+             (C) 1999-2000 Simon Hausmann <hausmann@kde.org>
+             (C) 1999 David Faure <faure@kde.org>
+             (C) 1998-2000 Torben Weis <weis@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,18 +25,24 @@
    Boston, MA 02111-1307, USA.
 */
 
-#ifndef __kspread_doc_h__
-#define __kspread_doc_h__
+#ifndef KSPREAD_DOC
+#define KSPREAD_DOC
+
+class KoOasisSettings;
+class KCommand;
 
 class KSpreadDoc;
 class KSpreadInterpreter;
-class KSpreadUndo;
 class KSpreadView;
 class KSpreadMap;
 class KSpreadSheet;
 class KSpreadStyleManager;
+class KSpreadUndoAction;
+class KSPLoadingInfo;
 
 class KoStore;
+class KoCommandHistory;
+class KoXmlWriter;
 
 class View;
 
@@ -38,32 +52,33 @@ class QDomDocument;
 
 class KSpellConfig;
 
-
 #include <koDocument.h>
-#include <koPageLayoutDia.h>
 #include <kozoomhandler.h>
+#include <koGenStyles.h>
+#include <koUnit.h>
 
 #include <kcompletion.h>
 #include <qmap.h>
 #include <qobject.h>
 #include <qpainter.h>
-#include <qpen.h>
 #include <qrect.h>
 #include <qstring.h>
+#include <qvaluelist.h>
 
-#include "kspread_interpreter.h"
-#include "kspread_locale.h"
+#include <kspread_global.h>
+
+#include <koscript_context.h>
 
 #define MIME_TYPE "application/x-kspread"
 
 struct Reference
 {
-    QString table_name;
+    QString sheet_name;
     QString ref_name;
     QRect rect;
 };
 
-class KSpreadPlugin 
+class KSpreadPlugin
 {
  public:
   KSpreadPlugin() {}
@@ -71,10 +86,22 @@ class KSpreadPlugin
   virtual QDomElement saveXML( QDomDocument & doc ) const = 0;
 };
 
+namespace KSpread
+{
+class Damage;
+class ValueParser;
+class ValueConverter;
+class ValueFormatter;
+class ValueCalc;
+}
+
+
+class DocPrivate;
+
 /**
  * This class holds the data that makes up a spreadsheet.
  */
-class KSpreadDoc : public KoDocument, public KoZoomHandler
+class KSPREAD_EXPORT KSpreadDoc : public KoDocument, public KoZoomHandler
 {
   Q_OBJECT
   Q_PROPERTY( bool getShowRowHeader READ getShowRowHeader )
@@ -84,44 +111,351 @@ class KSpreadDoc : public KoDocument, public KoZoomHandler
   Q_PROPERTY( bool dontCheckUpperWord READ dontCheckUpperWord WRITE setDontCheckUpperWord)
   Q_PROPERTY( bool dontCheckTitleCase READ dontCheckTitleCase WRITE setDontCheckTitleCase)
 
+  Q_PROPERTY( int syntaxVersion READ syntaxVersion )
+  Q_PROPERTY( bool showVerticalScrollBar READ showVerticalScrollBar WRITE setShowVerticalScrollBar )
+  Q_PROPERTY( bool showHorizontalScrollBar READ showHorizontalScrollBar WRITE setShowHorizontalScrollBar )
+  Q_PROPERTY( bool showColumnHeader READ showColumnHeader WRITE setShowColumnHeader )
+  Q_PROPERTY( bool showRowHeader READ showRowHeader WRITE setShowRowHeader )
+  Q_PROPERTY( bool showStatusBar READ showStatusBar WRITE setShowStatusBar )
+  Q_PROPERTY( bool showFormulaBar READ showFormulaBar WRITE setShowFormulaBar )
+  Q_PROPERTY( bool showTabBar READ showTabBar WRITE setShowTabBar )
+
 public:
-  KSpreadDoc( QWidget *parentWidget = 0, const char *widgetName = 0, QObject* parent = 0, const char* name = 0, bool singleViewMode = false );
+
+  /**
+   * Creates a new document.
+   */
+  KSpreadDoc( QWidget *parentWidget = 0, const char *widgetName = 0, QObject* parent = 0,
+  const char* name = 0, bool singleViewMode = false );
+
+  /**
+   * Destroys the document.
+   */
   ~KSpreadDoc();
 
+    enum { STYLE_PAGE = 20, STYLE_COLUMN, STYLE_ROW, STYLE_CELL, STYLE_PAGEMASTER, STYLE_USERSTYLE, STYLE_DEFAULTSTYLE,  STYLE_NUMERIC_NUMBER};
+
+
+  /**
+   * Returns list of all documents.
+   */
+  static QValueList<KSpreadDoc*> documents();
+
+  /**
+   * Returns the MIME type of KSpread document.
+   */
+  virtual QCString mimeType() const { return MIME_TYPE; }
+
+  KLocale *locale () const;
+  KSpreadMap *map () const;
+  KSpreadStyleManager *styleManager () const;
+  KSpread::ValueParser *parser () const;
+  KSpread::ValueFormatter *formatter () const;
+  KSpread::ValueConverter *converter () const;
+  KSpread::ValueCalc *calc () const;
+  
+  /**
+   * Adds a command to the command history. The command itself
+   * would not be executed.
+   */
+  void addCommand( KCommand* command );
+
+  /*
+   * Adds an undo object. This is the same as addCommand, except
+   * that it accepts KSpreadUndo instance. Once every undo object
+   * is converted to KCommand, this function will be obsoleted.
+   */
+  void addCommand( KSpreadUndoAction* command );
+
+  /**
+   * Undoes the last operation.
+   */
+  void undo();
+
+  /**
+   * Redoes the last undo.
+   */
+  void redo();
+
+  /**
+   * Locks the undo buffer.
+   */
+  void undoLock();
+
+  /**
+   * Releases lock of undo buffer.
+   */
+  void undoUnlock();
+
+  /**
+   * Returns true if undo buffer is locked.
+   */
+  bool undoLocked() const;
+
+  /**
+   * Returns the command history for the document. This is used
+   * in KSpreadView for updating the actions (i.e through
+   * signal KoCommandHistory::commandExecuted)
+   */
+  KoCommandHistory* commandHistory();
+
+  /**
+   * Returns the unit used to display margins.
+   */
+  KoUnit::Unit unit() const;
+
+  /**
+   * \deprecated Use unit().
+   */
+  KoUnit::Unit getUnit() const { return unit(); }
+
+  /**
+   * Sets the unit used to display margins.
+   */
+  void setUnit( KoUnit::Unit u );
+
+  /**
+   * Returns the name of the unit used to display margins.
+   * For example, if unit() returns KoUnit::U_MM, then
+   * this functions return "mm".
+   */
+  QString unitName() const;
+
+  /**
+   * \deprecated Use unitName().
+   */
+  QString getUnitName() const { return unitName(); }
+
+  /**
+   * Returns the syntax version of the currently opened file
+   */
+  int syntaxVersion( ) const;
+
+  /**
+   * If b is true, vertical scrollbar is visible, otherwise
+   * it will be hidden.
+   */
+  void setShowVerticalScrollBar( bool b );
+
+  /**
+   * Returns true if vertical scroll bar is visible.
+   */
+  bool showVerticalScrollBar() const;
+
+  /**
+   * \deprecated Use showVerticalScrollBar().
+   */
+  bool getShowVerticalScrollBar() const { return showVerticalScrollBar(); }
+
+  /**
+   * If b is true, horizontal scrollbar is visible, otherwise
+   * it will be hidden.
+   */
+  void setShowHorizontalScrollBar( bool b );
+
+  /**
+   * Returns true if horizontal scroll bar is visible.
+   */
+  bool showHorizontalScrollBar() const;
+
+  /**
+   * \deprecated Use showHorizontalScrollBar().
+   */
+  bool getShowHorizontalScrollBar() const { return showHorizontalScrollBar(); }
+
+  /**
+   * If b is true, column header is visible, otherwise
+   * it will be hidden.
+   */
+  void setShowColumnHeader( bool b );
+
+  /**
+   * Returns true if column header is visible.
+   */
+  bool showColumnHeader() const;
+
+  /**
+   * \deprecated Use setShowColumnHeader().
+   */
+  void setShowColHeader( bool b ){ setShowColumnHeader( b ) ; }
+
+  /**
+   * \deprecated Use showColumnHeader().
+   */
+  bool getShowColHeader() const { return showColumnHeader(); }
+
+  /**
+   * If b is true, row header is visible, otherwise
+   * it will be hidden.
+   */
+  void setShowRowHeader( bool b );
+
+  /**
+   * Returns true if row header is visible.
+   */
+  bool showRowHeader() const;
+
+  /**
+   * \deprecated Use showRowHeader().
+   */
+  bool getShowRowHeader() const { return showRowHeader(); }
+
+  /**
+   * Sets the color of the grid.
+   */
+  void setGridColor( const QColor& color );
+
+  /**
+   * Returns the color of the grid.
+   */
+  QColor gridColor() const;
+
+  /**
+   * Sets the indentation value.
+   */
+  void setIndentValue( double val );
+
+  /**
+   * Returns the indentation value.
+   */
+  double indentValue() const;
+
+  /**
+   * \deprecated Use indentValue().
+   */
+  double getIndentValue() const { return indentValue(); }
+
+  /**
+   * If b is true, status bar is visible, otherwise
+   * it will be hidden.
+   */
+  void setShowStatusBar( bool b );
+
+  /**
+   * Returns true if status bar is visible.
+   */
+  bool showStatusBar() const;
+
+  /**
+   * \deprecated Use showStatusBar().
+   */
+  bool getShowStatusBar() const { return showStatusBar(); }
+
+  /**
+   * If b is true, tab bar is visible, otherwise
+   * it will be hidden.
+   */
+  void setShowTabBar( bool b );
+
+  /**
+   * Returns true if tab bar is visible.
+   */
+  bool showTabBar() const;
+
+  /**
+   * \deprecated Use showTabBar().
+   */
+  bool getShowTabBar() const { return showTabBar(); }
+
+  /**
+   * If b is true, formula bar is visible, otherwise
+   * it will be hidden.
+   */
+  void setShowFormulaBar( bool b );
+
+  /**
+   * Returns true if formula bar is visible.
+   */
+  bool showFormulaBar() const;
+
+  /**
+   * \deprecated Use showFormulaBar().
+   */
+  bool getShowFormulaBar() const { return showFormulaBar(); }
+
+  /**
+   * If b is true, comment indicator is visible, otherwise
+   * it will be hidden.
+   */
+  void setShowCommentIndicator( bool b );
+
+  /**
+   * Returns true if comment indicator is visible.
+   */
+  bool showCommentIndicator() const;
+
+  /**
+   * \deprecated Use showCommentIndicator().
+   */
+  bool getShowCommentIndicator() const { return showCommentIndicator(); }
+
+  /**
+   * If b is true, an error message will pop up whenever error occurs.
+   */
+  void setShowMessageError( bool b );
+
+  /**
+   * Returns true if error message should pop up whenever error occurs.
+   */
+  bool showMessageError() const;
+
+  /**
+   * \deprecated Use showMessageError().
+   */
+  bool getShowMessageError() const{ return showMessageError(); }
+
+  /**
+  * completion mode
+  */
+
+  KGlobalSettings::Completion completionMode( )const ;
+  void setCompletionMode( KGlobalSettings::Completion _complMode);
+
+  KSpread::MoveTo getMoveToValue()const;
+  void setMoveToValue(KSpread::MoveTo _moveTo) ;
+
+  /**
+  * Method of calc
+  */
+  void setTypeOfCalc( MethodOfCalc _calc);
+  MethodOfCalc getTypeOfCalc() const;
+
+
+  /**
+   * get custom kspell config
+   */
+  void setKSpellConfig(KSpellConfig _kspell);
+  KSpellConfig * getKSpellConfig() const;
+
+  bool dontCheckUpperWord() const;
+  void setDontCheckUpperWord(bool _b);
+
+  bool dontCheckTitleCase() const;
+  void setDontCheckTitleCase(bool _b);
+
+  QColor pageBorderColor() const;
+  void changePageBorderColor( const QColor  & _color);
+
+
   virtual QDomDocument saveXML();
 
-  virtual bool loadChildren( KoStore* _store );
+  virtual bool saveOasis( KoStore* store, KoXmlWriter* manifestWriter );
+  void saveOasisDocumentStyles( KoStore* store, KoGenStyles& mainStyles ) const;
+  virtual int supportedSpecialFormats() const;
+
   virtual bool loadXML( QIODevice *, const QDomDocument& doc );
+  virtual bool loadOasis( const QDomDocument& doc, KoOasisStyles& oasisStyles, const QDomDocument& settings, KoStore* );
+  virtual bool loadChildren( KoStore* _store );
   QDomElement saveAreaName( QDomDocument& doc ) ;
+    void saveOasisAreaName( KoXmlWriter & xmlWriter );
+
   void loadAreaName( const QDomElement& element );
+  void loadOasisAreaName( const QDomElement& element );
+  void loadOasisCellValidation( const QDomElement&body );
+
   virtual void addView( KoView *_view );
 
-  virtual bool initDoc();
-
-  virtual QCString mimeType() const { return MIME_TYPE; }
-
-  /**
-   * @return a pointer to a new KSpreadSheet. The KSpreadSheet is not added to the map
-   *         nor added to the GUI.
-   */
-  KSpreadSheet * createTable();
-
-  /**
-   * Adds a KSpreadSheet to the GUI and makes it active. In addition the KSpreadSheet is
-   * added to the map.
-   *
-   * @see KSpreadView
-   * @see KSpreadMap
-   */
-  void addTable( KSpreadSheet * _table );
-
-  KSpreadMap * map() const { return m_pMap; }
-  KSpreadStyleManager * styleManager() const { return m_pStyleManager; }
-
-  /**
-   * @return the locale which was used for creating this document.
-   */
-  KLocale * locale() { return & m_locale; }
+  virtual bool initDoc(InitDocFlags flags, QWidget* parentWidget=0);
 
   /**
    * Change the zoom factor to @p z (e.g. 150 for 150%)
@@ -140,7 +474,7 @@ public:
   /**
    * @return the KScript Interpreter used by this document.
    */
-  KSpreadInterpreter* interpreter()const { return m_pInterpreter; }
+  KSpreadInterpreter* interpreter()const;
 
   /**
    * Kills the interpreter and creates a new one and
@@ -153,23 +487,7 @@ public:
    * @return a context that can be used for evaluating formulas.
    *         This function does remove any exception from the context.
    */
-  KSContext & context() { m_context.setException( 0 ); return m_context; }
-
-  /**
-   * Undo the last operation.
-   */
-  void undo();
-
-  /**
-   * Redo the last undo.
-   */
-  void redo();
-
-  /**
-   * @return the object that is respnsible for keeping track
-   *         of the undo buffer.
-   */
-  KSpreadUndo * undoBuffer()const { return m_pUndoBuffer; }
+  KSContext & context();
 
   // virtual void printMap( QPainter & _painter );
 
@@ -179,16 +497,13 @@ public:
   /**
    * @return TRUE if the document is currently loading.
    */
-  bool isLoading() const { return m_bLoading; }
+  bool isLoading() const;
 
-  void setDefaultGridPen( const QPen & );
-  const QPen & defaultGridPen() { return m_defaultGridPen; }
-
-  virtual void paintContent( QPainter & painter, const QRect & rect, bool transparent = false, 
+  virtual void paintContent( QPainter & painter, const QRect & rect, bool transparent = false,
                              double zoomX = 1.0, double zoomY = 1.0 );
-  void paintContent( QPainter & painter, const QRect & rect, bool transparent, 
-                     KSpreadSheet * table, bool drawCursor = true );
-  
+  void paintContent( QPainter & painter, const QRect & rect, bool transparent,
+                     KSpreadSheet * sheet, bool drawCursor = true );
+
   bool docData( QString const & xmlTag, QDomElement & data );
   void deregisterPlugin( KSpreadPlugin * plugin );
   void registerPlugin( KSpreadPlugin * plugin );
@@ -209,7 +524,7 @@ public:
    * @param cellRegions a list of rectangles indicating the cell ranges needing
    *                    painted.
    *
-   * @param table the table which the cells in cellRegions come from
+   * @param sheet the sheet which the cells in cellRegions come from
    *
    * @param drawCursor whether or not to draw the selection rectangle and the choose
    *                   marker
@@ -217,110 +532,20 @@ public:
   void paintCellRegions(QPainter& painter, const QRect &viewRect,
                         KSpreadView* view,
                         QValueList<QRect> cellRegions,
-                        const KSpreadSheet* table, bool drawCursor);
+                        const KSpreadSheet* sheet, bool drawCursor);
 
   virtual DCOPObject* dcopObject();
 
-  static QPtrList<KSpreadDoc>& documents();
-
-  void addAreaName(const QRect &_rect,const QString & name,const QString & tableName);
-  const QValueList<Reference>  & listArea(){return m_refs;}
+  void addAreaName(const QRect &_rect,const QString & name,const QString & sheetName);
+  const QValueList<Reference>  & listArea();
   void removeArea( const QString &name);
-
-  KCompletion & completion(){return listCompletion;}
+  KCompletion & completion();
   void addStringCompletion(const QString & stringCompletion);
 
-  void changeAreaTableName(const QString & oldName,const QString &tableName);
+  void changeAreaSheetName(const QString & oldName,const QString &sheetName);
 
 
-  QRect getRectArea(const QString &  _tableName);
-
-  /**
-  * hide/show scrollbar
-  */
-  void setShowVerticalScrollBar(bool _show) {   m_bVerticalScrollBarShow=_show;}
-  void setShowHorizontalScrollBar(bool _show) {   m_bHorizontalScrollBarShow=_show;}
-
-  bool getShowVerticalScrollBar()const { return  m_bVerticalScrollBarShow;}
-  bool getShowHorizontalScrollBar()const {  return  m_bHorizontalScrollBarShow;}
-
-  /**
-  * completion mode
-  */
-
-  KGlobalSettings::Completion completionMode( )const { return m_iCompletionMode;}
-  void setCompletionMode( KGlobalSettings::Completion _complMode) {  m_iCompletionMode=_complMode;}
-
-  /**
-  * hide/show row/col header
-  */
-  void setShowColHeader(bool _show) { m_bShowColHeader=_show; }
-  void setShowRowHeader(bool _show) { m_bShowRowHeader=_show; }
-
-  bool getShowColHeader()const { return  m_bShowColHeader; }
-  bool getShowRowHeader()const { return  m_bShowRowHeader; }
-
-  /**
-  * value of indent
-  */
-  double getIndentValue()const { return m_dIndentValue; }
-  void setIndentValue( double _val ) { m_dIndentValue = _val; }
-
-  KSpread::MoveTo getMoveToValue()const {return m_EMoveTo;}
-  void setMoveToValue(KSpread::MoveTo _moveTo) {m_EMoveTo=_moveTo;}
-
-  /**
-  * Show or not error message
-  */
-  void setShowMessageError(bool _show) {   m_bShowError=_show;}
-  bool getShowMessageError()const { return  m_bShowError;}
-
-  /**
-  * Method of calc
-  */
-  void setTypeOfCalc( MethodOfCalc _calc) { m_EMethodOfCalc=_calc;}
-  MethodOfCalc getTypeOfCalc()const{ return m_EMethodOfCalc;}
-
-  /**
-   * show/hide tabbar
-   */
-  void setShowTabBar(bool _tabbar) {  m_bShowTabBar=_tabbar;}
-  bool getShowTabBar()const { return  m_bShowTabBar;}
-
-  void changeDefaultGridPenColor( const QColor &_col){m_defaultGridPen.setColor(_col);}
-
-  QColor pageBorderColor() const { return m_pageBorderColor; }
-  void changePageBorderColor( const QColor  & _color) { m_pageBorderColor = _color; }
-
-  /**
-   * show/hide comment indicator
-   */
-  void setShowCommentIndicator(bool _indic) {  m_bShowCommentIndicator=_indic;}
-  bool getShowCommentIndicator()const { return  m_bShowCommentIndicator;}
-
-  /**
-   * show/hide formula bar
-   */
-  void setShowFormulaBar(bool _formulaBar) {  m_bShowFormulaBar=_formulaBar;}
-  bool getShowFormulaBar()const { return  m_bShowFormulaBar;}
-
-  /**
-   * get custom kspell config
-   */
-  void setKSpellConfig(KSpellConfig _kspell);
-  KSpellConfig * getKSpellConfig()const {return m_pKSpellConfig;}
-
-  bool dontCheckUpperWord() const { return m_bDontCheckUpperWord; }
-  void setDontCheckUpperWord(bool _b) { m_bDontCheckUpperWord = _b; }
-
-  bool dontCheckTitleCase() const { return  m_bDontCheckTitleCase; }
-  void setDontCheckTitleCase(bool _b) { m_bDontCheckTitleCase = _b; }
-
-  /**
-   * show/hide status bar
-   */
-  void setShowStatusBar(bool _statusBar) { m_bShowStatusBar=_statusBar;}
-  bool getShowStatusBar()const { return  m_bShowStatusBar;}
+  QRect getRectArea(const QString &  _sheetName);
 
   void insertChild( KoDocumentChild * child ) { KoDocument::insertChild( child ); }
 
@@ -352,36 +577,28 @@ public:
    * hourglass
    */
   virtual void emitBeginOperation();
-
+  
   /**
    * Mark the end of an operation and triggers repaints/calculations.
    * See above comment to emitBeginOperation(bool).
    */
-  void emitEndOperation();
+  virtual void emitEndOperation();
 
   /**
    * s.a. difference does only specified tasks and thats why it improves performance
-   * significantly. rect normally are the visible cells/the cells that need to be updated. 
+   * significantly. rect normally are the visible cells/the cells that need to be updated.
    */
   void emitEndOperation( QRect const & rect );
 
-  bool delayCalculation();
+  bool delayCalculation() const;
 
 
   void updateBorderButton();
 
-  void insertTable( KSpreadSheet * table );
-  void takeTable( KSpreadSheet * table );
-  
-  // The user-chosen global unit
-  QString getUnitName()const { return KoUnit::unitName( m_unit ); }
-  KoUnit::Unit getUnit()const { return m_unit; }
-  void setUnit( KoUnit::Unit _unit );
+  void insertSheet( KSpreadSheet * sheet );
+  void takeSheet( KSpreadSheet * sheet );
 
-  /**
-   * Returns the syntax version of the currently opened file
-   */
-  int syntaxVersion( ) const { return m_syntaxVersion; }
+  // The user-chosen global unit
 
   static QString getAttribute(const QDomElement &element, const char *attributeName, const QString &defaultValue)
   {
@@ -408,15 +625,20 @@ public:
 
     void addIgnoreWordAll( const QString & word);
     void clearIgnoreWordAll( );
-    void addIgnoreWordAllList( const QStringList & _lst)
-        { m_spellListIgnoreAll = _lst;}
-    QStringList spellListIgnoreAll() const { return m_spellListIgnoreAll;}
+    void addIgnoreWordAllList( const QStringList & _lst);
+    QStringList spellListIgnoreAll() const ;
 
-    void setDisplayTable(KSpreadSheet *_Table );
-    KSpreadSheet * displayTable()const;
+    void setDisplaySheet(KSpreadSheet *_Sheet );
+    KSpreadSheet * displaySheet() const;
+    KSPLoadingInfo * loadingInfo() const;
+  void increaseNumOperation();
+  void decreaseNumOperation();
 
-  void increaseNumOperation() { ++m_numOperations; }
-  void decreaseNumOperation() { --m_numOperations; }
+  void addDamage( KSpread::Damage* damage );
+
+/* Function specific when we load config from file */
+  void loadConfigFromFile();
+  bool configLoadFromFile() const;
 
 public slots:
 
@@ -424,12 +646,10 @@ public slots:
 
   void refreshInterface();
 
+  void flushDamages();
+
 signals:
   // Document signals
-  /**
-   * Emitted if a new table is added to the document.
-   */
-  void sig_addTable( KSpreadSheet *_table );
   /**
    * Emitted if all views have to be updated.
    */
@@ -443,6 +663,15 @@ signals:
    */
   void sig_refreshLocale();
 
+  void sig_addAreaName( const QString & );
+  void sig_removeAreaName( const QString & );
+
+  void damagesFlushed( const QValueList<KSpread::Damage*>& damages );
+
+protected slots:
+  void commandExecuted();
+  void documentRestored();  
+  
 protected:
   KoView* createViewInstance( QWidget* parent, const char* name );
 
@@ -465,137 +694,17 @@ protected:
    */
   void destroyInterpreter();
 
-  /**
-   * Pointer to the map that holds all the tables.
-   */
-  KSpreadMap *m_pMap;
-
-  /**
-   * Pointer to the manager of the styles
-   */
-  KSpreadStyleManager * m_pStyleManager;
-
-  /**
-   * This variable is used to give every KSpreadSheet a unique default name.
-   *
-   * @see #newKSpreadSheet
-   */
-  int m_iTableId;
-
-  /**
-   * The URL of the this part. This variable is only set if the @ref #load function
-   * had been called with an URL as argument.
-   *
-   * @see #load
-   */
-  QString m_strFileURL;
-
-  /**
-  * Contains the syntax version of the opened file
-  */
-  int m_syntaxVersion;
-
-  /**
-   * This variable hold the KScript Interpreter.
-   */
-  KSpreadInterpreter::Ptr m_pInterpreter;
-
-  /**
-   * This list contains the logical names of all modules
-   * which contains KSpread extensions. These modules are
-   * located in the apps/kspread directory in the global
-   * and the users environment. If a module of the same name
-   * exists in both environments, then the most specific one
-   * is in this list and the other one is dropped.
-   */
-  QStringList m_kscriptModules;
-  /**
-   * Used for undo.
-   */
-  KSpreadUndo *m_pUndoBuffer;
-
-  /**
-   * TRUE if loading is in process, otherwise FALSE.
-   * This flag is used to avoid updates etc. during loading.
-   *
-   * @see #isLoading
-   */
-  bool m_bLoading;
-
-  QPen m_defaultGridPen;
-  QColor m_pageBorderColor;
-
-  /**
-   * This DCOP object represents the document.
-   */
-  DCOPObject* m_dcop;
-
-  /**
-   * This module is used to execute formulas of this table.
-   */
-  KSModule::Ptr m_module;
-  /**
-   * This context is used to execute formulas of this table.
-   */
-  KSContext m_context;
-
-  QPtrList<KSpreadPlugin> m_plugins;
-
-  static QPtrList<KSpreadDoc>* s_docs;
-  static int s_docId;
-
-  QValueList<Reference> m_refs;
-  KCompletion listCompletion;
-
-  KSpreadLocale m_locale;
-
-  /**
-  * bool which define if you can show scroolbar
-  */
-  bool m_bVerticalScrollBarShow;
-  bool m_bHorizontalScrollBarShow;
-
-  /**
-  * completion mode
-  */
-  KGlobalSettings::Completion m_iCompletionMode;
-
-  /**
-  * bool which define if you can show col/row header
-  */
-  bool m_bShowColHeader;
-  bool m_bShowRowHeader;
-
-  double m_dIndentValue;
-
-  KSpread::MoveTo m_EMoveTo;
-
-  bool m_bShowError;
-
-  MethodOfCalc m_EMethodOfCalc;
-
-  bool m_bShowTabBar;
-
-  bool m_bShowCommentIndicator;
-  bool m_bShowFormulaBar;
-  bool m_bShowStatusBar;
-
-  bool m_bDelayCalculation;
-
-  KSpellConfig *m_pKSpellConfig;
-  bool m_bDontCheckUpperWord;
-  bool m_bDontCheckTitleCase;
-  QStringList m_spellListIgnoreAll;
-  KoUnit::Unit m_unit;
-  KSpreadSheet *m_activeTable;
-
-  int m_numOperations;
-
   class SavedDocParts : public QMap<QString, QDomElement> {};
   SavedDocParts m_savedDocParts;
 
 private:
 
+  DocPrivate* d;
+
+  // don't allow copy or assignment
+  KSpreadDoc( const KSpreadDoc& );
+  KSpreadDoc& operator=( const KSpreadDoc& );
+
   /* helper functions for painting */
 
   /**
@@ -606,19 +715,19 @@ private:
 
   void PaintRegion(QPainter& painter, const KoRect &viewRegion,
                    KSpreadView* view, const QRect &paintRegion,
-                   const KSpreadSheet* table);
+                   const KSpreadSheet* sheet);
   void PaintChooseRect(QPainter& painter, const KoRect &viewRect,
-                       KSpreadView* view, const KSpreadSheet* table,
+                       KSpreadView* view, const KSpreadSheet* sheet,
                        const QRect &chooseRect);
   void PaintNormalMarker(QPainter& painter, const KoRect &viewRect,
-                         KSpreadView* view, const KSpreadSheet* table,
+                         KSpreadView* view, const KSpreadSheet* sheet,
                          const QRect &selection);
 
   /**
    * helper function in drawing the marker and choose marker.
    * @param marker the rectangle that represents the marker being drawn
    *               (cell coordinates)
-   * @param table the table this marker is on
+   * @param sheet the sheet this marker is on
    * @param viewRect the visible area on the canvas
    * @param positions output parameter where the viewable left, top, right, and
    *                  bottom of the marker will be.  They are stored in the array
@@ -629,10 +738,15 @@ private:
    *                   Again, these are in the order left, top, right, bottom.
    *                   This should be preallocated with a size of at least 4.
    */
-  void retrieveMarkerInfo( const QRect &marker, const KSpreadSheet* table,
+  void retrieveMarkerInfo( const QRect &marker, const KSpreadSheet* sheet,
                            KSpreadView* view, const KoRect &viewRect,
                            double positions[], bool paintSides[] );
   void loadPaper( QDomElement const & paper );
+
+    void saveOasisSettings( KoXmlWriter &settingsWriter );
+    void loadOasisSettings( const QDomDocument&settingsDoc );
+    void loadOasisIgnoreList( const KoOasisSettings& settings );
+    KSPLoadingInfo *m_loadingInfo;
 };
 
-#endif
+#endif /* KSPREAD_DOC */
