@@ -28,6 +28,8 @@ class KSpreadCanvas;
 class QDomElement;
 class QDomDocument;
 class DCOPObject;
+class KoOasisStyles;
+class KoGenStyles;
 
 #include <qbrush.h>
 #include <qpen.h>
@@ -35,40 +37,27 @@ class DCOPObject;
 #include <qfont.h>
 
 #include "kspread_global.h"
-
+#include <koffice_export.h>
 class KLocale;
 class KSpreadCurrency;
 class KSpreadStyle;
+class KoStyleStack;
+class KoGenStyle;
 
 /**
  */
-class KSpreadFormat
+class KSPREAD_EXPORT KSpreadFormat
 {
 public:
     enum Align { Left = 1, Center = 2, Right = 3, Undefined = 4 };
     enum AlignY { Top = 1, Middle = 2, Bottom = 3, UndefinedY = 4 };
     enum FloatFormat { AlwaysSigned = 1, AlwaysUnsigned = 2, OnlyNegSigned = 3 };
     enum FloatColor { NegRed = 1, AllBlack = 2, NegBrackets = 3, NegRedBrackets = 4 };
-    enum FormatType { Number=0, Text_format=5, Money=10, Percentage=25, Scientific=30,
-                      ShortDate=35, TextDate=36, Time=50, SecondeTime=51,
-                      Time_format1=52, Time_format2=53, Time_format3=54, Time_format4=55,
-                      Time_format5=56, Time_format6=57, Time_format7=58, Time_format8=59,
-                      fraction_half=70,fraction_quarter=71,fraction_eighth=72,fraction_sixteenth=73,
-                      fraction_tenth=74,fraction_hundredth=75,fraction_one_digit=76,
-                      fraction_two_digits=77,fraction_three_digits=78,
-                      date_format1=200,date_format2=201,date_format3=202,date_format4=203,
-                      date_format5=204,date_format6=205,date_format7=206,date_format8=207,
-                      date_format9=208,date_format10=209,date_format11=210,date_format12=211,
-                      date_format13=212,date_format14=213,date_format15=214,date_format16=215,
-                      date_format17=216,date_format18=217,date_format19=218,date_format20=219,
-                      date_format21=220,date_format22=221,date_format23=222,date_format24=223,
-                      date_format25=224,date_format26=225,
-                      Custom = 300 };
 
     enum Properties{ PAlign  = 0x01,
 		     PAlignY = 0x02,
-		     PFactor = 0x04,
-		     PPrefix = 0x08,
+         //PFactor was here
+         PPrefix = 0x08,
 		     PPostfix = 0x10,
 		     PLeftBorder = 0x20,
 		     PRightBorder = 0x40,
@@ -103,7 +92,7 @@ public:
 
     /**
      * don't pass in 0 for _style: only if you copy another format on this directly after...
-     */ 
+     */
     KSpreadFormat( KSpreadSheet * _sheet, KSpreadStyle * _style );
     virtual ~KSpreadFormat();
 
@@ -122,13 +111,18 @@ public:
     QDomElement save( QDomDocument& doc,int _col, int _row,bool force = false, bool copy = false ) const;
     QDomElement saveFormat( QDomDocument& doc, bool force = false, bool copy = false ) const;
     QDomElement saveFormat( QDomDocument& doc, int _col, int _row, bool force = false, bool copy = false ) const;
+    virtual bool loadOasisStyleProperties(KoStyleStack & styleStack, const KoOasisStyles& oasisStyles );
+    virtual QString saveOasisCellStyle( KoGenStyle &currentCellStyle, KoGenStyles &mainStyle ,int _col, int _row , bool force = false, bool copy = false);
+    virtual QString saveOasisCellStyle( KoGenStyle &currentCellStyle, KoGenStyles &mainStyle );
+    void saveOasisFontCellStyle( KoGenStyle &currentCellStyle, const QFont &_font );
 
-
+    bool loadFontOasisStyle( KoStyleStack & font );
     ////////////////////////////////
     //
     // Properties
     //
     ////////////////////////////////
+    uint propertiesMask() { return m_mask; } // For the cell inspector only.
     void clearProperties();
     void clearProperty( Properties p );
 
@@ -176,7 +170,6 @@ public:
 
     virtual void setAlign( Align _align );
     virtual void setAlignY( AlignY _alignY );
-    virtual void setFactor( double _d );
     virtual void setPrefix( const QString& _prefix );
     virtual void setPostfix( const QString& _postfix );
     virtual void setPrecision( int _p );
@@ -344,8 +337,6 @@ public:
     virtual Align align( int col, int row ) const;
     virtual AlignY alignY( int col, int row ) const;
 
-    virtual double factor( int col, int row ) const;
-
     virtual bool multiRow( int col, int row ) const;
 
     virtual bool verticalText( int col, int row ) const;
@@ -365,11 +356,9 @@ public:
     virtual bool isHideFormula( int col, int row) const;
     virtual bool isProtected( int col, int row ) const;
 
-    KSpreadStyle * kspreadStyle() const { return m_pStyle; } 
-    KSpreadSheet* table() { return m_pTable; }
-    const KSpreadSheet* table() const { return m_pTable; }
-
-    KLocale* locale()const;
+    KSpreadStyle * kspreadStyle() const { return m_pStyle; }
+    KSpreadSheet* sheet() { return m_pSheet; }
+    const KSpreadSheet* sheet() const { return m_pSheet; }
 
     virtual bool hasProperty( Properties p, bool withoutParent = false ) const;
 
@@ -405,7 +394,7 @@ protected:
      */
     virtual bool isDefault() const;
 
-    KSpreadSheet * m_pTable;
+    KSpreadSheet * m_pSheet;
     KSpreadStyle * m_pStyle;
 
     uint m_mask;
@@ -440,7 +429,7 @@ private:
 
 /**
  */
-class RowFormat : public KSpreadFormat
+class KSPREAD_EXPORT RowFormat : public KSpreadFormat
 {
 public:
     RowFormat( KSpreadSheet * _sheet, int _row );
@@ -450,6 +439,7 @@ public:
 
     virtual QDomElement save( QDomDocument&, int yshift = 0, bool copy = false ) const;
     virtual bool load( const QDomElement& row, int yshift = 0, PasteMode sp = Normal, bool paste = false );
+    virtual bool loadOasis( const QDomElement& row, QDomElement * rowStyle );
 
     /**
      * @param _canvas is needed to get information about the zooming factor.
@@ -578,10 +568,10 @@ protected:
 
 /**
  */
-class ColumnFormat : public KSpreadFormat
+class KSPREAD_EXPORT ColumnFormat : public KSpreadFormat
 {
 public:
-    ColumnFormat( KSpreadSheet *_table, int _column );
+    ColumnFormat( KSpreadSheet *_sheet, int _column );
     ~ColumnFormat();
 
     virtual QDomElement save( QDomDocument&, int xshift = 0, bool copy = false ) const;
@@ -716,12 +706,12 @@ protected:
     DCOPObject*m_dcop;
 };
 
-class KSpreadCurrency
+class KSPREAD_EXPORT KSpreadCurrency
 {
  public:
 
-  typedef enum F1 { Gnumeric, OpenCalc, ApplixSpread,
-                    GobeProductiveSpread, HancomSheet } currencyFormat;
+  enum currencyFormat { Gnumeric, OpenCalc, ApplixSpread,
+                        GobeProductiveSpread, HancomSheet };
 
   KSpreadCurrency();
   ~KSpreadCurrency();
