@@ -32,8 +32,8 @@
 #include <koscript_func.h>
 #include <koscript_synext.h>
 
-#include <kspread_functions.h>
-#include <kspread_util.h>
+#include "kspread_functions.h"
+#include "kspread_util.h"
 
 
 // prototypes
