@@ -36,10 +36,14 @@
 #include <koscript_func.h>
 #include <koscript_synext.h>
 
-#include <kspread_functions.h>
-#include <kspread_util.h>
-#include <kspread_doc.h>
-#include <kspread_sheet.h>
+#include "kspread_functions.h"
+#include "kspread_util.h"
+#include "kspread_doc.h"
+#include "kspread_sheet.h"
+#include "kspread_interpreter.h"
+#include "kspread_value.h"
+#include "valueparser.h"
+#include "valueconverter.h"
 
 // prototypes (sort alphabetically)
 //bool kspreadfunc_countblank( KSContext & context );
@@ -454,12 +458,12 @@ bool kspreadfunc_type( KSContext & context )
   if ( !p.isEmpty() )
   {
     KSpreadMap *   map   = ((KSpreadInterpreter *) context.interpreter() )->document()->map();
-    KSpreadSheet * table = ((KSpreadInterpreter *) context.interpreter() )->table();
+    KSpreadSheet * sheet = ((KSpreadInterpreter *) context.interpreter() )->sheet();
 
-    KSpreadPoint point( p, map, table );
+    KSpreadPoint point( p, map, sheet );
     if ( point.isValid() )
     {
-      KSpreadCell * cell = point.table->cellAt( point.pos.x(), point.pos.y() );
+      KSpreadCell * cell = point.sheet->cellAt( point.pos.x(), point.pos.y() );
 
       if ( cell->hasError() )
       {
@@ -484,39 +488,41 @@ bool kspreadfunc_filename( KSContext & context )
 // Function: N
 bool kspreadfunc_n( KSContext & context )
 {
+  //currently the same as the VALUE function
+  
   QValueList<KSValue::Ptr>& args = context.value()->listValue();
 
   if ( !KSUtil::checkArgumentsCount( context, 1, "N", true ) )
     return false;
 
-  if ( KSUtil::checkType( context, args[0], KSValue::DoubleType, false ) )
-  {
-    context.setValue( new KSValue( args[0]->doubleValue() ) );
-    return true;
-  }
-
-  if ( KSUtil::checkType( context, args[0], KSValue::IntType, false ) )
-  {
-    context.setValue( new KSValue( args[0]->intValue() ) );
-    return true;
-  }
-
-  if ( KSUtil::checkType( context, args[0], KSValue::BoolType, false ) )
-  {
-    context.setValue( new KSValue( args[0]->boolValue() ) );
-    return true;
-  }
-
-  if ( KSUtil::checkType( context, args[0], KSValue::DateType, false ) )
-  {
-    QDate date = args[0]->dateValue();
-    QDate ref = QDate( 1900, 1, 1 );
-    long serialno = -date.daysTo( ref ) + 2;
-    context.setValue( new KSValue( serialno ) );
-    return true;
-  }
-
-  context.setValue( new KSValue( (int)0 ) );
+  KSpreadValue val;
+  
+  if( KSUtil::checkType( context, args[0], KSValue::StringType, false ) )
+    val.setValue (args[0]->stringValue());
+  
+  else if( KSUtil::checkType( context, args[0], KSValue::DoubleType, false ) )
+    val.setValue (args[0]->doubleValue());
+  
+  else if( KSUtil::checkType( context, args[0], KSValue::TimeType, false ) )
+    val.setValue (args[0]->timeValue());
+  
+  else if( KSUtil::checkType( context, args[0], KSValue::DateType, false ) )
+    val.setValue (args[0]->dateValue());
+  
+  else if( KSUtil::checkType( context, args[0], KSValue::IntType, false ) )
+    val.setValue (args[0]->intValue());
+  
+  else if( KSUtil::checkType( context, args[0], KSValue::BoolType, false ) )
+    val.setValue (args[0]->boolValue());
+    
+  // temporary ugly hack, yay!
+  KSpread::ValueParser *parser = new KSpread::ValueParser( KGlobal::locale() );
+  KSpread::ValueConverter *converter = new KSpread::ValueConverter( parser );
+  val = converter->asFloat (val);
+  delete converter;
+  delete parser;
+  
+  context.setValue( new KSValue( val.asFloat() ));
   return true;
 
 }
