@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-             (C) 1999-2002 The KSpread Team
+             (C) 1999-2005 The KSpread Team
                            www.koffice.org/kspread
 
    This library is free software; you can redistribute it and/or
@@ -19,8 +19,8 @@
    Boston, MA 02111-1307, USA.
 */
 
-#ifndef __kspread_table_h__
-#define __kspread_table_h__
+#ifndef KSPREAD_SHEET
+#define KSPREAD_SHEET
 
 class KSpreadSheet;
 class KSpreadSheetPrint;
@@ -34,19 +34,27 @@ class KSpreadPoint;
 class KSpreadMap;
 class KSpreadCanvas;
 class KSpreadDoc;
+class KSpreadSelection;
 class KSpreadUndoInsertRemoveAction;
 class KoDocumentEntry;
-
-class QStingList;
+class KoStyleStack;
+class KoGenStyles;
+class KSpreadGenValidationStyles;
 class QWidget;
 class QPainter;
 class QDomElement;
 
+namespace KSpread {
+  class DependencyManager;
+}
+
 class DCOPObject;
 class KPrinter;
+class KoOasisSettings;
 
 #include <koDocument.h>
 #include <koDocumentChild.h>
+#include <koOasisSettings.h> // for KoOasisSettings::NamedMap
 
 #include <qpen.h>
 #include <qptrlist.h>
@@ -55,15 +63,13 @@ class KPrinter;
 #include <qrect.h>
 #include <qwidget.h>
 #include <qdragobject.h>
-
-#define BORDER_SPACE 1
+#include <koOasisStyles.h>
+#include <koxmlwriter.h>
 
 #include "kspread_autofill.h"
 #include "kspread_format.h"
 #include "kspread_cell.h"
 #include "kspread_global.h"
-#include "kspread_cluster.h"
-#include "kspread_selection.h"
 
 /********************************************************************
  *
@@ -78,7 +84,7 @@ class CellBinding : public QObject
 {
     Q_OBJECT
 public:
-    CellBinding( KSpreadSheet *_table, const QRect& _area );
+    CellBinding( KSpreadSheet *_sheet, const QRect& _area );
     virtual ~CellBinding();
 
     bool contains( int _x, int _y );
@@ -95,14 +101,14 @@ public:
     virtual QRect& dataArea() { return m_rctDataArea; }
     virtual void setDataArea( const QRect _rect ) { m_rctDataArea = _rect; }
 
-    KSpreadSheet* table()const { return m_pTable; }
+    KSpreadSheet* sheet()const { return m_pSheet; }
 
 signals:
     void changed( KSpreadCell *_obj );
 
 protected:
     QRect m_rctDataArea;
-    KSpreadSheet *m_pTable;
+    KSpreadSheet *m_pSheet;
     bool m_bIgnoreChanges;
 };
 
@@ -118,15 +124,15 @@ protected:
 class KSpreadChild : public KoDocumentChild
 {
 public:
-  KSpreadChild( KSpreadDoc *parent, KSpreadSheet *_table, KoDocument* doc, const QRect& geometry );
-  KSpreadChild( KSpreadDoc *parent, KSpreadSheet *_table );
+  KSpreadChild( KSpreadDoc *parent, KSpreadSheet *_sheet, KoDocument* doc, const QRect& geometry );
+  KSpreadChild( KSpreadDoc *parent, KSpreadSheet *_sheet );
   ~KSpreadChild();
 
   KSpreadDoc* parent()const { return (KSpreadDoc*)parent(); }
-  KSpreadSheet* table()const { return m_pTable; }
+  KSpreadSheet* sheet()const { return m_pSheet; }
 
 protected:
-  KSpreadSheet *m_pTable;
+  KSpreadSheet *m_pSheet;
 };
 
 /********************************************************************
@@ -143,7 +149,7 @@ class ChartBinding : public CellBinding
     Q_OBJECT
 public:
 
-    ChartBinding( KSpreadSheet *_table, const QRect& _area, ChartChild *_child );
+    ChartBinding( KSpreadSheet *_sheet, const QRect& _area, ChartChild *_child );
     virtual ~ChartBinding();
 
     virtual void cellChanged( KSpreadCell *_obj );
@@ -156,8 +162,8 @@ class ChartChild : public KSpreadChild
 {
     Q_OBJECT
 public:
-    ChartChild( KSpreadDoc *_spread, KSpreadSheet *_table, KoDocument* doc, const QRect& _rect );
-    ChartChild( KSpreadDoc *_spread, KSpreadSheet *_table );
+    ChartChild( KSpreadDoc *_spread, KSpreadSheet *_sheet, KoDocument* doc, const QRect& _rect );
+    ChartChild( KSpreadDoc *_spread, KSpreadSheet *_sheet );
     ~ChartChild();
 
     void setDataArea( const QRect& _data );
@@ -218,65 +224,92 @@ protected:
 
 /********************************************************************
  *
- * Table
+ * Sheet
  *
  ********************************************************************/
 
+class SheetPrivate;
+
+
 /**
  */
-class KSpreadSheet : public QObject
+class KSPREAD_EXPORT KSpreadSheet : public QObject
 {
     friend class KSpreadCell;
 
     Q_OBJECT
+
+
+    Q_PROPERTY( QString sheetName READ sheetName )
+    Q_PROPERTY( bool autoCalc READ getAutoCalc WRITE setAutoCalc )
+    Q_PROPERTY( bool showGrid READ getShowGrid WRITE setShowGrid )
+
 public:
     enum Direction { Right, Left, Up, Down };
     enum SortingOrder{ Increase, Decrease };
     enum ChangeRef { ColumnInsert, ColumnRemove, RowInsert, RowRemove };
     enum TestType { Text, Validity, Comment, ConditionalCellAttribute };
 
-    KSpreadSheet( KSpreadMap *_map, const QString &tableName, const char *_name=0L );
+    enum LayoutDirection { LeftToRight, RightToLeft };
+
+    KSpreadSheet ( KSpreadMap* map, const QString &sheetName,
+        const char *_name=0L );
     ~KSpreadSheet();
 
     virtual bool isEmpty( unsigned long int x, unsigned long int y ) const;
 
     /**
-     * @return the name of this table.
-     *
-     * @see #setTableName
+     * Return the name of this sheet.
      */
-    QString tableName()const { return m_strName; }
+    QString sheetName() const;
+
     /**
-     * Renames a table. This will automatically adapt all formulas
-     * in all tables and all cells to reflect the new name.
+     * \deprecated Use sheetName().
+     */
+    QString tableName() const { return sheetName(); }
+
+    /**
+     * Renames a sheet. This will automatically adapt all formulas
+     * in all sheets and all cells to reflect the new name.
      *
      * If the name really changed then @ref #sig_nameChanged is emitted
-     * and the GUI will reflect the change. In addition a @ref KSpreadUndoSetTableName
-     * object will be created to implement undo.
+     * and the GUI will reflect the change.
      *
      * @param init If set to TRUE then no formula will be changed and no signal
      *             will be emitted and no undo action created. Usually you dont
      *             want to do that.
      *
      *
-     * @return FALSE if the table could not be renamed. Usually the reason is
+     * @return FALSE if the sheet could not be renamed. Usually the reason is
      *         that this name is already used.
      *
      * @see #changeCellTabName
      * @see KSpreadTabBar::renameTab
-     * @see #tableName
+     * @see #sheetName
      */
-    bool setTableName( const QString& name, bool init = FALSE, bool makeUndo=true );
+    bool setSheetName( const QString& name, bool init = FALSE, bool makeUndo=true );
+    
+    KSpreadMap* workbook();
+    KSpreadDoc* doc();
 
     /**
-     * Saves the table and all it's children in XML format
+     * Saves the sheet and all it's children in XML format
      */
     virtual QDomElement saveXML( QDomDocument& );
     /**
-     * Loads the table and all it's children in XML format
+     * Loads the sheet and all it's children in XML format
      */
     virtual bool loadXML( const QDomElement& );
 
+    virtual bool loadOasis( const QDomElement& sheet, const KoOasisStyles& oasisStyles );
+
+    virtual bool saveOasis( KoXmlWriter & xmlWriter, KoGenStyles &mainStyles, KSpreadGenValidationStyles &valStyle );
+    void saveOasisHeaderFooter( KoXmlWriter &xmlWriter ) const;
+
+    void loadOasisSettings( const KoOasisSettings::NamedMap &settings );
+    void saveOasisSettings( KoXmlWriter &settingsWriter, const QPoint& marker ) const;
+    void saveOasisPrintStyleLayout( KoGenStyle &style ) const;
+
     /**
      * Saves a children
      */
@@ -287,12 +320,27 @@ public:
     virtual bool loadChildren( KoStore* _store );
 
     bool isLoading();
-    inline bool isRightToLeft() const { return m_bRightToLeft; }
 
-    void password( QCString & passwd ) const { passwd = m_strPassword; }
-    bool isProtected() const { return !m_strPassword.isNull(); }
+    /**
+     * Returns the layout direction of the sheet.
+     */
+    LayoutDirection layoutDirection() const;
+
+    /**
+     * Sets the layout direction of the sheet. For example, for Arabic or Hebrew
+     * documents, it is possibly to layout the sheet from right to left.
+     */
+    void setLayoutDirection( LayoutDirection dir );
+
+    /**
+     * \deprecated Use direction().
+     */
+    bool isRightToLeft() const;
+
+    void password( QCString & passwd ) const ;
+    bool isProtected() const;
     void setProtected( QCString const & passwd );
-    bool checkPassword( QCString const & passwd ) const { return ( passwd == m_strPassword ); }
+    bool checkPassword( QCString const & passwd ) const;
 
     void setDefaultHeight( double height );
     void setDefaultWidth( double width );
@@ -316,7 +364,7 @@ public:
     RowFormat* nonDefaultRowFormat( int _row, bool force_creation = TRUE );
 
     /**
-     * @return the first cell of this table. Next cells can
+     * @return the first cell of this sheet. Next cells can
      * be retrieved by calling @ref KSpreadCell::nextCell.
      */
     KSpreadCell* firstCell() const;
@@ -362,10 +410,15 @@ public:
     KSpreadCell* nonDefaultCell( QPoint const & cellRef, bool scroll = false )
       { return nonDefaultCell( cellRef.x(), cellRef.y(), scroll ); }
 
-    KSpreadCell* defaultCell()const { return m_pDefaultCell; }
+    KSpreadCell* defaultCell() const;
 
-    KSpreadFormat* defaultFormat() { return m_defaultFormat; };
-    const KSpreadFormat* defaultFormat() const { return m_defaultFormat; }
+    KSpreadFormat* defaultFormat();
+    const KSpreadFormat* defaultFormat() const;
+
+    /** retrieve a value */
+    KSpreadValue value (int col, int row) const;
+    /** retrieve a range of values */
+    KSpreadValue valueRange (int col1, int row1, int col2, int row2) const;
 
     QRect visibleRect( KSpreadCanvas const * const _canvas ) const;
     int topRow( double _ypos, double &_top, const KSpreadCanvas *_canvas = 0L ) const;
@@ -378,7 +431,7 @@ public:
      *
      * @param _canvas If not 0 then the returned position is in screen
      *                coordinates. Otherwise the point (0|0) is in the upper
-     *                left corner of the table.
+     *                left corner of the sheet.
      */
     int columnPos( int _col, const KSpreadCanvas *_canvas = 0L ) const;
     /**
@@ -388,7 +441,7 @@ public:
      *
      * @param _canvas If not 0 then the returned position is in screen
      *                coordinates. Otherwise the point (0|0) is in the upper
-     *                left corner of the table.
+     *                left corner of the sheet.
      */
     double dblColumnPos( int _col, const KSpreadCanvas *_canvas = 0L ) const;
     /**
@@ -396,7 +449,7 @@ public:
      *
      * @param _canvas If not 0 then the returned position is in screen
      *                coordinates. Otherwise the point (0|0) is in the upper
-     *                top corner of the table.
+     *                top corner of the sheet.
      */
     int rowPos( int _row, const KSpreadCanvas *_canvas = 0L ) const;
     /**
@@ -406,18 +459,18 @@ public:
      *
      * @param _canvas If not 0 then the returned position is in screen
      *                coordinates. Otherwise the point (0|0) is in the upper
-     *                top corner of the table.
+     *                top corner of the sheet.
      */
     double dblRowPos( int _row, const KSpreadCanvas *_canvas = 0L ) const;
 
     /**
      * @return the maximum size of the column range
      */
-    double sizeMaxX()const { return m_dSizeMaxX; }
+    double sizeMaxX() const ;
     /**
      * @return the maximum size of the row range
      */
-    double sizeMaxY()const { return m_dSizeMaxY; }
+    double sizeMaxY() const;
 
     /**
      * Adjusts the internal reference of the sum of the widths of all columns.
@@ -444,24 +497,28 @@ public:
     void setCalcDirtyFlag();
 
     /**
-     * Calculates all cells in the table with the CalcDirtyFlag.
+     * Calculates all cells in the sheet with the CalcDirtyFlag.
      */
   //why on earth would we want to do this?
 //    void calc();
 
     /**
-     * Recalculates the current table. If you want to recalculate EVERYTHING, then
-     * call @ref Table::setCalcDirtyFlag for all tables in the @ref #m_pMap to make
-     * sure that no invalid values in other tables make you trouble.
+     * Recalculates the current sheet. If you want to recalculate EVERYTHING, then
+     * call @ref Sheet::setCalcDirtyFlag for all sheets in the @ref #m_pMap to make
+     * sure that no invalid values in other sheets make you trouble.
      */
     void recalc();
 
+    /** handles the fact that a cell has been changed - updates
+    things that need to be updated */
+    void valueChanged (KSpreadCell *cell);
+
     /**
      * Sets the contents of the cell at row,column to text
      * @param updateDepends set to false to disable updating the dependencies
      */
     void setText( int row, int column, const QString& text,
-                  bool updateDepends = true, bool asString = false );
+                  bool asString = false );
 
 
 
@@ -514,11 +571,8 @@ public:
      *                In this case the cell on which the marker is will
      *                be deleted.
      *
-     * @param preserveDoM preserve the DependingOnMe list (set this to true if you want
-     *        the cells in the selection to remember which cells depend on them)
-     *
      */
-    void deleteSelection( KSpreadSelection* selectionInfo, bool undo = true, bool preserveDoM = false );
+    void deleteSelection( KSpreadSelection* selectionInfo, bool undo = true );
 
     /**
      * @param _marker is used if there is no selection currently.
@@ -570,12 +624,12 @@ public:
     void sortByRow( const QRect &area, int key1, int key2, int key3,
                     SortingOrder order1, SortingOrder order2, SortingOrder order3,
                     QStringList const * firstKey, bool copyFormat, bool headerRow,
-                    KSpreadPoint const & outputPoint );
+                    KSpreadPoint const & outputPoint, bool respectCase );
     void sortByColumn( const QRect &area, int ref_column, SortingOrder );
     void sortByColumn( const QRect &area, int key1, int key2, int key3,
                        SortingOrder order1, SortingOrder order2, SortingOrder order3,
                        QStringList const * firstKey, bool copyFormat, bool headerRow,
-                       KSpreadPoint const & outputPoint );
+                       KSpreadPoint const & outputPoint, bool respectCase );
     void swapCells( int x1, int y1, int x2, int y2, bool cpFormat );
 
     /**
@@ -603,22 +657,22 @@ public:
 
     /**
      * Moves all columns which are >= @p col one position to the right and
-     * inserts a new and empty column. After this the table is redrawn.
+     * inserts a new and empty column. After this the sheet is redrawn.
      * nbCol is the number of column which are installing
      */
     bool insertColumn( int col, int nbCol=0, bool makeUndo=true );
     /**
      * Moves all rows which are >= @p row one position down and
-     * inserts a new and empty row. After this the table is redrawn.
+     * inserts a new and empty row. After this the sheet is redrawn.
      */
     bool insertRow( int row, int nbRow=0, bool makeUndo=true );
 
     /**
-     * Deletes the column @p col and redraws the table.
+     * Deletes the column @p col and redraws the sheet.
      */
     void removeColumn( int col, int nbCol=0, bool makeUndo=true );
     /**
-     * Deletes the row @p row and redraws the table.
+     * Deletes the row @p row and redraws the sheet.
      */
     void removeRow( int row, int nbRow=0, bool makeUndo=true );
 
@@ -658,50 +712,49 @@ public:
     /**
      * Returns, if the grid shall be shown on the screen
      */
-    bool getShowGrid() const { return m_bShowGrid; }
+    bool getShowGrid() const;
 
     /**
      * Sets, if the grid shall be shown on the screen
      */
-    void setShowGrid( bool _showGrid ) { m_bShowGrid=_showGrid; }
+    void setShowGrid( bool _showGrid );
 
     /**
      * Sets, if formula shall be shown instead of the result
      */
-    bool getShowFormula() const {return m_bShowFormula;}
+    bool getShowFormula() const;
 
-    void setShowFormula(bool _showFormula) {m_bShowFormula=_showFormula;}
+    void setShowFormula(bool _showFormula);
 
     /**
      * Sets, if indicator must be shown when the cell holds a formula
      */
-    bool getShowFormulaIndicator() const {return m_bShowFormulaIndicator;}
+    bool getShowFormulaIndicator() const;
 
-    void setShowFormulaIndicator(bool _showFormulaIndicator)
-        {m_bShowFormulaIndicator=_showFormulaIndicator;}
+    void setShowFormulaIndicator(bool _showFormulaIndicator);
 
-    bool getLcMode() const {return m_bLcMode;}
+    bool getLcMode() const;
 
-    void setLcMode(bool _lcMode) {m_bLcMode=_lcMode;}
+    void setLcMode(bool _lcMode);
 
-    bool getAutoCalc() const {return m_bAutoCalc;}
+    bool getAutoCalc() const;
 
-    void setAutoCalc(bool _AutoCalc) {m_bAutoCalc=_AutoCalc;}
+    void setAutoCalc(bool _AutoCalc);
 
-    bool getShowColumnNumber() const {return m_bShowColumnNumber;}
+    bool getShowColumnNumber() const;
 
-    void setShowColumnNumber(bool _showColumnNumber) {m_bShowColumnNumber=_showColumnNumber;}
+    void setShowColumnNumber(bool _showColumnNumber);
 
-    bool getHideZero() const {return m_bHideZero;}
+    bool getHideZero() const;
 
-    void setHideZero(bool _hideZero) {m_bHideZero=_hideZero;}
+    void setHideZero(bool _hideZero);
 
-    bool getFirstLetterUpper() const {return m_bFirstLetterUpper;}
+    bool getFirstLetterUpper() const;
 
-    void setFirstLetterUpper(bool _firstUpper) {m_bFirstLetterUpper=_firstUpper;}
+    void setFirstLetterUpper(bool _firstUpper);
 
-    void mergeCells( const QRect &area, bool makeUndo=true );
-    void dissociateCell( const QPoint &cellRef, bool makeUndo=true );
+    void mergeCells( const QRect &area );
+    void dissociateCell( const QPoint &cellRef );
     void changeMergedCell( int m_iCol, int m_iRow, int m_iExtraX, int m_iExtraY);
 
     void increaseIndent( KSpreadSelection* selectionInfo );
@@ -711,15 +764,15 @@ public:
 
     void refreshPreference() ;
 
-    void hideTable(bool _hide);
+    void hideSheet(bool _hide);
 
-    void removeTable();
+    void removeSheet();
 
     QRect selectionCellMerged(const QRect &_sel);
     /**
      * Change name of reference when the user inserts or removes a column,
      * a row or a cell (= insertion of a row [or column] on a single column [or row]).
-     * For example the formula =Table1!A1 is changed into =Table1!B1 if a Column
+     * For example the formula =Sheet1!A1 is changed into =Sheet1!B1 if a Column
      * is inserted before A.
      *
      * @param pos the point of insertion (only one coordinate may be used, depending
@@ -727,7 +780,7 @@ public:
      * @param fullRowOrColumn if true, a whole row or column has been inserted/removed.
      *                        if false, we inserted or removed a cell
      * @param ref see ChangeRef
-     * @param tabname completes the pos specification by giving the table name
+     * @param tabname completes the pos specification by giving the sheet name
      * @param undo is the handler of the undo class in case of lost cell references
      */
     void changeNameCellRef( const QPoint & pos, bool fullRowOrColumn,
@@ -747,7 +800,7 @@ public:
      * @param fullRowOrColumn if true, a whole row or column has been inserted/removed.
      *                        if false, we inserted or removed a cell
      * @param ref see ChangeRef
-     * @param tabname completes the pos specification by giving the table name
+     * @param tabname completes the pos specification by giving the sheet name
      */
     void refreshChart(const QPoint & pos, bool fullRowOrColumn, ChangeRef ref);
     /**
@@ -756,21 +809,13 @@ public:
     void refreshMergedCell();
 
     /**
-     * @return true if this table is hidden
+     * @return true if this sheet is hidden
      */
-    bool isHidden()const { return m_bTableHide; }
+    bool isHidden()const;
     /**
-     * Hides or shows this tables
+     * Hides or shows this sheets
      */
-    void setHidden( bool hidden ) { m_bTableHide=hidden; }
-
-    /**
-     * For internal use only.
-     */
-    void setMap( KSpreadMap* _map ) { m_pMap = _map; }
-
-    KSpreadDoc* doc()const { return m_pDoc; }
-    KSpreadMap* map()const { return m_pMap; }
+    void setHidden( bool hidden );
 
     /**
      * @return a painter for the hidden widget ( @ref #widget ).
@@ -778,21 +823,21 @@ public:
      * This function is useful while making formats where you
      * need some QPainter related functions.
      */
-    QPainter& painter() { return *m_pPainter; }
+    QPainter& painter();
     /**
      * @return a hidden widget.
      *
      * @see #painter
      */
-    QWidget* widget()const { return m_pWidget; }
+    QWidget* widget()const;
 
     /**
-     * @return a flag that indicates whether the table should paint the page breaks.
+     * @return a flag that indicates whether the sheet should paint the page breaks.
      *
      * @see #setShowPageBorders
      * @see #bShowPageBorders
      */
-    bool isShowPageBorders()const { return m_bShowPageBorders; }
+    bool isShowPageBorders() const;
 
     /**
      * Turns the page break lines on or off.
@@ -804,23 +849,23 @@ public:
 
     void addCellBinding( CellBinding *_bind );
     void removeCellBinding( CellBinding *_bind );
-    CellBinding* firstCellBinding() { return m_lstCellBindings.first(); }
-    CellBinding* nextCellBinding() { return m_lstCellBindings.next(); }
+    CellBinding* firstCellBinding();
+    CellBinding* nextCellBinding();
 
     /**
-     * Used by the 'chart' to get the table on which the chart is build.
+     * Used by the 'chart' to get the sheet on which the chart is build.
      * The cells we are interested in are in the rectangle '_range'.
      * The cells are stored row after row in '_list'.
      */
     bool getCellRectangle( const QRect &_range, QPtrList<KSpreadCell> &_list );
 
     /**
-     * A convenience function that finds a table by its name.
+     * A convenience function that finds a sheet by its name.
      */
-    KSpreadSheet *findTable( const QString & _name );
+    KSpreadSheet *findSheet( const QString & _name );
 
     /**
-     * Inserts the @p _cell into the table.
+     * Inserts the @p _cell into the sheet.
      * All cells depending on this cell will be actualized.
      * The border range will be actualized, when the cell is out of current range.
      */
@@ -878,12 +923,9 @@ public:
      *
      * @param rect The rectangle that contains the cells that should be deleted
      *
-     * @param preserveDoM preserve the DependingOnMe list (set this to true if you want
-     *        the cells in rect to remember which cells depend on them)
-     *
      * @see #loadCells
      */
-    void deleteCells( const QRect& rect, bool preserveDoM = false );
+    void deleteCells( const QRect& rect );
 
 
     /**
@@ -924,16 +966,16 @@ public:
     void insertChart( const QRect& _geometry, KoDocumentEntry&, const QRect& _data );
     void changeChildGeometry( KSpreadChild *_child, const QRect& _geometry );
 
-    const QColorGroup& colorGroup() { return m_pWidget->colorGroup(); }
+    const QColorGroup& colorGroup() { return widget()->colorGroup(); }
 
-    int id() const { return m_id; }
+    int id() const;
 
     /**
      * Return the currently maximum defined column of the horizontal scrollbar.
      * It's always 10 times higher than the maximum access column.
-     * In an empty table it starts with 256.
+     * In an empty sheet it starts with 256.
      */
-    int maxColumn()const { return m_iMaxColumn; }
+    int maxColumn() const ;
 
     /**
      * Checks if the argument _column is out of the current maximum range of the vertical border
@@ -946,9 +988,9 @@ public:
     /**
      * Return the currently maximum defined row of the vertical scrollbar.
      * It's always 10 times higher than the maximum access row.
-     * In an empty table it starts with 256.
+     * In an empty sheet it starts with 256.
      */
-    int maxRow()const { return m_iMaxRow; }
+    int maxRow() const ;
 
     /**
      * Checks if the argument _row is out of the current maximum range of the horizontal border
@@ -984,7 +1026,7 @@ public:
     void updateCellArea(const QRect &cellArea);
 
     /**
-     * Updates every cell on the table
+     * Updates every cell on the sheet
      */
     void update();
 
@@ -1012,9 +1054,9 @@ public:
      *
      * The returned pen has pen style NoPen set.
      */
-    const QPen& emptyPen() const { return m_emptyPen; }
-    const QBrush& emptyBrush() const { return m_emptyBrush; }
-    const QColor& emptyColor() const { return m_emptyColor; }
+    const QPen& emptyPen() const ;
+    const QBrush& emptyBrush() const;
+    const QColor& emptyColor() const;
 
     void updateLocale();
 
@@ -1126,43 +1168,61 @@ public:
    */
   KSpreadCell* getNextCellRight(int col, int row) const;
 
-  KSpreadSheetPrint * print() const { return m_pPrint; }
+  KSpreadSheetPrint * print() const;
 
+  /** returns a pointer to the dependency manager */
+  KSpread::DependencyManager *dependencies ();
 
 signals:
     void sig_refreshView();
-    void sig_updateView( KSpreadSheet *_table );
-    void sig_updateView( KSpreadSheet *_table, const QRect& );
-    void sig_updateHBorder( KSpreadSheet *_table );
-    void sig_updateVBorder( KSpreadSheet *_table );
+    void sig_updateView( KSpreadSheet *_sheet );
+    void sig_updateView( KSpreadSheet *_sheet, const QRect& );
+    void sig_updateHBorder( KSpreadSheet *_sheet );
+    void sig_updateVBorder( KSpreadSheet *_sheet );
     void sig_updateChildGeometry( KSpreadChild *_child );
     void sig_removeChild( KSpreadChild *_child );
     void sig_maxColumn( int _max_column );
     void sig_maxRow( int _max_row );
     /**
-     * @see #setTableName
+     * @see #setSheetName
      */
-    void sig_nameChanged( KSpreadSheet* table, const QString& old_name );
+    void sig_nameChanged( KSpreadSheet* sheet, const QString& old_name );
     /**
-     * Emitted if a certain area of some table has to be redrawn.
+     * Emitted if a certain area of some sheet has to be redrawn.
      * That is for example the case when a new child is inserted.
      */
     void sig_polygonInvalidated( const QPointArray& );
 
-    void sig_TableHidden( KSpreadSheet* table);
-    void sig_TableShown( KSpreadSheet* table);
-    void sig_TableRemoved( KSpreadSheet* table);
-    void sig_TableActivated( KSpreadSheet* );
+    void sig_SheetHidden( KSpreadSheet* sheet);
+    void sig_SheetShown( KSpreadSheet* sheet);
+    void sig_SheetRemoved( KSpreadSheet* sheet);
+    void sig_SheetActivated( KSpreadSheet* );
     void sig_RefreshView( KSpreadSheet* );
 
 protected:
     /**
-     * Change the name of a table in all formulas.
-     * When you change name table Table1 -> Price
-     * for all cell which refere to Table1, this function changes the name.
+     * Change the name of a sheet in all formulas.
+     * When you change name sheet Sheet1 -> Price
+     * for all cell which refere to Sheet1, this function changes the name.
      */
     void changeCellTabName( QString const & old_name,QString const & new_name );
 
+    bool loadRowFormat( const QDomElement& row, int &rowIndex, const KoOasisStyles& oasisStyles, bool isLast );
+    bool loadColumnFormat(const QDomElement& row, const KoOasisStyles& oasisStyles, int & indexCol );
+    bool loadSheetStyleFormat( QDomElement *style );
+    void loadOasisMasterLayoutPage( KoStyleStack &styleStack );
+
+    QString saveOasisSheetStyleName( KoGenStyles &mainStyles );
+    void saveOasisColRowCell( KoXmlWriter& xmlWriter, KoGenStyles &mainStyles, int maxCols, int maxRows, KSpreadGenValidationStyles &valStyle );
+    void saveOasisCells(  KoXmlWriter& xmlWriter, KoGenStyles &mainStyles, int row, int maxCols, KSpreadGenValidationStyles &valStyle );
+    void convertPart( const QString & part, KoXmlWriter & writer ) const;
+    void addText( const QString & text, KoXmlWriter & writer ) const;
+
+    void maxRowCols( int & maxCols, int & maxRows );
+
+    QString getPart( const QDomNode & part );
+    void replaceMacro( QString & text, const QString & old, const QString & newS );
+
     void insertChild( KSpreadChild *_child );
 
     /**
@@ -1170,130 +1230,8 @@ protected:
      */
     void fillSequence( QPtrList<KSpreadCell>& _srcList, QPtrList<KSpreadCell>& _destList, QPtrList<AutoFillSequence>& _seqList, bool down = true );
 
-    KSpreadCluster m_cells;
-    KSpreadRowCluster m_rows;
-    KSpreadColumnCluster m_columns;
-
-    KSpreadCell* m_pDefaultCell;
-    RowFormat* m_pDefaultRowFormat;
-    ColumnFormat* m_pDefaultColumnFormat;
-
-    /**
-     * The name of the table. This name shows in the tab bar on the bottom of the window.
-     */
-    QString m_strName;
-
-    /**
-     * Indicates whether the table should paint the page breaks.
-     * Doing so costs some time, so by default it should be turned off.
-     */
-    bool m_bShowPageBorders;
-
-    /**
-     * List of all cell bindings. For example charts use bindings to get
-     * informed about changing cell contents.
-     *
-     * @see #addCellBinding
-     * @see #removeCellBinding
-     */
-    QPtrList<CellBinding> m_lstCellBindings;
-
-    /**
-     * The label returned by @ref #columnLabel
-     */
-    char m_arrColumnLabel[20];
-
-    /**
-     * The map to which this table belongs.
-     */
-    KSpreadMap *m_pMap;
-    KSpreadDoc *m_pDoc;
-
-    /**
-     * Password for protecting this sheet
-     */
-    QCString m_strPassword;
-
-    /**
-     * Needed to get infos about font metrics.
-     */
-    QPainter *m_pPainter;
-    /**
-     * Used for @ref #m_pPainter
-     */
-    QWidget *m_pWidget;
-
-    /**
-     * List of all embedded objects.
-     */
-    // QPtrList<KSpreadChild> m_lstChildren;
-
-    int m_id;
-
-    /**
-     * The highest row ever accessed by the user.
-     */
-    int m_iMaxRow;
-    /**
-     * The highest column ever accessed by the user.
-     */
-    int m_iMaxColumn;
-
-    /**
-     * Max range of canvas in x direction.
-     * Depends on KS_colMax and the width of all columns
-     */
-    double m_dSizeMaxX;
-
-    /**
-     * Max range of canvas in y direction.
-     * Depends on KS_rowMax and the height of all rows
-     */
-    double m_dSizeMaxY;
-
-
-    bool m_bScrollbarUpdates;
-    bool m_bRightToLeft;
-
-    DCOPObject* m_dcop;
-    bool m_bTableHide;
-
     static int s_id;
-    static QIntDict<KSpreadSheet>* s_mapTables;
-
-    /**
-     * Show the grid on the screen
-     */
-    bool m_bShowGrid;
-    bool m_bShowFormula;
-    bool m_bShowFormulaIndicator;
-    bool m_bAutoCalc;
-    bool m_bLcMode;
-    bool m_bShowColumnNumber;
-    bool m_bHideZero;
-    bool m_bFirstLetterUpper;
-
-    KSpreadFormat* m_defaultFormat;
-
-    /**
-     * @see #emptyPen
-     */
-    QPen m_emptyPen;
-    QBrush m_emptyBrush;
-    QColor m_emptyColor;
-
-    int m_iScrollPosX;
-    int m_iScrollPosY;
-
-    /**
-     * Holds the pointer to the print object
-     */
-    KSpreadSheetPrint * m_pPrint;
-
-    /**
-     * Stores cells that need repainting
-     */
-    QValueList<QRect> m_paintDirtyList;
+    static QIntDict<KSpreadSheet>* s_mapSheets;
 
 public:
     // see kspread_sheet.cc for an explanation of this
@@ -1306,7 +1244,7 @@ public:
 	CellWorker( bool cid=true, bool es=true, bool tb=true ) : create_if_default( cid ), emit_signal( es ), type_B( tb ) { }
 	virtual ~CellWorker() { }
 
-	virtual class KSpreadUndoAction* createUndoAction( KSpreadDoc* doc, KSpreadSheet* table, QRect& r ) =0;
+	virtual class KSpreadUndoAction* createUndoAction( KSpreadDoc* doc, KSpreadSheet* sheet, QRect& r ) =0;
 
 	// these are only needed for type A
 	virtual bool testCondition( RowFormat* ) { return false; }
@@ -1323,9 +1261,9 @@ public:
     struct CellWorkerTypeA : public CellWorker {
 	CellWorkerTypeA( ) : CellWorker( true, true, false ) { }
 	virtual QString getUndoTitle( ) =0;
-	class KSpreadUndoAction* createUndoAction( KSpreadDoc* doc, KSpreadSheet* table, QRect& r );
+	class KSpreadUndoAction* createUndoAction( KSpreadDoc* doc, KSpreadSheet* sheet, QRect& r );
     };
-
+    static QString translateOpenCalcPoint( const QString & str );
 protected:
     typedef enum { CompleteRows, CompleteColumns, CellRegion } SelectionType;
     SelectionType workOnCells( KSpreadSelection* selectionInfo,
@@ -1345,8 +1283,15 @@ private:
     void checkCellContent(KSpreadCell * cell1, KSpreadCell * cell2, int & ret);
     int  adjustColumnHelper( KSpreadCell * c, int _col, int _row );
     void checkContentDirection( QString const & name );
+
+    SheetPrivate* d;
+
+    // don't allow copy or assignment
+    KSpreadSheet( const KSpreadSheet& );
+    KSpreadSheet& operator=( const KSpreadSheet& );
 };
 
-typedef KSpreadSheet KSpreadTable;
+// for compatibility only, remove in the future
+typedef KSpreadSheet KSpreadSheet;
 
-#endif
+#endif  // KSPREAD_SHEET
