@@ -23,8 +23,11 @@
 #include <qstring.h>
 #include <qrect.h>
 #include <qdatetime.h>
-#include <kspread_cell.h>
 
+#include "kspread_global.h"
+#include "kspread_value.h"
+#include <koffice_export.h>
+class KSpreadCell;
 class KSpreadMap;
 class KSpreadSheet;
 class KLocale;
@@ -34,36 +37,44 @@ class QPen;
 class QDomElement;
 class QDomDocument;
 
-struct KSpreadPoint
+struct KSPREAD_EXPORT KSpreadPoint
 {
 public:
-  KSpreadPoint() { pos.setX( -1 ); table = 0; columnFixed = false; rowFixed = false; }
+  KSpreadPoint() { pos.setX( -1 ); sheet = 0; columnFixed = false; rowFixed = false; }
   KSpreadPoint( const QString& );
-  KSpreadPoint( const QString&, KSpreadMap*, KSpreadSheet* default_table = 0 );
+  KSpreadPoint( const QString&, KSpreadMap*, KSpreadSheet* default_sheet = 0 );
   KSpreadPoint( const KSpreadPoint& c ) {
     pos = c.pos;
-    table = c.table; tableName = c.tableName;
+    sheet = c.sheet; sheetName = c.sheetName;
     columnFixed = c.columnFixed;
     rowFixed = c.rowFixed;
   }
 
-  bool isValid() const { return ( pos.x() >= 0 && ( table != 0 || tableName.isEmpty() ) ); }
-  bool isTableKnown() const { return ( !tableName.isEmpty() && table != 0 ); }
+  bool isValid() const { return ( pos.x() >= 0 && ( sheet != 0 || sheetName.isEmpty() ) ); }
+  bool isSheetKnown() const { return ( !sheetName.isEmpty() && sheet != 0 ); }
 
-  KSpreadCell* cell();
+  KSpreadCell* cell() const;
+
+  bool operator== (const KSpreadPoint &cell) const;
+  bool operator< (const KSpreadPoint &cell) const;
+
+  int row () const { return pos.y(); };
+  int column () const { return pos.x(); };
+  void setRow (int r) { pos.setY (r); };
+  void setColumn (int c) { pos.setX (c); };
 
   /*
     TODO
   bool columnFixed() const { return m_columnFixed; }
   bool rowFixed() const { return m_rowFixed; }
   QPoint pos() const { return m_pos; }
-  QString tableName() const { return m_tableName; }
-  KSpreadSheet* table() const { return m_table; }
+  QString sheetName() const { return m_sheetName; }
+  KSpreadSheet* sheet() const { return m_sheet; }
 
 private:
   */
-  KSpreadSheet* table;
-  QString tableName;
+  KSpreadSheet* sheet;
+  QString sheetName;
   QPoint pos;
   bool columnFixed;
   bool rowFixed;
@@ -72,37 +83,47 @@ private:
   void init( const QString& );
 };
 
-struct KSpreadRange
+struct KSPREAD_EXPORT KSpreadRange
 {
-  KSpreadRange() { table = 0; range.setLeft( -1 ); }
+  KSpreadRange() { sheet = 0; range.setLeft( -1 ); }
   KSpreadRange( const QString& );
-  KSpreadRange( const QString&, KSpreadMap*, KSpreadSheet* default_table = 0 );
+  KSpreadRange( const QString&, KSpreadMap*, KSpreadSheet* default_sheet = 0 );
   KSpreadRange( const KSpreadRange& r ) {
-    table = r.table;
-    tableName = r.tableName;
+    sheet = r.sheet;
+    sheetName = r.sheetName;
     range = r.range;
   }
   KSpreadRange( const KSpreadPoint& ul, const KSpreadPoint& lr )
   {
     range = QRect( ul.pos, lr.pos );
-    if ( ul.tableName != lr.tableName )
+    if ( ul.sheetName != lr.sheetName )
     {
       range.setLeft( -1 );
       return;
     }
-    tableName = ul.tableName;
-    table = ul.table;
+    sheetName = ul.sheetName;
+    sheet = ul.sheet;
     leftFixed = ul.columnFixed;
     rightFixed = lr.columnFixed;
     topFixed = ul.rowFixed;
     bottomFixed = lr.rowFixed;
   }
 
-  bool isValid() const { return ( range.left() >= 0 && range.right() >= 0 && ( table != 0 || tableName.isEmpty() ) ); }
-  bool isTableKnown() const { return ( !tableName.isEmpty() && table != 0 ); }
+  bool isValid() const { return ( range.left() >= 0 && range.right() >= 0 && ( sheet != 0 || sheetName.isEmpty() ) ); }
+  bool isSheetKnown() const { return ( !sheetName.isEmpty() && sheet != 0 ); }
 
-  KSpreadSheet* table;
-  QString tableName;
+  int startRow () const { return range.top(); };
+  int startCol () const { return range.left(); };
+  int endRow () const { return range.bottom(); };
+  int endCol () const { return range.right(); };
+
+  /** does this range contain the given cell? */
+  bool contains (const KSpreadPoint &cell) const;
+  /** do these two ranges have at least one common cell? */
+  bool intersects (const KSpreadRange &r) const;
+
+  KSpreadSheet* sheet;
+  QString sheetName;
   QRect range;
   bool leftFixed;
   bool rightFixed;
@@ -110,6 +131,19 @@ struct KSpreadRange
   bool bottomFixed;
 };
 
+/**
+range-list and cell-list
+TODO: move to a separate file, improve structure, add iterators and all that
+TODO: use this class instead of other means of range-walking all over KSpread
+TODO: use this as selection
+TODO: anything I forgot ;)
+*/
+struct RangeList {
+  QValueList<KSpreadPoint> cells;
+  QValueList<KSpreadRange> ranges;
+};
+
+
 /**
  * KSpreadRangeIterator
  *
@@ -121,9 +155,9 @@ class KSpreadRangeIterator
 public:
   /**
    * Contstruct the iterator with the rectangular cell area and which
-   * table the area is on
+   * sheet the area is on
    */
-  KSpreadRangeIterator(QRect _range, KSpreadSheet* _table);
+  KSpreadRangeIterator(QRect _range, KSpreadSheet* _sheet);
   ~KSpreadRangeIterator();
 
   /**
@@ -139,13 +173,19 @@ public:
 private:
 
   QRect range;
-  KSpreadSheet* table;
+  KSpreadSheet* sheet;
   QPoint current;
 };
 
+//helper functions for the formatting
+bool formatIsDate (FormatType fmt);
+bool formatIsTime (FormatType fmt);
+bool formatIsFraction (FormatType fmt);
 
-QString util_rangeName( const QRect &_area );
-QString util_rangeName( KSpreadSheet *_table, const QRect &_area );
+
+
+KSPREAD_EXPORT QString util_rangeName( const QRect &_area );
+KSPREAD_EXPORT QString util_rangeName( KSpreadSheet *_sheet, const QRect &_area );
 QString util_rangeColumnName( const QRect &_area);
 QString util_rangeRowName( const QRect &_area);
 
@@ -153,32 +193,23 @@ QString util_rangeRowName( const QRect &_area);
 * Call this function to decode the text of a column label to an integer
 * i.e. AA->27
 */
-int util_decodeColumnLabelText( const QString &_col );
+KSPREAD_EXPORT int util_decodeColumnLabelText( const QString &_col );
 /**
 * Call this function to encode an integer to the text of the column label
 * i.e. 27->AA
 */
-QString util_encodeColumnLabelText( int column );
-
-QString util_dateFormat( KLocale* locale, const QDate &_date, KSpreadCell::FormatType fmtType);
-
-QString util_timeFormat( KLocale* locale, const QDateTime &_time, KSpreadCell::FormatType fmtType);
-
-QString util_dateTimeFormat( KLocale * locale, double date, KSpreadCell::FormatType fmtType, QString const & format );
-
-QString util_fractionFormat( double value , KSpreadCell::FormatType fmtType);
+KSPREAD_EXPORT QString util_encodeColumnLabelText( int column );
 
 QString formatNumber( KSpreadValue const & value, QString format, bool & setRed,
                       KLocale const * const locale, bool insert );
 
 double util_fact( double val, double end );
 
+bool util_isAllSelected(const QRect &selection);
 bool util_isColumnSelected(const QRect &selection);
 bool util_isRowSelected(const QRect &selection);
 
-bool util_validateTableName(QString name);
-QDateTime util_readTime( const QString & intstr, KLocale * locale, bool withSeconds,
-                         bool * ok, bool & duration );
+bool util_validateSheetName(const QString &name);
 
 QDomElement util_createElement( const QString & tagName, const QFont & font, QDomDocument & doc );
 QDomElement util_createElement( const QString & tagname, const QPen & pen, QDomDocument & doc );
@@ -186,4 +217,16 @@ QFont       util_toFont( QDomElement & element );
 QPen        util_toPen( QDomElement & element );
 int         util_penCompare( QPen const & pen1, QPen const & pen2 );
 
+QString convertRefToRange( const QString & sheet, const QRect & rect );
+QString convertRefToBase( const QString & sheet, const QRect & rect );
+QString convertRangeToRef( const QString & sheetName, const QRect & _area );
+
+void insertBracket( QString & s );
+QString convertOasisPenToString( const QPen & pen );
+QPen convertOasisStringToPen( const QString &str );
+
+//Return true when it's a reference to cell from sheet.
+KSPREAD_EXPORT bool localReferenceAnchor( const QString &_ref );
+
+
 #endif
