@@ -30,7 +30,7 @@ static const KCmdLineOptions options[]=
         KCmdLineLastOption
 };
 
-int main( int argc, char **argv )
+extern "C" KSPREAD_EXPORT int kdemain( int argc, char **argv )
 {
 
     KCmdLineArgs::init( argc, argv, newKSpreadAboutData() );
@@ -38,9 +38,6 @@ int main( int argc, char **argv )
 
     KoApplication app;
 
-    app.dcopClient()->attach();
-    app.dcopClient()->registerAs( "kspread" );
-
     if (!app.start())
 	return 1;
     app.exec();
