@@ -1,6 +1,6 @@
 /*
 
- $Id: configdlg.cpp,v 1.11 2003/06/05 13:03:59 binner Exp $
+ $Id: configdlg.cpp 399247 2005-03-20 16:49:54Z johnflux $
 
  KCalc
 
@@ -145,11 +145,11 @@ ConfigDlg::ConfigDlg(QWidget *parent, const char *name, DefStruct *defstruct)
   statstyle->adjustSize();
   statstyle->setChecked(defst->style == 1 );
 
-  tablestyle = new QRadioButton(i18n("Table mode"),stylegroup,"Table");
-  grid2->addWidget(tablestyle,2,0);
-  tablestyle->adjustSize();
+  sheetstyle = new QRadioButton(i18n("Sheet mode"),stylegroup,"Sheet");
+  grid2->addWidget(sheetstyle,2,0);
+  sheetstyle->adjustSize();
 
-  tablestyle->setChecked(defst->style == 2 );
+  sheetstyle->setChecked(defst->style == 2 );
   button3 = new QPushButton(stylegroup);
   grid2->addWidget(button3,0,1);
   button3->setText(i18n("Help"));
