@@ -1,6 +1,6 @@
 /*
 
- $Id: dlabel.h,v 1.1.1.1 1999/10/20 10:10:32 kulow Exp $
+ $Id: dlabel.h 212185 2003-03-07 22:11:39Z waba $
 
  KCalc 
 
@@ -20,7 +20,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
  */
 
