@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc.cpp,v 1.21 2003/09/17 09:03:14 lukas Exp $
+    $Id: kcalc.cpp 273394 2003-12-16 19:28:32Z binner $
 
     kCalculator, a simple scientific calculator for KDE
 
@@ -1453,7 +1453,7 @@ void QtCalculator::configclicked(){
   QTabDialog * tabdialog;
   tabdialog = new QTabDialog(0,"tabdialog",TRUE);
 
-  tabdialog->setCaption( i18n("KCalc Configuraton") );
+  tabdialog->setCaption( i18n("KCalc Configuration") );
   tabdialog->resize( 360, 390 );
   tabdialog->setCancelButton( i18n("&Cancel") );
   tabdialog->setOKButton(i18n("&OK"));
