@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc.h,v 1.8 2003/09/17 09:03:14 lukas Exp $
+    $Id: kcalc.h 399247 2005-03-20 16:49:54Z johnflux $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -227,7 +227,7 @@ public:
 
     void setLabel( const char *_text );
     void setValue( double _value );
-    void setData( const QRect& _range, const char *_table );
+    void setData( const QRect& _range, const char *_sheet );
     void useData();
 
 public slots:
@@ -435,8 +435,8 @@ private:
     QListBox            *paper;
     QTimer		*status_timer;
 
-    QRect               table_range;
-    QString             table_name;
+    QRect               sheet_range;
+    QString             sheet_name;
     Calculator*         corba;
     QWidget *mSmallPage;
     QWidget *mLargePage;
