@@ -32,16 +32,13 @@ static const KCmdLineOptions options[]=
 	KCmdLineLastOption
 };
 
-int main( int argc, char **argv )
+extern "C" KUGARDESIGNER_EXPORT int kdemain( int argc, char **argv )
 {
     KLocale::setMainCatalogue("kugar");
     KCmdLineArgs::init( argc, argv, newKudesignerAboutData() );
     KCmdLineArgs::addCmdLineOptions( options );
     KoApplication app;
 
-    app.dcopClient()->attach();
-    app.dcopClient()->registerAs( "kudesigner" );
-
     if (!app.start()) // parses command line args, create initial docs and shells
         return 1;
     return app.exec();
