@@ -16,7 +16,7 @@
 #include "report.h"
 
 
-int main(int argc,char **argv)
+extern "C" int kdemain(int argc,char **argv)
 {
 	KAboutData about("kugar", I18N_NOOP("Kugar"), VERSION,
 		I18N_NOOP("A template driven report viewer for XML data."),
@@ -36,8 +36,8 @@ int main(int argc,char **argv)
 	// Handle the command line.
 
 	static KCmdLineOptions options[] = {
-		{"d <data>", I18N_NOOP("The XML data file."),0},
-		{"r <reportURL>", I18N_NOOP("The XML template file URL."),0},
+		{"d <data>", I18N_NOOP("The XML data file"),0},
+		{"r <reportURL>", I18N_NOOP("The XML template file URL"),0},
 		KCmdLineLastOption
 	};
 
