@@ -138,6 +138,12 @@ k_dcop:
     void sortText();
     void insertPage();
     void createLinkedFrame();
+
+    void lineBreak();
+
+    void increaseNumberingLevel();
+    void decreaseNumberingLevel();
+
 private:
     KWView *view;
 
