@@ -65,13 +65,16 @@ enum NoteType { FootNote, EndNote };
 
 enum SeparatorLinePos { SLP_LEFT = 0, SLP_CENTERED = 1, SLP_RIGHT = 2};
 enum SeparatorLineLineType { SLT_SOLID = 0, SLT_DASH = 1, SLT_DOT = 2, SLT_DASH_DOT = 3, SLT_DASH_DOT_DOT = 4};
-enum sortType { KW_SORTINCREASE = 0, KW_SORTDECREASE = 1};
+
+// Shared between sortdia.h and kwtextframeset.h
+enum SortType { KW_SORTINCREASE, KW_SORTDECREASE };
 
 /**
    Relative position of the mouse compared to a frame, or "meaning of a click right there".
    Can be: nothing ; inside a frame ; or on a border.
    When clicking on a frame's border, this can be for moving it, resizing it, or simply select it. */
 enum MouseMeaning { MEANING_NONE = 0, MEANING_MOUSE_INSIDE, MEANING_MOUSE_INSIDE_TEXT,
+                    MEANING_MOUSE_OVER_LINK, MEANING_MOUSE_OVER_FOOTNOTE,
                     MEANING_MOUSE_MOVE, MEANING_MOUSE_SELECT, MEANING_ACTIVATE_PART,
                     MEANING_TOPLEFT, MEANING_TOP, MEANING_TOPRIGHT, MEANING_RIGHT,
                     MEANING_BOTTOMRIGHT, MEANING_BOTTOM, MEANING_BOTTOMLEFT, MEANING_LEFT,
