@@ -33,12 +33,12 @@
 #include <kdebug.h>
 
 
-KWDocListViewItem::KWDocListViewItem(QListViewItem *_parent, QString _text)
+KWDocListViewItem::KWDocListViewItem(QListViewItem *_parent, const QString &_text)
     :QListViewItem( _parent, _text )
 {
 }
 
-KWDocListViewItem::KWDocListViewItem( QListViewItem *_parent, QListViewItem *_after, QString _text )
+KWDocListViewItem::KWDocListViewItem( QListViewItem *_parent, QListViewItem *_after, const QString &_text )
     :QListViewItem( _parent, _after, _text )
 {
 }
@@ -47,14 +47,14 @@ KWDocListViewItem::KWDocListViewItem( QListViewItem *_parent, QListViewItem *_af
 /* Class: KWDocStructParagItem                                    */
 /******************************************************************/
 
-KWDocStructParagItem::KWDocStructParagItem( QListViewItem *_parent, QString _text, KWTextParag *_parag, KWGUI*__parent )
+KWDocStructParagItem::KWDocStructParagItem( QListViewItem *_parent, const QString &_text, KWTextParag *_parag, KWGUI*__parent )
     : KWDocListViewItem(_parent,_text)
 {
     parag = _parag;
     gui = __parent;
 }
 
-KWDocStructParagItem::KWDocStructParagItem( QListViewItem *_parent, QListViewItem *_after, QString _text, KWTextParag *_parag, KWGUI*__parent )
+KWDocStructParagItem::KWDocStructParagItem( QListViewItem *_parent, QListViewItem *_after, const QString &_text, KWTextParag *_parag, KWGUI*__parent )
     : KWDocListViewItem( _parent, _after, _text )
 {
     parag = _parag;
@@ -101,7 +101,7 @@ void KWDocStructParagItem::deleteFrameSet()
 /* Class: KWDocStructFrameItem                                    */
 /******************************************************************/
 
-KWDocStructFrameItem::KWDocStructFrameItem( QListViewItem *_parent, QString _text, KWFrameSet *_frameset, KWFrame *_frame, KWGUI*__parent )
+KWDocStructFrameItem::KWDocStructFrameItem( QListViewItem *_parent, const QString &_text, KWFrameSet *_frameset, KWFrame *_frame, KWGUI*__parent )
     : KWDocListViewItem( _parent, _text )
 {
     frame = _frame;
@@ -145,7 +145,7 @@ void KWDocStructFrameItem::editProperties()
 /* Class: KWDocStructTableItem                                    */
 /******************************************************************/
 
-KWDocStructTableItem::KWDocStructTableItem( QListViewItem *_parent, QString _text, KWTableFrameSet *_table, KWGUI*__parent )
+KWDocStructTableItem::KWDocStructTableItem( QListViewItem *_parent, const QString &_text, KWTableFrameSet *_table, KWGUI*__parent )
     :KWDocListViewItem( _parent, _text )
 {
     table = _table;
@@ -191,7 +191,7 @@ void KWDocStructTableItem::editProperties()
 /* Class: KWDocStructPictureItem                                  */
 /******************************************************************/
 
-KWDocStructPictureItem::KWDocStructPictureItem( QListViewItem *_parent, QString _text, KWPictureFrameSet *_pic, KWGUI*__parent )
+KWDocStructPictureItem::KWDocStructPictureItem( QListViewItem *_parent, const QString &_text, KWPictureFrameSet *_pic, KWGUI*__parent )
     : KWDocListViewItem( _parent, _text )
 {
     pic = _pic;
@@ -232,7 +232,7 @@ void KWDocStructPictureItem::editProperties()
 /* Class: KWDocStructFormulaItem                                  */
 /******************************************************************/
 
-KWDocStructFormulaItem::KWDocStructFormulaItem( QListViewItem *_parent, QString _text, KWFormulaFrameSet *_form, KWGUI*__parent )
+KWDocStructFormulaItem::KWDocStructFormulaItem( QListViewItem *_parent, const QString &_text, KWFormulaFrameSet *_form, KWGUI*__parent )
     : KWDocListViewItem( _parent, _text )
 {
     form = _form;
@@ -277,7 +277,7 @@ void KWDocStructFormulaItem::editProperties()
 /* Class: KWDocStructPartItem                                     */
 /******************************************************************/
 
-KWDocStructPartItem::KWDocStructPartItem( QListViewItem *_parent, QString _text, KWPartFrameSet *_part, KWGUI*__parent )
+KWDocStructPartItem::KWDocStructPartItem( QListViewItem *_parent, const QString &_text, KWPartFrameSet *_part, KWGUI*__parent )
     : KWDocListViewItem( _parent, _text )
 {
     part = _part;
@@ -410,7 +410,7 @@ void KWDocStructRootItem::setupArrangement()
     QListViewItem *item = 0L;
     QString _name;
 
-    for ( int i = doc->getNumFrameSets() - 1; i >= 0; i-- )
+    for ( int i = doc->numFrameSets() - 1; i >= 0; i-- )
     {
         frameset = doc->frameSet( i );
         if ( frameset->type() == FT_TEXT && frameset->frameSetInfo() == KWFrameSet::FI_BODY && !frameset->getGroupManager() && frameset->getNumFrames()>0)
@@ -475,7 +475,7 @@ void KWDocStructRootItem::setupTextFrames()
     QString _name;
     KWDocStructFrameItem *child;
 
-    for ( int i = doc->getNumFrameSets() - 1; i >= 0; i-- )
+    for ( int i = doc->numFrameSets() - 1; i >= 0; i-- )
     {
         frameset = doc->frameSet( i );
         if ( frameset->type() == FT_TEXT && frameset->frameSetInfo() == KWFrameSet::FI_BODY && !frameset->getGroupManager() && frameset->getNumFrames()>0)
@@ -525,7 +525,7 @@ void KWDocStructRootItem::setupFormulaFrames()
     QString _name;
     KWDocStructFormulaItem *child;
 
-    for ( int i = doc->getNumFrameSets() - 1; i >= 0; i-- )
+    for ( int i = doc->numFrameSets() - 1; i >= 0; i-- )
     {
         frameset = doc->frameSet( i );
         if ( frameset->type() == FT_FORMULA &&
@@ -561,7 +561,7 @@ void KWDocStructRootItem::setupTables()
     QString _name;
     KWDocStructTableItem *child;
 
-    for ( int i = doc->getNumFrameSets() - 1; i >= 0; i-- )
+    for ( int i = doc->numFrameSets() - 1; i >= 0; i-- )
     {
         KWFrameSet *fs = doc->frameSet(i);
         if ( fs->type() != FT_TABLE)
@@ -602,7 +602,7 @@ void KWDocStructRootItem::setupPictures()
     KWDocStructPictureItem *child;
 
     int j = 0;
-    for ( int i = doc->getNumFrameSets() - 1; i >= 0; i-- )
+    for ( int i = doc->numFrameSets() - 1; i >= 0; i-- )
     {
         frameset = doc->frameSet( i );
         if ( frameset->type() == FT_PICTURE && frameset->getNumFrames()>0)
@@ -639,7 +639,7 @@ void KWDocStructRootItem::setupEmbedded()
     QString _name;
     KWDocStructPartItem *child;
 
-    for ( int i = doc->getNumFrameSets() - 1; i >= 0; i-- )
+    for ( int i = doc->numFrameSets() - 1; i >= 0; i-- )
     {
         frameset = doc->frameSet( i );
         if ( frameset->type() == FT_PART && frameset->getNumFrames()>0)
@@ -780,7 +780,7 @@ bool KWDocStructTree::testExistTypeOfFrame(TypeStructDocItem _type)
     KWTextParag *parag = 0L;
     KoTextDocument * textdoc=0L;
 
-    for ( int i = doc->getNumFrameSets() - 1; i >= 0; i-- )
+    for ( int i = doc->numFrameSets() - 1; i >= 0; i-- )
     {
         frameset = doc->frameSet( i );
         switch ( _type )
