@@ -17,21 +17,32 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include "kwcommand.h"
 #include "kwdoc.h"
 #include "kwtextframeset.h"
-#include "kwcommand.h"
 #include "kwtablestyle.h"
 #include "kwtabletemplate.h"
 #include "kwtableframeset.h"
 #include "kwpartframeset.h"
+#include "kwtextdocument.h"
 #include "kwtextparag.h"
 #include "kwanchor.h"
 #include "kwvariable.h"
-#include "kovariable.h"
+#include "kwoasisloader.h"
+
 #include <kotextobject.h>
+#include <koOasisStyles.h>
+#include <kooasiscontext.h>
+#include <koxmlns.h>
+#include <kodom.h>
+#include <koStore.h>
+#include <koOasisStore.h>
+
 #include <klocale.h>
 #include <kdebug.h>
 
+#include <qxml.h>
+#include <qbuffer.h>
 
 KWPasteTextCommand::KWPasteTextCommand( KoTextDocument *d, int parag, int idx,
                                 const QCString & data )
@@ -55,7 +66,7 @@ KoTextCursor * KWPasteTextCommand::execute( KoTextCursor *c )
     QDomDocument domDoc;
     domDoc.setContent( m_data );
     QDomElement elem = domDoc.documentElement();
-    KWTextDocument * textdoc = static_cast<KWTextDocument *>(c->parag()->document());
+    KWTextDocument * textdoc = static_cast<KWTextDocument *>(doc);
     KWTextFrameSet * textFs = textdoc->textFrameSet();
     // We iterate twice over the list of paragraphs.
     // First time to gather the text,
@@ -134,13 +145,12 @@ KoTextCursor * KWPasteTextCommand::execute( KoTextCursor *c )
             parag->setFormat( 0, len, parag->paragFormat(), TRUE );
             parag->loadFormatting( paragElem, 0, (textFs->isMainFrameset()) );
         }
-        parag->invalidate(0); // the formatting will be done by caller (either KWTextFrameSet::pasteKWord or KoTextObject::undo/redo)
+        parag->invalidate(0); // the formatting will be done by caller (either KWTextFrameSet::pasteOasis or KoTextObject::undo/redo)
         parag->setChanged( TRUE );
         parag = static_cast<KWTextParag *>(parag->next());
         //kdDebug() << "KWPasteTextCommand::execute going to next parag: " << parag << endl;
     }
     textFs->textObject()->setNeedSpellCheck( true );
-    textFs->zoom( false );
     // In case loadFormatting queued any image request
     KWDocument * doc = textFs->kWordDocument();
     doc->processPictureRequests();
@@ -201,8 +211,7 @@ KoTextCursor * KWPasteTextCommand::unexecute( KoTextCursor *c )
         return 0;
     }
     Q_ASSERT( lastParag->document() );
-    // Get hold of the document before deleting the parag
-    KoTextDocument* textdoc = lastParag->document();
+    KWTextDocument * textdoc = static_cast<KWTextDocument *>(doc);
 
     //kdDebug() << "Undoing paste: deleting from (" << firstParag->paragId() << "," << m_idx << ")"
     //          << " to (" << lastParag->paragId() << "," << m_lastIndex << ")" << endl;
@@ -216,7 +225,86 @@ KoTextCursor * KWPasteTextCommand::unexecute( KoTextCursor *c )
 
     doc->removeSelectedText( KoTextDocument::Temp, c /* sets c to the correct position */ );
 
-    KWTextFrameSet * textFs = static_cast<KWTextDocument *>(textdoc)->textFrameSet();
+    KWTextFrameSet * textFs = textdoc->textFrameSet();
+
+    textFs->renumberFootNotes();
+    if ( m_idx == 0 ) {
+        Q_ASSERT( m_oldParagLayout );
+        if ( m_oldParagLayout )
+            firstParag->setParagLayout( *m_oldParagLayout );
+    }
+    return c;
+}
+
+KWOasisPasteCommand::KWOasisPasteCommand( KoTextDocument *d, int parag, int idx,
+                                const QByteArray& data )
+    : KoTextDocCommand( d ), m_parag( parag ), m_idx( idx ), m_data( data ), m_oldParagLayout( 0 )
+{
+}
+
+KoTextCursor * KWOasisPasteCommand::execute( KoTextCursor *c )
+{
+    KoTextParag *firstParag = doc->paragAt( m_parag );
+    if ( !firstParag ) {
+        qWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
+        return c;
+    }
+    //kdDebug() << "KWOasisPasteCommand::execute m_parag=" << m_parag << " m_idx=" << m_idx
+    //          << " firstParag=" << firstParag << " " << firstParag->paragId() << endl;
+    cursor.setParag( firstParag );
+    cursor.setIndex( m_idx );
+    c->setParag( firstParag );
+    c->setIndex( m_idx );
+
+    KWTextDocument * textdoc = static_cast<KWTextDocument *>(doc);
+
+    QBuffer buffer( m_data );
+
+    KoStore * store = KoStore::createStore( &buffer, KoStore::Read );
+    KWDocument* kwdoc = textdoc->textFrameSet()->kWordDocument();
+    KWOasisLoader loader( kwdoc );
+    loader.insertOasisData( store, c );
+
+    delete store;
+
+    m_lastParag = c->parag()->paragId();
+    m_lastIndex = c->index();
+    return c;
+}
+
+KoTextCursor * KWOasisPasteCommand::unexecute( KoTextCursor *c )
+{
+    KoTextParag *firstParag = doc->paragAt( m_parag );
+    if ( !firstParag ) {
+        qWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
+        return 0;
+    }
+    cursor.setParag( firstParag );
+    cursor.setIndex( m_idx );
+    doc->setSelectionStart( KoTextDocument::Temp, &cursor );
+
+    KoTextParag *lastParag = doc->paragAt( m_lastParag );
+    if ( !lastParag ) {
+        qWarning( "can't locate parag at %d, last parag: %d", m_lastParag, doc->lastParag()->paragId() );
+        return 0;
+    }
+    Q_ASSERT( lastParag->document() );
+    // Get hold of the document before deleting the parag
+    KWTextDocument * textdoc = static_cast<KWTextDocument *>(doc);
+
+    //kdDebug() << "Undoing paste: deleting from (" << firstParag->paragId() << "," << m_idx << ")"
+    //          << " to (" << lastParag->paragId() << "," << m_lastIndex << ")" << endl;
+
+    cursor.setParag( lastParag );
+    cursor.setIndex( m_lastIndex );
+    doc->setSelectionEnd( KoTextDocument::Temp, &cursor );
+    // Delete all custom items
+    KWDeleteCustomItemVisitor visitor;
+    doc->visitSelection( KoTextDocument::Temp, &visitor );
+
+    doc->removeSelectedText( KoTextDocument::Temp, c /* sets c to the correct position */ );
+
+    KWTextFrameSet * textFs = textdoc->textFrameSet();
 
     textFs->renumberFootNotes();
     if ( m_idx == 0 ) {
@@ -957,70 +1045,28 @@ void KWFramePropertiesCommand::unexecute()
 }
 
 
-KWFrameSetPropertyCommand::KWFrameSetPropertyCommand( const QString &name, KWFrameSet *frameset, Property prop, const QString& value ) :
+KWFrameSetInlineCommand::KWFrameSetInlineCommand( const QString &name, KWFrameSet *frameset, bool value ) :
     KNamedCommand(name),
     m_pFrameSet( frameset ),
-    m_property( prop ),
     m_value( value )
 {
-    switch ( m_property ) {
-    case FSP_NAME:
-        m_oldValue = m_pFrameSet->getName();
-        break;
-    case FSP_FLOATING:
-        m_oldValue = m_pFrameSet->isFloating() ? "true" : "false";
-        break;
-    case FSP_KEEPASPECTRATION:
-        m_oldValue = static_cast<KWPictureFrameSet*>(m_pFrameSet)->keepAspectRatio() ? "keepRatio" : "dontKeepRatio";
-        break;
-    case FSP_PROTECTSIZE:
-        m_oldValue = m_pFrameSet->isProtectSize() ? "true" : "false";
-        break;
-    }
+    m_oldValue = m_pFrameSet->isFloating();
 }
 
-void KWFrameSetPropertyCommand::setValue( const QString &value )
+void KWFrameSetInlineCommand::setValue( bool value )
 {
-    kdDebug() << "KWFrameSetPropertyCommand::execute" << endl;
-    switch ( m_property ) {
-    case FSP_NAME:
-        m_pFrameSet->setName( value );
-        break;
-    case FSP_FLOATING:
-        if ( value == "true" )
-        {
-            // Make frame(set) floating
-            m_pFrameSet->setFloating();
-            // ## We might want to store a list of anchors in the command, and reuse them
-            // in execute/unexecute. Currently setFixed forgets the anchors and setFloating recreates new ones...
-        }
-        else if(value == "false")
-        {
-            // Make frame(set) non-floating
-            m_pFrameSet->setFixed();
-        }
-    case FSP_KEEPASPECTRATION:
-        if( value == "keepRatio")
-        {
-            KWPictureFrameSet * frameSet=dynamic_cast<KWPictureFrameSet*>(m_pFrameSet);
-            if(frameSet)
-                frameSet->setKeepAspectRatio( true );
-        }
-        else if( value=="dontKeepRatio")
-        {
-            KWPictureFrameSet * frameSet=dynamic_cast<KWPictureFrameSet*>(m_pFrameSet);
-            if(frameSet)
-                frameSet->setKeepAspectRatio( false );
-        }
-        break;
-    case FSP_PROTECTSIZE:
-        if( value == "true")
-            m_pFrameSet->setProtectSize( true );
-        else
-            m_pFrameSet->setProtectSize( false );
-        m_pFrameSet->kWordDocument()->repaintResizeHandles();
-        m_pFrameSet->kWordDocument()->updateCursorType();
-        break;
+    kdDebug() << "KWFrameSetInlineCommand::execute" << endl;
+    if ( value )
+    {
+        // Make frame(set) floating
+        m_pFrameSet->setFloating();
+        // ## We might want to store a list of anchors in the command, and reuse them
+        // in execute/unexecute. Currently setFixed forgets the anchors and setFloating recreates new ones...
+    }
+    else
+    {
+        // Make frame(set) non-floating
+        m_pFrameSet->setFixed();
     }
 
     m_pFrameSet->kWordDocument()->updateResizeHandles();
@@ -1030,12 +1076,12 @@ void KWFrameSetPropertyCommand::setValue( const QString &value )
     m_pFrameSet->kWordDocument()->updateRulerFrameStartEnd();
 }
 
-void KWFrameSetPropertyCommand::execute()
+void KWFrameSetInlineCommand::execute()
 {
     setValue( m_value );
 }
 
-void KWFrameSetPropertyCommand::unexecute()
+void KWFrameSetInlineCommand::unexecute()
 {
     setValue( m_oldValue );
 }
@@ -1522,13 +1568,13 @@ KWChangeStartingPageCommand::KWChangeStartingPageCommand( const QString &name, K
 
 void KWChangeStartingPageCommand::execute()
 {
-    m_doc->getVariableCollection()->variableSetting()->setStartingPage(newStartingPage);
+    m_doc->variableCollection()->variableSetting()->setStartingPage(newStartingPage);
     m_doc->recalcVariables( VT_PGNUM );
 }
 
 void KWChangeStartingPageCommand::unexecute()
 {
-    m_doc->getVariableCollection()->variableSetting()->setStartingPage(oldStartingPage);
+    m_doc->variableCollection()->variableSetting()->setStartingPage(oldStartingPage);
     m_doc->recalcVariables( VT_PGNUM );
 }
 
@@ -1546,19 +1592,19 @@ void KWChangeVariableSettingsCommand::changeValue( bool b )
     switch(type)
     {
     case VS_DISPLAYLINK:
-        m_doc->getVariableCollection()->variableSetting()->setDisplayLink(b);
+        m_doc->variableCollection()->variableSetting()->setDisplayLink(b);
         m_doc->recalcVariables( VT_LINK );
         break;
     case  VS_UNDERLINELINK:
-        m_doc->getVariableCollection()->variableSetting()->setUnderlineLink(b);
+        m_doc->variableCollection()->variableSetting()->setUnderlineLink(b);
         m_doc->recalcVariables( VT_LINK );
         break;
     case VS_DISPLAYCOMMENT:
-        m_doc->getVariableCollection()->variableSetting()->setDisplayComment(b);
+        m_doc->variableCollection()->variableSetting()->setDisplayComment(b);
         m_doc->recalcVariables( VT_NOTE );
         break;
     case VS_DISPLAYFIELDCODE:
-        m_doc->getVariableCollection()->variableSetting()->setDisplayFieldCode(b);
+        m_doc->variableCollection()->variableSetting()->setDisplayFieldCode(b);
         //hack necessary otherwise footnote frameset is not refreshing
         //and footnote is not resize.
         m_doc->displayFootNoteFieldCode();
@@ -1708,7 +1754,7 @@ KWProtectContentCommand::KWProtectContentCommand( const QString &name, KWTextFra
 
 void KWProtectContentCommand::execute()
 {
-    m_pFrameSet->textObject()->setProtectContent(m_bProtect);
+    m_pFrameSet->setProtectContent(m_bProtect);
     m_pFrameSet->kWordDocument()->updateTextFrameSetEdit();
     m_pFrameSet->kWordDocument()->testAndCloseAllFrameSetProtectedContent();
     m_pFrameSet->kWordDocument()->updateRulerInProtectContentMode();
@@ -1717,7 +1763,7 @@ void KWProtectContentCommand::execute()
 
 void KWProtectContentCommand::unexecute()
 {
-    m_pFrameSet->textObject()->setProtectContent(!m_bProtect);
+    m_pFrameSet->setProtectContent(!m_bProtect);
     m_pFrameSet->kWordDocument()->updateTextFrameSetEdit();
     m_pFrameSet->kWordDocument()->testAndCloseAllFrameSetProtectedContent();
     m_pFrameSet->kWordDocument()->updateRulerInProtectContentMode();
@@ -1756,48 +1802,48 @@ void KWInsertRemovePageCommand::unexecute()
     }
 }
 
-FrameMarginsStruct::FrameMarginsStruct( KWFrame *frame )
+FramePaddingStruct::FramePaddingStruct( KWFrame *frame )
 {
-    topMargin = frame->bTop();
-    bottomMargin= frame->bBottom();
-    leftMargin = frame->bLeft();
-    rightMargin= frame->bRight();
+    topPadding = frame->paddingTop();
+    bottomPadding= frame->paddingBottom();
+    leftPadding = frame->paddingLeft();
+    rightPadding= frame->paddingRight();
 }
 
-FrameMarginsStruct::FrameMarginsStruct( double _left, double _top, double _right, double _bottom ):
-    topMargin(_top),
-    bottomMargin(_bottom),
-    leftMargin(_left),
-    rightMargin(_right)
+FramePaddingStruct::FramePaddingStruct( double _left, double _top, double _right, double _bottom ):
+    topPadding(_top),
+    bottomPadding(_bottom),
+    leftPadding(_left),
+    rightPadding(_right)
 {
 }
 
 
-KWFrameChangeFrameMarginCommand::KWFrameChangeFrameMarginCommand( const QString &name, FrameIndex _frameIndex, FrameMarginsStruct _frameMarginsBegin, FrameMarginsStruct _frameMarginsEnd ) :
+KWFrameChangeFramePaddingCommand::KWFrameChangeFramePaddingCommand( const QString &name, FrameIndex _frameIndex, FramePaddingStruct _framePaddingBegin, FramePaddingStruct _framePaddingEnd ) :
     KNamedCommand(name),
     m_indexFrame(_frameIndex),
-    m_frameMarginsBegin(_frameMarginsBegin),
-    m_frameMarginsEnd(_frameMarginsEnd)
+    m_framePaddingBegin(_framePaddingBegin),
+    m_framePaddingEnd(_framePaddingEnd)
 {
 }
 
-void KWFrameChangeFrameMarginCommand::execute()
+void KWFrameChangeFramePaddingCommand::execute()
 {
     KWFrameSet *frameSet = m_indexFrame.m_pFrameSet;
     Q_ASSERT( frameSet );
     KWFrame *frame = frameSet->frame(m_indexFrame.m_iFrameIndex);
     Q_ASSERT( frame );
-    frame->setFrameMargins( m_frameMarginsEnd.leftMargin,m_frameMarginsEnd.topMargin , m_frameMarginsEnd.rightMargin, m_frameMarginsEnd.bottomMargin);
+    frame->setFramePadding( m_framePaddingEnd.leftPadding,m_framePaddingEnd.topPadding , m_framePaddingEnd.rightPadding, m_framePaddingEnd.bottomPadding);
     frameSet->kWordDocument()->frameChanged( frame );
 }
 
-void KWFrameChangeFrameMarginCommand::unexecute()
+void KWFrameChangeFramePaddingCommand::unexecute()
 {
     KWFrameSet *frameSet = m_indexFrame.m_pFrameSet;
     Q_ASSERT( frameSet );
     KWFrame *frame = frameSet->frame(m_indexFrame.m_iFrameIndex);
     Q_ASSERT( frame );
-    frame->setFrameMargins( m_frameMarginsBegin.leftMargin,m_frameMarginsBegin.topMargin , m_frameMarginsBegin.rightMargin, m_frameMarginsBegin.bottomMargin);
+    frame->setFramePadding( m_framePaddingBegin.leftPadding,m_framePaddingBegin.topPadding , m_framePaddingBegin.rightPadding, m_framePaddingBegin.bottomPadding);
     frameSet->kWordDocument()->frameChanged( frame );
 }
 
@@ -1824,11 +1870,11 @@ void KWChangeFootEndNoteSettingsCommand::changeCounter( KoParagCounter counter)
 {
     if (m_footNote )
     {
-        static_cast<KWVariableSettings*>(m_doc->getVariableCollection()->variableSetting())->changeFootNoteCounter(counter );
+        static_cast<KWVariableSettings*>(m_doc->variableCollection()->variableSetting())->changeFootNoteCounter(counter );
     }
     else
     {
-        static_cast<KWVariableSettings*>(m_doc->getVariableCollection()->variableSetting())->changeEndNoteCounter(counter );
+        static_cast<KWVariableSettings*>(m_doc->variableCollection()->variableSetting())->changeEndNoteCounter(counter );
     }
     m_doc->changeFootNoteConfig();
 }
