@@ -29,15 +29,16 @@ namespace KFormula {
 class KWView;
 class QCheckBox;
 class KIntNumInput;
-class KDoubleNumInput;
-class KSpellConfig;
+class KoBuggyUnitDoubleSpinBox;
 class KConfig;
 class QComboBox;
 class KIntNumInput;
 class KCommand;
 class KWDocument;
 class KListView;
-class KoSpellConfigWidget;
+namespace KSpell2 {
+    class ConfigWidget;
+}
 
 class ConfigureSpellPage : public QObject
 {
@@ -49,7 +50,7 @@ public:
 private:
     KWView* m_pView;
     KConfig* config;
-    KoSpellConfigWidget *m_spellConfigWidget;
+    KSpell2::ConfigWidget *m_spellConfigWidget;
 };
 
 class ConfigureInterfacePage : public QObject
@@ -59,14 +60,20 @@ public:
     ConfigureInterfacePage( KWView *_view, QVBox *box, char *name = 0 );
     void apply();
     void slotDefault();
+    void setUnit( KoUnit::Unit unit );
+
+signals:
+    // For KWConfig
+    void unitChanged( int );
 private:
     KWView* m_pView;
-    KDoubleNumInput* gridX,*gridY;
-    KDoubleNumInput* indent;
+    KConfig* config;
+    QComboBox *m_unitCombo;
+    KoBuggyUnitDoubleSpinBox* gridX,*gridY;
+    KoBuggyUnitDoubleSpinBox* indent;
     KIntNumInput* recentFiles;
     QCheckBox *showStatusBar, *showScrollBar, *pgUpDownMovesCaret;
     int oldNbRecentFiles;
-    KConfig* config;
     KIntNumInput *m_nbPagePerRow;
 };
 
@@ -77,11 +84,10 @@ public:
     ConfigureMiscPage( KWView *_view, QVBox *box, char *name = 0 );
     KCommand* apply();
     void slotDefault();
+    void setUnit( KoUnit::Unit unit );
 private:
     KWView* m_pView;
     KConfig* config;
-    QComboBox *m_unit;
-    int m_oldUnit;
     KIntNumInput* m_undoRedoLimit;
     int m_oldNbRedo;
     bool m_oldFormattingEndParag, m_oldFormattingSpace, m_oldFormattingTabs, m_oldFormattingBreak;
@@ -98,6 +104,7 @@ public:
     ~ConfigureDefaultDocPage();
     KCommand* apply();
     void slotDefault();
+    void setUnit( KoUnit::Unit unit );
 public slots:
     void selectNewDefaultFont();
 private:
@@ -105,8 +112,9 @@ private:
     KConfig* config;
     QFont *font;
     QLabel *fontName;
+    QLabel *tabStop;
 
-    KDoubleNumInput* columnSpacing;
+    KoBuggyUnitDoubleSpinBox* m_columnSpacing;
 
     KIntNumInput* autoSave;
     int oldAutoSaveValue;
@@ -115,10 +123,10 @@ private:
     int m_oldStartingPage;
     bool m_oldBackupFile;
     KIntNumInput* m_variableNumberOffset;
-    KDoubleNumInput *m_tabStopWidth;
+    KoBuggyUnitDoubleSpinBox *m_tabStopWidth;
     QCheckBox *m_cursorInProtectedArea;
     QCheckBox *m_createBackupFile;
-    QCheckBox *m_directInsertCursor;
+//     QCheckBox *m_directInsertCursor;
     QCheckBox *m_autoHyphenation;
     QComboBox *m_globalLanguage;
     QString m_oldLanguage;
@@ -152,6 +160,7 @@ public:
 public slots:
     void slotApply();
     void slotDefault();
+    void unitChanged( int );
 private:
     ConfigureSpellPage *m_spellPage;
     ConfigureInterfacePage *m_interfacePage;
