@@ -28,6 +28,7 @@
 #include "kwcommand.h"
 #include "kwcreatebookmarkdia.h"
 #include "kwcreatebookmarkdiabase.h"
+#include "kwframe.h"
 
 KWCreateBookmarkDia::KWCreateBookmarkDia( const QStringList & _list, QWidget *parent, const char *name )
     : KDialogBase( parent, name , true, "", Ok|Cancel, Ok, true )
@@ -49,11 +50,10 @@ KWCreateBookmarkDia::KWCreateBookmarkDia( const QStringList & _list, const QStri
 void KWCreateBookmarkDia::init()
 {
     KWCreateBookmarkDiaBase *dia = new KWCreateBookmarkDiaBase( this );
-    m_bookmarkName=dia->m_bookmarkName;
+    m_bookmarkName = dia->m_bookmarkName;
     enableButtonOK( false );
     connect( m_bookmarkName, SIGNAL(textChanged ( const QString & )), this, SLOT(nameChanged( const QString &)));
-    setMainWidget(dia);
-    resize( 300, 200);
+    setMainWidget( dia );
     m_bookmarkName->setFocus();
 }
 
