@@ -21,9 +21,10 @@
 #include "kwframestylemanager.moc"
 #include "kwimportstyledia.h"
 
-#include <kwdoc.h>
+#include "kwdoc.h"
+#include "framedia.h" // for KWBrushStylePreview
+
 #include <koParagDia.h>
-#include <framedia.h>
 
 #include <kcolorbutton.h>
 #include <klocale.h>
@@ -176,7 +177,7 @@ void KWFrameStyleManager::setupWidget(const QPtrList<KWFrameStyle> & styleList)
     m_stylesList = new QListBox( frame1, "stylesList" );
     for ( ; style.current() ; ++style )
     {
-        m_stylesList->insertItem( style.current()->translatedName() );
+        m_stylesList->insertItem( style.current()->displayName() );
         m_frameStyles.append( new KWFrameStyleListItem( style.current(),new KWFrameStyle(*style.current())) );
         m_styleOrder<<style.current()->name();
     }
@@ -185,12 +186,12 @@ void KWFrameStyleManager::setupWidget(const QPtrList<KWFrameStyle> & styleList)
 
 
     m_moveUpButton = new QPushButton( frame1, "moveUpButton" );
-    m_moveUpButton->setPixmap( BarIcon( "up", KIcon::SizeSmall ) );
+    m_moveUpButton->setIconSet( SmallIconSet( "up" ) );
     connect( m_moveUpButton, SIGNAL( clicked() ), this, SLOT( moveUpStyle() ) );
     frame1Layout->addWidget( m_moveUpButton, 1, 1 );
 
     m_moveDownButton = new QPushButton( frame1, "moveDownButton" );
-    m_moveDownButton->setPixmap( BarIcon( "down", KIcon::SizeSmall ) );
+    m_moveDownButton->setIconSet( SmallIconSet( "down" ) );
     connect( m_moveDownButton, SIGNAL( clicked() ), this, SLOT( moveDownStyle() ) );
     frame1Layout->addWidget( m_moveDownButton, 1, 0 );
 
@@ -308,7 +309,7 @@ void KWFrameStyleManager::updateGUI()
         it.current()->update();
     }
 
-    m_nameString->setText(m_currentFrameStyle->translatedName());
+    m_nameString->setText(m_currentFrameStyle->displayName());
 
     // update delete button (can't delete first style);
     m_deleteButton->setEnabled(m_stylesList->currentItem() != 0);
@@ -358,7 +359,7 @@ void KWFrameStyleManager::addStyle(const QPtrList<KWFrameStyle> &listStyle )
     for ( ; style.current() ; ++style )
     {
         noSignals=true;
-        m_stylesList->insertItem( style.current()->translatedName() );
+        m_stylesList->insertItem( style.current()->displayName() );
         m_frameStyles.append( new KWFrameStyleListItem( 0L,new KWFrameStyle(*style.current())) );
         m_styleOrder<<style.current()->name();
         noSignals=false;
