@@ -19,6 +19,7 @@
 
 #include <klocale.h>
 #include "kwdoc.h"
+
 #include <qvbox.h>
 #include <qlayout.h>
 #include <qlineedit.h>
@@ -28,13 +29,15 @@
 #include "kwimportstyledia.h"
 #include <koStore.h>
 #include <qfile.h>
+
 #include <kfiledialog.h>
 #include <kdebug.h>
 #include <qlabel.h>
-#include <kwtextparag.h>
 
-KWImportStyleDia::KWImportStyleDia( KWDocument *_doc, const QStringList &_list, QWidget *parent, const char *name )
-    :KoImportStyleDia( _list, parent, name ),
+#include "kwtextparag.h"
+
+KWImportStyleDia::KWImportStyleDia( KWDocument *_doc, KoStyleCollection* currentCollection, QWidget *parent, const char *name )
+    :KoImportStyleDia( currentCollection, parent, name ),
      m_doc(_doc)
 {
 
@@ -48,7 +51,11 @@ KWImportStyleDia::~KWImportStyleDia()
 void KWImportStyleDia::loadFile()
 {
     KFileDialog fd( QString::null, QString::null, 0, 0, TRUE );
-    fd.setMimeFilter( "application/x-kword" );
+    QStringList lst = "application/x-kword";
+#if 0
+    lst << "application/vnd.oasis.opendocument.text";
+#endif
+    fd.setMimeFilter( lst );
     fd.setCaption(i18n("Import Style"));
     KURL url;
     if ( fd.exec() != QDialog::Accepted )
@@ -63,14 +70,12 @@ void KWImportStyleDia::loadFile()
     }
     QMap<QString, QString>insertStyle;
 
-    // ### TODO network transparency
-    KoStore* store=KoStore::createStore( url.path(), KoStore::Read );
+    KoStore* store=KoStore::createStore( this, url, KoStore::Read );
     if (store )
     {
         if (store->open("maindoc.xml") )
         {
-            m_styleList.setAutoDelete(true);
-            m_styleList.clear();
+            clear();
             m_listStyleName->clear();
 
             QDomDocument doc;
@@ -81,6 +86,12 @@ void KWImportStyleDia::loadFile()
             {
                 //todo
                 //duplicate code try to remove it !
+                // TODO: use loadOasisStyleTemplates() for OASIS
+                //       (and put as much code as possible in koimportstyledia of course)
+                //
+                // I guess we'll have to keep this old loading code forever though,
+                // so we can't really get rid of the subclasses.
+
                 QValueList<QString> followingStyles;
                 QDomNodeList listStyles = stylesElem.elementsByTagName( "STYLE" );
                 for (unsigned int item = 0; item < listStyles.count(); item++)
@@ -89,12 +100,16 @@ void KWImportStyleDia::loadFile()
 
                     KWStyle *sty = new KWStyle( QString::null );
                     // Load the paraglayout from the <STYLE> element
-                    sty->loadStyle( styleElem, m_doc->syntaxVersion() );
+                    sty->loadStyle( styleElem, m_doc->syntaxVersion() ); //#### wrong syntaxVersion!
 
-                    QString name = sty->name();
-                    if ( m_list.findIndex( name )!=-1 )
-                        sty->setName(generateStyleName( sty->translatedName() + QString( "-%1")));
-                    insertStyle.insert( name, sty->name());
+                    QString name = sty->displayName();
+                    if ( currentCollection()->findStyle( name ) )
+                        sty->setInternalName(generateStyleName(sty->name() + "-%1"));
+                    // ### TODO: we should offer the option of updating the
+                    // existing style instead of creating a foo-1 style. Any ideas for a GUI?
+                    if ( currentCollection()->findTranslatedStyle( name ) )
+                        sty->setDisplayName(generateStyleDisplayName(sty->displayName() + "-%1"));
+                    insertStyle.insert( name, sty->name() ); // old name -> new name
 
                     QDomElement formatElem = styleElem.namedItem( "FORMAT" ).toElement();
                     if ( !formatElem.isNull() )
@@ -136,6 +151,10 @@ void KWImportStyleDia::loadFile()
             }
 
         }
+        else if ( store->hasFile( "content.xml" ) )
+        {
+            //oasis file format (for koffice-1.5)
+        }
         else
         {
             KMessageBox::error( this,
@@ -188,7 +207,11 @@ QString KWImportFrameTableStyleDia::generateStyleName( const QString & templateN
 void KWImportFrameTableStyleDia::loadFile()
 {
     KFileDialog fd( QString::null, QString::null, 0, 0, TRUE );
-    fd.setMimeFilter( "application/x-kword" );
+    QStringList lst = "application/x-kword";
+#if 0
+    lst << "application/vnd.oasis.opendocument.text";
+#endif
+    fd.setMimeFilter( lst );
     fd.setCaption(i18n("Import Style"));
     KURL url;
     if ( fd.exec() != QDialog::Accepted )
@@ -201,8 +224,7 @@ void KWImportFrameTableStyleDia::loadFile()
                             i18n("Import Style"));
         return;
     }
-    // ### TODO network transparency
-    KoStore* store=KoStore::createStore( url.path(), KoStore::Read );
+    KoStore* store=KoStore::createStore( this, url, KoStore::Read );
     if (store )
     {
         if (store->open("maindoc.xml") )
@@ -219,7 +241,7 @@ void KWImportFrameTableStyleDia::loadFile()
                     KWFrameStyle *sty = new KWFrameStyle( styleElem );
                     QString name =sty->name();
                     if ( m_list.findIndex( name )!=-1 )
-                        sty->setName(generateStyleName( sty->translatedName() + QString( "-%1")));
+                        sty->setName(generateStyleName( sty->displayName() + QString( "-%1")));
                     m_frameStyleList.append( sty);
                 }
             }
@@ -231,7 +253,7 @@ void KWImportFrameTableStyleDia::loadFile()
                     KWTableStyle *sty = new KWTableStyle( styleElem,m_doc,2 );
                     QString name =sty->name();
                     if ( m_list.findIndex( name )!=-1 )
-                        sty->setName(generateStyleName( sty->translatedName() + QString( "-%1")));
+                        sty->setName(generateStyleName( sty->displayName() + QString( "-%1")));
                     m_tableStyleList.append( sty);
                 }
             }
@@ -243,6 +265,10 @@ void KWImportFrameTableStyleDia::loadFile()
             }
 
         }
+        else if ( store->hasFile( "content.xml" ) )
+        {
+            //oasis file format (for koffice-1.5)
+        }
         else
         {
             KMessageBox::error( this,
@@ -263,14 +289,14 @@ void KWImportFrameTableStyleDia::initList()
     {
         for ( KWFrameStyle * p = m_frameStyleList.first(); p != 0L; p = m_frameStyleList.next() )
         {
-            lst<<p->translatedName();
+            lst<<p->displayName();
         }
     }
     else
     {
         for ( KWTableStyle * p = m_tableStyleList.first(); p != 0L; p = m_tableStyleList.next() )
         {
-            lst<<p->translatedName();
+            lst<<p->displayName();
         }
     }
 
@@ -284,26 +310,26 @@ void KWImportFrameTableStyleDia::slotOk()
         if ( !m_listStyleName->isSelected( i ))
         {
             QString name = m_listStyleName->text(i );
-            if ( m_typeStyle ==frameStyle )
+            if ( m_typeStyle ==frameStyle ) // frame styles
             {
                 //remove this style from list
                 QPtrListIterator<KWFrameStyle> styleIt( m_frameStyleList );
                 for ( ; styleIt.current(); ++styleIt )
                 {
-                    if ( styleIt.current()->name() == name )
+                    if ( styleIt.current()->displayName() == name )
                     {
                         m_frameStyleList.remove(styleIt.current());
                         break;
                     }
                 }
             }
-            else
+            else // then it will have to be table styles
             {
                 //remove this style from list
                 QPtrListIterator<KWTableStyle> styleIt( m_tableStyleList );
                 for ( ; styleIt.current(); ++styleIt )
                 {
-                    if ( styleIt.current()->name() == name )
+                    if ( styleIt.current()->displayName() == name )
                     {
                         m_tableStyleList.remove(styleIt.current());
                         break;
