@@ -40,15 +40,15 @@ public:
      * @param _path the name of the old file
      * @return the loaded picture (Picture is null if cancelled.)
      */
-    static KoPicture selectPictureDia( const QString & _path = QString::null );
-    
+    static KoPicture selectPictureDia( const QString & _path, QWidget* parent );
+
     KoPicture picture ( void ) const;
 
 protected slots:
     void slotChooseImage();
 
 protected:
-    static KoPicture selectPicture( KFileDialog & fd );
+    static KoPicture selectPicture( KFileDialog & fd, QWidget *parent );
 
 private:
 
