@@ -21,9 +21,11 @@
 #include "kwtablestylemanager.moc"
 #include "kwimportstyledia.h"
 
-#include <kwdoc.h>
+#include "kwdoc.h"
+
 #include <koparagcounter.h>
 #include <kotextdocument.h>
+
 #include "kwstyle.h"
 #include "kwframestylemanager.h"
 #include "kwstylemanager.h"
@@ -51,7 +53,7 @@ KWTableStylePreview::KWTableStylePreview( const QString& title, const QString& t
 {
     m_zoomHandler = new KoZoomHandler;
     QFont font = KoGlobal::defaultFont();
-    m_textdoc = new KoTextDocument( m_zoomHandler, new KoTextFormatCollection( font, QColor(),KGlobal::locale()->language(), false, 1.0 ));
+    m_textdoc = new KoTextDocument( m_zoomHandler, new KoTextFormatCollection( font, QColor(),KGlobal::locale()->language(), false ) );
     KoTextParag * parag = m_textdoc->firstParag();
     parag->insert( 0, text );
 }
@@ -223,7 +225,7 @@ void KWTableStyleManager::setupWidget(const QPtrList<KWTableStyle> & styleList)
     m_stylesList = new QListBox( frame1, "stylesList" );
     for ( ; style.current() ; ++style )
     {
-        m_stylesList->insertItem( style.current()->translatedName() );
+        m_stylesList->insertItem( style.current()->displayName() );
         m_tableStyles.append( new KWTableStyleListItem(style.current(),new KWTableStyle(*style.current()) ) );
         m_styleOrder<<style.current()->name();
     }
@@ -232,12 +234,12 @@ void KWTableStyleManager::setupWidget(const QPtrList<KWTableStyle> & styleList)
 
 
     m_moveUpButton = new QPushButton( frame1, "moveUpButton" );
-    m_moveUpButton->setPixmap( BarIcon( "up", KIcon::SizeSmall ) );
+    m_moveUpButton->setIconSet( SmallIconSet( "up" ) );
     connect( m_moveUpButton, SIGNAL( clicked() ), this, SLOT( moveUpStyle() ) );
     frame1Layout->addWidget( m_moveUpButton, 1, 1 );
 
     m_moveDownButton = new QPushButton( frame1, "moveDownButton" );
-    m_moveDownButton->setPixmap( BarIcon( "down", KIcon::SizeSmall ) );
+    m_moveDownButton->setIconSet( SmallIconSet( "down" ) );
     connect( m_moveDownButton, SIGNAL( clicked() ), this, SLOT( moveDownStyle() ) );
     frame1Layout->addWidget( m_moveDownButton, 1, 0 );
 
@@ -376,12 +378,12 @@ void KWTableStyleManager::updateGUI()
     kdDebug() << "KWTableStyleManager::updateGUI m_currentTableStyle=" << m_currentTableStyle << " " << m_currentTableStyle->name() << endl;
 
     // Update name
-    m_nameString->setText(m_currentTableStyle->translatedName());
+    m_nameString->setText(m_currentTableStyle->displayName());
     // Update style and framestyle
     if ( m_doc->styleCollection()->findStyle( m_currentTableStyle->pStyle()->name() ) )
-        m_style->setCurrentText(m_currentTableStyle->pStyle()->translatedName());
+        m_style->setCurrentText(m_currentTableStyle->pStyle()->displayName());
     if ( m_doc->frameStyleCollection()->findFrameStyle( m_currentTableStyle->pFrameStyle()->name() ) )
-        m_frameStyle->setCurrentText(m_currentTableStyle->pFrameStyle()->translatedName());
+        m_frameStyle->setCurrentText(m_currentTableStyle->pFrameStyle()->displayName());
 
     // update delete button (can't delete first style);
     m_deleteButton->setEnabled(m_stylesList->currentItem() != 0);
@@ -442,7 +444,7 @@ void KWTableStyleManager::addStyle(const QPtrList<KWTableStyle> &listStyle )
     for ( ; style.current() ; ++style )
     {
         noSignals=true;
-        m_stylesList->insertItem( style.current()->translatedName() );
+        m_stylesList->insertItem( style.current()->displayName() );
         m_styleOrder<<style.current()->name();
         m_tableStyles.append( new KWTableStyleListItem( 0L,new KWTableStyle(*style.current())) );
         noSignals=false;
@@ -628,7 +630,7 @@ void KWTableStyleManager::changeStyle()
     save();
 
 // 1. Execute stylist
-    KWStyleManager * styleManager = new KWStyleManager( this, m_doc->getUnit(),m_doc, m_doc->styleCollection()->styleList());
+    KWStyleManager * styleManager = new KWStyleManager( this, m_doc->unit(),m_doc, m_doc->styleCollection()->styleList());
     styleManager->exec();
 
 // 2. Apply changes
@@ -694,7 +696,7 @@ void KWTableStyleManager::selectFrameStyle(int index)
 {
     kdDebug() << "KWTableStyleManager::selectFrameStyle index " << index << endl;
 
-    if ( (index>=0) && ( index < m_doc->frameStyleCollection()->frameStyleList().count() ) )
+    if ( (index>=0) && ( index < (int)m_doc->frameStyleCollection()->frameStyleList().count() ) )
         m_currentTableStyle->setFrameStyle( m_doc->frameStyleCollection()->frameStyleAt(index) );
     save();
     updateGUI();
@@ -703,7 +705,7 @@ void KWTableStyleManager::selectFrameStyle(int index)
 void KWTableStyleManager::selectStyle(int index)
 {
     kdDebug() << "KWTableStyleManager::selectStyle index " << index << endl;
-    if ( (index>=0) && ( index < m_doc->styleCollection()->styleList().count() ) )
+    if ( (index>=0) && ( index < (int)m_doc->styleCollection()->styleList().count() ) )
         m_currentTableStyle->setStyle( m_doc->styleCollection()->styleAt(index) );
     save();
     updateGUI();
