@@ -20,9 +20,9 @@
 #ifndef kwtextparag_h
 #define kwtextparag_h
 
-//#include <kotextparag.h>
-#include "korichtext.h"
+#include "kotextparag.h"
 
+class KoStyleCollection;
 class QDomDocument;
 class KWTextFrameSet;
 class KWTextDocument;
@@ -46,7 +46,7 @@ public:
 
     KWTextDocument * kwTextDocument() const;
 
-    virtual void setParagLayout( const KoParagLayout &layout, int flags = KoParagLayout::All );
+    virtual void setParagLayout( const KoParagLayout &layout, int flags = KoParagLayout::All, int marginIndex = -1 );
 
     /** The type of page-breaking behaviour */
     void setPageBreaking( int pb ); // warning this sets all the flags!
@@ -55,30 +55,34 @@ public:
     bool hardFrameBreakBefore() const { return m_layout.pageBreaking & KoParagLayout::HardFrameBreakBefore; }
     bool hardFrameBreakAfter() const { return m_layout.pageBreaking & KoParagLayout::HardFrameBreakAfter; }
 
-    /** Public for loading a style */
+    /** Public for loading a style (KWord-1.3 XML) */
     static KoTextFormat loadFormat( QDomElement &formatElem, KoTextFormat *refFormat, const QFont &defaultFont, const QString & defaultLanguage, bool hyphanation );
-    /** Public for saving a style */
+    /** Public for saving a style (KWord-1.3 XML) */
     static QDomElement saveFormat( QDomDocument &doc, KoTextFormat *curFormat, KoTextFormat *refFormat, int pos, int len );
 
 
-    /** Save the whole paragraph */
+    /** Save (to KWord-1.3 XML) the whole paragraph */
     void save( QDomElement &parentElem, bool saveAnchorsFramesets = false );
 
-    /** Save a portion of the paragraph */
+    /** Save (to KWord-1.3 XML) a portion of the paragraph */
     void save( QDomElement &parentElem, int from, int to, bool saveAnchorsFramesets = false );
 
-    /** Load the paragraph */
+    /** Load (from KWord-1.3 XML) the paragraph */
     void load( QDomElement &attributes );
 
-    /** Load and apply <FORMAT> tags (used by KWTextParag::load and by KWPasteCommand) */
+    /** Load (from KWord-1.3 XML) and apply <FORMAT> tags (used by KWTextParag::load and by KWPasteCommand) */
     void loadFormatting( QDomElement &attributes, int offset = 0, bool loadFootNote=true );
 
-    /** Load and apply paragraph layout */
+    /** Load (from KWord-1.3 XML) and apply paragraph layout */
     void loadLayout( QDomElement & attributes );
 
-    /** Load from XML, optionally using styles from document. */
+    /** Load (from KWord-1.3 XML), optionally using styles from document. */
     static KoParagLayout loadParagLayout( QDomElement & parentElem, KWDocument *doc, bool useRefStyle );
 
+    virtual void loadOasis( const QDomElement& e, KoOasisContext& context, KoStyleCollection *styleCollection, uint& pos );
+    virtual void saveOasis( KoXmlWriter& writer, KoSavingContext& context,
+                            int from, int to, bool saveAnchorsFramesets = false ) const;
+
     virtual void join( KoTextParag *parag );
 protected:
     virtual void drawFormattingChars( QPainter &painter, int start, int len,
