@@ -21,15 +21,18 @@
 
 #include "kwtextframeset.h"
 #include "kwtextdocument.h"
-#include <kovariable.h>
 #include "mailmerge.h"
 #include "kwdoc.h"
 #include "kwcommand.h"
 #include "kwviewmode.h"
+
+#include <kovariable.h>
+#include <koxmlwriter.h>
+#include <koxmlns.h>
+#include <kodom.h>
+
 #include <klocale.h>
 #include <kdebug.h>
-#include <qdom.h>
-#include <qtimer.h>
 
 KWVariableSettings::KWVariableSettings() : KoVariableSettings()
 {
@@ -49,6 +52,44 @@ void KWVariableSettings::changeEndNoteCounter( KoParagCounter _c )
     m_endNoteCounter = _c;
 }
 
+void KWVariableSettings::saveNoteConfiguration( KoXmlWriter& writer ) const
+{
+    writer.startElement( "text:notes-configuration" );
+    writer.addAttribute( "text:note-class", "footnote" );
+    // let the counter save: num-prefix num-suffix num-format start-value
+    m_footNoteCounter.saveOasisListLevel( writer, false );
+    writer.addAttribute( "text:footnotes-position", "page" ); // tell OO what we do
+    writer.addAttribute( "text:start-numbering-at", "document" ); // tell OO what we do
+    writer.endElement();
+    writer.startElement( "text:notes-configuration" );
+    writer.addAttribute( "text:note-class", "endnote" );
+    // let the counter save: num-prefix num-suffix num-format start-value
+    m_endNoteCounter.saveOasisListLevel( writer, false );
+    writer.addAttribute( "text:start-numbering-at", "document" ); // tell OO what we do
+    writer.endElement();
+}
+
+void KWVariableSettings::loadNoteConfiguration( const QDomElement& parent )
+{
+    QDomElement e;
+    forEachElement( e, parent )
+    {
+        if ( e.localName() == "notes-configuration" && e.namespaceURI() == KoXmlNS::text )
+        {
+            const QString noteClass = e.attributeNS( KoXmlNS::text, "note-class", QString::null );
+            if ( noteClass == "footnote" ) {
+                m_footNoteCounter.loadOasisListStyle( e, QDomElement(), -1, true, false, 1, false );
+                m_footNoteCounter.setNumbering( KoParagCounter::NUM_FOOTNOTE );
+                m_footNoteCounter.setRestartCounter( false );
+            }
+            else if ( noteClass == "endnote" ) {
+                m_endNoteCounter.loadOasisListStyle( e, QDomElement(), -1, true, false, 1, false );
+                m_endNoteCounter.setNumbering( KoParagCounter::NUM_FOOTNOTE );
+                m_endNoteCounter.setRestartCounter( false );
+            }
+        }
+    }
+}
 
 void KWVariableSettings::save( QDomElement &parentElem )
 {
@@ -78,6 +119,41 @@ KWVariableCollection::KWVariableCollection(KWVariableSettings *_setting, KoVaria
 {
 }
 
+KoVariable* KWVariableCollection::loadOasisField( KoTextDocument* textdoc, const QDomElement& tag, KoOasisContext& context )
+{
+    const QString localName( tag.localName() );
+    const bool isTextNS = tag.namespaceURI() == KoXmlNS::text;
+    if ( isTextNS )
+    {
+        //kdDebug()<<" localName :"<<localName<<endl;
+        if ( localName ==  "note" )
+        {
+            QString key = "STRING";
+            int type = VT_FOOTNOTE;
+            return loadOasisFieldCreateVariable( textdoc, tag, context, key, type );
+        }
+        else if ( localName == "table-count"  ||
+                  localName == "object-count"  ||
+                  localName == "picture-count"  ||
+                  localName == "paragraph-count"  ||
+                  localName == "word-count"  ||
+                  localName == "character-count" ||
+                  localName == "sentence-count" ||
+                  localName == "line-count" ||
+                  localName == "frame-count"  ||
+                  localName == "non-whitespace-character-count" ||
+                  localName == "syllable-count")
+        {
+            QString key = "NUMBER";
+            int type = VT_STATISTIC;
+            return loadOasisFieldCreateVariable( textdoc, tag, context, key, type );
+        }
+        else
+            return KoVariableCollection::loadOasisField( textdoc, tag, context );
+    }
+    else
+        return KoVariableCollection::loadOasisField( textdoc, tag, context );
+}
 
 KoVariable *KWVariableCollection::createVariable( int type, short int subtype, KoVariableFormatCollection * coll, KoVariableFormat *varFormat,KoTextDocument *textdoc, KoDocument * doc, int _correct,bool _forceDefaultFormat, bool loadFootNote )
 {
@@ -86,7 +162,7 @@ KoVariable *KWVariableCollection::createVariable( int type, short int subtype, K
     switch(type) {
     case VT_PGNUM:
         if ( !varFormat )
-            varFormat = (subtype == KoPgNumVariable::VST_CURRENT_SECTION) ? coll->format("STRING") : coll->format("NUMBER");
+            varFormat = (subtype == KoPageVariable::VST_CURRENT_SECTION) ? coll->format("STRING") : coll->format("NUMBER");
         var = new KWPgNumVariable( textdoc, subtype, varFormat, this, m_doc );
         break;
     case VT_MAILMERGE:
@@ -99,6 +175,11 @@ KoVariable *KWVariableCollection::createVariable( int type, short int subtype, K
             varFormat =  coll->format("STRING");
         var = new KWFootNoteVariable( textdoc, varFormat, this, m_doc );
         break;
+    case VT_STATISTIC:
+        if ( !varFormat )
+            varFormat = coll->format("NUMBER");
+        var = new KWStatisticVariable( textdoc, subtype, varFormat, this, m_doc );
+        break;
     default:
         return KoVariableCollection::createVariable( type, subtype, coll, varFormat, textdoc, doc, _correct, _forceDefaultFormat );
     }
@@ -109,7 +190,7 @@ KoVariable *KWVariableCollection::createVariable( int type, short int subtype, K
 /* Class: KWPgNumVariable                                         */
 /******************************************************************/
 KWPgNumVariable::KWPgNumVariable( KoTextDocument *textdoc, int subtype, KoVariableFormat *varFormat ,KoVariableCollection *_varColl, KWDocument *doc  )
-    : KoPgNumVariable( textdoc, subtype, varFormat ,_varColl ), m_doc(doc)
+    : KoPageVariable( textdoc, subtype, varFormat ,_varColl ), m_doc(doc)
 {
 }
 
@@ -155,7 +236,7 @@ KWMailMergeVariable::KWMailMergeVariable( KoTextDocument *textdoc, const QString
 
 QString KWMailMergeVariable::value() const
 {
-    return m_doc->getMailMergeDataBase()->getValue( m_varValue.toString() );
+    return m_doc->mailMergeDataBase()->getValue( m_varValue.toString() );
 }
 
 QString KWMailMergeVariable::text(bool realValue)
@@ -164,7 +245,7 @@ QString KWMailMergeVariable::text(bool realValue)
         return fieldCode();
     // ## should use a format maybe
     QString v = value();
-    if (m_doc->getMailMergeDataBase()->isSampleRecord() )
+    if ( m_doc->mailMergeDataBase()->isSampleRecord() )
         return "<" + v + ">";
     return v;
 }
@@ -194,6 +275,94 @@ void KWFootNoteVariable::setNumberingType( Numbering _type )
     setVariableFormat(m_doc->variableFormatCollection()->format("STRING"));
 }
 
+void KWFootNoteVariable::loadOasis( const QDomElement& footNoteTag, KoOasisContext& context )
+{
+    /*<text:note text:id="ftn0" text:note-class="footnote"><text:note-citation>1</text:note-citation><text:note-body>
+      <text:p text:style-name="Footnote"></text:p></text:note-body></text:note> */
+    const QString id = footNoteTag.attributeNS( KoXmlNS::text, "id", QString::null );
+
+    if ( footNoteTag.hasAttributeNS( KoXmlNS::text, "note-class" ) )
+    {
+      const QString str =  footNoteTag.attributeNS( KoXmlNS::text, "note-class", QString::null );
+      if ( str == "footnote" )
+        m_noteType = FootNote;
+      else if ( str == "endnote" )
+        m_noteType = EndNote;
+      else {
+        kdWarning()<<" Unknown footnote type: '" << str << "'" << endl;
+        m_noteType = FootNote;
+      }
+    }
+
+    QDomElement element;
+    QDomElement bodyElement;
+    forEachElement( element, footNoteTag )
+    {
+      if ( element.namespaceURI() != KoXmlNS::text )
+        continue;
+
+      const QString localName = element.localName();
+      if( localName == "note-citation" )
+      {
+        if ( element.hasAttributeNS( KoXmlNS::text, "label" ) )
+            m_numberingType = Manual;
+        else
+            m_numberingType = Auto;
+        if ( m_numberingType == Auto )
+        {
+            //kdDebug()<<" automatic \n";
+            m_numDisplay = element.text().toInt();
+            formatedNote();
+        }
+        else
+        {
+           // kdDebug()<<" manual \n";
+            m_varValue = QVariant( element.text() );
+        }
+      } else if ( localName == "note-body" ) {
+          bodyElement = element;
+      }
+    }
+    Q_ASSERT( !bodyElement.isNull() );
+
+    Q_ASSERT( !m_frameset );
+    m_frameset = new KWFootNoteFrameSet( m_doc, id );
+    m_frameset->setFrameSetInfo( KWFrameSet::FI_FOOTNOTE );
+
+    m_frameset->setFootNoteVariable( this );
+    m_frameset->createInitialFrame( 0 );
+    m_doc->addFrameSet( m_frameset );
+
+    // Load the body of the footnote
+    m_frameset->loadOasisContent( bodyElement, context );
+}
+
+void KWFootNoteVariable::saveOasis( KoXmlWriter& writer, KoSavingContext& context ) const
+{
+    //<text:note text:id="ftn0" text:note-class="footnote"><text:note-citation>1</text:note-citation><text:note-body><text:p text:style-name="Footnote"/></text:note-body></text:note>
+    //<text:note text:id="ftn1" text:note-class="endnote"><text:note-citation>i</text:note-citation><text:note-body><text:p text:style-name="Endnote"/></text:note-body></text:note>
+    //<text:note text:id="ftn2" text:note-class="footnote"><text:note-citation text:label="vv">vv</text:note-citation><text:note-body><text:p text:style-name="Footnote"/></text:note-body></text:note>
+    writer.startElement( "text:note" );
+    writer.addAttribute( "text:id",m_frameset->getName() );
+    writer.addAttribute( "text:note-class", m_noteType == FootNote ? "footnote" : "endnote" );
+
+    writer.startElement( "text:note-citation" );
+    if ( m_numberingType == Auto )
+        writer.addTextNode( QString( "%1" ).arg( m_numDisplay ) );
+    else
+    {
+        writer.addAttribute( "text:label", m_varValue.toString() );
+        writer.addTextNode(m_varValue.toString() );
+    }
+    writer.endElement();
+
+    writer.startElement( "text:note-body" );
+    //save text from end/footnote
+    m_frameset->saveOasisContent( writer, context );
+    writer.endElement();
+
+    writer.endElement();
+}
 
 void KWFootNoteVariable::saveVariable( QDomElement &parentElem )
 {
@@ -207,7 +376,8 @@ void KWFootNoteVariable::saveVariable( QDomElement &parentElem )
     footnoteElem.setAttribute( "notetype", m_noteType == FootNote ? "footnote" : "endnote" );
     footnoteElem.setAttribute( "numberingtype", m_numberingType == Auto ? "auto" : "manual" );
     Q_ASSERT( m_frameset );
-    footnoteElem.setAttribute( "frameset", m_frameset->getName() );
+    if( m_frameset )
+      footnoteElem.setAttribute( "frameset", m_frameset->getName() );
 }
 
 void KWFootNoteVariable::load( QDomElement &elem )
@@ -469,3 +639,102 @@ double KWFootNoteVariable::varY() const
         return 0;
     }
 }
+
+
+KWStatisticVariable::KWStatisticVariable( KoTextDocument *textdoc,  int subtype, KoVariableFormat *varFormat,KoVariableCollection *_varColl, KWDocument *doc )
+    : KoStatisticVariable( textdoc, subtype, varFormat, _varColl ),
+      m_doc(doc)
+{
+}
+
+void KWStatisticVariable::recalc()
+{
+    if ( m_doc->viewMode()->type() == "ModeText")
+    {
+        //necessary to resize it in this mode because in this mode
+        //we don't call KWTextFrameSet::drawFrame()
+        resize();
+        return;
+    }
+    int nb = 0;
+    ulong charsWithSpace = 0L;
+    ulong charsWithoutSpace = 0L;
+    ulong words = 0L;
+    ulong sentences = 0L;
+    ulong lines = 0L;
+    ulong syllables = 0L;
+    bool frameInfo = ( m_subtype == VST_STATISTIC_NB_WORD ||
+                        m_subtype == VST_STATISTIC_NB_SENTENCE ||
+                        m_subtype == VST_STATISTIC_NB_LINES ||
+                        m_subtype == VST_STATISTIC_NB_CHARACTERE);
+    QPtrListIterator<KWFrameSet> framesetIt( m_doc->framesetsIterator() );
+    //TODO chnage int to ulong
+    for ( framesetIt.toFirst(); framesetIt.current(); ++framesetIt )
+    {
+        KWFrameSet *frameSet = framesetIt.current();
+        if ( frameSet->isVisible() )
+        {
+            if ( m_subtype == VST_STATISTIC_NB_FRAME )
+                ++nb;
+            else if( m_subtype == VST_STATISTIC_NB_PICTURE && frameSet->type() == FT_PICTURE)
+            {
+                ++nb;
+            }
+            else if( m_subtype == VST_STATISTIC_NB_TABLE && frameSet->type() == FT_TABLE)
+            {
+                ++nb;
+            }
+            else if( m_subtype == VST_STATISTIC_NB_EMBEDDED && frameSet->type() == FT_PART )
+            {
+                ++nb;
+            }
+            if ( frameInfo )
+            {
+            if ( (frameSet->frameSetInfo() == KWFrameSet::FI_FOOTNOTE || frameSet->frameSetInfo() == KWFrameSet::FI_BODY) && frameSet->isVisible() )
+                frameSet->statistics( 0L, charsWithSpace, charsWithoutSpace, words, sentences, syllables, lines, false );
+            }
+        }
+        if ( frameInfo )
+        {
+            if( m_subtype == VST_STATISTIC_NB_WORD )
+            {
+                nb = words;
+            }
+            else if( m_subtype == VST_STATISTIC_NB_SENTENCE )
+            {
+                nb = sentences;
+            }
+            else if( m_subtype == VST_STATISTIC_NB_LINES )
+            {
+                nb = lines;
+            }
+            else if ( m_subtype == VST_STATISTIC_NB_CHARACTERE )
+            {
+                nb = charsWithSpace;
+            }
+            else if ( m_subtype ==VST_STATISTIC_NB_NON_WHITESPACE_CHARACTERE )
+            {
+                nb = charsWithoutSpace;
+            }
+            else if ( m_subtype ==VST_STATISTIC_NB_SYLLABLE )
+            {
+                nb = syllables;
+            }
+
+            else
+                nb = 0;
+        }
+    }
+    m_varValue = QVariant(nb);
+    resize();
+    if ( width == -1 )
+        width = 0;
+}
+
+QString KWStatisticVariable::text(bool realValue)
+{
+    if (m_varColl->variableSetting()->displayFieldCode()&& !realValue)
+        return fieldCode();
+    else
+        return m_varFormat->convert( m_varValue );
+}
