@@ -35,6 +35,7 @@
 #include <koView.h>
 #include <kshortcut.h>
 class DCOPObject;
+class KURL;
 
 class KoPicture;
 class KWDocStruct;
@@ -50,7 +51,7 @@ class KWStyleManager;
 class KWTableDia;
 class KWView;
 class QResizeEvent;
-class KSpell;
+//class KSpell;
 class QScrollView;
 class QSplitter;
 class KAction;
@@ -79,7 +80,14 @@ class KWTableStyle;
 class KoTextIterator;
 class KWTableFrameSet;
 
-class KOSpell;
+class KoSpell;
+#ifdef HAVE_LIBKSPELL2
+#include <kspell2/broker.h>
+namespace KSpell2 {
+    class Dialog;
+}
+#endif
+
 
 /******************************************************************/
 /* Class: KWView						  */
@@ -113,6 +121,13 @@ public:
     bool viewFrameBorders() const { return m_viewFrameBorders; }
     void setViewFrameBorders(bool b);
 
+#ifdef HAVE_LIBKSPELL2
+    /**
+     * Returns the KWord global KSpell2 Broker object.
+     */
+    KSpell2::Broker *broker() const;
+#endif
+
     // Currently unused
     //bool viewTableGrid() const { return m_viewTableGrid; }
     //void setViewTableGrid(bool _b) { m_viewTableGrid = _b;}
@@ -170,7 +185,13 @@ public:
     QPtrList<KAction> &variableActionList() { return m_variableActionList; }
     QPtrList<KAction> &tableActions() { return m_tableActionList; }
 
-    static void checkClipboard( QMimeSource *data, bool &providesImage, bool &providesKWordText, bool &providesKWord, bool &providesFormula );
+    enum { // bitfield
+        ProvidesImage = 1,
+        ProvidesPlainText = 2,
+        ProvidesOasis = 4,
+        ProvidesFormula = 8
+    };
+    static int checkClipboard( QMimeSource *data );
 
     bool insertInlinePicture();
 
@@ -183,8 +204,7 @@ public:
     void updateHeader();
     void switchModeView();
     void changeFootNoteMenuItem( bool b);
-    void insertFile(const QString & path);
-    void configureSpellChecker();
+    void insertFile(const KURL& _url);
     void testAndCloseAllFrameSetProtectedContent();
     void updateBgSpellCheckingState();
     void updateRulerInProtectContentMode();
@@ -203,12 +223,15 @@ public:
     int tableDeleteRow(const QValueList<uint>& rows, KWTableFrameSet *table = 0);
     int tableDeleteCol(const QValueList<uint>& cols, KWTableFrameSet *table = 0);
 
+    void pasteData( QMimeSource* data );
+
 public slots:
     void fileStatistics();
     void editCut();
     void editCopy();
     void editPaste();
     void editSelectAll();
+    void editSelectAllFrames();
     void editFind();
     void editFindNext();
     void editFindPrevious();
@@ -317,7 +340,7 @@ public slots:
     void configure();
     void configureCompletion();
 
-    void newPageLayout( KoPageLayout _layout );
+    void newPageLayout( const KoPageLayout &_layout );
     void newLeftIndent( double _leftIndent);
     void newFirstIndent( double _firstIndent);
     void newRightIndent( double _rightIndent);
@@ -327,6 +350,7 @@ public slots:
 
     void updatePageInfo();
     void updateFrameStatusBarItem();
+    void setTemporaryStatusBarText(const QString &text);
 
     void slotSpecialChar(QChar , const QString &);
     void slotFrameSetEditChanged();
@@ -382,6 +406,10 @@ public slots:
     void slotSoftHyphen();
     void slotLineBreak();
     void slotNonbreakingSpace();
+    void slotNonbreakingHyphen();
+
+    void slotIncreaseNumberingLevel();
+    void slotDecreaseNumberingLevel();
 
     void refreshAllVariable();
 
@@ -433,16 +461,14 @@ public slots:
     void editFrameSetProperties();
 
 protected slots:
-    virtual void slotChildActivated( bool a ); // from KoView
+    virtual void slotChildActivated( bool a ); ///< from KoView
     void slotSetInitialPosition();
 
-    void spellCheckerReady();
-    void spellCheckerMisspelling( const QString &, const QStringList &, unsigned int );
-    void spellCheckerCorrected( const QString &, const QString &, unsigned int);
+    void spellCheckerMisspelling( const QString &, int );
+    void spellCheckerCorrected( const QString &, int, const QString & );
     void spellCheckerDone( const QString & );
-    void spellCheckerFinished( );
-    void spellCheckerIgnoreAll( const QString &);
-    void spellCheckerReplaceAll( const QString &,  const QString &);
+    void spellCheckerCancel();
+
     void spellAddAutoCorrect (const QString & originalword, const QString & newword);
     void slotApplyFont();
     void slotApplyParag();
@@ -457,7 +483,7 @@ protected:
 
     void loadexpressionActions( KActionMenu * parentMenu);
 
-    void createExpressionActions( KActionMenu * parentMenu,const QString& filename,int &i , bool insertSepar );
+    void createExpressionActions( KActionMenu * parentMenu,const QString& filename,int &i , bool insertSepar, const QMap<QString, KShortcut>& personalShortCut );
 
     void insertPicture( const KoPicture& picture, const bool makeInline, const bool _keepRatio );
 
@@ -481,7 +507,7 @@ protected:
 
 
     void startKSpell();
-    void clearSpellChecker();
+    void clearSpellChecker(bool cancelSpellCheck = false );
 
     QValueList<QString> getInlineFramesets( const QDomNode &framesetElem );
 
@@ -494,12 +520,14 @@ protected:
     int lowerFrame(const QPtrList<KWFrame> frameSelection, const KWFrame *frame);
     int bringToFront(const QPtrList<KWFrame> frameSelection, const KWFrame *frame);
     int sendToBack(const QPtrList<KWFrame> frameSelection, const KWFrame *frame);
-    void textStyleSelected( KoStyle *_sty );
+    void textStyleSelected( KoParagStyle *_sty );
     void frameStyleSelected( KWFrameStyle *_sty );
     void tableStyleSelected( KWTableStyle *_sty );
     void changeFootEndNoteState();
     void refreshDeletePageAction();
 
+    void spellCheckerRemoveHighlight();
+
 private:
     KWDocument *m_doc;
 
@@ -620,11 +648,11 @@ private:
     TKSelectColorAction *actionBackgroundColor;
     struct
     {
-        KoBorder left;    // Values specific to left border.
-        KoBorder right;   // right.
-        KoBorder top;     // top.
-        KoBorder bottom;  // bottom.
-        KoBorder common;  // Value common to left, right top and bottom borders.
+        KoBorder left;    ///< Values specific to left border.
+        KoBorder right;   ///< right.
+        KoBorder top;     ///< top.
+        KoBorder bottom;  ///< bottom.
+        KoBorder common;  ///< Value common to left, right top and bottom borders.
     } m_border;
 
     KAction *actionTableDelRow;
@@ -697,6 +725,7 @@ private:
     KAction *actionConvertToTextBox;
 
     KAction *actionSpellIgnoreAll;
+    KAction *actionSpellCheck;
 
 #if 0 // KWORD_HORIZONTAL_LINE
     // MOC_SKIP_BEGIN
@@ -727,11 +756,11 @@ private:
     QPtrList<KAction> m_variableActionList;
     QPtrList<KAction> m_tableActionList;
 
-    int m_currentPage; // 0-based current page number
+    int m_currentPage; ///< 0-based current page number
 
     // Statusbar items
-    QLabel * m_sbPageLabel; // 'Current page number and page count' label
-    QLabel * m_sbFramesLabel; // Info about selected frames
+    QLabel * m_sbPageLabel; ///< 'Current page number and page count' label
+    QLabel * m_sbFramesLabel; ///< Info about selected frames
 
     // Zoom values for each viewmode ( todo a viewmode enum and a qmap or so )
     int m_zoomViewModeNormal;
@@ -739,16 +768,22 @@ private:
 
     bool m_viewFrameBorders /*, m_viewTableGrid*/;
 
-    // Spell-checking
+    /// Spell-checking
     struct {
-        KOSpell *kospell;
+        KoSpell *kospell;
 	KMacroCommand * macroCmdSpellCheck;
         QStringList replaceAll;
         KoTextIterator * textIterator;
+#ifdef HAVE_LIBKSPELL2
+        KSpell2::Dialog *dlg;
+#endif
      } m_spell;
+#ifdef HAVE_LIBKSPELL2
+    KSpell2::Broker::Ptr m_broker;
+#endif
+
 
     KWFrameSet *fsInline;
-    QMap<QString, KShortcut> *m_personalShortCut;
 
 };
 
@@ -792,7 +827,7 @@ public slots:
     void reorganize();
 
 protected slots:
-    void unitChanged( QString  );
+    void unitChanged( KoUnit::Unit );
 
 protected:
     void resizeEvent( QResizeEvent *e );
