@@ -24,10 +24,6 @@
 #include "kwtextframeset.h"
 #include "kwtableframeset.h"
 #include <kdebug.h>
-#include <kdeversion.h>
-#if ! KDE_IS_VERSION(3,1,90)
-#include <kdebugclasses.h>
-#endif
 
 const unsigned short KWViewMode::s_shadowOffset = 3;
 
@@ -343,7 +339,7 @@ KWTextFrameSet * KWViewModeText::determineTextFrameSet( KWDocument* doc ) // sta
     }
 
     if (!fs || fs->type() != FT_TEXT || fs->isHeaderOrFooter() || fs->isFootEndNote())
-        if ( doc->getNumFrameSets() > 0 && doc->frameSet( 0 )->isVisible() )
+        if ( doc->numFrameSets() > 0 && doc->frameSet( 0 )->isVisible() )
             fs = doc->frameSet( 0 );  // if not a textFS, or header/footer/footnote: fallback to fs 0
 
     return dynamic_cast<KWTextFrameSet *>(fs);
