@@ -28,16 +28,13 @@ static const KCmdLineOptions options[]=
 	KCmdLineLastOption
 };
 
-int main( int argc, char **argv )
+extern "C" KWORD_EXPORT int kdemain( int argc, char **argv )
 {
     KCmdLineArgs::init( argc, argv, newKWordAboutData());
     KCmdLineArgs::addCmdLineOptions( options );
 
     KoApplication app;
 
-    app.dcopClient()->attach();
-    app.dcopClient()->registerAs("kword");
-
     if (!app.start())
 	return 1;
     app.exec();
