@@ -123,12 +123,17 @@ void KWResizeHandle::mouseMoveEvent( QMouseEvent *e )
 
 void KWResizeHandle::mousePressEvent( QMouseEvent *e )
 {
+    if ( e->button() != LeftButton )
+    {
+        e->ignore(); // let KWCanvas handle it
+        return;
+    }
     KWFrameSet *fs = 0;
     KWFrame *frm = 0;
 
     // Deselect all other frames
     KWDocument * doc = frame->frameSet()->kWordDocument();
-    for ( unsigned int i = 0; i < doc->getNumFrameSets(); ++i ) {
+    for ( unsigned int i = 0; i < doc->numFrameSets(); ++i ) {
         fs = doc->frameSet( i );
         for ( unsigned int j = 0; j < fs->getNumFrames(); ++j ) {
             frm = fs->frame( j );
@@ -145,12 +150,19 @@ void KWResizeHandle::mousePressEvent( QMouseEvent *e )
 
     MouseMeaning meaning = doc->getMouseMeaning( nPoint, e->state() );
     Q_ASSERT( meaning >= MEANING_TOPLEFT ); // had be better be about resizing...
+    if ( meaning < MEANING_TOPLEFT )
+        kdDebug(32001) << "KWResizeHandle: got unexpected meaning " << meaning << endl;
 
     m_canvas->mpEditFrame( 0, nPoint, meaning );
 }
 
 void KWResizeHandle::mouseReleaseEvent( QMouseEvent *e )
 {
+    if ( e->button() != LeftButton )
+    {
+        e->ignore(); // let KWCanvas handle it
+        return;
+    }
     mousePressed = false;
     QPoint vPoint( x() + e->x(), y() + e->y() );
     QPoint nPoint = m_canvas->viewMode()->viewToNormal( vPoint );
