@@ -448,7 +448,7 @@ bool FractionElement::readContentFromDom(QDomNode& node)
 QString FractionElement::toLatex()
 {
     if ( withLine ) {
-        return "\\frac" + numerator->toLatex() + denominator->toLatex();
+        return "\\frac{" + numerator->toLatex() +"}{" + denominator->toLatex() + "}";
     }
     else {
         return "{" + numerator->toLatex() + "\\atop " + denominator->toLatex() + "}";
@@ -460,13 +460,13 @@ QString FractionElement::formulaString()
     return "(" + numerator->formulaString() + ")/(" + denominator->formulaString() + ")";
 }
 
-void FractionElement::writeMathML( QDomDocument doc, QDomNode parent )
+void FractionElement::writeMathML( QDomDocument& doc, QDomNode parent, bool oasisFormat )
 {
-    QDomElement de = doc.createElement( "mfrac" );
+    QDomElement de = doc.createElement( oasisFormat ? "math:mfrac": "mfrac" );
     if ( !withLine ) // why is this no function?
         de.setAttribute( "linethickness", 0 );
-    numerator->writeMathML( doc, de );
-    denominator->writeMathML( doc, de );
+    numerator->writeMathML( doc, de, oasisFormat );
+    denominator->writeMathML( doc, de, oasisFormat );
     parent.appendChild( de );
 }
 
