@@ -25,15 +25,16 @@
 #include <qdom.h>
 
 #include "kformulacontainer.h"
+#include <koffice_export.h>
 
 KFORMULA_NAMESPACE_BEGIN
 class FormulaElement;
 
 
-class MimeSource : public QMimeSource, public FormulaDocument
+class KOFORMULA_EXPORT MimeSource : public QMimeSource, public FormulaDocument
 {
 public:
-    MimeSource(Document* doc, QDomDocument formula);
+    MimeSource(Document* doc, const QDomDocument& formula);
     ~MimeSource();
 
     virtual const char* format ( int n = 0 ) const;
