@@ -194,7 +194,7 @@ public:
 
     SequenceElement* elementAt(uint row, uint column);
 
-    virtual void writeMathML( QDomDocument doc, QDomNode parent );
+    virtual void writeMathML( QDomDocument& doc, QDomNode parent, bool oasisFormat = false );
 
 protected:
 
@@ -359,7 +359,7 @@ public:
 
     virtual QString formulaString();
 
-    virtual void writeMathML( QDomDocument doc, QDomNode parent );
+    virtual void writeMathML( QDomDocument& doc, QDomNode parent, bool oasisFormat = false );
 
 protected:
 
