@@ -66,7 +66,7 @@ void SequenceElement::setCreationStrategy( ElementCreationStrategy* strategy )
 
 
 SequenceElement::SequenceElement(BasicElement* parent)
-        : BasicElement(parent), parseTree(0), textSequence(true)
+        : BasicElement(parent), parseTree(0), textSequence(true),singlePipe(true)
 {
     assert( creationStrategy != 0 );
     children.setAutoDelete(true);
@@ -1233,45 +1233,71 @@ KCommand* SequenceElement::input( Container* container, QChar ch )
     case '(': {
         BracketRequest r( container->document()->leftBracketChar(),
                           container->document()->rightBracketChar() );
+        singlePipe = true;
         return buildCommand( container, &r );
     }
     case '[': {
         BracketRequest r( LeftSquareBracket, RightSquareBracket );
+        singlePipe = true;
         return buildCommand( container, &r );
     }
     case '{': {
         BracketRequest r( LeftCurlyBracket, RightCurlyBracket );
+        singlePipe = true;
         return buildCommand( container, &r );
     }
-    case '|': {
-        BracketRequest r( LeftLineBracket, RightLineBracket );
-        return buildCommand( container, &r );
+    case '|': {	
+        if (!singlePipe) { // We have had 2 '|' in a row so we want brackets
+
+          DirectedRemove rDelete( req_remove, beforeCursor ); //Delete the previous '|' we dont need it any more
+          KCommand* command = buildCommand( container, &rDelete );
+          command->execute();
+          
+          BracketRequest rBracket( LeftLineBracket , RightLineBracket);
+          singlePipe = true;  //the next '|' will be a single pipe again
+          return buildCommand( container, &rBracket );    
+        }
+        else { // We really do only want 1 '|'
+          TextCharRequest r(ch);
+
+          //in case another '|' character is entered right after this one, '| |' brackets are made; see above
+          singlePipe = false;
+
+          return buildCommand( container, &r );   
+        }
     }
     case '^': {
         IndexRequest r( upperRightPos );
+        singlePipe = true;
         return buildCommand( container, &r );
     }
     case '_': {
         IndexRequest r( lowerRightPos );
+        singlePipe = true;
         return buildCommand( container, &r );
     }
     case ' ': {
         Request r( req_compactExpression );
+        singlePipe = true;
         return buildCommand( container, &r );
     }
     case '}': {
         Request r( req_addEmptyBox );
+        singlePipe = true;
         return buildCommand( container, &r );
     }
     case ']':
     case ')':
+        singlePipe = true; 
         break;
     case '\\': {
         Request r( req_addNameSequence );
+        singlePipe = true;
         return buildCommand( container, &r );
     }
     default: {
         TextCharRequest r( ch );
+        singlePipe = true;
         return buildCommand( container, &r );
     }
     }
@@ -1281,7 +1307,7 @@ KCommand* SequenceElement::input( Container* container, QChar ch )
 /**
  * Stores the given childrens dom in the element.
  */
-void SequenceElement::getChildrenDom(QDomDocument doc, QDomElement elem,
+void SequenceElement::getChildrenDom( QDomDocument& doc, QDomElement elem,
                                      uint from, uint to)
 {
     for (uint i = from; i < to; i++) {
@@ -1415,16 +1441,14 @@ bool SequenceElement::isFirstOfToken( BasicElement* child )
 QString SequenceElement::toLatex()
 {
     QString content;
-    content += "{";
     uint count = children.count();
     for ( uint i = 0; i < count; i++ ) {
         BasicElement* child = children.at( i );
-        if ( isFirstOfToken( child ) ) {
-            content += " ";
-        }
+//         if ( isFirstOfToken( child ) ) {
+//             content += "";
+//         }
         content += child->toLatex();
     }
-    content += "}";
     return content;
 }
 
@@ -1444,9 +1468,9 @@ QString SequenceElement::formulaString()
 }
 
 
-void SequenceElement::writeMathML( QDomDocument doc, QDomNode parent )
+void SequenceElement::writeMathML( QDomDocument& doc, QDomNode parent, bool oasisFormat )
 {
-    QDomElement de = doc.createElement( "mrow" );
+    QDomElement de = doc.createElement( oasisFormat ? "math:mrow" : "mrow" );
 
     BasicElement* last = children.last();
     if ( last != 0 ) {
@@ -1460,12 +1484,12 @@ void SequenceElement::writeMathML( QDomDocument doc, QDomNode parent )
         }
 
         if ( tokenList.count() == 1 ) {
-            tokenList.first()->saveMathML( this, doc, parent.toElement() );
+            tokenList.first()->saveMathML( this, doc, parent.toElement(), oasisFormat );
             return;
         }
 
         for ( uint i = 0; i < tokenList.count(); ++i ) {
-            tokenList.at( i )->saveMathML( this, doc, de );
+            tokenList.at( i )->saveMathML( this, doc, de, oasisFormat );
         }
     }
     parent.appendChild( de );
@@ -1691,9 +1715,9 @@ bool NameSequence::isValidSelection( FormulaCursor* cursor )
     return sequence->onlyTextSelected( cursor );
 }
 
-void NameSequence::writeMathML( QDomDocument doc, QDomNode parent )
+void NameSequence::writeMathML( QDomDocument& doc, QDomNode parent,bool oasisFormat )
 {
-    QDomElement de = doc.createElement( "mi" );
+    QDomElement de = doc.createElement( oasisFormat ? "math:mi" : "mi" );
     QString value;
     for ( int i = 0; i < countChildren(); ++i ) {
         // these are supposed to by TextElements
