@@ -163,10 +163,10 @@ bool SpaceElement::readContentFromDom(QDomNode& node)
     return BasicElement::readContentFromDom( node );
 }
 
-void SpaceElement::writeMathML( QDomDocument doc, QDomNode parent )
+void SpaceElement::writeMathML( QDomDocument& doc, QDomNode parent, bool oasisFormat )
 {
 
-    QDomElement de = doc.createElement( "mspace" );
+    QDomElement de = doc.createElement( oasisFormat ? "math:mspace" : "mspace" );
     QString width;
 
     switch ( spaceWidth ) {
