@@ -97,7 +97,7 @@ public:
      */
     virtual QString toLatex();
 
-    virtual void writeMathML( QDomDocument doc, QDomNode parent );
+    virtual void writeMathML( QDomDocument& doc, QDomNode parent, bool oasisFormat = false );
 
 protected:
 
