@@ -23,18 +23,14 @@
 namespace std { }
 using namespace std;
 #include <kapplication.h>
-
-// Be VERY careful with this. There is no KoApplication when embedded into e.g. konqueror
-// Ah well, don't even use it at all, that would be better.
-// Next version: remove completely
-#define KOAPP ((KoApplication *)KApplication::kApplication())
+#include <koffice_export.h>
 
 class KoApplicationPrivate;
 
 /**
- *  Base class for all KOffice apps
+ *  @brief Base class for all %KOffice apps
  *
- *  This class handles given arguments giving on the command line and
+ *  This class handles arguments given on the command line and
  *  shows a generic about dialog for all KOffice apps.
  *
  *  In addition it adds the standard directories where KOffice applications
@@ -42,10 +38,8 @@ class KoApplicationPrivate;
  *
  *  If the last mainwindow becomes closed, KoApplication automatically
  *  calls @ref QApplication::quit.
- *
- *  @short Base class for all KOffice apps.
  */
-class KoApplication : public KApplication
+class KOFFICECORE_EXPORT KoApplication : public KApplication
 {
     Q_OBJECT
 
@@ -83,7 +77,7 @@ public:
 private:
     bool initHack();
     KoApplicationPrivate* d;
-    static bool m_starting ; // is the application starting or not
+    static bool m_starting ; ///< is the application starting or not
     class ResetStarting;
     friend class ResetStarting;
 };
