@@ -890,6 +890,9 @@ bool KoDocument::saveChildrenOasis( KoStore* store, KoXmlWriter* manifestWriter
                 kdDebug(30003)<<k_funcinfo<<" external (don't save) url:" << childDoc->url().url()<<endl;
                 path = childDoc->url().url();
             }
+            // OOo uses a trailing slash for the path to embedded objects (== directories)
+            if ( !path.endsWith( "/" ) )
+                path += '/';
             manifestWriter->addManifestEntry( path, childDoc->nativeOasisMimeType() );
         }
     }
@@ -1793,7 +1796,9 @@ bool KoDocument::loadOasisFromStore( KoStore* store )
     //if ( !oasisStore.loadAndParse( "tar:/META-INF/manifest.xml", manifestDoc, d->lastErrorMessage ) )
     //    return false;
 
-    (void)oasisStore.loadAndParse( "settings.xml", settingsDoc, d->lastErrorMessage );
+    if ( store->hasFile( "settings.xml" ) ) {
+        (void)oasisStore.loadAndParse( "settings.xml", settingsDoc, d->lastErrorMessage );
+    }
     if ( !loadOasis( contentDoc, oasisStyles, settingsDoc, store ) )
         return false;
 
@@ -1846,7 +1851,7 @@ void KoDocument::setModified( bool mod )
     }
     d->modifiedAfterAutosave = mod;
 
-    if ( mod == KParts::ReadWritePart::isModified() )
+    if ( mod == isModified() )
         return;
 
     KParts::ReadWritePart::setModified( mod );
@@ -1920,9 +1925,12 @@ int KoDocument::queryCloseExternalChildren()
             KoDocument *doc = it.current()->document();
             if ( doc )
             {
-                if ( doc->isStoredExtern() ) //###TODO: Handle non-native mimetype docs
+		bool foo = doc->isStoredExtern();
+		kdDebug(36001) << "========== isStoredExtern() returned " 
+			       << foo << " ==========" << endl;
+
+                if ( foo ) //###TODO: Handle non-native mimetype docs
                 {
-                    if ( doc->isModified() )
                     {
                         kdDebug(30003)<<k_funcinfo<<" found modified child: "<<doc->url().url()<<" extern="<<doc->isStoredExtern()<<endl;
                         if ( doc->queryCloseDia() == KMessageBox::Cancel )
