@@ -30,8 +30,12 @@
 #include "koPictureShared.h"
 #include "koPicture.h"
 
+uint KoPicture::uniqueValue = 0;
+
+
 KoPicture::KoPicture(void) : m_sharedData(NULL)
 {
+  m_uniqueName = "Pictures"+ QString::number(uniqueValue++);
 }
 
 KoPicture::~KoPicture(void)
@@ -39,12 +43,31 @@ KoPicture::~KoPicture(void)
     unlinkSharedData();
 }
 
+QString KoPicture::uniqueName() const
+{
+  return m_uniqueName;
+}
+
 KoPicture::KoPicture(const KoPicture &other)
 {
     m_sharedData=NULL;
     (*this)=other;
 }
 
+void KoPicture::assignPictureId( uint _id)
+{
+    if ( m_sharedData )
+        m_sharedData->assignPictureId(_id);
+}
+
+QString KoPicture::uniquePictureId() const
+{
+    if ( m_sharedData )
+        return m_sharedData->uniquePictureId();
+    else
+        return QString::null;
+}
+
 KoPicture& KoPicture::operator=( const KoPicture &other )
 {
     //kdDebug(30003) << "KoPicture::= before" << endl;
@@ -98,6 +121,7 @@ void KoPicture::setKey(const KoPictureKey& key)
     m_key=key;
 }
 
+
 bool KoPicture::isNull(void) const
 {
     if (m_sharedData)
@@ -132,7 +156,7 @@ bool KoPicture::loadXpm(QIODevice* io)
     return m_sharedData->loadXpm(io);
 }
 
-bool KoPicture::save(QIODevice* io)
+bool KoPicture::save(QIODevice* io) const
 {
     if (!io)
         return false;
@@ -141,7 +165,7 @@ bool KoPicture::save(QIODevice* io)
     return false;
 }
 
-bool KoPicture::saveAsKOffice1Dot1(QIODevice* io)
+bool KoPicture::saveAsKOffice1Dot1(QIODevice* io) const
 {
     if (!io)
         return false;
@@ -150,6 +174,14 @@ bool KoPicture::saveAsKOffice1Dot1(QIODevice* io)
     return false;
 }
 
+
+bool KoPicture::saveAsBase64( KoXmlWriter& writer ) const
+{
+    if ( m_sharedData )
+        return m_sharedData->saveAsBase64( writer );
+    return false;
+}
+
 void KoPicture::clear(void)
 {
     unlinkSharedData();
@@ -197,6 +229,12 @@ bool KoPicture::loadFromFile(const QString& fileName)
     return m_sharedData->loadFromFile(fileName);
 }
 
+bool KoPicture::loadFromBase64( const QCString& str )
+{
+    createSharedData();
+    return m_sharedData->loadFromBase64( str );
+}
+
 QSize KoPicture::getOriginalSize(void) const
 {
     if (m_sharedData)
@@ -218,12 +256,12 @@ bool KoPicture::isClipartAsKOffice1Dot1(void) const
     return false;
 }
 
-bool KoPicture::setKeyAndDownloadPicture(const KURL& url)
+bool KoPicture::setKeyAndDownloadPicture(const KURL& url, QWidget *window)
 {
     bool result=false;
 
     QString tmpFileName;
-    if ( KIO::NetAccess::download(url, tmpFileName) )
+    if ( KIO::NetAccess::download(url, tmpFileName, window) )
     {
         KoPictureKey key;
         key.setKeyFromFile( tmpFileName );
@@ -274,4 +312,3 @@ void KoPicture::clearCache(void)
     if (m_sharedData)
         m_sharedData->clearCache();
 }
-
