@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (c) 2001 Simon Hausmann <hausmann@kde.org>
-   Copyright (C) 2002, 2003 Nicolas GOUTTE <goutte@kde.org>
+   Copyright (C) 2002, 2003, 2004 Nicolas GOUTTE <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,6 +29,7 @@ class KoPictureImagePrivate;
 /**
  * @internal
  * KoPictureImage is a container class for a QImage-based picture
+ * \todo remove private class, as the header is not installed
  */
 class KoPictureImage : public KoPictureBase
 {
@@ -53,7 +54,8 @@ public:
     virtual bool isNull(void) const;
 
     /**
-     * Draw the image in a painter.
+     * @brief Draw the image in a painter.
+     *
      * No, this isn't as simple as painter.drawPixmap().
      * This method ensures that the best quality is used when printing, scaling the painter.
      *
@@ -73,9 +75,9 @@ public:
 
     virtual QDragObject* dragObject( QWidget *dragSource = 0L, const char *name = 0L );
 
-    virtual bool load(const QByteArray& array, const QString& extension);
+    virtual bool loadData(const QByteArray& array, const QString& extension);
 
-    virtual bool save(QIODevice* io);
+    virtual bool save(QIODevice* io) const;
 
     virtual QSize getOriginalSize(void) const;
 
@@ -105,10 +107,10 @@ protected:
     void scaleAndCreatePixmap(const QSize& size, bool fastMode=false);
 
 private:
-    QImage  m_originalImage;
-    QByteArray m_rawData;
-    QPixmap m_cachedPixmap;
-    QSize m_cachedSize;
+    QImage  m_originalImage; ///< Image as Qimage
+    QByteArray m_rawData; ///< Binary copy of the loaded image file
+    QPixmap m_cachedPixmap; ///< Cached pixmap
+    QSize m_cachedSize; ///< size of the currently cached pixmap @see m_cachedPixmap
     /**
      * true, if the last cached image was done using fast mode.
      * false, if the last cached image was done using slow mode.
