@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (c) 2001 Simon Hausmann <hausmann@kde.org>
-   Copyright (C) 2002 Nicolas GOUTTE <goutte@kde.org>
+   Copyright (C) 2002, 2004 Nicolas GOUTTE <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,37 +22,57 @@
 
 #include <qstring.h>
 #include <qdatetime.h>
+#include <koffice_export.h>
+/**
+ * \file koPictureKey.h
+ * \todo correct documentation (for example: sed "s/image/picture/g")
+ */
 
 class QDomElement;
 
 namespace KoPictureType
 {
-    // 3 = Qt 2.1.x and later
-    // 4 = Qt 3.0
-    // 5 = Qt 3.1 and later
-    // -1 = current QT
+    /**
+     * QPicture version used by KoPictureClipart
+     *
+     * Possible values:
+     * \li 3 for Qt 2.1.x and later Qt 2.x
+     * \li 4 for Qt 3.0
+     * \li 5 for Qt 3.1 and later Qt 3.x
+     * \li -1 for current Qt
+     */
     const int formatVersionQPicture=-1;
 
     enum Type
     {
-        TypeUnknown = 0,
-        TypeImage,          /// Image, QImage-based
-        TypeEps,            /// Encapsulated Postscript
-        TypeClipart,        /// Clipart, QPicture-based
-        TypeWmf             /// WMF (Windows Meta File)
+        TypeUnknown = 0,    ///< Unknown or not-an-image @see KoPictureBase
+        TypeImage,          ///< Image, QImage-based @see KoPictureImage
+        TypeEps,            ///< Encapsulated Postscript @see KoPictureEps
+        TypeClipart,        ///< Clipart, QPicture-based @see KoPictureClipart
+        TypeWmf             ///< WMF (Windows Meta File) @see KoPictureWmf
     };
 }
 
-// TODO: correct documentation
-
 /**
- * KoPictureKey is the structure describing an image in a unique way.
- * It currently includes the original path to the image and the modification
+ * KoPictureKey is the structure describing a picture in a unique way.
+ * It currently includes the original path to the picture and the modification
  * date.
  *
- * @short Structure describing an image on disk
+ * @short Structure describing a picture on disk
+ *
+ * @note We use the *nix epoch (1970-01-01) as a time base because it is a valid date.
+ * That way we do not depend on a behaviour of the current QDateTime that might change in future versions of Qt
+ * and we are also nice to non-Qt programs wanting to read KOffice's files.
+ *
+ * @note This behaviour is also needed for re-saving KWord files having \<FORMAT id="2"\>. When saving again,
+ * these files get a \<KEY\> element as child of \<PIXMAPS\> but not one as child of \<FORMAT\> and \<IMAGE\>.
+ * Therefore we need to be careful that the key remains compatible to default values 
+ * (another good reason for the *NIX epoch)
+ *
+ * @note In case of a remote path, the "original path" is the name of the temporary file that was
+ *  used to download the file.
  */
-class KoPictureKey
+class KOFFICEUI_EXPORT KoPictureKey
 {
 public:
     /**
@@ -61,7 +81,8 @@ public:
     KoPictureKey();
 
     /**
-     * Constructs a key, from a filename and a modification date
+     * @brief Constructs a key, from a filename and a modification date
+     *
      * Storing the modification date as part of the key allows the user
      * to update the file and import it into the application again, without
      * the application reusing the old copy from the collection.
@@ -69,7 +90,8 @@ public:
     KoPictureKey( const QString &fn, const QDateTime &mod );
 
     /**
-     * Constructs a key, from a filename (without modification date)
+     * Constructs a key from a filename 
+     * @note The modification date is set to 1970-01-01
      */
     KoPictureKey( const QString &fn );
 
@@ -89,7 +111,8 @@ public:
     bool operator==( const KoPictureKey &key ) const;
 
     /**
-     * Comparison operator - used for sorting in the collection's map
+     * Comparison operator 
+     * @note Used for sorting in the collection's map
      */
     bool operator<( const KoPictureKey &key ) const;
 
@@ -99,12 +122,12 @@ public:
     QString toString() const;
 
     /**
-     * Save this key in XML.
+     * Save this key in XML (as %KOffice 1.3)
      */
     void saveAttributes( QDomElement &elem ) const;
 
     /**
-     * Load this key from XML.
+     * Load this key from XML (as %KOffice 1.3)
      */
     void loadAttributes( const QDomElement &elem );
 
@@ -119,7 +142,7 @@ public:
     QDateTime lastModified() const { return m_lastModified; }
 
     /**
-     * Sets the key according to @p filename modification time
+     * Sets the key according to @p filename, including modification time
      */
     void setKeyFromFile (const QString& filename);
 
