@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (c) 2001 Simon Hausmann <hausmann@kde.org>
-   Copyright (C) 2002, 2003 Nicolas GOUTTE <goutte@kde.org>
+   Copyright (C) 2002, 2003, 2004 Nicolas GOUTTE <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,6 +27,7 @@
 
 #include "koPictureKey.h"
 
+class KoXmlWriter;
 class QPainter;
 class QSize;
 
@@ -38,7 +39,7 @@ class KoPictureBase;
  * @internal
  * KoPictureShared is the class that contains the shared part for KoPicture
  *
- * As with all QShared objects, the sharing is neither automatic nor transparent!
+ * @warning As with all QShared objects, the sharing is neither automatic nor transparent!
  */
 class KoPictureShared : public QShared
 {
@@ -54,14 +55,14 @@ public:
     ~KoPictureShared(void);
 
     /**
-     * Copy constructor
+     * @brief Copy constructor
      *
      * This makes a deep copy. Do not use if you want to share!
      */
     KoPictureShared(const KoPictureShared &other);
 
     /**
-     * Assignment operator
+     * @brief Assignment operator
      *
      * This makes a deep copy. Do not use if you want to share!
      */
@@ -75,7 +76,7 @@ public:
     bool isNull(void) const;
 
     /**
-     * Draw the image in a painter.
+     * @brief Draw the image in a painter.
      *
      * The parameter @p fastMode allows the picture to be re-sized and drawn quicker if possible
      *
@@ -97,17 +98,24 @@ public:
     QDragObject* dragObject( QWidget *dragSource = 0L, const char *name = 0L );
 
     bool load(QIODevice* io, const QString& extension);
+    bool loadFromBase64( const QCString& str );
 
     /**
-     * save file
+     * Save picture into a QIODevice
      * @param io QIODevice used for saving
      */
-    bool save(QIODevice* io);
+    bool save(QIODevice* io) const;
 
     /**
-     *  Save picture in the format supported by KOffice 1,1
+     * Save picture in the format supported by KOffice 1.1
      */
-    bool saveAsKOffice1Dot1(QIODevice* io);
+    bool saveAsKOffice1Dot1(QIODevice* io) const;
+
+    /**
+     * OASIS FlatXML support:
+     * Save picture as base64-encoded data into an XML writer.
+     */
+    bool saveAsBase64( KoXmlWriter& writer ) const;
 
     void setExtension(const QString& extension);
 
@@ -120,7 +128,7 @@ public:
     /**
      * Clear and set the mode of this KoPictureShared
      *
-     * @p newMode is a file extension (like "png") giving the wanted mode
+     * @param newMode file extension (like "png") giving the wanted mode
      */
     void clearAndSetMode(const QString& newMode);
 
@@ -129,10 +137,10 @@ public:
      */
     void clear(void);
 
-    /*
+    /**
      * Load a file
      *
-     * @p fileName is the name of the file to load
+     * @param fileName the name of the file to load
      */
     bool loadFromFile(const QString& fileName);
 
@@ -145,13 +153,13 @@ public:
      * @deprecated
      * Returns a QPixmap from an image
      *
-     * @p size is the wanted size for the QPixmap
+     * @param size the wanted size for the QPixmap
      */
     QPixmap generatePixmap(const QSize& size, bool smoothScale = false);
 
     /**
      * Helper function for saving
-     * @return true if it is a clipart in KOffice 1.1, false if not
+     * @return true if it is a clipart in %KOffice 1.1, false if not
      */
     bool isClipartAsKOffice1Dot1(void) const;
 
@@ -159,6 +167,7 @@ public:
 
     /**
      * Generate a QImage
+     *
      * (always in slow mode)
      *
      * @param size the wanted size for the QImage
@@ -170,15 +179,21 @@ public:
     QImage createAlphaMask(int conversion_flags = 0) const;
 
     /**
-     * Clear any cache (to avoid using too much memory
-     * especially if the application somehow also caches the KoPicture's output)
+     * Clear any cache
+     *
+     * It is used to avoid using too much memory
+     * especially if the application somehow caches the KoPicture too.
      */
     void clearCache(void);
 
+    QString uniquePictureId() const;
+    void assignPictureId( uint _id);
+
 protected:
     /**
      * @internal
-     * Load a WMF file (a .wmf file could be a QPicture file)
+     * Load a WMF file
+     * \note In %KOffice 1.1, a .wmf file was a QPicture file
      */
     bool loadWmf(QIODevice* io);
 
@@ -188,9 +203,25 @@ protected:
      */
     bool loadTmp(QIODevice* io);
 
+    /// Find type of image, create base accordingly, and load data
+    bool identifyAndLoad( QByteArray data );
+
+    /**
+     * @internal
+     * Loads a compressed file
+     *
+     * @warning risk of endless recurision, be careful when it is called from @see load
+     *
+     * @param io QIODevice of the compressed file/strea,
+     * @param mimeType mimetype of the (de-)compressor
+     * @param extension extension of the uncompressed file
+     */
+    bool loadCompressed( QIODevice* io, const QString& mimeType, const QString& extension );
+
 protected:
     KoPictureBase* m_base;
     QString m_extension;
+    uint m_pictureId;
 };
 
 #endif /* __koPictureShared_h__ */
