@@ -33,8 +33,6 @@
 #include <kstatusbar.h>
 #include <qapplication.h>
 
-#define DEBUGRECT(rc) (rc).x() << "," << (rc).y() << " " << (rc).width() << "x" << (rc).height()
-
 class KoViewPrivate
 {
 public:
@@ -148,18 +146,28 @@ KoView::KoView( KoDocument *document, QWidget *parent, const char *name )
                this, SLOT( slotActionStatusText( const QString & ) ) );
       connect( coll, SIGNAL( clearStatusText() ),
                this, SLOT( slotClearStatusText() ) );
+
+      connect( d->m_doc, SIGNAL( sigStatusBarMessage( const QString& ) ),
+               this, SLOT( slotActionStatusText( const QString& ) ) );
+      connect( d->m_doc, SIGNAL( sigClearStatusBarMessage() ),
+               this, SLOT( slotClearStatusText() ) );
   }
+  d->m_doc->setCurrent();
 }
 
 KoView::~KoView()
 {
   kdDebug(30003) << "KoView::~KoView " << this << endl;
   delete d->m_dcopObject;
-  if ( koDocument() && !koDocument()->isSingleViewMode() )
+  if (!d->m_documentDeleted)
   {
-    if ( d->m_manager && d->m_registered ) // if we aren't registered we mustn't unregister :)
-      d->m_manager->removePart( koDocument() );
-    d->m_doc->removeView(this);
+    if ( koDocument() && !koDocument()->isSingleViewMode() )
+    {
+      if ( d->m_manager && d->m_registered ) // if we aren't registered we mustn't unregister :)
+        d->m_manager->removePart( koDocument() );
+      d->m_doc->removeView(this);
+      d->m_doc->setCurrent( false );
+    }
   }
   delete d;
 }
@@ -384,24 +392,21 @@ void KoView::partSelectEvent( KParts::PartSelectEvent *event )
 }
 
 void KoView::guiActivateEvent( KParts::GUIActivateEvent * ev )
+{
+    showAllStatusBarItems( ev->activated() );
+}
+
+void KoView::showAllStatusBarItems( bool show )
 {
     KStatusBar * sb = statusBar();
-    //kdDebug() << "KoView::guiActivateEvent activated=" << ev->activated()
-    //          << " sb=" << (void*)sb << endl;
     if ( !sb )
         return;
-    if ( ev->activated() )
-    {
-        QValueListIterator<KoViewPrivate::StatusBarItem> it = d->m_statusBarItems.begin();
-        for ( ; it != d->m_statusBarItems.end() ; ++it )
+    QValueListIterator<KoViewPrivate::StatusBarItem> it = d->m_statusBarItems.begin();
+    for ( ; it != d->m_statusBarItems.end() ; ++it )
+        if ( show )
             (*it).ensureItemShown( sb );
-    }
-    else
-    {
-        QValueListIterator<KoViewPrivate::StatusBarItem> it = d->m_statusBarItems.begin();
-        for ( ; it != d->m_statusBarItems.end() ; ++it )
+        else
             (*it).ensureItemHidden( sb );
-    }
 }
 
 void KoView::addStatusBarItem( QWidget * widget, int stretch, bool permanent )
@@ -583,7 +588,6 @@ bool KoView::isInOperation() const
 
 void KoView::beginOperation()
 {
-   QApplication::setOverrideCursor(waitCursor);
    d->m_inOperation = true;
    canvas()->setUpdatesEnabled(FALSE);
 }
@@ -592,9 +596,8 @@ void KoView::endOperation()
 {
    canvas()->setUpdatesEnabled(TRUE);
    d->m_inOperation = false;
-   QApplication::restoreOverrideCursor();
 
-   canvas()->update();
+//   canvas()->update();
 }
 
 KoMainWindow * KoView::shell() const
@@ -666,7 +669,7 @@ KoViewChild::KoViewChild( KoDocumentChild *child, KoView *_parentView )
   parentView()->canvasAddChild( this );
 
 
-  /**
+  /*
    KoViewChild has basically three geometries to keep in sync.
    - The KoDocumentChild geometry (i.e. the embedded object's geometry, unzoomed)
    - Its own geometry (used for hit-test etc.)
@@ -743,7 +746,7 @@ void KoViewChild::slotFrameGeometryChanged()
                         static_cast<int>( (double)borderLessRect.height() / zoom + 0.5 ) );
     kdDebug() << "KoViewChild::slotFrameGeometryChanged child geometry "
               << ( m_child->geometry() == unzoomedRect ? "already " : "set to " )
-              << DEBUGRECT( unzoomedRect ) << endl;
+              << unzoomedRect << endl;
 
     // We don't want to trigger slotDocGeometryChanged again
     lock();
@@ -766,7 +769,7 @@ void KoViewChild::slotDocGeometryChanged()
                     static_cast<int>( (double)geom.height() * zoom + 0.5 ) + m_frame->topBorder() + m_frame->bottomBorder() );
   kdDebug() << "KoViewChild::slotDocGeometryChanged frame geometry "
             << ( m_frame->geometry() == borderRect ? "already " : "set to " )
-            << DEBUGRECT( borderRect ) << endl;
+            << borderRect << endl;
 
   m_frame->setGeometry( borderRect );
 }
