@@ -17,6 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <kapplication.h>
 #include <klocale.h>
 
 #include <qlayout.h>
@@ -33,13 +34,14 @@
 #include <kdesktopfile.h>
 #include <krecentdocument.h>
 
+using namespace KOfficePrivate;
 
-KoInsertLinkDia::KoInsertLinkDia( QWidget */*parent*/, const char */*name*/,bool displayBookmarkLink )
+KoInsertLinkDia::KoInsertLinkDia( QWidget *parent, const char *name, bool displayBookmarkLink )
     : KDialogBase( KDialogBase::IconList, i18n("Insert Link"),
 		   KDialogBase::Ok | KDialogBase::Cancel,
-		   KDialogBase::Ok)
+		   KDialogBase::Ok, parent, name )
 {
-    bookmarkLink = 0L;
+  bookmarkLink = 0L;
   QVBox *page=addVBoxPage(i18n("Internet"), QString::null,BarIcon("html",KIcon::SizeMedium));
   internetLink = new  internetLinkPage(page );
   connect(internetLink,SIGNAL(textChanged()),this,SLOT(slotTextChanged (  )));
@@ -59,21 +61,48 @@ KoInsertLinkDia::KoInsertLinkDia( QWidget */*parent*/, const char */*name*/,bool
       connect(bookmarkLink,SIGNAL(textChanged()),this,SLOT(slotTextChanged ()));
   }
 
+  connect( this, SIGNAL( aboutToShowPage(QWidget *) ), this, SLOT( tabChanged(QWidget *) ) );
+
   slotTextChanged ( );
   resize(400,300);
 }
 
+void KoInsertLinkDia::tabChanged(QWidget *)
+{
+    switch( activePageIndex() )
+    {
+    case 0:
+      internetLink->setLinkName( currentText );
+      break;
+    case 1:
+      mailLink->setLinkName( currentText );
+      break;
+    case 2:
+      fileLink->setLinkName( currentText );
+      break;
+    case 3:
+    {
+        if ( bookmarkLink)
+            bookmarkLink->setLinkName( currentText );
+    }
+    break;
+    default:
+      kdDebug()<<"Error in linkName\n";
+    }
+    enableButtonOK( !(linkName().isEmpty()  || hrefName().isEmpty()) );
+}
 
 void KoInsertLinkDia::slotTextChanged ( )
 {
     enableButtonOK( !(linkName().isEmpty()  || hrefName().isEmpty()));
+    currentText = linkName();
 }
 
-bool KoInsertLinkDia::createLinkDia(QString & _linkName, QString & _hrefName, QStringList bkmlist, bool displayBookmarkLink)
+bool KoInsertLinkDia::createLinkDia(QString & _linkName, QString & _hrefName, const QStringList& bkmlist, bool displayBookmarkLink, QWidget* parent, const char* name)
 {
     bool res = false;
 
-    KoInsertLinkDia *dlg = new KoInsertLinkDia( 0L, "Insert Link", displayBookmarkLink );
+    KoInsertLinkDia *dlg = new KoInsertLinkDia( parent, name, displayBookmarkLink );
     dlg->setHrefLinkName(_hrefName,_linkName, bkmlist);
     if ( dlg->exec() == Accepted )
     {
@@ -90,8 +119,16 @@ void KoInsertLinkDia::setHrefLinkName(const QString &_href, const QString &_link
 {
     if ( bookmarkLink)
         bookmarkLink->setBookmarkList(bkmlist);
-    if( _href.isEmpty())
+    if ( _href.isEmpty())
+    {
+        if ( !_link.isEmpty() )
+        {
+            internetLink->setLinkName(_link);
+            showPage(0);
+            slotTextChanged ( );
+        }
         return;
+    }
     if(_href.find("http://")!=-1 || _href.find("https://")!=-1 ||_href.find("ftp://")!=-1 )
     {
         internetLink->setHrefName(_href);
@@ -122,7 +159,7 @@ void KoInsertLinkDia::setHrefLinkName(const QString &_href, const QString &_link
     slotTextChanged ( );
 }
 
-QString KoInsertLinkDia::linkName()const
+QString KoInsertLinkDia::linkName() const
 {
     QString result;
     switch(activePageIndex())
@@ -148,7 +185,7 @@ QString KoInsertLinkDia::linkName()const
   return result;
 }
 
-QString KoInsertLinkDia::hrefName()
+QString KoInsertLinkDia::hrefName() const
 {
     QString result;
     switch(activePageIndex())
@@ -205,6 +242,8 @@ internetLinkPage::internetLinkPage( QWidget *parent , char *name  )
 
   lay2->addWidget(m_hrefName);
 
+  lay2->addStretch( 1 );
+  
   m_linkName->setFocus();
 
   connect(m_linkName,SIGNAL(textChanged ( const QString & )),this,SLOT(textChanged ( const QString & )));
@@ -277,6 +316,8 @@ bookmarkLinkPage::bookmarkLinkPage( QWidget *parent , char *name  )
 
   lay2->addWidget(m_hrefName);
 
+  lay2->addStretch( 1 );
+  
   m_linkName->setFocus();
 
   connect(m_linkName,SIGNAL(textChanged ( const QString & )),this,SLOT(textChanged ( const QString & )));
@@ -357,6 +398,8 @@ mailLinkPage::mailLinkPage( QWidget *parent , char *name  )
   m_hrefName = new QLineEdit( this );
 
   lay2->addWidget(m_hrefName);
+  lay2->addStretch( 1 );
+  
   connect(m_linkName,SIGNAL(textChanged ( const QString & )),this,SLOT(textChanged ( const QString & )));
   connect(m_hrefName,SIGNAL(textChanged ( const QString & )),this,SLOT(textChanged ( const QString & )));
   KSeparator* bar1 = new KSeparator( KSeparator::HLine, this);
@@ -423,8 +466,8 @@ fileLinkPage::fileLinkPage( QWidget *parent , char *name  )
   lay2->addWidget(tmpQLabel);
   tmpQLabel->setText(i18n("Recent file:"));
 
-
   QComboBox * recentFile = new QComboBox( this );
+  recentFile->setMaximumWidth( kapp->desktop()->width()*3/4 );
   lay2->addWidget(recentFile);
 
   QStringList fileList = KRecentDocument::recentDocuments();
@@ -444,6 +487,9 @@ fileLinkPage::fileLinkPage( QWidget *parent , char *name  )
   }
   else
       recentFile->insertStringList( lst);
+  
+  recentFile->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
+  
   connect( recentFile , SIGNAL(highlighted ( const QString &)), this,  SLOT( slotSelectRecentFile( const QString & )));
 
   tmpQLabel = new QLabel( this);
@@ -453,6 +499,7 @@ fileLinkPage::fileLinkPage( QWidget *parent , char *name  )
   m_hrefName = new KURLRequester( this );
 
   lay2->addWidget(m_hrefName);
+  lay2->addStretch( 1 );
 
   connect(m_linkName,SIGNAL(textChanged ( const QString & )),this,SLOT(textChanged ( const QString & )));
   connect(m_hrefName,SIGNAL(textChanged ( const QString & )),this,SLOT(textChanged ( const QString & )));
