@@ -28,7 +28,8 @@
 #include <qcursor.h>
 #include <qpainter.h>
 #include <qpopupmenu.h>
-#include <koUnit.h>
+#include <qtooltip.h>
+#include <koPageLayout.h>
 
 class KoRulerPrivate {
 public:
@@ -42,6 +43,7 @@ public:
     bool whileMovingBorderLeft, whileMovingBorderRight;
     bool whileMovingBorderTop, whileMovingBorderBottom;
     QPixmap pmFirst, pmLeft;
+    KoPageLayout layout;
     KoTabChooser *tabChooser;
     KoTabulatorList tabList;
     // Do we have to remove a certain tab in the DC Event?
@@ -90,7 +92,7 @@ KoRuler::KoRuler( QWidget *_parent, QWidget *_canvas, Orientation _orientation,
 
     d->canvas = _canvas;
     orientation = _orientation;
-    layout = _layout;
+    d->layout = _layout;
     d->flags = _flags;
 
     d->m_bReadWrite=true;
@@ -122,11 +124,11 @@ KoRuler::KoRuler( QWidget *_parent, QWidget *_canvas, Orientation _orientation,
 
     d->removeTab.type = T_INVALID;
     if ( orientation == Qt::Horizontal ) {
-        frameStart = qRound( zoomIt(layout.ptLeft) );
-        d->frameEnd = qRound( zoomIt(layout.ptWidth - layout.ptRight) );
+        frameStart = qRound( zoomIt(d->layout.ptLeft) );
+        d->frameEnd = qRound( zoomIt(d->layout.ptWidth - d->layout.ptRight) );
     } else {
-        frameStart = qRound( zoomIt(layout.ptTop) );
-        d->frameEnd = qRound( zoomIt(layout.ptHeight - layout.ptBottom) );
+        frameStart = qRound( zoomIt(d->layout.ptTop) );
+        d->frameEnd = qRound( zoomIt(d->layout.ptHeight - d->layout.ptBottom) );
     }
     m_bFrameStartSet = false;
 
@@ -204,10 +206,10 @@ void KoRuler::drawHorizontal( QPainter *_painter )
     QPainter p( &buffer );
     p.fillRect( 0, 0, width(), height(), QBrush( colorGroup().brush( QColorGroup::Background ) ) );
 
-    int totalw = qRound( zoomIt(layout.ptWidth) );
+    int totalw = qRound( zoomIt(d->layout.ptWidth) );
     QString str;
     QFont font; // Use the global KDE font. Let's hope it's appropriate.
-    font.setPixelSize( 8 );
+    font.setPointSize( 8 );
     QFontMetrics fm( font );
 
     p.setBrush( colorGroup().brush( QColorGroup::Base ) );
@@ -231,18 +233,30 @@ void KoRuler::drawHorizontal( QPainter *_painter )
     // Draw the numbers
     double dist = lineDistance();
     int maxwidth = 0;
+
     for ( double i = 0.0;i <= (double)totalw;i += dist ) {
-        str = QString::number( KoUnit::ptToUnit( i / m_zoom, m_unit ) );
+        str = QString::number( KoUnit::toUserValue( i / m_zoom, m_unit ) );
         int textwidth = fm.width( str );
+        maxwidth = QMAX( maxwidth, textwidth );
+    }
+
+    // Make sure that the ruler stays readable at lower zoom levels
+    while( dist <= maxwidth ) {
+        dist += lineDistance();
+    }
+
+    for ( double i = 0.0;i <= (double)totalw;i += dist ) {
+        str = QString::number( KoUnit::toUserValue( i / m_zoom, m_unit ) );
+        int textwidth = fm.width( str );
+        maxwidth = QMAX( maxwidth, textwidth );
         p.drawText( qRound(i) - diffx - qRound(textwidth * 0.5),
                     qRound(( height() - fm.height() ) * 0.5),
                     textwidth, height(), AlignLeft | AlignTop, str );
-        maxwidth = QMAX( maxwidth, textwidth );
     }
 
     // Draw the medium-sized lines
     // Only if we have enough space (i.e. not at 33%)
-    if ( dist > maxwidth + 1 )
+    if ( dist > maxwidth + 2 )
     {
         for ( double i = dist * 0.5;i <= (double)totalw;i += dist ) {
             int ii=qRound(i);
@@ -252,7 +266,7 @@ void KoRuler::drawHorizontal( QPainter *_painter )
 
     // Draw the small lines
     // Only if we have enough space (i.e. not at 33%)
-    if ( dist * 0.5 > maxwidth + 1 )
+    if ( dist * 0.5 > maxwidth + 2 )
     {
         for ( double i = dist * 0.25;i <= (double)totalw;i += dist * 0.5 ) {
             int ii=qRound(i);
@@ -353,7 +367,7 @@ void KoRuler::drawVertical( QPainter *_painter )
     QPainter p( &buffer );
     p.fillRect( 0, 0, width(), height(), QBrush( colorGroup().brush( QColorGroup::Background ) ) );
 
-    int totalh = qRound( zoomIt(layout.ptHeight) );
+    int totalh = qRound( zoomIt(d->layout.ptHeight) );
     // Clip rect - this gives basically always a rect like (2,2,width-2,height-2)
     QRect paintRect = _painter->clipRegion( QPainter::CoordPainter ).boundingRect();
     // Ruler rect
@@ -362,7 +376,7 @@ void KoRuler::drawVertical( QPainter *_painter )
     if ( paintRect.intersects( rulerRect ) )  {
         QString str;
         QFont font; // Use the global KDE font. Let's hope it's appropriate.
-        font.setPixelSize( 8 ); // Hardcode the size? (Werner)
+        font.setPointSize( 8 ); // Hardcode the size? (Werner)
         QFontMetrics fm( font );
 
         p.setBrush( colorGroup().brush( QColorGroup::Base ) );
@@ -386,17 +400,33 @@ void KoRuler::drawVertical( QPainter *_painter )
         // Draw the numbers
         double dist = lineDistance();
         int maxheight = 0;
+
         for ( double i = 0.0;i <= (double)totalh;i += dist ) {
-            str = QString::number( KoUnit::ptToUnit( i / m_zoom, m_unit ) );
+            str = QString::number( KoUnit::toUserValue( i / m_zoom, m_unit ) );
+            int textwidth = fm.width( str );
+            maxheight = QMAX( maxheight, textwidth );
+        }
+
+        // Make sure that the ruler stays readable at lower zoom levels
+        while( dist <= maxheight ) {
+            dist += lineDistance();
+        }
+
+        for ( double i = 0.0;i <= (double)totalh;i += dist ) {
+            str = QString::number( KoUnit::toUserValue( i / m_zoom, m_unit ) );
             int textheight = fm.height();
-            maxheight = QMAX( maxheight, textheight );
-            p.drawText( qRound(( width() - fm.width( str ) ) * 0.5),
-                        qRound(i) - diffy - qRound(textheight * 0.5),
-                        width(), textheight, AlignLeft | AlignTop, str );
+            int textwidth = fm.width( str );
+            maxheight = QMAX( maxheight, textwidth );
+            p.save();
+            p.translate( qRound(( width() - textheight ) * 0.5),
+                         qRound(i) - diffy + qRound(textwidth * 0.5) );
+            p.rotate( -90 );
+            p.drawText( 0, 0, textwidth + 1, textheight, AlignLeft | AlignTop, str );
+            p.restore();
         }
 
         // Draw the medium-sized lines
-        if ( dist > maxheight + 1 )
+        if ( dist > maxheight + 2 )
         {
             for ( double i = dist * 0.5;i <= (double)totalh;i += dist ) {
                 int ii=qRound(i);
@@ -405,7 +435,7 @@ void KoRuler::drawVertical( QPainter *_painter )
         }
 
         // Draw the small lines
-        if ( dist * 0.5 > maxheight + 1 )
+        if ( dist * 0.5 > maxheight + 2 )
         {
             for ( double i = dist * 0.25;i <=(double)totalh;i += dist *0.5 ) {
                 int ii=qRound(i);
@@ -559,7 +589,7 @@ void KoRuler::mouseReleaseEvent( QMouseEvent *e )
         if ( d->canvas )
             drawLine(d->oldMx, -1);
         update();
-        emit newPageLayout( layout );
+        emit newPageLayout( d->layout );
     } else if ( d->action == A_BR_TOP || d->action == A_BR_BOTTOM ) {
         d->whileMovingBorderTop = false;
         d->whileMovingBorderBottom = false;
@@ -571,7 +601,7 @@ void KoRuler::mouseReleaseEvent( QMouseEvent *e )
             p.end();
         }
         update();
-        emit newPageLayout( layout );
+        emit newPageLayout( d->layout );
     } else if ( d->action == A_FIRST_INDENT ) {
         if ( d->canvas )
             drawLine(d->oldMx, -1);
@@ -627,12 +657,12 @@ void KoRuler::mouseMoveEvent( QMouseEvent *e )
     hasToDelete = false;
 
     int pw = d->frameEnd - frameStart;
-    int ph = qRound(zoomIt(layout.ptHeight));
+    int ph = qRound(zoomIt(d->layout.ptHeight));
     int left = frameStart - diffx;
-    int top = qRound(zoomIt(layout.ptTop));
+    int top = qRound(zoomIt(d->layout.ptTop));
     top -= diffy;
     int right = d->frameEnd - diffx;
-    int bottom = qRound(zoomIt(layout.ptBottom));
+    int bottom = qRound(zoomIt(d->layout.ptBottom));
     bottom = ph - bottom - diffy;
     // Cumulate first-line-indent
     int ip_first = qRound( zoomIt( i_first + ( d->rtl ? d->i_right : i_left) ) );
@@ -644,6 +674,7 @@ void KoRuler::mouseMoveEvent( QMouseEvent *e )
     int my = e->y();
     my = my+diffy < 0 ? 0 : my;
 
+    QToolTip::remove( this);
     switch ( orientation ) {
         case Qt::Horizontal: {
             if ( !d->mousePressed ) {
@@ -674,14 +705,17 @@ void KoRuler::mouseMoveEvent( QMouseEvent *e )
                     int firstX = d->rtl ? right - ip_first : left + ip_first;
                     if ( mx > firstX - 5 && mx < firstX + 5 &&
                          my >= 2 && my <= d->pmFirst.size().height() + 2 ) {
+                        QToolTip::add( this, i18n("First line indent") );
                         setCursor( ArrowCursor );
                         d->action = A_FIRST_INDENT;
                     } else if ( mx > left + ip_left - 5 && mx < left + ip_left + 5 &&
                                 my >= height() - d->pmLeft.size().height() - 2 && my <= height() - 2 ) {
+                        QToolTip::add( this, i18n("Left indent") );
                         setCursor( ArrowCursor );
                         d->action = A_LEFT_INDENT;
                     } else if ( mx > right - ip_right - 5 && mx < right - ip_right + 5 &&
                                 my >= height() - d->pmLeft.size().height() - 2 && my <= height() - 2 ) {
+                        QToolTip::add( this, i18n("Right indent") );
                         setCursor( ArrowCursor );
                         d->action = A_RIGHT_INDENT;
                     }
@@ -703,7 +737,7 @@ void KoRuler::mouseMoveEvent( QMouseEvent *e )
                     case A_BR_LEFT: {
                         if ( d->canvas && mx < right-10 && mx+diffx-2 > 0) {
                             drawLine( d->oldMx, mx );
-                            layout.ptLeft = unZoomIt(static_cast<double>(mx + diffx));
+                            d->layout.ptLeft = unZoomIt(static_cast<double>(mx + diffx));
                             if( ip_left > right-left-15 ) {
                                 ip_left=right-left-15;
                                 ip_left=ip_left<0 ? 0 : ip_left;
@@ -726,7 +760,7 @@ void KoRuler::mouseMoveEvent( QMouseEvent *e )
                     case A_BR_RIGHT: {
                         if ( d->canvas && mx > left+10 && mx+diffx <= pw-2) {
                             drawLine( d->oldMx, mx );
-                            layout.ptRight = unZoomIt(static_cast<double>(pw - ( mx + diffx )));
+                            d->layout.ptRight = unZoomIt(static_cast<double>(pw - ( mx + diffx )));
                             if( ip_left > right-left-15 ) {
                                 ip_left=right-left-15;
                                 ip_left=ip_left<0 ? 0 : ip_left;
@@ -833,9 +867,11 @@ void KoRuler::mouseMoveEvent( QMouseEvent *e )
                 if ( d->flags & F_NORESIZE )
                     break;
                 if ( my > top - 5 && my < top + 5 ) {
+                    QToolTip::add( this, i18n("Top margin") );
                     setCursor( Qt::sizeVerCursor );
                     d->action = A_BR_TOP;
                 } else if ( my > bottom - 5 && my < bottom + 5 ) {
+                    QToolTip::add( this, i18n("Bottom margin") );
                     setCursor( Qt::sizeVerCursor );
                     d->action = A_BR_BOTTOM;
                 }
@@ -848,7 +884,7 @@ void KoRuler::mouseMoveEvent( QMouseEvent *e )
                             p.drawLine( 0, d->oldMy, d->canvas->width(), d->oldMy );
                             p.drawLine( 0, my, d->canvas->width(), my );
                             p.end();
-                            layout.ptTop = unZoomIt(static_cast<double>(my + diffy));
+                            d->layout.ptTop = unZoomIt(static_cast<double>(my + diffy));
                             d->oldMx = mx;
                             d->oldMy = my;
                             update();
@@ -863,7 +899,7 @@ void KoRuler::mouseMoveEvent( QMouseEvent *e )
                             p.drawLine( 0, d->oldMy, d->canvas->width(), d->oldMy );
                             p.drawLine( 0, my, d->canvas->width(), my );
                             p.end();
-                            layout.ptBottom = unZoomIt(static_cast<double>(ph - ( my + diffy )));
+                            d->layout.ptBottom = unZoomIt(static_cast<double>(ph - ( my + diffy )));
                             d->oldMx = mx;
                             d->oldMy = my;
                             update();
@@ -951,7 +987,7 @@ void KoRuler::setTabList( const KoTabulatorList & _tabList )
 
 double KoRuler::makeIntern( double _v )
 {
-    return KoUnit::ptFromUnit( _v, m_unit );
+    return KoUnit::fromUserValue( _v, m_unit );
 }
 
 void KoRuler::setupMenu()
@@ -997,6 +1033,8 @@ void KoRuler::setZoom( const double& zoom )
 {
     if(zoom==m_zoom)
         return;
+    if(zoom < 1E-4) // Don't do 0 or negative values
+        return;
     m_zoom=zoom;
     m_1_zoom=1/m_zoom;
     update();
@@ -1121,8 +1159,32 @@ void KoRuler::slotMenuActivated( int i )
     {
         KoUnit::Unit unit = static_cast<KoUnit::Unit>(i);
         setUnit( unit );
-        emit unitChanged( KoUnit::unitName( unit ) );
+        emit unitChanged( unit );
     }
 }
 
+QSize KoRuler::minimumSizeHint() const
+{
+    QSize size;
+    QFont font; // Use the global KDE font. Let's hope it's appropriate.
+    font.setPointSize( 8 );
+    QFontMetrics fm( font );
+
+    size.setWidth( fm.height() + 4 );
+    size.setHeight( fm.height() + 4 );
+
+    return size;
+}
+
+QSize KoRuler::sizeHint() const
+{
+    return minimumSizeHint();
+}
+
+void KoRuler::setPageLayout( const KoPageLayout& _layout )
+{
+    d->layout = _layout;
+    update();
+}
+
 #include "koRuler.moc"
