@@ -65,7 +65,8 @@ class MyFileDialog : public KFileDialog
                 QWidget *parent=0,
                 const char *name=0,
                 bool modal=0)
-            :  KFileDialog (startDir, filter, parent, name, modal) {}
+            :  KFileDialog (startDir, filter, parent, name, modal),
+        m_slotOkCalled( false ) {}
 
         KURL currentURL()
         {
@@ -88,6 +89,14 @@ class MyFileDialog : public KFileDialog
             }
             return ok;
         }
+        // Called directly by pressing Return in the location combo
+        // (so we need to remember that it got called, to avoid calling it twice)
+        // Called "by hand" when clicking on our OK button
+        void slotOk() {
+            m_slotOkCalled = true;
+            KFileDialog::slotOk();
+        }
+        bool slotOkCalled() const { return m_slotOkCalled; }
     protected:
     // Typing a file that doesn't exist closes the file dialog, we have to
     // handle this case better here.
@@ -100,7 +109,8 @@ class MyFileDialog : public KFileDialog
 		KFileDialog::reject();
 		emit cancelClicked();
         }
-
+private:
+        bool m_slotOkCalled;
 };
 
 /*================================================================*/
@@ -210,6 +220,7 @@ KoTemplateChooseDia::~KoTemplateChooseDia()
     d=0L;
 }
 
+// Keep in sync with KoMainWindow::chooseNewDocument
 static bool cancelQuits() {
     bool onlyDoc = !KoDocument::documentList() || KoDocument::documentList()->count() <= 1;
     bool onlyMainWindow = !KMainWindow::memberList || KMainWindow::memberList->count() <= 1;
@@ -261,10 +272,6 @@ KoTemplateChooseDia::ReturnType KoTemplateChooseDia::choose(KInstance* instance,
     }
 
     delete dlg;
-    if ( rt == Cancel && dialogType == Everything && cancelQuits() )
-        // The button says quit, so let's quit
-        kapp->quit();
-
     return rt;
 }
 
@@ -308,12 +315,19 @@ void KoTemplateChooseDia::setupRecentDialog(QWidget * widgetbase, QGridLayout *
                 QString key=QString( "File%1" ).arg( i );
                 value=d->m_instance->config()->readPathEntry( key );
                 if ( !value.isEmpty() ) {
-                        KURL url(value);
+                    // Support for kdelibs-3.5's new RecentFiles format: name[url]
+                    QString s = value;
+                    if ( s.endsWith("]") )
+                    {
+                        int pos = s.find("[");
+                        s = s.mid( pos + 1, s.length() - pos - 2);
+                    }
+                    KURL url(s);
 
-                        if(!url.isLocalFile() || QFile::exists(url.path())) {
-                                KFileItem *item = new KFileItem( KFileItem::Unknown, KFileItem::Unknown, url );
-                                d->m_recent->insertItem(item);
-                        }
+                    if(!url.isLocalFile() || QFile::exists(url.path())) {
+                        KFileItem *item = new KFileItem( KFileItem::Unknown, KFileItem::Unknown, url );
+                        d->m_recent->insertItem(item);
+                    }
                 }
                 i++;
         } while ( !value.isEmpty() || i<=10 );
@@ -458,7 +472,7 @@ void KoTemplateChooseDia::setupTemplateDialog(QWidget * widgetbase, QGridLayout
 	d->m_jwidget->showPage(templateNum);
     else if ( defaultTemplateGroup != -1)
 	d->m_jwidget->showPage(defaultTemplateGroup);
-    
+
 
     // Set the initially selected template, possibly from the last usage of the dialog
     currentChanged(itemtoselect);
@@ -640,10 +654,13 @@ void KoTemplateChooseDia::slotOk()
 	    {
 		// The checkbox m_nodiag is in tri-state mode for new documents
 		// fixes bug:77542
-		if (d->m_nodiag->isChecked())
+
+		if (d->m_nodiag->state() == QButton::On) {
 		    grp.writeEntry( "NoStartDlg", "yes");
-		else if (!d->m_nodiag->isChecked())
+		}
+		else if (d->m_nodiag->state() == QButton::Off) {
 		    grp.writeEntry( "NoStartDlg", "no");
+		}
 	    }
 	}
 	else
@@ -699,10 +716,12 @@ bool KoTemplateChooseDia::collectInfo()
 	else
 	{
 		// Existing file from file dialog
+	        if ( !d->m_filedialog->slotOkCalled() )
+	            d->m_filedialog->slotOk();
 		KURL url = d->m_filedialog->currentURL();
 		d->m_fullTemplateName = url.url();
-		d->m_returnType = File;
-                return d->m_filedialog->checkURL();
+	        d->m_returnType = File;
+	        return d->m_filedialog->checkURL();
 	}
 	return true;
     }
