@@ -22,6 +22,7 @@
 
 #include <koTemplateCreateDia.h>
 
+#include <qfile.h>
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qgroupbox.h>
@@ -34,13 +35,14 @@
 #include <klistview.h>
 #include <klocale.h>
 #include <koTemplates.h>
-#include <kfiledialog.h>
-#include <klineeditdlg.h>
+#include <kicondialog.h>
+#include <kinputdialog.h>
 #include <kmessagebox.h>
 #include <kimageio.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 #include <kio/netaccess.h>
+#include <kiconloader.h>
 
 #include <stdlib.h>
 #include <kinstance.h>
@@ -48,8 +50,8 @@
 
 class KoTemplateCreateDiaPrivate {
 public:
-    KoTemplateCreateDiaPrivate()
-    : m_tempFile( QString::null, ".png" )
+    KoTemplateCreateDiaPrivate( QWidget* parent )
+         : m_tempFile( QString::null, ".png" )
     {
         m_tree=0L;
         m_name=0L;
@@ -76,6 +78,7 @@ public:
     KListView *m_groups;
     QPushButton *m_add, *m_remove;
     bool m_changed;
+    /// Temp file for remote picture file
     KTempFile m_tempFile;
 };
 
@@ -91,7 +94,7 @@ KoTemplateCreateDia::KoTemplateCreateDia( const QCString &templateType, KInstanc
     KDialogBase( parent, "template create dia", true, i18n( "Create Template" ),
                  KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok ), m_file(file), m_pixmap(pix) {
 
-    d=new KoTemplateCreateDiaPrivate();
+    d=new KoTemplateCreateDiaPrivate( parent );
 
     QFrame *mainwidget=makeMainWidget();
     QHBoxLayout *mbox=new QHBoxLayout(mainwidget, KDialogBase::marginHint(),
@@ -178,9 +181,11 @@ void KoTemplateCreateDia::slotSelectionChanged()
     d->m_remove->setEnabled( item );
     if ( ! item )
         return;
-    
+
     if ( item->depth() > 0 )
+    {
         d->m_name->setText( item->text( 0 ) );
+    }
 }
 
 void KoTemplateCreateDia::createTemplate( const QCString &templateType, KInstance *instance,
@@ -226,7 +231,7 @@ void KoTemplateCreateDia::slotOk() {
 
     // copy the tmp file and the picture the app provides
     QString dir=d->m_tree->instance()->dirs()->saveLocation(d->m_tree->templateType());
-    dir+=KoTemplates::stripWhiteSpace(group->name());
+    dir+=group->name();
     QString templateDir=dir+"/.source/";
     QString iconDir=dir+"/.icon/";
 
@@ -237,22 +242,32 @@ void KoTemplateCreateDia::slotOk() {
     icon+=".png";
 
     // try to find the extension for the template file :P
-    unsigned int k=0;
-    unsigned int foo=m_file.length();
-    while(m_file[foo-k]!=QChar('.') && k<=foo) {
-        ++k;
-    }
-    if(k<foo)
-        file+=m_file.right(k);
+    const int pos = m_file.findRev( '.' );
+    QString ext;
+    if ( pos > -1 )
+        ext = m_file.mid( pos );
+    else
+        kdWarning(30004) << "Template extension not found!" << endl;
 
-    KoTemplate *t=new KoTemplate(d->m_name->text(), QString::null, ".source/"+file, tmpIcon, false, true);
+    KURL dest;
+    dest.setPath(templateDir+file+ext);
+    if ( QFile::exists( dest.prettyURL(0, KURL::StripFileProtocol) ) )
+    {
+        do
+        {
+            file.prepend( '_' );
+            dest.setPath( templateDir + file + ext );
+            tmpIcon=".icon/"+file+".png";
+            icon=iconDir+file+".png";
+        }
+        while ( KIO::NetAccess::exists( dest, true, this ) );
+    }
+    bool ignore = false;
+    kdDebug(30004) << "Trying to create template: " << d->m_name->text() << "URL=" << ".source/"+file+ext << " ICON=" << tmpIcon << endl;
+    KoTemplate *t=new KoTemplate(d->m_name->text(), QString::null, ".source/"+file+ext, tmpIcon, "", false, true);
     if(!group->add(t)) {
-        KoTemplate *existingTemplate=group->find(t->name());
-        // if the original template is hidden, we simply force the update >:->
-        if(existingTemplate && existingTemplate->isHidden())
-            group->add(t, true);
-        // Otherwise ask the user
-        else if(existingTemplate && !existingTemplate->isHidden()) {
+        KoTemplate *existingTemplate=group->find(d->m_name->text());
+        if(existingTemplate && !existingTemplate->isHidden()) {
             if(KMessageBox::warningYesNo(this, i18n("Do you really want to overwrite"
                                                     " the existing '%1' template?").
                                          arg(existingTemplate->name()))==KMessageBox::Yes)
@@ -263,6 +278,8 @@ void KoTemplateCreateDia::slotOk() {
                 return;
             }
         }
+        else
+            ignore = true;
     }
 
     if(!KStandardDirs::makeDir(templateDir) || !KStandardDirs::makeDir(iconDir)) {
@@ -271,34 +288,38 @@ void KoTemplateCreateDia::slotOk() {
         return;
     }
 
-    // copy the template file
-    KURL dest;
-    dest.setPath(templateDir+file);
-    KIO::NetAccess::del( dest );
-    KIO::NetAccess::copy(m_file, dest);
+    KURL orig;
+    orig.setPath( m_file );
+    // don't overwrite the hidden template file with a new non-hidden one
+    if ( !ignore )
+    {
+        // copy the template file
+        KIO::NetAccess::file_copy( orig, dest, -1, true, false, this );
+
+        // save the picture
+        if(d->m_default->isChecked() && !m_pixmap.isNull())
+            m_pixmap.save(icon, "PNG");
+        else if(!d->m_customPixmap.isNull())
+            d->m_customPixmap.save(icon, "PNG");
+        else
+            kdWarning(30004) << "Could not save the preview picture!" << endl;
+    }
 
     // if there's a .directory file, we copy this one, too
     bool ready=false;
     QStringList tmp=group->dirs();
     for(QStringList::ConstIterator it=tmp.begin(); it!=tmp.end() && !ready; ++it) {
         if((*it).contains(dir)==0) {
-            QString f=(*it)+".directory";
-            QFileInfo info(f);
-            if(info.exists()) {
+            orig.setPath( (*it)+".directory" );
+            // Check if we can read the file
+            if( KIO::NetAccess::exists(orig, true, this) ) {
                 dest.setPath( dir+"/.directory" );
-                KIO::NetAccess::del( dest );
-                KIO::NetAccess::copy( f, dest );
+                // We copy the file with overwrite
+                KIO::NetAccess::file_copy( orig, dest, -1, true, false, this );
                 ready=true;
             }
         }
     }
-    // save the picture
-    if(d->m_default->isChecked() && !m_pixmap.isNull())
-        m_pixmap.save(icon, "PNG");
-    else if(!d->m_customPixmap.isNull())
-        d->m_customPixmap.save(icon, "PNG");
-    else
-        kdWarning(30004) << "Could not save the preview picture!" << endl;
 
     d->m_tree->writeTemplateTree();
     KDialogBase::slotOk();
@@ -326,45 +347,24 @@ void KoTemplateCreateDia::slotSelect() {
     d->m_default->setChecked(false);
     d->m_custom->setChecked(true);
 
-    KFileDialog fd(QString::null, KImageIO::pattern(KImageIO::Reading), 0, 0, true);
-    fd.setCaption(i18n("Select Picture"));
-    KURL url;
-    if (fd.exec()==QDialog::Accepted)
-        url=fd.selectedURL();
-
-    if(url.isEmpty()) {
+    QString name = KIconDialog::getIcon();
+    if( name.isEmpty() ) {
         if(d->m_customFile.isEmpty()) {
             d->m_default->setChecked(true);
             d->m_custom->setChecked(false);
         }
         return;
     }
-
-    if ( url.isLocalFile() )
-    {
-        d->m_customFile = url.path();
-    }
-    else
-    {
-        QString target ( d->m_tempFile.name() );
-        if ( KIO::NetAccess::download( url, target ) )
-        {
-            d->m_customFile = target;
-        }
-        else
-        {
-            KMessageBox::sorry( 0L, i18n( "Could not open\n%1" ).arg( url.prettyURL() ) );
-            return;
-        }
-    }
-    
+    // ### TODO: do a better remote loading without having to have d->m_tempFile
+    QString path = KGlobal::iconLoader()->iconPath(name, KIcon::Desktop);
+    d->m_customFile = path;
     d->m_customPixmap=QPixmap();
     updatePixmap();
 }
 
 void KoTemplateCreateDia::slotNameChanged(const QString &name) {
 
-    if((name.isEmpty() || !d->m_groups->firstChild()) && !d->m_changed)
+    if( ( name.stripWhiteSpace().isEmpty() || !d->m_groups->firstChild() ) && !d->m_changed )
         enableButtonOK(false);
     else
         enableButtonOK(true);
@@ -372,13 +372,15 @@ void KoTemplateCreateDia::slotNameChanged(const QString &name) {
 
 void KoTemplateCreateDia::slotAddGroup() {
     bool ok=false;
-    QString name=KLineEditDlg::getText( i18n("Add Group"),i18n("Enter group name:"),QString::null, &ok, this );
+    const QString name ( KInputDialog::getText( i18n("Add Group"), i18n("Enter group name:"), QString::null, &ok, this ) );
     if(!ok)
         return;
     KoTemplateGroup *group=d->m_tree->find(name);
     if(group && !group->isHidden())
+    {
+        KMessageBox::information( this, i18n("This name is already used."), i18n("Add Group") );
         return;
-
+    }
     QString dir=d->m_tree->instance()->dirs()->saveLocation(d->m_tree->templateType());
     dir+=name;
     KoTemplateGroup *newGroup=new KoTemplateGroup(name, dir, true);
@@ -407,8 +409,8 @@ void KoTemplateCreateDia::slotRemove() {
         removed = i18n("Remove Template");
         }
 
-    if(KMessageBox::warningYesNo(this, what,
-                                 removed)==KMessageBox::No) {
+    if(KMessageBox::warningContinueCancel(this, what,
+                                 removed,KGuiItem(i18n("&Delete"),"editdelete"))==KMessageBox::Cancel) {
         d->m_name->setFocus();
         return;
     }
@@ -441,10 +443,14 @@ void KoTemplateCreateDia::updatePixmap() {
         d->m_preview->setPixmap(m_pixmap);
     else if(d->m_custom->isChecked() && !d->m_customFile.isEmpty()) {
         if(d->m_customPixmap.isNull()) {
+            kdDebug(30004) << "Trying to load picture " << d->m_customFile << endl;
             // use the code in KoTemplate to load the image... hacky, I know :)
             KoTemplate t("foo", "bar", QString::null, d->m_customFile);
-            d->m_customPixmap=t.loadPicture();
+            d->m_customPixmap=t.loadPicture(d->m_tree->instance());
         }
+        else
+            kdWarning(30004) << "Trying to load picture" << endl;
+
         if(!d->m_customPixmap.isNull())
             d->m_preview->setPixmap(d->m_customPixmap);
         else
