@@ -139,160 +139,160 @@ void KoColorPanel::insertDefaultColors()
     int currentRow = m_nextPosition.y; // we have to repaint this row below
 
     // Note: No checking for duplicates, so take care when you modify that list
-    insertColor(qRgb( 255 ,     0 ,     0 ), i18n( "Color", "Red" ), false);
-    insertColor(qRgb( 255 ,   165 ,     0 ), i18n( "Color", "Orange" ), false);
-    insertColor(qRgb( 255 ,     0 ,   255 ), i18n( "Color", "Magenta" ), false);
-    insertColor(qRgb(   0 ,     0 ,   255 ), i18n( "Color", "Blue" ), false);
-    insertColor(qRgb(   0 ,   255 ,   255 ), i18n( "Color", "Cyan" ), false);
-    insertColor(qRgb(   0 ,   255 ,     0 ), i18n( "Color", "Green" ), false);
-    insertColor(qRgb( 255 ,   255 ,     0 ), i18n( "Color", "Yellow" ), false);
-    insertColor(qRgb( 165 ,    42 ,    42 ), i18n( "Color", "Brown" ), false);
-    insertColor(qRgb( 139 ,     0 ,     0 ), i18n( "Color", "Dark Red" ), false);
-    insertColor(qRgb( 255 ,   140 ,     0 ), i18n( "Color", "Dark Orange" ), false);
-    insertColor(qRgb( 139 ,     0 ,   139 ), i18n( "Color", "Dark Magenta" ), false);
-    insertColor(qRgb(   0 ,     0 ,   139 ), i18n( "Color", "Dark Blue" ), false);
-    insertColor(qRgb(   0 ,   139 ,   139 ), i18n( "Color", "Dark Cyan" ), false);
-    insertColor(qRgb(   0 ,   100 ,     0 ), i18n( "Color", "Dark Green" ), false);
-    insertColor(qRgb( 130 ,   127 ,     0 ), i18n( "Color", "Dark Yellow" ), false);
-    insertColor(qRgb( 255 ,   255 ,   255 ), i18n( "Color", "White" ), false);
+    insertColor(QColor( 255 ,     0 ,     0 ), i18n( "color", "Red" ), false);
+    insertColor(QColor( 255 ,   165 ,     0 ), i18n( "color", "Orange" ), false);
+    insertColor(QColor( 255 ,     0 ,   255 ), i18n( "color", "Magenta" ), false);
+    insertColor(QColor(   0 ,     0 ,   255 ), i18n( "color", "Blue" ), false);
+    insertColor(QColor(   0 ,   255 ,   255 ), i18n( "color", "Cyan" ), false);
+    insertColor(QColor(   0 ,   255 ,     0 ), i18n( "color", "Green" ), false);
+    insertColor(QColor( 255 ,   255 ,     0 ), i18n( "color", "Yellow" ), false);
+    insertColor(QColor( 165 ,    42 ,    42 ), i18n( "color", "Brown" ), false);
+    insertColor(QColor( 139 ,     0 ,     0 ), i18n( "color", "DarkRed" ), false);
+    insertColor(QColor( 255 ,   140 ,     0 ), i18n( "color", "DarkOrange" ), false);
+    insertColor(QColor( 139 ,     0 ,   139 ), i18n( "color", "DarkMagenta" ), false);
+    insertColor(QColor(   0 ,     0 ,   139 ), i18n( "color", "DarkBlue" ), false);
+    insertColor(QColor(   0 ,   139 ,   139 ), i18n( "color", "DarkCyan" ), false);
+    insertColor(QColor(   0 ,   100 ,     0 ), i18n( "color", "DarkGreen" ), false);
+    insertColor(QColor( 130 ,   127 ,     0 ), i18n( "color", "DarkYellow" ), false);
+    insertColor(QColor( 255 ,   255 ,   255 ), i18n( "color", "White" ), false);
     // xgettext:no-c-format
-    insertColor(qRgb( 229 ,   229 ,   229 ), i18n( "Color", "Gray 90%" ), false);
+    insertColor(QColor( 229 ,   229 ,   229 ), i18n( "color", "Gray 90%" ), false);
     // xgettext:no-c-format
-    insertColor(qRgb( 204 ,   204 ,   204 ), i18n( "Color", "Gray 80%" ), false);
+    insertColor(QColor( 204 ,   204 ,   204 ), i18n( "color", "Gray 80%" ), false);
     // xgettext:no-c-format
-    insertColor(qRgb( 178 ,   178 ,   178 ), i18n( "Color", "Gray 70%" ), false);
+    insertColor(QColor( 178 ,   178 ,   178 ), i18n( "color", "Gray 70%" ), false);
     // xgettext:no-c-format
-    insertColor(qRgb( 153 ,   153 ,   153 ), i18n( "Color", "Gray 60%" ), false);
+    insertColor(QColor( 153 ,   153 ,   153 ), i18n( "color", "Gray 60%" ), false);
     // xgettext:no-c-format
-    insertColor(qRgb( 127 ,   127 ,   127 ), i18n( "Color", "Gray 50%" ), false);
+    insertColor(QColor( 127 ,   127 ,   127 ), i18n( "color", "Gray 50%" ), false);
     // xgettext:no-c-format
-    insertColor(qRgb( 102 ,   102 ,   102 ), i18n( "Color", "Gray 40%" ), false);
+    insertColor(QColor( 102 ,   102 ,   102 ), i18n( "color", "Gray 40%" ), false);
     // xgettext:no-c-format
-    insertColor(qRgb(  76 ,    76 ,    76 ), i18n( "Color", "Gray 30%" ), false);
+    insertColor(QColor(  76 ,    76 ,    76 ), i18n( "color", "Gray 30%" ), false);
     // xgettext:no-c-format
-    insertColor(qRgb(  51 ,    51 ,    51 ), i18n( "Color", "Gray 20%" ), false);
+    insertColor(QColor(  51 ,    51 ,    51 ), i18n( "color", "Gray 20%" ), false);
     // xgettext:no-c-format
-    insertColor(qRgb(  25 ,    25 ,    25 ), i18n( "Color", "Gray 10%" ), false);
-    insertColor(qRgb(   0 ,     0 ,     0 ), i18n( "Color", "Black" ), false);
-    insertColor(qRgb( 255 ,   255 ,   240 ), i18n( "Color", "Ivory" ), false);
-    insertColor(qRgb( 255 ,   250 ,   250 ), i18n( "Color", "Snow" ), false);
-    insertColor(qRgb( 245 ,   255 ,   250 ), i18n( "Color", "Mint Cream" ), false);
-    insertColor(qRgb( 255 ,   250 ,   240 ), i18n( "Color", "Floral White" ), false);
-    insertColor(qRgb( 255 ,   255 ,   224 ), i18n( "Color", "Light Yellow" ), false);
-    insertColor(qRgb( 240 ,   255 ,   255 ), i18n( "Color", "Azure" ), false);
-    insertColor(qRgb( 248 ,   248 ,   255 ), i18n( "Color", "Ghost White" ), false);
-    insertColor(qRgb( 240 ,   255 ,   240 ), i18n( "Color", "Honeydew" ), false);
-    insertColor(qRgb( 255 ,   245 ,   238 ), i18n( "Color", "Seashell" ), false);
-    insertColor(qRgb( 240 ,   248 ,   255 ), i18n( "Color", "Alice Blue" ), false);
-    insertColor(qRgb( 255 ,   248 ,   220 ), i18n( "Color", "Cornsilk" ), false);
-    insertColor(qRgb( 255 ,   240 ,   245 ), i18n( "Color", "Lavender Blush" ), false);
-    insertColor(qRgb( 253 ,   245 ,   230 ), i18n( "Color", "Old Lace" ), false);
-    insertColor(qRgb( 245 ,   245 ,   245 ), i18n( "Color", "White Smoke" ), false);
-    insertColor(qRgb( 255 ,   250 ,   205 ), i18n( "Color", "Lemon Chiffon" ), false);
-    insertColor(qRgb( 224 ,   255 ,   255 ), i18n( "Color", "Light Cyan" ), false);
-    insertColor(qRgb( 250 ,   250 ,   210 ), i18n( "Color", "Light Goldenrod Yellow" ), false);
-    insertColor(qRgb( 250 ,   240 ,   230 ), i18n( "Color", "Linen" ), false);
-    insertColor(qRgb( 245 ,   245 ,   220 ), i18n( "Color", "Beige" ), false);
-    insertColor(qRgb( 255 ,   239 ,   213 ), i18n( "Color", "Papaya Whip" ), false);
-    insertColor(qRgb( 255 ,   235 ,   205 ), i18n( "Color", "Blanched Almond" ), false);
-    insertColor(qRgb( 250 ,   235 ,   215 ), i18n( "Color", "Antique White" ), false);
-    insertColor(qRgb( 255 ,   228 ,   225 ), i18n( "Color", "Misty Rose" ), false);
-    insertColor(qRgb( 230 ,   230 ,   250 ), i18n( "Color", "Lavender" ), false);
-    insertColor(qRgb( 255 ,   228 ,   196 ), i18n( "Color", "Bisque" ), false);
-    insertColor(qRgb( 255 ,   228 ,   181 ), i18n( "Color", "Moccasin" ), false);
-    insertColor(qRgb( 255 ,   222 ,   173 ), i18n( "Color", "Navajo White" ), false);
-    insertColor(qRgb( 255 ,   218 ,   185 ), i18n( "Color", "Peach Puff" ), false);
-    insertColor(qRgb( 238 ,   232 ,   170 ), i18n( "Color", "Pale Goldenrod" ), false);
-    insertColor(qRgb( 245 ,   222 ,   179 ), i18n( "Color", "Wheat" ), false);
-    insertColor(qRgb( 220 ,   220 ,   220 ), i18n( "Color", "Gainsboro" ), false);
-    insertColor(qRgb( 240 ,   230 ,   140 ), i18n( "Color", "Khaki" ), false);
-    insertColor(qRgb( 175 ,   238 ,   238 ), i18n( "Color", "Pale Turquoise" ), false);
-    insertColor(qRgb( 255 ,   192 ,   203 ), i18n( "Color", "Pink" ), false);
-    insertColor(qRgb( 238 ,   221 ,   130 ), i18n( "Color", "Light Goldenrod" ), false);
-    insertColor(qRgb( 211 ,   211 ,   211 ), i18n( "Color", "Light Gray" ), false);
-    insertColor(qRgb( 255 ,   182 ,   193 ), i18n( "Color", "Light Pink" ), false);
-    insertColor(qRgb( 176 ,   224 ,   230 ), i18n( "Color", "Powder Blue" ), false);
-    insertColor(qRgb( 127 ,   255 ,   212 ), i18n( "Color", "Aquamarine" ), false);
-    insertColor(qRgb( 216 ,   191 ,   216 ), i18n( "Color", "Thistle" ), false);
-    insertColor(qRgb( 173 ,   216 ,   230 ), i18n( "Color", "Light Blue" ), false);
-    insertColor(qRgb( 152 ,   251 ,   152 ), i18n( "Color", "Pale Green" ), false);
-    insertColor(qRgb( 255 ,   215 ,     0 ), i18n( "Color", "Gold" ), false);
-    insertColor(qRgb( 173 ,   255 ,    47 ), i18n( "Color", "Green Yellow" ), false);
-    insertColor(qRgb( 176 ,   196 ,   222 ), i18n( "Color", "Light Steel Blue" ), false);
-    insertColor(qRgb( 144 ,   238 ,   144 ), i18n( "Color", "Light Green" ), false);
-    insertColor(qRgb( 221 ,   160 ,   221 ), i18n( "Color", "Plum" ), false);
-    insertColor(qRgb( 190 ,   190 ,   190 ), i18n( "Color", "Gray" ), false);
-    insertColor(qRgb( 222 ,   184 ,   135 ), i18n( "Color", "Burly Wood" ), false);
-    insertColor(qRgb( 135 ,   206 ,   250 ), i18n( "Color", "Light Sky Blue" ), false);
-    insertColor(qRgb( 255 ,   160 ,   122 ), i18n( "Color", "Light Salmon" ), false);
-    insertColor(qRgb( 135 ,   206 ,   235 ), i18n( "Color", "Sky Blue" ), false);
-    insertColor(qRgb( 210 ,   180 ,   140 ), i18n( "Color", "Tan" ), false);
-    insertColor(qRgb( 238 ,   130 ,   238 ), i18n( "Color", "Violet" ), false);
-    insertColor(qRgb( 244 ,   164 ,    96 ), i18n( "Color", "Sandy Brown" ), false);
-    insertColor(qRgb( 233 ,   150 ,   122 ), i18n( "Color", "Dark Salmon" ), false);
-    insertColor(qRgb( 189 ,   183 ,   107 ), i18n( "Color", "Dark Khaki" ), false);
-    insertColor(qRgb( 127 ,   255 ,     0 ), i18n( "Color", "Chartreuse" ), false);
-    insertColor(qRgb( 169 ,   169 ,   169 ), i18n( "Color", "Dark Gray" ), false);
-    insertColor(qRgb( 124 ,   252 ,     0 ), i18n( "Color", "Lawn Green" ), false);
-    insertColor(qRgb( 255 ,   105 ,   180 ), i18n( "Color", "Hot Pink" ), false);
-    insertColor(qRgb( 250 ,   128 ,   114 ), i18n( "Color", "Salmon" ), false);
-    insertColor(qRgb( 240 ,   128 ,   128 ), i18n( "Color", "Light Coral" ), false);
-    insertColor(qRgb(  64 ,   224 ,   208 ), i18n( "Color", "Turquoise" ), false);
-    insertColor(qRgb( 143 ,   188 ,   143 ), i18n( "Color", "Dark Sea Green" ), false);
-    insertColor(qRgb( 218 ,   112 ,   214 ), i18n( "Color", "Orchid" ), false);
-    insertColor(qRgb( 102 ,   205 ,   170 ), i18n( "Color", "Medium Aquamarine" ), false);
-    insertColor(qRgb( 255 ,   127 ,    80 ), i18n( "Color", "Coral" ), false);
-    insertColor(qRgb( 154 ,   205 ,    50 ), i18n( "Color", "Yellow Green" ), false);
-    insertColor(qRgb( 218 ,   165 ,    32 ), i18n( "Color", "Goldenrod" ), false);
-    insertColor(qRgb(  72 ,   209 ,   204 ), i18n( "Color", "Medium Turquoise" ), false);
-    insertColor(qRgb( 188 ,   143 ,   143 ), i18n( "Color", "Rosy Brown" ), false);
-    insertColor(qRgb( 219 ,   112 ,   147 ), i18n( "Color", "Pale Violet Red" ), false);
-    insertColor(qRgb(   0 ,   250 ,   154 ), i18n( "Color", "Medium Spring Green" ), false);
-    insertColor(qRgb( 255 ,    99 ,    71 ), i18n( "Color", "Tomato" ), false);
-    insertColor(qRgb( 0   ,   255 ,   127 ), i18n( "Color", "Spring Green" ), false);
-    insertColor(qRgb( 205 ,   133 ,    63 ), i18n( "Color", "Peru" ), false);
-    insertColor(qRgb( 100 ,   149 ,   237 ), i18n( "Color", "Cornflower Blue" ), false);
-    insertColor(qRgb( 132 ,   112 ,   255 ), i18n( "Color", "Light Slate Blue" ), false);
-    insertColor(qRgb( 147 ,   112 ,   219 ), i18n( "Color", "Medium Purple" ), false);
-    insertColor(qRgb( 186 ,    85 ,   211 ), i18n( "Color", "Medium Orchid" ), false);
-    insertColor(qRgb(  95 ,   158 ,   160 ), i18n( "Color", "Cadet Blue" ), false);
-    insertColor(qRgb(   0 ,   206 ,   209 ), i18n( "Color", "Dark Turquoise" ), false);
-    insertColor(qRgb(   0 ,   191 ,   255 ), i18n( "Color", "Deep Sky Blue" ), false);
-    insertColor(qRgb( 119 ,   136 ,   153 ), i18n( "Color", "Light Slate Gray" ), false);
-    insertColor(qRgb( 184 ,   134 ,    11 ), i18n( "Color", "Dark Goldenrod" ), false);
-    insertColor(qRgb( 123 ,   104 ,   238 ), i18n( "Color", "Medium Slate Blue" ), false);
-    insertColor(qRgb( 205 ,    92 ,    92 ), i18n( "Color", "Indian Red" ), false);
-    insertColor(qRgb( 210 ,   105 ,    30 ), i18n( "Color", "Chocolate" ), false);
-    insertColor(qRgb(  60 ,   179 ,   113 ), i18n( "Color", "Medium Sea Green" ), false);
-    insertColor(qRgb(  50 ,   205 ,    50 ), i18n( "Color", "Lime Green" ), false);
-    insertColor(qRgb(  32 ,   178 ,   170 ), i18n( "Color", "Light Sea Green" ), false);
-    insertColor(qRgb( 112 ,   128 ,   144 ), i18n( "Color", "Slate Gray" ), false);
-    insertColor(qRgb(  30 ,   144 ,   255 ), i18n( "Color", "Dodger Blue" ), false);
-    insertColor(qRgb( 255 ,    69 ,     0 ), i18n( "Color", "Orange Red" ), false);
-    insertColor(qRgb( 255 ,    20 ,   147 ), i18n( "Color", "Deep Pink" ), false);
-    insertColor(qRgb(  70 ,   130 ,   180 ), i18n( "Color", "Steel Blue" ), false);
-    insertColor(qRgb( 106 ,    90 ,   205 ), i18n( "Color", "Slate Blue" ), false);
-    insertColor(qRgb( 107 ,   142 ,    35 ), i18n( "Color", "Olive Drab" ), false);
-    insertColor(qRgb(  65 ,   105 ,   225 ), i18n( "Color", "Royal Blue" ), false);
-    insertColor(qRgb( 208 ,    32 ,   144 ), i18n( "Color", "Violet Red" ), false);
-    insertColor(qRgb( 153 ,    50 ,   204 ), i18n( "Color", "Dark Orchid" ), false);
-    insertColor(qRgb( 160 ,    32 ,   240 ), i18n( "Color", "Purple" ), false);
-    insertColor(qRgb( 105 ,   105 ,   105 ), i18n( "Color", "Dim Gray" ), false);
-    insertColor(qRgb( 138 ,    43 ,   226 ), i18n( "Color", "Blue Violet" ), false);
-    insertColor(qRgb( 160 ,    82 ,    45 ), i18n( "Color", "Sienna" ), false);
-    insertColor(qRgb( 199 ,    21 ,   133 ), i18n( "Color", "Medium Violet Red" ), false);
-    insertColor(qRgb( 176 ,    48 ,    96 ), i18n( "Color", "Maroon" ), false);
-    insertColor(qRgb(  46 ,   139 ,    87 ), i18n( "Color", "Sea Green" ), false);
-    insertColor(qRgb(  85 ,   107 ,    47 ), i18n( "Color", "Dark Olive Green" ), false);
-    insertColor(qRgb(  34 ,   139 ,    34 ), i18n( "Color", "Forest Green" ), false);
-    insertColor(qRgb( 139 ,    69 ,    19 ), i18n( "Color", "Saddle Brown" ), false);
-    insertColor(qRgb( 148 ,     0 ,   211 ), i18n( "Color", "Dark Violet" ), false);
-    insertColor(qRgb( 178 ,    34 ,    34 ), i18n( "Color", "Fire Brick" ), false);
-    insertColor(qRgb(  72 ,    61 ,   139 ), i18n( "Color", "Dark Slate Blue" ), false);
-    insertColor(qRgb(  47 ,    79 ,    79 ), i18n( "Color", "Dark Slate Gray" ), false);
-    insertColor(qRgb(  25 ,    25 ,   112 ), i18n( "Color", "Midnight Blue" ), false);
-    insertColor(qRgb(   0 ,     0 ,   205 ), i18n( "Color", "Medium Blue" ), false);
-    insertColor(qRgb(   0 ,     0 ,   128 ), i18n( "Color", "Navy" ), false);
+    insertColor(QColor(  25 ,    25 ,    25 ), i18n( "color", "Gray 10%" ), false);
+    insertColor(QColor(   0 ,     0 ,     0 ), i18n( "color", "Black" ), false);
+    insertColor(QColor( 255 ,   255 ,   240 ), i18n( "color", "Ivory" ), false);
+    insertColor(QColor( 255 ,   250 ,   250 ), i18n( "color", "Snow" ), false);
+    insertColor(QColor( 245 ,   255 ,   250 ), i18n( "color", "MintCream" ), false);
+    insertColor(QColor( 255 ,   250 ,   240 ), i18n( "color", "FloralWhite" ), false);
+    insertColor(QColor( 255 ,   255 ,   224 ), i18n( "color", "LightYellow" ), false);
+    insertColor(QColor( 240 ,   255 ,   255 ), i18n( "color", "Azure" ), false);
+    insertColor(QColor( 248 ,   248 ,   255 ), i18n( "color", "GhostWhite" ), false);
+    insertColor(QColor( 240 ,   255 ,   240 ), i18n( "color", "Honeydew" ), false);
+    insertColor(QColor( 255 ,   245 ,   238 ), i18n( "color", "Seashell" ), false);
+    insertColor(QColor( 240 ,   248 ,   255 ), i18n( "color", "AliceBlue" ), false);
+    insertColor(QColor( 255 ,   248 ,   220 ), i18n( "color", "Cornsilk" ), false);
+    insertColor(QColor( 255 ,   240 ,   245 ), i18n( "color", "LavenderBlush" ), false);
+    insertColor(QColor( 253 ,   245 ,   230 ), i18n( "color", "OldLace" ), false);
+    insertColor(QColor( 245 ,   245 ,   245 ), i18n( "color", "WhiteSmoke" ), false);
+    insertColor(QColor( 255 ,   250 ,   205 ), i18n( "color", "LemonChiffon" ), false);
+    insertColor(QColor( 224 ,   255 ,   255 ), i18n( "color", "LightCyan" ), false);
+    insertColor(QColor( 250 ,   250 ,   210 ), i18n( "color", "LightGoldenrodYellow" ), false);
+    insertColor(QColor( 250 ,   240 ,   230 ), i18n( "color", "Linen" ), false);
+    insertColor(QColor( 245 ,   245 ,   220 ), i18n( "color", "Beige" ), false);
+    insertColor(QColor( 255 ,   239 ,   213 ), i18n( "color", "PapayaWhip" ), false);
+    insertColor(QColor( 255 ,   235 ,   205 ), i18n( "color", "BlanchedAlmond" ), false);
+    insertColor(QColor( 250 ,   235 ,   215 ), i18n( "color", "AntiqueWhite" ), false);
+    insertColor(QColor( 255 ,   228 ,   225 ), i18n( "color", "MistyRose" ), false);
+    insertColor(QColor( 230 ,   230 ,   250 ), i18n( "color", "Lavender" ), false);
+    insertColor(QColor( 255 ,   228 ,   196 ), i18n( "color", "Bisque" ), false);
+    insertColor(QColor( 255 ,   228 ,   181 ), i18n( "color", "Moccasin" ), false);
+    insertColor(QColor( 255 ,   222 ,   173 ), i18n( "color", "NavajoWhite" ), false);
+    insertColor(QColor( 255 ,   218 ,   185 ), i18n( "color", "PeachPuff" ), false);
+    insertColor(QColor( 238 ,   232 ,   170 ), i18n( "color", "PaleGoldenrod" ), false);
+    insertColor(QColor( 245 ,   222 ,   179 ), i18n( "color", "Wheat" ), false);
+    insertColor(QColor( 220 ,   220 ,   220 ), i18n( "color", "Gainsboro" ), false);
+    insertColor(QColor( 240 ,   230 ,   140 ), i18n( "color", "Khaki" ), false);
+    insertColor(QColor( 175 ,   238 ,   238 ), i18n( "color", "PaleTurquoise" ), false);
+    insertColor(QColor( 255 ,   192 ,   203 ), i18n( "color", "Pink" ), false);
+    insertColor(QColor( 238 ,   221 ,   130 ), i18n( "color", "LightGoldenrod" ), false);
+    insertColor(QColor( 211 ,   211 ,   211 ), i18n( "color", "LightGray" ), false);
+    insertColor(QColor( 255 ,   182 ,   193 ), i18n( "color", "LightPink" ), false);
+    insertColor(QColor( 176 ,   224 ,   230 ), i18n( "color", "PowderBlue" ), false);
+    insertColor(QColor( 127 ,   255 ,   212 ), i18n( "color", "Aquamarine" ), false);
+    insertColor(QColor( 216 ,   191 ,   216 ), i18n( "color", "Thistle" ), false);
+    insertColor(QColor( 173 ,   216 ,   230 ), i18n( "color", "LightBlue" ), false);
+    insertColor(QColor( 152 ,   251 ,   152 ), i18n( "color", "PaleGreen" ), false);
+    insertColor(QColor( 255 ,   215 ,     0 ), i18n( "color", "Gold" ), false);
+    insertColor(QColor( 173 ,   255 ,    47 ), i18n( "color", "GreenYellow" ), false);
+    insertColor(QColor( 176 ,   196 ,   222 ), i18n( "color", "LightSteelBlue" ), false);
+    insertColor(QColor( 144 ,   238 ,   144 ), i18n( "color", "LightGreen" ), false);
+    insertColor(QColor( 221 ,   160 ,   221 ), i18n( "color", "Plum" ), false);
+    insertColor(QColor( 190 ,   190 ,   190 ), i18n( "color", "Gray" ), false);
+    insertColor(QColor( 222 ,   184 ,   135 ), i18n( "color", "BurlyWood" ), false);
+    insertColor(QColor( 135 ,   206 ,   250 ), i18n( "color", "LightSkyBlue" ), false);
+    insertColor(QColor( 255 ,   160 ,   122 ), i18n( "color", "LightSalmon" ), false);
+    insertColor(QColor( 135 ,   206 ,   235 ), i18n( "color", "SkyBlue" ), false);
+    insertColor(QColor( 210 ,   180 ,   140 ), i18n( "color", "Tan" ), false);
+    insertColor(QColor( 238 ,   130 ,   238 ), i18n( "color", "Violet" ), false);
+    insertColor(QColor( 244 ,   164 ,    96 ), i18n( "color", "SandyBrown" ), false);
+    insertColor(QColor( 233 ,   150 ,   122 ), i18n( "color", "DarkSalmon" ), false);
+    insertColor(QColor( 189 ,   183 ,   107 ), i18n( "color", "DarkKhaki" ), false);
+    insertColor(QColor( 127 ,   255 ,     0 ), i18n( "color", "Chartreuse" ), false);
+    insertColor(QColor( 169 ,   169 ,   169 ), i18n( "color", "DarkGray" ), false);
+    insertColor(QColor( 124 ,   252 ,     0 ), i18n( "color", "LawnGreen" ), false);
+    insertColor(QColor( 255 ,   105 ,   180 ), i18n( "color", "HotPink" ), false);
+    insertColor(QColor( 250 ,   128 ,   114 ), i18n( "color", "Salmon" ), false);
+    insertColor(QColor( 240 ,   128 ,   128 ), i18n( "color", "LightCoral" ), false);
+    insertColor(QColor(  64 ,   224 ,   208 ), i18n( "color", "Turquoise" ), false);
+    insertColor(QColor( 143 ,   188 ,   143 ), i18n( "color", "DarkSeaGreen" ), false);
+    insertColor(QColor( 218 ,   112 ,   214 ), i18n( "color", "Orchid" ), false);
+    insertColor(QColor( 102 ,   205 ,   170 ), i18n( "color", "MediumAquamarine" ), false);
+    insertColor(QColor( 255 ,   127 ,    80 ), i18n( "color", "Coral" ), false);
+    insertColor(QColor( 154 ,   205 ,    50 ), i18n( "color", "YellowGreen" ), false);
+    insertColor(QColor( 218 ,   165 ,    32 ), i18n( "color", "Goldenrod" ), false);
+    insertColor(QColor(  72 ,   209 ,   204 ), i18n( "color", "MediumTurquoise" ), false);
+    insertColor(QColor( 188 ,   143 ,   143 ), i18n( "color", "RosyBrown" ), false);
+    insertColor(QColor( 219 ,   112 ,   147 ), i18n( "color", "PaleVioletRed" ), false);
+    insertColor(QColor(   0 ,   250 ,   154 ), i18n( "color", "MediumSpringGreen" ), false);
+    insertColor(QColor( 255 ,    99 ,    71 ), i18n( "color", "Tomato" ), false);
+    insertColor(QColor( 0   ,   255 ,   127 ), i18n( "color", "SpringGreen" ), false);
+    insertColor(QColor( 205 ,   133 ,    63 ), i18n( "color", "Peru" ), false);
+    insertColor(QColor( 100 ,   149 ,   237 ), i18n( "color", "CornflowerBlue" ), false);
+    insertColor(QColor( 132 ,   112 ,   255 ), i18n( "color", "LightSlateBlue" ), false);
+    insertColor(QColor( 147 ,   112 ,   219 ), i18n( "color", "MediumPurple" ), false);
+    insertColor(QColor( 186 ,    85 ,   211 ), i18n( "color", "MediumOrchid" ), false);
+    insertColor(QColor(  95 ,   158 ,   160 ), i18n( "color", "CadetBlue" ), false);
+    insertColor(QColor(   0 ,   206 ,   209 ), i18n( "color", "DarkTurquoise" ), false);
+    insertColor(QColor(   0 ,   191 ,   255 ), i18n( "color", "DeepSkyBlue" ), false);
+    insertColor(QColor( 119 ,   136 ,   153 ), i18n( "color", "LightSlateGray" ), false);
+    insertColor(QColor( 184 ,   134 ,    11 ), i18n( "color", "DarkGoldenrod" ), false);
+    insertColor(QColor( 123 ,   104 ,   238 ), i18n( "color", "MediumSlateBlue" ), false);
+    insertColor(QColor( 205 ,    92 ,    92 ), i18n( "color", "IndianRed" ), false);
+    insertColor(QColor( 210 ,   105 ,    30 ), i18n( "color", "Chocolate" ), false);
+    insertColor(QColor(  60 ,   179 ,   113 ), i18n( "color", "MediumSeaGreen" ), false);
+    insertColor(QColor(  50 ,   205 ,    50 ), i18n( "color", "LimeGreen" ), false);
+    insertColor(QColor(  32 ,   178 ,   170 ), i18n( "color", "LightSeaGreen" ), false);
+    insertColor(QColor( 112 ,   128 ,   144 ), i18n( "color", "SlateGray" ), false);
+    insertColor(QColor(  30 ,   144 ,   255 ), i18n( "color", "DodgerBlue" ), false);
+    insertColor(QColor( 255 ,    69 ,     0 ), i18n( "color", "OrangeRed" ), false);
+    insertColor(QColor( 255 ,    20 ,   147 ), i18n( "color", "DeepPink" ), false);
+    insertColor(QColor(  70 ,   130 ,   180 ), i18n( "color", "SteelBlue" ), false);
+    insertColor(QColor( 106 ,    90 ,   205 ), i18n( "color", "SlateBlue" ), false);
+    insertColor(QColor( 107 ,   142 ,    35 ), i18n( "color", "OliveDrab" ), false);
+    insertColor(QColor(  65 ,   105 ,   225 ), i18n( "color", "RoyalBlue" ), false);
+    insertColor(QColor( 208 ,    32 ,   144 ), i18n( "color", "VioletRed" ), false);
+    insertColor(QColor( 153 ,    50 ,   204 ), i18n( "color", "DarkOrchid" ), false);
+    insertColor(QColor( 160 ,    32 ,   240 ), i18n( "color", "Purple" ), false);
+    insertColor(QColor( 105 ,   105 ,   105 ), i18n( "color", "DimGray" ), false);
+    insertColor(QColor( 138 ,    43 ,   226 ), i18n( "color", "BlueViolet" ), false);
+    insertColor(QColor( 160 ,    82 ,    45 ), i18n( "color", "Sienna" ), false);
+    insertColor(QColor( 199 ,    21 ,   133 ), i18n( "color", "MediumVioletRed" ), false);
+    insertColor(QColor( 176 ,    48 ,    96 ), i18n( "color", "Maroon" ), false);
+    insertColor(QColor(  46 ,   139 ,    87 ), i18n( "color", "SeaGreen" ), false);
+    insertColor(QColor(  85 ,   107 ,    47 ), i18n( "color", "DarkOliveGreen" ), false);
+    insertColor(QColor(  34 ,   139 ,    34 ), i18n( "color", "ForestGreen" ), false);
+    insertColor(QColor( 139 ,    69 ,    19 ), i18n( "color", "SaddleBrown" ), false);
+    insertColor(QColor( 148 ,     0 ,   211 ), i18n( "color", "DarkViolet" ), false);
+    insertColor(QColor( 178 ,    34 ,    34 ), i18n( "color", "FireBrick" ), false);
+    insertColor(QColor(  72 ,    61 ,   139 ), i18n( "color", "DarkSlateBlue" ), false);
+    insertColor(QColor(  47 ,    79 ,    79 ), i18n( "color", "DarkSlateGray" ), false);
+    insertColor(QColor(  25 ,    25 ,   112 ), i18n( "color", "MidnightBlue" ), false);
+    insertColor(QColor(   0 ,     0 ,   205 ), i18n( "color", "MediumBlue" ), false);
+    insertColor(QColor(   0 ,     0 ,   128 ), i18n( "color", "Navy" ), false);
 
     finalizeInsertion( m_nextPosition );  // with a no-op paint() call as we repaint anyway
     updateGeometry();
