@@ -30,7 +30,7 @@
 #include <kdebug.h>
 
 KoPixmapWidget::KoPixmapWidget(const QPixmap &aPixmap, QWidget *parent, const char *name):
-QFrame(parent, name, WStyle_Customize | WStyle_NoBorder)
+QFrame(parent, name, WStyle_Customize | WStyle_NoBorder | WType_Dialog)
 {
   setFrameStyle(QFrame::WinPanel | QFrame::Raised);
   mPixmap = aPixmap;
@@ -59,7 +59,7 @@ void KoPixmapWidget::paintEvent(QPaintEvent *e)
 
 
 
-KoIconChooser::KoIconChooser(QSize aIconSize, QWidget *parent, const char *name):
+KoIconChooser::KoIconChooser(QSize aIconSize, QWidget *parent, const char *name, bool sort):
 QGridView(parent, name)
 {
   QGridView::setBackgroundColor(Qt::white);
@@ -70,7 +70,7 @@ QGridView(parent, name)
 
   mIconList.clear();
   mPixmapWidget = 0L;
-  nCols = 0;
+  mNCols = 0;
   mCurRow = 0;
   mCurCol = 0;
   mItemCount = 0;
@@ -78,6 +78,7 @@ QGridView(parent, name)
   mItemHeight = aIconSize.height();
   mMouseButtonDown = false;
   mDragEnabled = false;
+  mSort = sort;
 }
 
 KoIconChooser::~KoIconChooser()
@@ -90,11 +91,34 @@ KoIconChooser::~KoIconChooser()
 void KoIconChooser::addItem(KoIconItem *item)
 {
   Q_INT32 n = mItemCount;
+  KoIconItem *current = currentItem();
 
   Q_ASSERT(item);
-  mIconList.insert(mItemCount++, item);
+
+  int i;
+
+  if (mSort)
+  {
+    i = sortInsertionIndex(item);
+  }
+  else
+  {
+    i = mItemCount;
+  }
+
+  mIconList.insert(i, item);
+  mItemCount++;
   calculateCells();
-  updateCell(n / numCols(), n - (n / numCols()) * numCols());
+
+  if (mSort)
+  {
+    setCurrentItem(current);
+    updateContents();
+  }
+  else
+  {
+    updateCell(n / numCols(), n - (n / numCols()) * numCols());
+  }
 }
 
 bool KoIconChooser::removeItem(KoIconItem *item)
@@ -132,17 +156,19 @@ void KoIconChooser::setCurrentItem(KoIconItem *item)
   int index = mIconList.find(item);
 
   // item is available
-  if(index != -1 && nCols > 0)
+  if(index != -1 && mNCols > 0)
   {
     int oldRow = mCurRow;
     int oldCol = mCurCol;
 
-    mCurRow = index / nCols;
-    mCurCol = index % nCols;
+    mCurRow = index / mNCols;
+    mCurCol = index % mNCols;
 
     // repaint the old and the new item
-    updateCell(oldRow, oldCol);
-    updateCell(mCurRow, mCurCol);
+    repaintCell(oldRow, oldCol);
+    repaintCell(mCurRow, mCurCol);
+
+    ensureCellVisible(mCurRow, mCurCol);
   }
 }
 
@@ -155,26 +181,25 @@ void KoIconChooser::mousePressEvent(QMouseEvent *e)
   {
     QPoint p = e->pos();
     mDragStartPos = p;
-    int row = rowAt(contentsY() + p.y());
-    int col = columnAt(contentsX() + p.x());
+    int x = contentsX() + p.x();
+    int y = contentsY() + p.y();
+    QSize gridExtent = gridSize();
 
-    KoIconItem *item = itemAt(row, col);
-    if(item)
+    if (x < gridExtent.width() && y < gridExtent.height())
     {
-      const QPixmap &pix = item->pixmap();
-      if(pix.width() > mItemWidth || pix.height() > mItemHeight)
-      showFullPixmap(pix, p);
+      int row = rowAt(y);
+      int col = columnAt(x);
 
-      int oldRow = mCurRow;
-      int oldCol = mCurCol;
+      KoIconItem *item = itemAt(row, col);
+      if(item)
+      {
+        const QPixmap &pix = item->pixmap();
+        if(pix.width() > mItemWidth || pix.height() > mItemHeight)
+          showFullPixmap(pix, p);
 
-      mCurRow = row;
-      mCurCol = col;
-
-      updateCell(oldRow, oldCol);
-      updateCell(mCurRow, mCurCol);
-
-      emit selected( item );
+        setCurrentItem(item);
+        emit selected( item );
+      }
     }
   }
 }
@@ -223,14 +248,19 @@ void KoIconChooser::resizeEvent(QResizeEvent *e)
   QGridView::resizeEvent(e);
 
   KoIconItem *item = currentItem();
-  int oldNCols = nCols;
-  nCols = numCols();
+  int oldNCols = mNCols;
 
-  if(nCols != oldNCols)
+  if (cellWidth() != 0)
   {
-    setNumCols(nCols);
+    mNCols = e -> size().width() / cellWidth();
+  }
+
+  if(mNCols != oldNCols)
+  {
+    setNumCols(mNCols);
     calculateCells();
     setCurrentItem(item);
+    updateContents();
   }
 }
 
@@ -322,29 +352,76 @@ int KoIconChooser::cellIndex(int row, int col)
   if(row < 0 || col < 0)
     return -1;
   else
-    return((row * nCols) + col);
+    return((row * mNCols) + col);
 }
 
 // calculate the grid and set the number of rows and columns
 // reorder all items approrpriately
 void KoIconChooser::calculateCells()
 {
-  if(nCols == 0)
+  if(mNCols == 0)
     return;
   bool update = isUpdatesEnabled();
-  int rows = mItemCount / nCols;
+  int rows = mItemCount / mNCols;
   setUpdatesEnabled(false);
-  if((rows * nCols) < mItemCount)
+  if((rows * mNCols) < mItemCount)
     rows++;
   setNumRows(rows);
   setUpdatesEnabled(update);
-  repaint();
+  updateContents();
 }
 
 // show the full pixmap of a large item in an extra widget
 void KoIconChooser::showFullPixmap(const QPixmap &pix, const QPoint &/*p*/)
 {
-  mPixmapWidget = new KoPixmapWidget(pix, 0L);
+  mPixmapWidget = new KoPixmapWidget(pix, this);
+}
+
+int KoIconChooser::sortInsertionIndex(const KoIconItem *item)
+{
+  int index = 0;
+
+  if (!mIconList.isEmpty())
+  {
+    // Binary insertion
+    int first = 0;
+    int last = mIconList.count() - 1;
+    
+    while (first != last)
+    {
+      int middle = (first + last) / 2;
+    
+      if (item -> compare(mIconList.at(middle)) < 0)
+      {
+        last = middle - 1;
+
+        if (last < first)
+        {
+          last = first;
+        }
+      }
+      else
+      {
+        first = middle + 1;
+
+        if (first > last)
+        {
+          first = last;
+        }
+      }
+    }
+
+    if (item -> compare(mIconList.at(first)) < 0)
+    {
+      index = first;
+    }
+    else
+    {
+      index = first + 1;
+    }
+  }
+
+  return index;
 }
 
 KoPatternChooser::KoPatternChooser( const QPtrList<KoIconItem> &list, QWidget *parent, const char *name )
