@@ -27,6 +27,8 @@
 
 #include <kregexp.h>
 
+#include <../kofficecore/koffice_export.h>
+
 #include "koscript_context.h"
 #include "koscript_parsenode.h"
 #include "koscript_ptr.h"
@@ -42,7 +44,7 @@ class QIODevice;
  *
  * @author Torben Weis <weis@kde.org>
  */
-class KSInterpreter : public QShared
+class KOSCRIPT_EXPORT KSInterpreter : public QShared
 {
 public:
   typedef KSSharedPtr<KSInterpreter> Ptr;
@@ -61,6 +63,7 @@ public:
    * Reads the script @p filename from the hard disk and tries to execute it.
    *
    * @param args is the list of parameters passed to the main function
+   * @param filename is a string containing the name of the file to read
    *
    * @return the stringified exception or an empty string if everything was ok.
    *         This is a convenience function for @ref #runModule.
@@ -76,6 +79,8 @@ public:
    *        of "context" is deleted, you may no longer use the exception contained
    *        in "context". That means you may not extract the exception and destroy
    *        the KSContext object and then still use the exception object.
+   * @param filename is a string containing the name of the file to read
+   * @param name is the name of the module within the file
    * @param args is the list of parameters passed to the main function
    */
   bool runModule( KSContext& context, const QString& name, const QString& filename, const QStringList& args );
@@ -180,7 +185,7 @@ protected:
    */
   QTextStream* m_outStream;
   /**
-   * Used for @ref #m_stream
+   * Used for @ref #m_outStream
    */
   QIODevice* m_outDevice;
   /**
