@@ -739,8 +739,9 @@ bool KSEval_func_dcl( KSParseNode* node, KSContext& context )
   // Are parameters left ?
   if ( !context.value()->listValue().isEmpty() )
   {
-    QString tmp( i18n("%1 arguments are not needed") );
-    context.setException( new KSException( "TooManyArguments", tmp.arg( context.value()->listValue().count() ), node->getLineNo() ) );
+    // x-gettext: no-c-format
+    const QString tmp( i18n("1 argument is not needed", "%n arguments are not needed", context.value()->listValue().count() ) );
+    context.setException( new KSException( "TooManyArguments", tmp, node->getLineNo() ) );
     context.scope()->popLocalScope();
     return false;
   }
@@ -2126,8 +2127,9 @@ bool KSEval_destructor_dcl( KSParseNode* node, KSContext& context )
   // Are parameters left ?
   if ( !context.value()->listValue().isEmpty() )
   {
-    QString tmp( i18n("%1 arguments are not needed") );
-    context.setException( new KSException( "TooManyArguments", tmp.arg( context.value()->listValue().count() ), node->getLineNo() ) );
+    // x-gettext: no-c-format
+    const QString tmp( i18n("1 argument is not needed", "%n arguments are not needed", context.value()->listValue().count() ) );
+    context.setException( new KSException( "TooManyArguments", tmp, node->getLineNo() ) );
     context.scope()->popLocalScope();
     return false;
   }
