@@ -32,7 +32,8 @@
 #include "koparagcounter.h"
 #include <knuminput.h>
 #include <qgroupbox.h>
-
+#include <qvgroupbox.h>
+#include <koffice_export.h>
 class KButtonBox;
 class KColorButton;
 class KoTextDocument;
@@ -60,7 +61,7 @@ class QVBoxLayout;
  * that handles modifying a part of a KoParagLayout.
  * Used by the paragraph dialog (this file) and by the style editor.
  */
-class KoParagLayoutWidget : public QWidget
+class KOTEXT_EXPORT KoParagLayoutWidget : public QWidget
 {
     Q_OBJECT
 public:
@@ -95,11 +96,11 @@ private:
 /**
  * The widget for editing idents and spacings (tab 1)
  */
-class KoIndentSpacingWidget : public KoParagLayoutWidget
+class KOTEXT_EXPORT KoIndentSpacingWidget : public KoParagLayoutWidget
 {
     Q_OBJECT
 public:
-    KoIndentSpacingWidget( KoUnit::Unit unit, bool breakLine, double _frameWidth, QWidget * parent,const char * name = 0 );
+    KoIndentSpacingWidget( KoUnit::Unit unit, double _frameWidth, QWidget * parent,const char * name = 0 );
     virtual ~KoIndentSpacingWidget() {}
 
     virtual void display( const KoParagLayout & lay );
@@ -113,7 +114,6 @@ public:
     double spaceBeforeParag() const;
     double spaceAfterParag() const;
     double lineSpacing() const;
-    int pageBreaking() const;
     KoParagLayout::SpacingType lineSpacingType() const;
 private slots:
     void leftChanged( double );
@@ -128,7 +128,6 @@ private:
 
     KDoubleNumInput *eLeft, *eRight, *eFirstLine, *eBefore, *eAfter, *eSpacing;
     QComboBox *cSpacing;
-    QCheckBox *cKeepLinesTogether, *cHardBreakBefore, *cHardBreakAfter;
     KPagePreview *prev1;
     KoUnit::Unit m_unit;
 };
@@ -136,18 +135,19 @@ private:
 /**
  * The widget for editing paragraph alignment (tab 2)
  */
-class KoParagAlignWidget : public KoParagLayoutWidget
+class KOTEXT_EXPORT KoParagAlignWidget : public KoParagLayoutWidget
 {
     Q_OBJECT
 public:
-    KoParagAlignWidget( QWidget * parent, const char * name = 0 );
+    KoParagAlignWidget(bool breakLine, QWidget * parent, const char * name = 0 );
     virtual ~KoParagAlignWidget() {}
 
     virtual void display( const KoParagLayout & lay );
     virtual void save( KoParagLayout & lay );
     //virtual bool isModified();
     virtual QString tabName();
-
+    
+    int pageBreaking() const;
     int align() const;
 
 protected slots:
@@ -161,13 +161,14 @@ protected:
 
 private:
     QRadioButton *rLeft, *rCenter, *rRight, *rJustify;
+    QCheckBox *cKeepLinesTogether, *cHardBreakBefore, *cHardBreakAfter;
     KPagePreview2 *prev2;
 };
 
 /**
  * The widget for editing paragraph borders (tab 3)
  */
-class KoParagBorderWidget : public KoParagLayoutWidget
+class KOTEXT_EXPORT KoParagBorderWidget : public KoParagLayoutWidget
 {
     Q_OBJECT
 public:
@@ -205,7 +206,7 @@ private:
     KoBorderPreview *prev3;
 };
 
-class KoCounterStyleWidget : public QWidget
+class KOTEXT_EXPORT KoCounterStyleWidget : public QWidget
 {
     Q_OBJECT
 public:
@@ -233,7 +234,7 @@ public:
     void display( const KoParagLayout & lay );
     void changeKWSpinboxType(KoParagCounter::Style st);
     const KoParagCounter & counter() const { return m_counter; }
-    void setCounter (KoParagCounter counter );
+    void setCounter( const KoParagCounter& counter );
 
 public slots:
     void numTypeChanged( int nType );
@@ -286,7 +287,7 @@ private:
 /**
  * The widget for editing counters (bullets & numbering) (tab 4)
  */
-class KoParagCounterWidget : public KoParagLayoutWidget
+class KOTEXT_EXPORT KoParagCounterWidget : public KoParagLayoutWidget
 {
     Q_OBJECT
 public:
@@ -345,7 +346,7 @@ protected:
 /**
  * The widget for editing tabulators (tab 5)
  */
-class KoParagTabulatorsWidget : public KoParagLayoutWidget
+class KOTEXT_EXPORT KoParagTabulatorsWidget : public KoParagLayoutWidget
 {
     Q_OBJECT
 public:
@@ -415,7 +416,7 @@ public:
 
     /** Apply the given @p style to the preview.
      * Note that this overwrites anything done by setCounter. */
-    void setStyle( KoStyle *style );
+    void setStyle( KoParagStyle *style );
 
     /** Set the given @p counter to the preview. */
     void setCounter( const KoParagCounter & counter );
@@ -433,7 +434,7 @@ protected:
  * (*) the flags (to only show parts of it) have been kept just in case
  * but are not currently used.
  */
-class KoParagDia : public KDialogBase
+class KOTEXT_EXPORT KoParagDia : public KDialogBase
 {
     Q_OBJECT
 
@@ -447,6 +448,7 @@ public:
     KoParagDia( QWidget*, const char*, int flags, KoUnit::Unit unit, double _frameWidth=-1,bool breakLine=true, bool disableAll = false);
     ~KoParagDia();
 
+    /** Flags passed to constructor */
     int getFlags()const { return m_flags; }
 
     /** Make a given page the current one - @p page is a flag (PD_something) value */
@@ -463,10 +465,10 @@ public:
     double spaceAfterParag() const { return m_indentSpacingWidget->spaceAfterParag(); }
     double lineSpacing() const { return m_indentSpacingWidget->lineSpacing(); }
     KoParagLayout::SpacingType lineSpacingType() const{ return m_indentSpacingWidget->lineSpacingType(); }
-    int pageBreaking() const { return m_indentSpacingWidget->pageBreaking(); }
 
     // tab 2
     int align() const { return m_alignWidget->align(); }
+    int pageBreaking() const { return m_alignWidget->pageBreaking(); }
 
     // tab 3
     KoBorder leftBorder() const { return m_borderWidget->leftBorder(); }
@@ -497,6 +499,9 @@ public:
                                            oldLayout.topBorder!=topBorder() ||
                                            oldLayout.bottomBorder!=bottomBorder() ); }
     bool listTabulatorChanged() const {return oldLayout.tabList()!=tabListTabulator();}
+    KoParagLayout paragLayout() const;
+    /// @return the set of flags which were changed
+    int changedFlags() const;
 
 protected slots:
     void slotReset();
