@@ -47,7 +47,8 @@
    When an orig entry is empty and the other is not, a new one has to be made,
    when the orig is present and the other is not, the orig has to be deleted.
    Otherwise all changes are copied from the changed ones to the origs on OK.
-   OK also frees all the changed ones and updates the doc if styles are deleted.
+   OK updates the doc if styles are deleted.
+   The dtor frees all the changed ones.
 */
 /* Months later the above seems SOO stupid.. Just should have created a small class
    containing the orig and the copy and an enum plus some simple methods..
@@ -60,7 +61,9 @@ public:
     QCheckBox* cbIncludeInTOC;
 };
 
-KoStyleManager::KoStyleManager( QWidget *_parent,KoUnit::Unit unit, const QPtrList<KoStyle> & style, const QString & activeStyleName)
+KoStyleManager::KoStyleManager( QWidget *_parent, KoUnit::Unit unit,
+                                const QPtrList<KoParagStyle> & style, const QString & activeStyleName,
+                                int flags )
     : KDialogBase( _parent, "Stylist", true,
                    i18n("Style Manager"),
                    KDialogBase::Ok | KDialogBase::Cancel | KDialogBase::Apply )
@@ -72,16 +75,16 @@ KoStyleManager::KoStyleManager( QWidget *_parent,KoUnit::Unit unit, const QPtrLi
     m_origStyles.setAutoDelete(false);
     m_changedStyles.setAutoDelete(false);
     setupWidget(style); // build the widget with the buttons and the list selector.
-    addGeneralTab();
+    addGeneralTab( flags );
     KoStyleFontTab * fontTab = new KoStyleFontTab( m_tabs );
     addTab( fontTab );
 
     KoStyleParagTab *newTab = new KoStyleParagTab( m_tabs );
-    newTab->setWidget( new KoIndentSpacingWidget( unit, true,-1/*no limit*/,newTab ) );
+    newTab->setWidget( new KoIndentSpacingWidget( unit, -1/*no limit*/,newTab ) );
     addTab( newTab );
 
     newTab = new KoStyleParagTab( m_tabs );
-    newTab->setWidget( new KoParagAlignWidget( newTab ) );
+    newTab->setWidget( new KoParagAlignWidget( true, newTab ) );
     addTab( newTab );
 
     newTab = new KoStyleParagTab( m_tabs );
@@ -109,6 +112,13 @@ KoStyleManager::KoStyleManager( QWidget *_parent,KoUnit::Unit unit, const QPtrLi
 
 KoStyleManager::~KoStyleManager()
 {
+    for (unsigned int i =0 ; m_origStyles.count() > i ; i++) {
+        KoParagStyle *orig = m_origStyles.at(i);
+        KoParagStyle *changed = m_changedStyles.at(i);
+        if( orig && changed && orig != changed ) // modified style, we can delete the changed one now that changes have been applied
+            delete changed;
+    }
+
     delete d;
 }
 
@@ -119,17 +129,17 @@ void KoStyleManager::addTab( KoStyleManagerTab * tab )
     tab->layout()->activate();
 }
 
-void KoStyleManager::setupWidget(const QPtrList<KoStyle> & styleList)
+void KoStyleManager::setupWidget(const QPtrList<KoParagStyle> & styleList)
 {
     QFrame * frame1 = makeMainWidget();
     QGridLayout *frame1Layout = new QGridLayout( frame1, 0, 0, // auto
                                                  KDialog::marginHint(), KDialog::spacingHint() );
-    QPtrListIterator<KoStyle> style( styleList );
+    QPtrListIterator<KoParagStyle> style( styleList );
     numStyles = styleList.count();
     m_stylesList = new QListBox( frame1, "stylesList" );
     for ( ; style.current() ; ++style )
     {
-        m_stylesList->insertItem( style.current()->translatedName() );
+        m_stylesList->insertItem( style.current()->displayName() );
         m_origStyles.append( style.current() );
         m_changedStyles.append( style.current() );
         m_styleOrder<< style.current()->name();
@@ -139,12 +149,12 @@ void KoStyleManager::setupWidget(const QPtrList<KoStyle> & styleList)
 
 
     m_moveUpButton = new QPushButton( frame1, "moveUpButton" );
-    m_moveUpButton->setPixmap( BarIcon( "up", KIcon::SizeSmall ) );
+    m_moveUpButton->setIconSet( SmallIconSet( "up" ) );
     connect( m_moveUpButton, SIGNAL( clicked() ), this, SLOT( moveUpStyle() ) );
     frame1Layout->addWidget( m_moveUpButton, 1, 1 );
 
     m_moveDownButton = new QPushButton( frame1, "moveDownButton" );
-    m_moveDownButton->setPixmap( BarIcon( "down", KIcon::SizeSmall ) );
+    m_moveDownButton->setIconSet( SmallIconSet( "down" ) );
     connect( m_moveDownButton, SIGNAL( clicked() ), this, SLOT( moveDownStyle() ) );
     frame1Layout->addWidget( m_moveDownButton, 1, 0 );
 
@@ -168,7 +178,7 @@ void KoStyleManager::setupWidget(const QPtrList<KoStyle> & styleList)
     connect( m_tabs, SIGNAL( currentChanged ( QWidget * ) ), this, SLOT( switchTabs() ) );
 }
 
-void KoStyleManager::addGeneralTab() {
+void KoStyleManager::addGeneralTab( int flags ) {
     QWidget *tab = new QWidget( m_tabs );
 
     QGridLayout *tabLayout = new QGridLayout( tab );
@@ -207,12 +217,19 @@ void KoStyleManager::addGeneralTab() {
 
     tabLayout->addWidget( inheritStyleLabel, 2, 0 );
 
-    d->cbIncludeInTOC = new QCheckBox( i18n("Include in table of contents"), tab );
-    tabLayout->addMultiCellWidget( d->cbIncludeInTOC, 3, 3, 0, 1 );
+    int row = 3;
 
-    d->preview = new KoStylePreview( i18n( "Preview" ), i18n( "The quick brown fox jumps over the lazy dog" ), tab, "stylepreview" );
+    if ( flags & ShowIncludeInToc ) {
+        d->cbIncludeInTOC = new QCheckBox( i18n("Include in table of contents"), tab );
+        tabLayout->addMultiCellWidget( d->cbIncludeInTOC, row, row, 0, 1 );
+        ++row;
+    } else {
+        d->cbIncludeInTOC = 0;
+    }
 
-    tabLayout->addMultiCellWidget( d->preview, 4, 4, 0, 1 );
+    d->preview = new KoStylePreview( i18n( "Preview" ), i18n( "The quick brown fox jumps over the lazy dog. And, what about the cat, one may ask? Well, the cat is playing cards with the mouse, the bird and the fish. It is, to say the least a hell of a party!" ), tab, "stylepreview" );
+
+    tabLayout->addMultiCellWidget( d->preview, row, row, 0, 1 );
 
     m_tabs->insertTab( tab, i18n( "General" ) );
 
@@ -237,7 +254,7 @@ void KoStyleManager::switchStyle() {
     int num = styleIndex( m_stylesList->currentItem() );
     kdDebug(32500) << "KoStyleManager::switchStyle switching to " << num << endl;
     if(m_origStyles.at(num) == m_changedStyles.at(num)) {
-        m_currentStyle = new KoStyle( *m_origStyles.at(num) );
+        m_currentStyle = new KoParagStyle( *m_origStyles.at(num) );
         m_changedStyles.take(num);
         m_changedStyles.insert(num, m_currentStyle);
     } else {
@@ -265,7 +282,7 @@ int KoStyleManager::styleIndex( int pos ) {
     int p = 0;
     for(unsigned int i=0; i < m_changedStyles.count(); i++) {
         // Skip deleted styles, they're no in m_stylesList anymore
-        KoStyle * style = m_changedStyles.at(i);
+        KoParagStyle * style = m_changedStyles.at(i);
         if ( !style ) continue;
         if ( p == pos )
             return i;
@@ -290,9 +307,9 @@ void KoStyleManager::updateGUI() {
         it.current()->update();
     }
 
-    m_nameString->setText(m_currentStyle->translatedName());
+    m_nameString->setText(m_currentStyle->displayName());
 
-    QString followingName = m_currentStyle->followingStyle() ? m_currentStyle->followingStyle()->translatedName() : QString::null;
+    QString followingName = m_currentStyle->followingStyle() ? m_currentStyle->followingStyle()->displayName() : QString::null;
     kdDebug(32500) << "KoStyleManager::updateGUI updating combo to " << followingName << endl;
     for ( int i = 0; i < m_styleCombo->count(); i++ ) {
         if ( m_styleCombo->text( i ) == followingName ) {
@@ -302,7 +319,7 @@ void KoStyleManager::updateGUI() {
         }
     }
 
-    QString inheritName = m_currentStyle->parentStyle() ? m_currentStyle->parentStyle()->translatedName() : QString::null;
+    QString inheritName = m_currentStyle->parentStyle() ? m_currentStyle->parentStyle()->displayName() : QString::null;
     kdDebug(32500) << "KoStyleManager::updateGUI updating combo to " << inheritName << endl;
     for ( int i = 0; i < m_inheritCombo->count(); i++ ) {
         if ( m_inheritCombo->text( i ) == inheritName ) {
@@ -314,7 +331,8 @@ void KoStyleManager::updateGUI() {
             m_inheritCombo->setCurrentItem( 0 );//none !!!
     }
 
-    d->cbIncludeInTOC->setChecked( m_currentStyle->isOutline() );
+    if ( d->cbIncludeInTOC )
+        d->cbIncludeInTOC->setChecked( m_currentStyle->isOutline() );
 
     // update delete button (can't delete first style);
     m_deleteButton->setEnabled(m_stylesList->currentItem() != 0);
@@ -339,26 +357,25 @@ void KoStyleManager::save() {
             it.current()->save();
 
 	// Rename the style - only if it's actually been renamed.
-	// Take care of not renaming a style from its English name to its translated name by mistake,
-	// this would break the TOC stuff.
         if ( m_currentStyle->name() != m_nameString->text() &&
-            m_currentStyle->translatedName() != m_nameString->text() )
+            m_currentStyle->displayName() != m_nameString->text() )
         {
-            m_currentStyle->setName( m_nameString->text() );
+            m_currentStyle->setDisplayName( m_nameString->text() );
         }
 
         int indexNextStyle = styleIndex( m_styleCombo->currentItem() );
         m_currentStyle->setFollowingStyle( m_origStyles.at( indexNextStyle ) ); // point to orig, not changed! (#47377)
         m_currentStyle->setParentStyle( style( m_inheritCombo->currentText() ) );
-        m_currentStyle->setOutline( d->cbIncludeInTOC->isChecked() );
+        if ( d->cbIncludeInTOC )
+            m_currentStyle->setOutline( d->cbIncludeInTOC->isChecked() );
     }
 }
 
-KoStyle * KoStyleManager::style( const QString & _name )
+KoParagStyle * KoStyleManager::style( const QString & _name )
 {
     for(unsigned int i=0; i < m_changedStyles.count(); i++) {
         // Skip deleted styles, they're no in m_stylesList anymore
-        KoStyle * style = m_changedStyles.at(i);
+        KoParagStyle * style = m_changedStyles.at(i);
         if ( !style ) continue;
         if ( style->name() == _name)
             return style;
@@ -366,17 +383,29 @@ KoStyle * KoStyleManager::style( const QString & _name )
     return 0;
 }
 
+QString KoStyleManager::generateUniqueName()
+{
+    int count = 1;
+    QString name;
+    do {
+        name = "new" + QString::number( count++ );
+    } while ( style( name ) );
+    return name;
+}
+
+
 void KoStyleManager::addStyle() {
     save();
 
     QString str = i18n( "New Style Template (%1)" ).arg(numStyles++);
     if ( m_currentStyle )
     {
-        m_currentStyle = new KoStyle( *m_currentStyle ); // Create a new style, initializing from the current one
-        m_currentStyle->setName( str );
+        m_currentStyle = new KoParagStyle( *m_currentStyle ); // Create a new style, initializing from the current one
+        m_currentStyle->setDisplayName( str );
+        m_currentStyle->setInternalName( generateUniqueName() );
     }
     else
-        m_currentStyle = new KoStyle( str );
+        m_currentStyle = new KoParagStyle( str );
     m_currentStyle->setFollowingStyle( m_currentStyle ); // #45868
 
     noSignals=true;
@@ -387,14 +416,14 @@ void KoStyleManager::addStyle() {
     m_inheritCombo->insertItem( str );
     m_stylesList->setCurrentItem( m_stylesList->count() - 1 );
     noSignals=false;
-    m_styleOrder<< str;
+    m_styleOrder << m_currentStyle->name();
 
     updateGUI();
 }
 
-void KoStyleManager::updateFollowingStyle( KoStyle *s )
+void KoStyleManager::updateFollowingStyle( KoParagStyle *s )
 {
-    for ( KoStyle* p = m_changedStyles.first(); p != 0L; p = m_changedStyles.next() )
+    for ( KoParagStyle* p = m_changedStyles.first(); p != 0L; p = m_changedStyles.next() )
     {
         if ( p->followingStyle() == s)
             p->setFollowingStyle(p);
@@ -402,9 +431,9 @@ void KoStyleManager::updateFollowingStyle( KoStyle *s )
 
 }
 
-void KoStyleManager::updateInheritStyle( KoStyle *s )
+void KoStyleManager::updateInheritStyle( KoParagStyle *s )
 {
-    for ( KoStyle* p = m_changedStyles.first(); p != 0L; p = m_changedStyles.next() )
+    for ( KoParagStyle* p = m_changedStyles.first(); p != 0L; p = m_changedStyles.next() )
     {
         //when we remove style, we must replace inherite style to 0L
         //when parent style was removed.
@@ -420,7 +449,7 @@ void KoStyleManager::deleteStyle() {
     unsigned int cur = styleIndex( m_stylesList->currentItem() );
     unsigned int curItem = m_stylesList->currentItem();
     QString name = m_stylesList->currentText();
-    KoStyle *s = m_changedStyles.at(cur);
+    KoParagStyle *s = m_changedStyles.at(cur);
     m_styleOrder.remove( s->name());
     updateFollowingStyle( s );
     updateInheritStyle( s );
@@ -443,11 +472,11 @@ void KoStyleManager::deleteStyle() {
 
 void KoStyleManager::moveUpStyle()
 {
+    Q_ASSERT( m_currentStyle );
     if ( m_currentStyle )
         save();
-    unsigned int pos = 0;
-    QString currentStyleName=m_stylesList->currentText ();
-
+    const QString currentStyleName = m_currentStyle->name();
+    const QString currentStyleDisplayName = m_stylesList->currentText();
     int pos2 = m_styleOrder.findIndex( currentStyleName );
     if ( pos2 != -1 )
     {
@@ -455,13 +484,13 @@ void KoStyleManager::moveUpStyle()
         m_styleOrder.insert( m_styleOrder.at(pos2-1), currentStyleName);
     }
 
-    pos=m_stylesList->currentItem();
+    int pos = m_stylesList->currentItem();
     noSignals=true;
     m_stylesList->changeItem( m_stylesList->text( pos-1 ), pos );
     m_styleCombo->changeItem( m_stylesList->text( pos-1 ), pos );
 
-    m_stylesList->changeItem( currentStyleName, pos-1 );
-    m_styleCombo->changeItem( currentStyleName, pos-1 );
+    m_stylesList->changeItem( currentStyleDisplayName, pos-1 );
+    m_styleCombo->changeItem( currentStyleDisplayName, pos-1 );
 
     m_stylesList->setCurrentItem( m_stylesList->currentItem() );
     noSignals=false;
@@ -471,10 +500,11 @@ void KoStyleManager::moveUpStyle()
 
 void KoStyleManager::moveDownStyle()
 {
+    Q_ASSERT( m_currentStyle );
     if ( m_currentStyle )
         save();
-    unsigned int pos = 0;
-    QString currentStyleName=m_stylesList->currentText ();
+    const QString currentStyleName = m_currentStyle->name();
+    const QString currentStyleDisplayName = m_stylesList->currentText();
     int pos2 = m_styleOrder.findIndex( currentStyleName );
     if ( pos2 != -1 )
     {
@@ -482,13 +512,12 @@ void KoStyleManager::moveDownStyle()
         m_styleOrder.insert( m_styleOrder.at(pos2+1), currentStyleName);
     }
 
-
-    pos=m_stylesList->currentItem();
+    int pos = m_stylesList->currentItem();
     noSignals=true;
-    m_stylesList->changeItem( m_stylesList->text ( pos+1 ),pos);
-    m_styleCombo->changeItem( m_stylesList->text ( pos+1 ),pos);
-    m_stylesList->changeItem( currentStyleName ,pos+1);
-    m_styleCombo->changeItem( currentStyleName ,pos+1);
+    m_stylesList->changeItem( m_stylesList->text( pos+1 ), pos );
+    m_styleCombo->changeItem( m_stylesList->text( pos+1 ), pos );
+    m_stylesList->changeItem( currentStyleDisplayName, pos+1 );
+    m_styleCombo->changeItem( currentStyleDisplayName, pos+1 );
     m_stylesList->setCurrentItem( m_stylesList->currentItem() );
     noSignals=false;
 
@@ -509,30 +538,28 @@ void KoStyleManager::slotApply() {
 
 void KoStyleManager::apply() {
     noSignals=true;
-    StyleChangeDefMap styleChanged;
-    QPtrList<KoStyle> removeStyle;
+    KoStyleChangeDefMap styleChanged;
+    QPtrList<KoParagStyle> removeStyle;
     for (unsigned int i =0 ; m_origStyles.count() > i ; i++) {
         if(m_origStyles.at(i) == 0L && m_changedStyles.at(i)!=0L) {           // newly added style
             kdDebug(32500) << "adding new " << m_changedStyles.at(i)->name() << " (" << i << ")" << endl;
-            KoStyle *tmp = addStyleTemplate(m_changedStyles.take(i));
+            KoParagStyle *tmp = addStyleTemplate(m_changedStyles.take(i));
             m_changedStyles.insert(i, tmp);
         } else if(m_changedStyles.at(i) == 0L && m_origStyles.at(i) != 0L) { // deleted style
             kdDebug(32500) << "deleting orig " << m_origStyles.at(i)->name() << " (" << i << ")" << endl;
 
-            KoStyle *orig = m_origStyles.at(i);
+            KoParagStyle *orig = m_origStyles.at(i);
             //applyStyleChange( orig, -1, -1 );
-            StyleChangeDef tmp( -1,-1);
+            KoStyleChangeDef tmp( -1,-1);
             styleChanged.insert( orig, tmp);
 
             removeStyle.append( orig );
             // Note that the style is never deleted (we'll need it for undo/redo purposes)
 
-        } else if(m_changedStyles.at(i) != 0L && m_origStyles.at(i)!=0L) {
+        } else if(m_changedStyles.at(i) != 0L && m_origStyles.at(i)!=0L) { // simply updated style
             kdDebug(32500) << "update style " << m_changedStyles.at(i)->name() << " (" << i << ")" << endl;
-                                                // simply updated style
-            KoStyle *orig = m_origStyles.at(i);
-            KoStyle *changed = m_changedStyles.at(i);
-
+            KoParagStyle *orig = m_origStyles.at(i);
+            KoParagStyle *changed = m_changedStyles.at(i);
             if ( orig != changed )
             {
                 int paragLayoutChanged = orig->paragLayout().compare( changed->paragLayout() );
@@ -546,9 +573,10 @@ void KoStyleManager::apply() {
                 // Apply the change selectively - i.e. only what changed
                 //applyStyleChange( orig, paragLayoutChanged, formatChanged );
                 if ( formatChanged != 0 || paragLayoutChanged != 0 ) {
-                  StyleChangeDef tmp(paragLayoutChanged, formatChanged);
-                  styleChanged.insert( orig, tmp );
+                    KoStyleChangeDef tmp(paragLayoutChanged, formatChanged);
+                    styleChanged.insert( orig, tmp );
                 }
+
             }
 
         }// else
@@ -557,11 +585,11 @@ void KoStyleManager::apply() {
 
     applyStyleChange( styleChanged );
 
-    KoStyle *tmp = 0L;
+    KoParagStyle *tmp = 0L;
     for ( tmp = removeStyle.first(); tmp ;tmp = removeStyle.next() )
         removeStyleTemplate( tmp );
 
-    updateStyleListOrder( m_styleOrder);
+    updateStyleListOrder( m_styleOrder );
     updateAllStyleLists();
     noSignals=false;
 }
@@ -577,7 +605,7 @@ void KoStyleManager::renameStyle(const QString &theText) {
     kdDebug(32500) << "KoStyleManager::renameStyle before " << m_styleCombo->currentText() << endl;
     m_styleCombo->changeItem( theText, index );
     m_inheritCombo->changeItem( theText, index+1 );
-    m_styleOrder[index]=theText;
+    //m_styleOrder[index]=theText; // not needed anymore, we use internal names
     kdDebug(32500) << "KoStyleManager::renameStyle after " << m_styleCombo->currentText() << endl;
     m_stylesList->changeItem( theText, index );
 
