@@ -18,9 +18,13 @@
 */
 
 #include <qstring.h>
-class KoTextParag;
+#include <koffice_export.h>
 class QDomElement;
+class KoXmlWriter;
+class KoGenStyle;
+class KoTextParag;
 class KoTextFormat;
+class KoOasisContext;
 
 #ifndef koparagcounter_h
 #define koparagcounter_h
@@ -29,7 +33,7 @@ class KoTextFormat;
  * This is the structure associated with a paragraph (KoTextParag),
  * to define the bullet or numbering of the paragraph.
  */
-class KoParagCounter
+class KOTEXT_EXPORT KoParagCounter
 {
 public:
     KoParagCounter();
@@ -63,9 +67,26 @@ public:
      */
     int bulletX();
 
-    /** XML support. */
+    /// KOffice-1.3 loading code
     void load( QDomElement & element );
+    /// KOffice-1.3 saving code
     void save( QDomElement & element );
+    /** Load from OASIS XML
+     * @param heading true if heading, false if normal list
+     * @param level 1-based
+     * @param loadingStyle true if loading a style, false if loading a paragraph
+     */
+    void loadOasis( KoOasisContext& context, int restartNumbering, bool orderedList, bool heading, int level, bool loadingStyle = false );
+    /// Part of loadOasis that is shared with KWVariableSettings::loadOasis for footnotes/endnotes
+    void loadOasisListStyle( const QDomElement& listStyle,
+                             const QDomElement& listStyleProperties,
+                             int restartNumbering,
+                             bool orderedList, bool heading, int level, bool loadingStyle );
+    /// Save as OASIS XML
+    void saveOasis( KoGenStyle& listStyle, bool savingStyle = false ) const;
+    /// Part of saveOasis that is shared with KoStyleCollection::saveOasisOutlineStyles
+    /// and KWVariableSettings::saveOasis for footnotes/endnotes
+    void saveOasisListLevel( KoXmlWriter& listLevelWriter, bool includeLevelAndProperties, bool savingStyle = false ) const;
 
     bool operator==( const KoParagCounter & c2 ) const;
     bool operator!=( const KoParagCounter & c2 ) const { return !(*this == c2); }
@@ -165,6 +186,10 @@ public:
     static int fromAlphaUpperNumber( const QString & );
     static int fromAlphaLowerNumber( const QString & );
 
+#ifndef NDEBUG
+    void printRTDebug( KoTextParag* parag );
+#endif
+
 private:
 
     /** Return our parent paragraph, if there is such a thing. For a paragraph "1.1.",
@@ -172,15 +197,13 @@ private:
      */
     KoTextParag *parent( const KoTextParag *paragraph );
 
-    char m_numbering; // Numbering
-    char m_style;     // Style
+    Numbering m_numbering:3; // Numbering (maximum value: 8)
+    bool m_restartCounter:1;
+    bool unused:4;
+    Style m_style:8;     // Style
     char m_displayLevels; // Number of levels to display (e.g. 3 => 1.2.1)
     char m_depth;
 
-    bool m_restartCounter;
-    char unused; // padding, feel free to use
-    short int padding; // padding, feel free to use
-
     short int m_startNumber;
     QChar m_customBulletChar;
 
