@@ -117,7 +117,7 @@ void KoStyleCollection::loadOasisStyleTemplates( KoOasisContext& context )
     Q_ASSERT( findStyle( "Standard" ) );
 }
 
-QMap<KoParagStyle*, QString> KoStyleCollection::saveOasis( KoGenStyles& styles, int styleType ) const
+QMap<KoParagStyle*, QString> KoStyleCollection::saveOasis( KoGenStyles& styles, int styleType, KoSavingContext& context ) const
 {
     // Remember the style names (the automatic names generated by KoGenStyles)
     QMap<KoParagStyle*, QString> autoNames;
@@ -129,7 +129,7 @@ QMap<KoParagStyle*, QString> KoStyleCollection::saveOasis( KoGenStyles& styles,
     QString refStyleName;
 
     for( QPtrListIterator<KoParagStyle> p( m_styleList ); *p; ++p ) {
-        const QString name = (*p)->saveStyle( styles, styleType, refStyleName );
+        const QString name = (*p)->saveStyle( styles, styleType, refStyleName, context );
         kdDebug() << k_funcinfo << "Saved style " << (*p)->displayName() << " to OASIS format as " << name << endl;
         autoNames.insert( *p, name );
         if ( refStyleName.isEmpty() ) // i.e. first style
@@ -568,7 +568,7 @@ void KoParagStyle::loadStyle( QDomElement & styleElem, KoOasisContext& context )
     context.styleStack().restore();
 }
 
-QString KoParagStyle::saveStyle( KoGenStyles& genStyles, int styleType, const QString& parentStyleName ) const
+QString KoParagStyle::saveStyle( KoGenStyles& genStyles, int styleType, const QString& parentStyleName, KoSavingContext& context ) const
 {
     KoGenStyle gs( styleType, "paragraph", parentStyleName );
 
@@ -580,20 +580,23 @@ QString KoParagStyle::saveStyle( KoGenStyles& genStyles, int styleType, const QS
             // ### kword-specific attribute, see loadOasis
             gs.addAttribute( "style:default-level", (int)m_paragLayout.counter->depth() + 1 );
 
-        KoGenStyle listStyle( KoGenStyle::STYLE_LIST /*, no family*/ );
-        m_paragLayout.counter->saveOasis( listStyle, true );
-        // This display-name will probably look nicer in OO, but this also means
-        // no re-use possible between list styles...
-        listStyle.addAttribute( "style:display-name",
-                                i18n( "Numbering Style for %1" ).arg( m_displayName ) );
+        if ( m_paragLayout.counter->style() != KoParagCounter::STYLE_NONE )
+        {
+            KoGenStyle listStyle( KoGenStyle::STYLE_LIST /*, no family*/ );
+            m_paragLayout.counter->saveOasis( listStyle, true );
+            // This display-name will probably look nicer in OO, but this also means
+            // no re-use possible between list styles...
+            listStyle.addAttribute( "style:display-name",
+                                    i18n( "Numbering Style for %1" ).arg( m_displayName ) );
 
-        QString autoListStyleName = genStyles.lookup( listStyle, "L", true );
-        gs.addAttribute( "style:list-style-name", autoListStyleName );
+            QString autoListStyleName = genStyles.lookup( listStyle, "L", true );
+            gs.addAttribute( "style:list-style-name", autoListStyleName );
+        }
     }
 
-    m_paragLayout.saveOasis( gs, true );
+    m_paragLayout.saveOasis( gs, context, true );
 
-    m_format.save( gs );
+    m_format.save( gs, context );
 
     // try to preserve existing internal name, if it looks adequate (no spaces)
     // ## TODO: check XML-Schemacs NCName conformity
