@@ -22,7 +22,7 @@
 #define KOTEXTDOCUMENT_H
 
 #include "korichtext.h"
-
+#include <koffice_export.h>
 #if defined(Q_TEMPLATEDLL)
 // MOC_SKIP_BEGIN
 template class Q_EXPORT QMap<int, QColor>;
@@ -32,6 +32,9 @@ template class Q_EXPORT QPtrList<KoTextDocument>;
 // MOC_SKIP_END
 #endif
 
+class KoStyleCollection;
+class KoXmlWriter;
+class KoGenStyles;
 class KoZoomHandler;
 class KoTextFormatCollection;
 class KoParagVisitor;
@@ -39,7 +42,7 @@ class KoTextFormatter;
 class KoTextParag;
 class CustomItemsMap;
 
-class Q_EXPORT KoTextDocument : public QObject
+class KOTEXT_EXPORT KoTextDocument : public QObject
 {
     Q_OBJECT
 
@@ -49,6 +52,8 @@ class Q_EXPORT KoTextDocument : public QObject
 public:
     enum SelectionIds {
 	Standard = 0,
+        InputMethodPreedit = 1,
+        // 2 is taken by kotextobject (HighlightSelection)
 	Temp = 32000 // This selection must not be drawn, it's used e.g. by undo/redo to
 	// remove multiple lines with removeSelectedText()
     };
@@ -62,8 +67,8 @@ public:
 
     void setText( const QString &text, const QString &context );
 
-    QString text() const;
-    QString text( int parag ) const;
+    //QString text() const;
+    //QString text( int parag ) const;
     //QString originalText() const;
 
     int x() const;
@@ -95,9 +100,6 @@ public:
     void setFormatter( KoTextFormatterBase *f );
     KoTextFormatterBase *formatter() const;
 
-    void setIndent( KoTextIndent *i );
-    KoTextIndent *indent() const;
-
     QColor selectionColor( int id ) const;
     bool invertSelectionText( int id ) const;
     void setSelectionColor( int id, const QColor &c );
@@ -121,7 +123,6 @@ public:
     QString selectedText( int id, bool withCustom = TRUE ) const;
     //void copySelectedText( int id );
     void removeSelectedText( int id, KoTextCursor *cursor );
-    void indentSelection( int id );
 
     KoTextParag *paragAt( int i ) const;
 
@@ -181,8 +182,8 @@ public:
 
     void setPlainText( const QString &text );
     //void setRichText( const QString &text, const QString &context );
-    QString richText( KoTextParag *p = 0 ) const;
-    QString plainText( KoTextParag *p = 0 ) const;
+    //QString richText( KoTextParag *p = 0 ) const;
+    QString plainText() const;
 
     //bool focusNextPrevChild( bool next );
 
@@ -200,20 +201,20 @@ public:
     int length() const;
     void clear( bool createEmptyParag = FALSE );
 
+    KoTextParag* loadList( const QDomElement& list, KoOasisContext& context, KoTextParag* lastParagraph, KoStyleCollection * styleColl, KoTextParag* nextParagraph );
+
+    // For normal loading nextParagraph and pos are 0.
+    KoTextParag* loadOasisText( const QDomElement &bodyElem, KoOasisContext& context, KoTextParag* lastParagraph, KoStyleCollection * styleColl, KoTextParag* nextParagraph );
+
+    QString copySelection( KoXmlWriter& writer, KoSavingContext& context, int selectionId );
+
+    void saveOasisContent( KoXmlWriter& writer, KoSavingContext& context ) const;
+
     virtual KoTextParag *createParag( KoTextDocument *d, KoTextParag *pr = 0, KoTextParag *nx = 0, bool updateIds = TRUE );
-    void insertChild( QObject *o ) { QObject::insertChild( o ); }
-    void removeChild( QObject *o ) { QObject::removeChild( o ); }
-    //void insertChild( KoTextDocument *d ) { childList.append( d ); }
-    //void removeChild( KoTextDocument *d ) { childList.removeRef( d ); }
-    //QPtrList<KoTextDocument> children() const { return childList; }
 
     void setAddMargins( bool b ) { addMargs = b; }
     int addMargins() const { return addMargs; }
 
-    //bool hasFocusParagraph() const;
-    //QString focusHref() const;
-
-    //void invalidateOriginalText() { oTextValid = FALSE; }
     void informParagraphDeleted( KoTextParag* parag );
 
 signals:
@@ -335,6 +336,30 @@ protected:
     void drawWithoutDoubleBuffer( QPainter *p, const QRect &rect, const QColorGroup &cg,
                                   KoZoomHandler* zoomHandler, const QBrush *paper = 0 );
 
+    /**
+     * Called by loadOasisText. This allows to extend the loading mechanism
+     * for special tags no handled by kotext (images, textboxes, tables, etc.)
+     * @return true if @p tag was handled.
+     */
+    virtual bool loadOasisBodyTag( const QDomElement& /*tag*/, KoOasisContext& /*context*/,
+                                   KoTextParag* & /*lastParagraph*/, KoStyleCollection* /*styleColl*/,
+                                   KoTextParag* /*nextParagraph*/ ) {
+        return false;
+    }
+
+    /**
+     * Called by KoTextParag::loadOasisSpan. This allows to extend the loading mechanism
+     * for special tags no handled by kotext (bookmarks, image, textbox, link, footnotes etc.)
+     * This method is here instead of in KoTextParag because it's easier to derive from
+     * KoTextDocument.
+     * @return true (and optionally @p textData and @p customItem) if @p tag was handled.
+     */
+    virtual bool loadSpanTag( const QDomElement& /*tag*/, KoOasisContext& /*context*/,
+                              KoTextParag* /*parag*/, uint /*pos*/,
+                              QString& /*textData*/, KoTextCustomItem* & /*customItem*/ ) {
+        return false;
+    }
+
 private:
     // The zoom handler used when formatting
     // (due to the pixelx/pixelww stuff in KoTextFormatter)
@@ -359,7 +384,6 @@ private:
     QMap<int, bool> selectionText;
     KoTextDocCommandHistory *commandHistory;
     KoTextFormatterBase *pFormatter;
-    KoTextIndent *indenter;
     KoTextFormatCollection *fCollection;
     //Qt::TextFormat txtFormat;
     //bool preferRichText : 1;
@@ -369,15 +393,9 @@ private:
     bool underlLinks : 1;
     //bool nextDoubleBuffered : 1;
     bool addMargs : 1;
-    //bool oTextValid : 1;
     int nSelections;
     KoTextFlow *flow_;
     QPtrList<KoTextCustomItem> customItems;
-    //KoTextDocument *par;
-#ifdef QTEXTTABLE_AVAILABLE
-    KoTextTableCell *tc;
-#endif
-    KoTextCursor *tmpCursor;
     QBrush *backBrush;
     QPixmap *buf_pixmap;
     //Focus focusIndicator;
@@ -388,9 +406,6 @@ private:
     int align;
     int *tArray;
     int tStopWidth;
-    int uDepth; // ?
-    //QString oText;
-    //QColor linkColor;
 };
 
 inline int KoTextDocument::x() const
@@ -492,16 +507,6 @@ inline KoTextFormatterBase *KoTextDocument::formatter() const
     return pFormatter;
 }
 
-inline void KoTextDocument::setIndent( KoTextIndent *i )
-{
-    indenter = i;
-}
-
-inline KoTextIndent *KoTextDocument::indent() const
-{
-    return indenter;
-}
-
 inline QColor KoTextDocument::selectionColor( int id ) const
 {
     return selectionColors[ id ];
