@@ -8,6 +8,7 @@
 #include "kotextformatter.h"
 #include "kotextformat.h"
 #include "kotextdocument.h"
+#include "kotextparag.h"
 #include "kozoomhandler.h"
 #include "koparagcounter.h"
 
@@ -60,7 +61,7 @@ KoTextFormatterTest::KoTextFormatterTest()
 {
     zh = new KoZoomHandler;
     QFont defaultFont( "helvetica", 12 );
-    KoTextFormatCollection* fc = new KoTextFormatCollection( defaultFont, Qt::black, "en_US", false /*no hyphenation*/, 1.0 );
+    KoTextFormatCollection* fc = new KoTextFormatCollection( defaultFont, Qt::black, "en_US", false /*no hyphenation*/ );
     KoTextFormatter* formatter = new KoTextFormatter;
     // fc and formatter are owned by the doc
     doc = new KoTextDocument( zh, fc, formatter );
