@@ -18,10 +18,18 @@
 */
 
 #include "koZipStore.h"
+
+#include <qbuffer.h>
+
 #include <kzip.h>
 #include <kdebug.h>
 #include <kdeversion.h>
-#include <qbuffer.h>
+#include <kurl.h>
+#include <kio/netaccess.h>
+#if ! KDE_IS_VERSION( 3, 4, 1 )
+#include <qdir.h>
+#include <qfileinfo.h>
+#endif
 
 KoZipStore::KoZipStore( const QString & _filename, Mode _mode, const QCString & appIdentification )
 {
@@ -30,7 +38,23 @@ KoZipStore::KoZipStore( const QString & _filename, Mode _mode, const QCString &
                     << " mimetype = " << appIdentification << endl;
 
     m_pZip = new KZip( _filename );
-    m_bGood = init( _mode, appIdentification ); // open the zip file and init some vars
+
+#if ! KDE_IS_VERSION( 3, 4, 1 )
+    // Workaround for KZip KSaveFile double deletion in kdelibs-3.4,
+    // when trying to write to a non-writable directory.
+    QDir dir( QFileInfo( _filename ).dir() );
+    if (_mode == Write && !QFileInfo( dir.path() ).isWritable()  )
+    {
+        kdWarning(s_area) << dir.path() << " isn't writable" << endl;
+        m_bGood = false;
+        m_currentDir = 0;
+        KoStore::init( _mode );
+    }
+    else
+#endif
+    {
+        m_bGood = init( _mode, appIdentification ); // open the zip file and init some vars
+    }
 }
 
 KoZipStore::KoZipStore( QIODevice *dev, Mode mode, const QCString & appIdentification )
@@ -39,11 +63,48 @@ KoZipStore::KoZipStore( QIODevice *dev, Mode mode, const QCString & appIdentific
     m_bGood = init( mode, appIdentification );
 }
 
+KoZipStore::KoZipStore( QWidget* window, const KURL & _url, const QString & _filename, Mode _mode, const QCString & appIdentification )
+{
+    kdDebug(s_area) << "KoZipStore Constructor url" << _url.prettyURL()
+                    << " filename = " << _filename
+                    << " mode = " << int(_mode)
+                    << " mimetype = " << appIdentification << endl;
+
+    m_url = _url;
+    m_window = window;
+
+    if ( _mode == KoStore::Read )
+    {
+        m_fileMode = KoStoreBase::RemoteRead;
+        m_localFileName = _filename;
+
+    }
+    else
+    {
+        m_fileMode = KoStoreBase::RemoteWrite;
+        m_localFileName = "/tmp/kozip"; // ### FIXME with KTempFile
+    }
+
+    m_pZip = new KZip( m_localFileName );
+    m_bGood = init( _mode, appIdentification ); // open the zip file and init some vars
+}
+
 KoZipStore::~KoZipStore()
 {
     kdDebug(s_area) << "KoZipStore::~KoZipStore" << endl;
     m_pZip->close();
     delete m_pZip;
+
+    // Now we have still some job to do for remote files.
+    if ( m_fileMode == KoStoreBase::RemoteRead )
+    {
+        KIO::NetAccess::removeTempFile( m_localFileName );
+    }
+    else if ( m_fileMode == KoStoreBase::RemoteWrite )
+    {
+        KIO::NetAccess::upload( m_localFileName, m_url, m_window );
+        // ### FIXME: delete temp file
+    }
 }
 
 bool KoZipStore::init( Mode _mode, const QCString& appIdentification )
@@ -59,9 +120,7 @@ bool KoZipStore::init( Mode _mode, const QCString& appIdentification )
         //kdDebug(s_area) << "KoZipStore::init writing mimetype " << appIdentification << endl;
 
         m_pZip->setCompression( KZip::NoCompression );
-#if KDE_IS_VERSION(3,1,93)
         m_pZip->setExtraField( KZip::NoExtraField );
-#endif
         // Write identification
         (void)m_pZip->writeFile( "mimetype", "", "", appIdentification.length(), appIdentification.data() );
         m_pZip->setCompression( KZip::DeflateCompression );
@@ -171,7 +230,8 @@ bool KoZipStore::enterAbsoluteDirectory( const QString& path )
     return m_currentDir != 0;
 }
 
-bool KoZipStore::fileExists( const QString& absPath )
+bool KoZipStore::fileExists( const QString& absPath ) const
 {
-    return m_pZip->directory()->entry( absPath ) != 0;
+    const KArchiveEntry *entry = m_pZip->directory()->entry( absPath );
+    return entry && entry->isFile();
 }
