@@ -1,5 +1,5 @@
 /*
-   $Id: main.cc,v 1.40.2.1 2004/01/01 15:20:24 goutte Exp $
+   $Id: main.cc 414162 2005-05-15 13:01:41Z mlaurent $
    This file is part of the KDE project
    Copyright (C) 2001,2002,2003 Daniel Naber <daniel.naber@t-online.de>
    This is a thesaurus based on a subset of WordNet. It also offers an
@@ -96,11 +96,11 @@ Thesaurus::Thesaurus(QObject* parent, const char* name, const QStringList &)
     row1->addWidget(m_edit, 1);
     row1->addWidget(m_search, 0);
     m_back = new QToolButton(m_page);
-    m_back->setPixmap(BarIcon(QString::fromLatin1("back")));
+    m_back->setIconSet(BarIconSet(QString::fromLatin1("back")));
     QToolTip::add(m_back, i18n("Back"));
     row1->addWidget(m_back, 0);
     m_forward = new QToolButton(m_page);
-    m_forward->setPixmap(BarIcon(QString::fromLatin1("forward")));
+    m_forward->setIconSet(BarIconSet(QString::fromLatin1("forward")));
     QToolTip::add(m_forward, i18n("Forward"));
     row1->addWidget(m_forward, 0);
     m_lang = new KPushButton(i18n("Change Language..."), m_page);
@@ -218,26 +218,16 @@ Thesaurus::Thesaurus(QObject* parent, const char* name, const QStringList &)
 
 Thesaurus::~Thesaurus()
 {
-#if KDE_IS_VERSION(3,1,3)
     m_config->writePathEntry("datafile", m_data_file);
-#else
-    m_config->writeEntry("datafile", m_data_file);
-#endif
     m_config->sync();
     delete m_config;
     // FIXME?: this hopefully fixes the problem of a wrong cursor
     // and a crash (when closing e.g. konqueror) when the thesaurus dialog 
     // gets close while it was still working and showing the wait cursor
     QApplication::restoreOverrideCursor();
-    if( m_thesproc ) {
-        delete m_thesproc;
-    }
-    if( m_wnproc ) {
-        delete m_wnproc;
-    }
-    if( m_dialog ) {
-        delete m_dialog;
-    }
+    delete m_thesproc;
+    delete m_wnproc;
+    delete m_dialog;
 }
 
 
@@ -276,7 +266,7 @@ bool Thesaurus::run(const QString& command, void* data, const QString& datatype,
     QString buffer = *((QString *)data);
     buffer = buffer.stripWhiteSpace();
     QRegExp re("[.,;!?\"'()\\[\\]]");
-    buffer.replace(re, "");
+    buffer.remove(re);
     buffer = buffer.left(100);        // limit maximum length
 
     m_wnproc_stdout = "";
@@ -301,7 +291,7 @@ void Thesaurus::slotChangeLanguage()
 {
     QString filename = KFileDialog::getOpenFileName(
         KGlobal::dirs()->findResourceDir("data", "thesaurus/")+"thesaurus/");
-    if( filename != QString::null ) {
+    if( !filename.isNull() ) {
         m_data_file = filename;
         setCaption();
     }
@@ -449,7 +439,7 @@ void Thesaurus::thesExited(KProcess *)
     QStringList hyper;
     QStringList hypo;
 
-    QStringList lines = lines.split(QRegExp("\n"), m_thesproc_stdout, false);
+    QStringList lines = lines.split(QChar('\n'), m_thesproc_stdout, false);
     for ( QStringList::Iterator it = lines.begin(); it != lines.end(); ++it ) {
         QString line = (*it);
         if( line.startsWith("  ") ) {  // ignore license (two spaces)
@@ -458,8 +448,8 @@ void Thesaurus::thesExited(KProcess *)
         int sep_pos = line.find("#");
         QString syn_part = line.left(sep_pos);
         QString hyper_part = line.right(line.length()-sep_pos-1);
-        QStringList syn_tmp = QStringList::split(QRegExp(";"), syn_part);
-        QStringList hyper_tmp = QStringList::split(QRegExp(";"), hyper_part);
+        QStringList syn_tmp = QStringList::split(QChar(';'), syn_part);
+        QStringList hyper_tmp = QStringList::split(QChar(';'), hyper_part);
         if( syn_tmp.grep(search_term, false).size() > 0 ) {
             // match on the left side of the '#' -- synonyms
             for ( QStringList::Iterator it2 = syn_tmp.begin(); it2 != syn_tmp.end(); ++it2 ) {
@@ -666,7 +656,7 @@ void Thesaurus::wnExited(KProcess *)
         m_resultbox->setText(i18n("No match for '%1'.").arg(m_edit->currentText()));
     } else {
         // render in a table, each line one row:
-        QStringList lines = lines.split(QRegExp("\n"), m_wnproc_stdout, false);
+        QStringList lines = lines.split(QChar('\n'), m_wnproc_stdout, false);
         QString result = "<qt><table>\n";
         // TODO in Qt > 3.01: try without the following line (it's necessary to ensure the
         // first column is really always quite small):
@@ -681,8 +671,8 @@ void Thesaurus::wnExited(KProcess *)
             }
             // Escape XML:
             l = l.replace('&', "&amp;");
-            l = l.replace(QRegExp("<"), "&lt;");
-            l = l.replace(QRegExp(">"), "&gt;");
+            l = l.replace('<', "&lt;");
+            l = l.replace('>', "&gt;");
             // TODO?: 
             // move "=>" in own column?
             l = formatLine(l);
@@ -761,17 +751,17 @@ QString Thesaurus::formatLine(QString l)
     if( re.search(l) != -1 ) {
         l = re.cap(1);
         l += re.cap(2);
-        QStringList links = links.split(QRegExp(";"), re.cap(3), false);
+        QStringList links = links.split(QChar(';'), re.cap(3), false);
         for ( QStringList::Iterator it = links.begin(); it != links.end(); ++it ) {
             QString link = (*it);
             if( it != links.begin() ) {
                 l += ", ";
             }
             link = link.stripWhiteSpace();
-            link = link.replace(QRegExp("#\\d+"), "");
+            link = link.remove(QRegExp("#\\d+"));
             l += "<a href=\"" +link+ "\">" +link+ "</a>";
         }
-        l = " " + l;        // indent in table
+        l.prepend (' ');        // indent in table
     }
 
     re.setPattern("(.*)(=&gt;|HAS \\w+:|PART OF:)(.*) --");
@@ -781,7 +771,7 @@ QString Thesaurus::formatLine(QString l)
         QString line_end = l.mid(dash_pos+2, l.length()-dash_pos);
         l = re.cap(1);
         l += re.cap(2) + " ";
-        QStringList links = links.split(QRegExp(","), re.cap(3), false);
+        QStringList links = links.split(QChar(','), re.cap(3), false);
         for ( QStringList::Iterator it = links.begin(); it != links.end(); ++it ) {
             QString link = (*it);
             if( it != links.begin() ) {
@@ -791,7 +781,7 @@ QString Thesaurus::formatLine(QString l)
             l += "<a href=\"" +link+ "\">" +link+ "</a>";
         }
         l += "<font color=\"#777777\">" +line_end+ "</font>";
-        l = " " + l;        // indent in table
+        l.prepend(' ');        // indent in table
         return l;
     }
     re.setMinimal(false);    // greedy again
@@ -799,7 +789,9 @@ QString Thesaurus::formatLine(QString l)
     return l;
 }
 
-/** Sort a list case insensitively.
+/** 
+ * Sort a list case insensitively.
+ * Be careful: @p list is modified
  * TODO: use ksortablevaluelist?
  */
 QStringList Thesaurus::sortQStringList(QStringList list)
