@@ -17,7 +17,7 @@
     Boston, MA 02111-1307, USA.
 */
 
-// $Id: kofficecreator.cpp,v 1.5 2003/08/11 21:51:45 mueller Exp $
+// $Id: kofficecreator.cpp 414159 2005-05-15 12:56:52Z mlaurent $
 
 #include <time.h>
 
@@ -35,10 +35,11 @@
 #include "kofficecreator.h"
 #include <koStore.h>
 #include <koDocument.h>
+#include "koffice_export.h"
 
 extern "C"
 {
-    ThumbCreator *new_creator()
+    KOFFICETOOLS_EXPORT ThumbCreator *new_creator()
     {
         return new KOfficeCreator;
     }
